Class: Google::Apis::DfareportingV5::Ad

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a Campaign Manager ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Ad

Returns a new instance of Ad.



810
811
812
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this ad. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


586
587
588
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 586

def 
  @account_id
end

#activeBoolean Also known as: active?

Whether this ad is active. When true, archived must be false. Corresponds to the JSON property active

Returns:

  • (Boolean)


591
592
593
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 591

def active
  @active
end

#advertiser_idFixnum

Advertiser ID of this ad. This is a required field on insertion. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


597
598
599
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 597

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



602
603
604
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 602

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#archivedBoolean Also known as: archived?

Whether this ad is archived. When true, active must be false. Corresponds to the JSON property archived

Returns:

  • (Boolean)


607
608
609
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 607

def archived
  @archived
end

#audience_segment_idFixnum

Audience segment ID that is being targeted for this ad. Applicable when type is AD_SERVING_STANDARD_AD. Corresponds to the JSON property audienceSegmentId

Returns:

  • (Fixnum)


614
615
616
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 614

def audience_segment_id
  @audience_segment_id
end

#campaign_idFixnum

Campaign ID of this ad. This is a required field on insertion. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


619
620
621
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 619

def campaign_id
  @campaign_id
end

#campaign_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property campaignIdDimensionValue



624
625
626
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 624

def campaign_id_dimension_value
  @campaign_id_dimension_value
end

#click_through_urlGoogle::Apis::DfareportingV5::ClickThroughUrl

Click-through URL Corresponds to the JSON property clickThroughUrl



629
630
631
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 629

def click_through_url
  @click_through_url
end

#click_through_url_suffix_propertiesGoogle::Apis::DfareportingV5::ClickThroughUrlSuffixProperties

Click Through URL Suffix settings. Corresponds to the JSON property clickThroughUrlSuffixProperties



634
635
636
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 634

def click_through_url_suffix_properties
  @click_through_url_suffix_properties
end

#commentsString

Comments for this ad. Corresponds to the JSON property comments

Returns:

  • (String)


639
640
641
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 639

def comments
  @comments
end

#compatibilityString

Compatibility of this ad. Applicable when type is AD_SERVING_DEFAULT_AD. DISPLAY and DISPLAY_INTERSTITIAL refer to either rendering on desktop or on mobile devices or in mobile apps for regular or interstitial ads, respectively. APP and APP_INTERSTITIAL are only used for existing default ads. New mobile placements must be assigned DISPLAY or DISPLAY_INTERSTITIAL and default ads created for those placements will be limited to those compatibility types. IN_STREAM_VIDEO refers to rendering in-stream video ads developed with the VAST standard. Corresponds to the JSON property compatibility

Returns:

  • (String)


651
652
653
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 651

def compatibility
  @compatibility
end

#contextual_keyword_targetingGoogle::Apis::DfareportingV5::ContextualKeywordTargeting

Contextual Keyword Targeting. Corresponds to the JSON property contextualKeywordTargeting



656
657
658
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 656

def contextual_keyword_targeting
  @contextual_keyword_targeting
end

#create_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



661
662
663
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 661

def create_info
  @create_info
end

#creative_group_assignmentsArray<Google::Apis::DfareportingV5::CreativeGroupAssignment>

Creative group assignments for this ad. Applicable when type is AD_SERVING_CLICK_TRACKER. Only one assignment per creative group number is allowed for a maximum of two assignments. Corresponds to the JSON property creativeGroupAssignments



668
669
670
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 668

def creative_group_assignments
  @creative_group_assignments
end

#creative_rotationGoogle::Apis::DfareportingV5::CreativeRotation

Creative Rotation. Corresponds to the JSON property creativeRotation



673
674
675
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 673

def creative_rotation
  @creative_rotation
end

#day_part_targetingGoogle::Apis::DfareportingV5::DayPartTargeting

Day Part Targeting. Corresponds to the JSON property dayPartTargeting



678
679
680
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 678

def day_part_targeting
  @day_part_targeting
end

#default_click_through_event_tag_propertiesGoogle::Apis::DfareportingV5::DefaultClickThroughEventTagProperties

Properties of inheriting and overriding the default click-through event tag. A campaign may override the event tag defined at the advertiser level, and an ad may also override the campaign's setting further. Corresponds to the JSON property defaultClickThroughEventTagProperties



685
686
687
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 685

def default_click_through_event_tag_properties
  @default_click_through_event_tag_properties
end

#delivery_scheduleGoogle::Apis::DfareportingV5::DeliverySchedule

Delivery Schedule. Corresponds to the JSON property deliverySchedule



690
691
692
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 690

def delivery_schedule
  @delivery_schedule
end

#dynamic_click_trackerBoolean Also known as: dynamic_click_tracker?

Whether this ad is a dynamic click tracker. Applicable when type is AD_SERVING_CLICK_TRACKER. This is a required field on insert, and is read-only after insert. Corresponds to the JSON property dynamicClickTracker

Returns:

  • (Boolean)


697
698
699
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 697

def dynamic_click_tracker
  @dynamic_click_tracker
end

#end_timeDateTime

Corresponds to the JSON property endTime

Returns:

  • (DateTime)


703
704
705
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 703

def end_time
  @end_time
end

#event_tag_overridesArray<Google::Apis::DfareportingV5::EventTagOverride>

Event tag overrides for this ad. Corresponds to the JSON property eventTagOverrides



708
709
710
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 708

def event_tag_overrides
  @event_tag_overrides
end

#geo_targetingGoogle::Apis::DfareportingV5::GeoTargeting

Geographical Targeting. Corresponds to the JSON property geoTargeting



713
714
715
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 713

def geo_targeting
  @geo_targeting
end

#idFixnum

ID of this ad. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


718
719
720
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 718

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



723
724
725
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 723

def id_dimension_value
  @id_dimension_value
end

#key_value_targeting_expressionGoogle::Apis::DfareportingV5::KeyValueTargetingExpression

Key Value Targeting Expression. Corresponds to the JSON property keyValueTargetingExpression



728
729
730
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 728

def key_value_targeting_expression
  @key_value_targeting_expression
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#ad". Corresponds to the JSON property kind

Returns:

  • (String)


734
735
736
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 734

def kind
  @kind
end

#language_targetingGoogle::Apis::DfareportingV5::LanguageTargeting

Language Targeting. Corresponds to the JSON property languageTargeting



739
740
741
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 739

def language_targeting
  @language_targeting
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



744
745
746
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 744

def last_modified_info
  @last_modified_info
end

#nameString

Name of this ad. This is a required field and must be less than 256 characters long. Corresponds to the JSON property name

Returns:

  • (String)


750
751
752
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 750

def name
  @name
end

#placement_assignmentsArray<Google::Apis::DfareportingV5::PlacementAssignment>

Placement assignments for this ad. Corresponds to the JSON property placementAssignments



755
756
757
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 755

def placement_assignments
  @placement_assignments
end

#remarketing_list_expressionGoogle::Apis::DfareportingV5::ListTargetingExpression

Remarketing List Targeting Expression. Corresponds to the JSON property remarketingListExpression



760
761
762
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 760

def remarketing_list_expression
  @remarketing_list_expression
end

#sizeGoogle::Apis::DfareportingV5::Size

Represents the dimensions of ads, placements, creatives, or creative assets. Corresponds to the JSON property size



765
766
767
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 765

def size
  @size
end

#ssl_compliantBoolean Also known as: ssl_compliant?

Whether this ad is ssl compliant. This is a read-only field that is auto- generated when the ad is inserted or updated. Corresponds to the JSON property sslCompliant

Returns:

  • (Boolean)


771
772
773
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 771

def ssl_compliant
  @ssl_compliant
end

#ssl_requiredBoolean Also known as: ssl_required?

Whether this ad requires ssl. This is a read-only field that is auto-generated when the ad is inserted or updated. Corresponds to the JSON property sslRequired

Returns:

  • (Boolean)


778
779
780
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 778

def ssl_required
  @ssl_required
end

#start_timeDateTime

Corresponds to the JSON property startTime

Returns:

  • (DateTime)


784
785
786
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 784

def start_time
  @start_time
end

#subaccount_idFixnum

Subaccount ID of this ad. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


789
790
791
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 789

def subaccount_id
  @subaccount_id
end

#targeting_template_idFixnum

Targeting template ID, used to apply preconfigured targeting information to this ad. This cannot be set while any of dayPartTargeting, geoTargeting, keyValueTargetingExpression, languageTargeting, remarketingListExpression, or technologyTargeting are set. Applicable when type is AD_SERVING_STANDARD_AD. Corresponds to the JSON property targetingTemplateId

Returns:

  • (Fixnum)


797
798
799
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 797

def targeting_template_id
  @targeting_template_id
end

#technology_targetingGoogle::Apis::DfareportingV5::TechnologyTargeting

Technology Targeting. Corresponds to the JSON property technologyTargeting



802
803
804
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 802

def technology_targeting
  @technology_targeting
end

#typeString

Type of ad. This is a required field on insertion. Note that default ads ( AD_SERVING_DEFAULT_AD) cannot be created directly (see Creative resource). Corresponds to the JSON property type

Returns:

  • (String)


808
809
810
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 808

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 815

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @active = args[:active] if args.key?(:active)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @archived = args[:archived] if args.key?(:archived)
  @audience_segment_id = args[:audience_segment_id] if args.key?(:audience_segment_id)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @campaign_id_dimension_value = args[:campaign_id_dimension_value] if args.key?(:campaign_id_dimension_value)
  @click_through_url = args[:click_through_url] if args.key?(:click_through_url)
  @click_through_url_suffix_properties = args[:click_through_url_suffix_properties] if args.key?(:click_through_url_suffix_properties)
  @comments = args[:comments] if args.key?(:comments)
  @compatibility = args[:compatibility] if args.key?(:compatibility)
  @contextual_keyword_targeting = args[:contextual_keyword_targeting] if args.key?(:contextual_keyword_targeting)
  @create_info = args[:create_info] if args.key?(:create_info)
  @creative_group_assignments = args[:creative_group_assignments] if args.key?(:creative_group_assignments)
  @creative_rotation = args[:creative_rotation] if args.key?(:creative_rotation)
  @day_part_targeting = args[:day_part_targeting] if args.key?(:day_part_targeting)
  @default_click_through_event_tag_properties = args[:default_click_through_event_tag_properties] if args.key?(:default_click_through_event_tag_properties)
  @delivery_schedule = args[:delivery_schedule] if args.key?(:delivery_schedule)
  @dynamic_click_tracker = args[:dynamic_click_tracker] if args.key?(:dynamic_click_tracker)
  @end_time = args[:end_time] if args.key?(:end_time)
  @event_tag_overrides = args[:event_tag_overrides] if args.key?(:event_tag_overrides)
  @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @key_value_targeting_expression = args[:key_value_targeting_expression] if args.key?(:key_value_targeting_expression)
  @kind = args[:kind] if args.key?(:kind)
  @language_targeting = args[:language_targeting] if args.key?(:language_targeting)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @placement_assignments = args[:placement_assignments] if args.key?(:placement_assignments)
  @remarketing_list_expression = args[:remarketing_list_expression] if args.key?(:remarketing_list_expression)
  @size = args[:size] if args.key?(:size)
  @ssl_compliant = args[:ssl_compliant] if args.key?(:ssl_compliant)
  @ssl_required = args[:ssl_required] if args.key?(:ssl_required)
  @start_time = args[:start_time] if args.key?(:start_time)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @targeting_template_id = args[:targeting_template_id] if args.key?(:targeting_template_id)
  @technology_targeting = args[:technology_targeting] if args.key?(:technology_targeting)
  @type = args[:type] if args.key?(:type)
end