Class: Google::Apis::DfareportingV5::AdBlockingConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Campaign ad blocking settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdBlockingConfiguration

Returns a new instance of AdBlockingConfiguration.



872
873
874
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Whether this campaign has enabled ad blocking. When true, ad blocking is enabled for placements in the campaign, but this may be overridden by site and placement settings. When false, ad blocking is disabled for all placements under the campaign, regardless of site and placement settings. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


869
870
871
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 869

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



877
878
879
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 877

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
end