Class: Google::Apis::DfareportingV5::AdvertiserGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Groups advertisers together so that reports can be generated for the entire group at once.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdvertiserGroup

Returns a new instance of AdvertiserGroup.



1077
1078
1079
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this advertiser group. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


1058
1059
1060
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1058

def 
  @account_id
end

#idFixnum

ID of this advertiser group. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


1063
1064
1065
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1063

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#advertiserGroup". Corresponds to the JSON property kind

Returns:

  • (String)


1069
1070
1071
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1069

def kind
  @kind
end

#nameString

Name of this advertiser group. This is a required field and must be less than 256 characters long and unique among advertiser groups of the same account. Corresponds to the JSON property name

Returns:

  • (String)


1075
1076
1077
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1075

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1082
1083
1084
1085
1086
1087
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1082

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
end