Class: Google::Apis::DfareportingV5::AdvertiserInvoicesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::AdvertiserInvoicesListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Invoice List Response
Instance Attribute Summary collapse
-
#invoices ⇒ Array<Google::Apis::DfareportingV5::Invoice>
Invoice collection Corresponds to the JSON property
invoices. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdvertiserInvoicesListResponse
constructor
A new instance of AdvertiserInvoicesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdvertiserInvoicesListResponse
Returns a new instance of AdvertiserInvoicesListResponse.
1142 1143 1144 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#invoices ⇒ Array<Google::Apis::DfareportingV5::Invoice>
Invoice collection
Corresponds to the JSON property invoices
1129 1130 1131 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1129 def invoices @invoices end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#advertiserInvoicesListResponse".
Corresponds to the JSON property kind
1135 1136 1137 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1135 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
1140 1141 1142 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1140 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1147 1148 1149 1150 1151 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1147 def update!(**args) @invoices = args[:invoices] if args.key?(:invoices) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |