Class: Google::Apis::DfareportingV5::AdvertiserLandingPagesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::AdvertiserLandingPagesListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Landing Page List Response
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#landing_pages ⇒ Array<Google::Apis::DfareportingV5::LandingPage>
Landing page collection Corresponds to the JSON property
landingPages. -
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdvertiserLandingPagesListResponse
constructor
A new instance of AdvertiserLandingPagesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdvertiserLandingPagesListResponse
Returns a new instance of AdvertiserLandingPagesListResponse.
1174 1175 1176 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#advertiserLandingPagesListResponse".
Corresponds to the JSON property kind
1162 1163 1164 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1162 def kind @kind end |
#landing_pages ⇒ Array<Google::Apis::DfareportingV5::LandingPage>
Landing page collection
Corresponds to the JSON property landingPages
1167 1168 1169 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1167 def landing_pages @landing_pages end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
1172 1173 1174 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1172 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1179 1180 1181 1182 1183 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1179 def update!(**args) @kind = args[:kind] if args.key?(:kind) @landing_pages = args[:landing_pages] if args.key?(:landing_pages) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |