Class: Google::Apis::DfareportingV5::BillingAssignment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

List account, subaccount, advertiser, and campaign associated with a given Billing Profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BillingAssignment

Returns a new instance of BillingAssignment.



1321
1322
1323
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

ID of the account associated with the billing assignment.This is a read-only, auto-generated field. Corresponds to the JSON property accountId

Returns:

  • (String)


1294
1295
1296
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1294

def 
  @account_id
end

#advertiser_idString

ID of the advertiser associated with the billing assignment.Wildcard (*) means this assignment is not limited to a single advertiser Corresponds to the JSON property advertiserId

Returns:

  • (String)


1300
1301
1302
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1300

def advertiser_id
  @advertiser_id
end

#campaign_idString

ID of the campaign associated with the billing assignment. Wildcard (*) means this assignment is not limited to a single campaign Corresponds to the JSON property campaignId

Returns:

  • (String)


1306
1307
1308
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1306

def campaign_id
  @campaign_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#billingAssignment". Corresponds to the JSON property kind

Returns:

  • (String)


1312
1313
1314
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1312

def kind
  @kind
end

#subaccount_idString

ID of the subaccount associated with the billing assignment.Wildcard (*) means this assignment is not limited to a single subaccountThis is a read-only, auto- generated field. Corresponds to the JSON property subaccountId

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1319

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1326
1327
1328
1329
1330
1331
1332
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1326

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @kind = args[:kind] if args.key?(:kind)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end