Class: Google::Apis::DfareportingV5::BillingProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::BillingProfilesListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Billing profile List Response
Instance Attribute Summary collapse
-
#billing_profiles ⇒ Array<Google::Apis::DfareportingV5::BillingProfile>
Billing profiles collection.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BillingProfilesListResponse
constructor
A new instance of BillingProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BillingProfilesListResponse
Returns a new instance of BillingProfilesListResponse.
1484 1485 1486 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_profiles ⇒ Array<Google::Apis::DfareportingV5::BillingProfile>
Billing profiles collection.
Corresponds to the JSON property billingProfiles
1471 1472 1473 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1471 def billing_profiles @billing_profiles end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#billingProfilesListResponse".
Corresponds to the JSON property kind
1477 1478 1479 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1477 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
1482 1483 1484 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1482 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1489 1490 1491 1492 1493 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1489 def update!(**args) @billing_profiles = args[:billing_profiles] if args.key?(:billing_profiles) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |