Class: Google::Apis::DfareportingV5::BillingRatesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::BillingRatesListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Billing Rate List Response
Instance Attribute Summary collapse
-
#billing_rates ⇒ Array<Google::Apis::DfareportingV5::BillingRate>
Billing rates collection.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BillingRatesListResponse
constructor
A new instance of BillingRatesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BillingRatesListResponse
Returns a new instance of BillingRatesListResponse.
1615 1616 1617 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1615 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_rates ⇒ Array<Google::Apis::DfareportingV5::BillingRate>
Billing rates collection.
Corresponds to the JSON property billingRates
1602 1603 1604 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1602 def billing_rates @billing_rates end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#billingRatesListResponse".
Corresponds to the JSON property kind
1608 1609 1610 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1608 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
1613 1614 1615 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1613 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1620 1621 1622 1623 1624 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1620 def update!(**args) @billing_rates = args[:billing_rates] if args.key?(:billing_rates) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |