Class: Google::Apis::DfareportingV5::Campaign

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a Campaign Manager campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Campaign

Returns a new instance of Campaign.



1871
1872
1873
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this campaign. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


1724
1725
1726
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1724

def 
  @account_id
end

#ad_blocking_configurationGoogle::Apis::DfareportingV5::AdBlockingConfiguration

Campaign ad blocking settings. Corresponds to the JSON property adBlockingConfiguration



1729
1730
1731
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1729

def ad_blocking_configuration
  @ad_blocking_configuration
end

#additional_creative_optimization_configurationsArray<Google::Apis::DfareportingV5::CreativeOptimizationConfiguration>

Additional creative optimization configurations for the campaign. Corresponds to the JSON property additionalCreativeOptimizationConfigurations



1734
1735
1736
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1734

def additional_creative_optimization_configurations
  @additional_creative_optimization_configurations
end

#advertiser_group_idFixnum

Advertiser group ID of the associated advertiser. Corresponds to the JSON property advertiserGroupId

Returns:

  • (Fixnum)


1739
1740
1741
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1739

def advertiser_group_id
  @advertiser_group_id
end

#advertiser_idFixnum

Advertiser ID of this campaign. This is a required field. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


1744
1745
1746
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1744

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



1749
1750
1751
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1749

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#archivedBoolean Also known as: archived?

Whether this campaign has been archived. Corresponds to the JSON property archived

Returns:

  • (Boolean)


1754
1755
1756
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1754

def archived
  @archived
end

#audience_segment_groupsArray<Google::Apis::DfareportingV5::AudienceSegmentGroup>

Audience segment groups assigned to this campaign. Cannot have more than 300 segment groups. Corresponds to the JSON property audienceSegmentGroups



1761
1762
1763
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1761

def audience_segment_groups
  @audience_segment_groups
end

#billing_invoice_codeString

Billing invoice code included in the Campaign Manager client billing invoices associated with the campaign. Corresponds to the JSON property billingInvoiceCode

Returns:

  • (String)


1767
1768
1769
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1767

def billing_invoice_code
  @billing_invoice_code
end

#click_through_url_suffix_propertiesGoogle::Apis::DfareportingV5::ClickThroughUrlSuffixProperties

Click Through URL Suffix settings. Corresponds to the JSON property clickThroughUrlSuffixProperties



1772
1773
1774
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1772

def click_through_url_suffix_properties
  @click_through_url_suffix_properties
end

#commentString

Arbitrary comments about this campaign. Must be less than 256 characters long. Corresponds to the JSON property comment

Returns:

  • (String)


1777
1778
1779
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1777

def comment
  @comment
end

#create_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



1782
1783
1784
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1782

def create_info
  @create_info
end

#creative_group_idsArray<Fixnum>

List of creative group IDs that are assigned to the campaign. Corresponds to the JSON property creativeGroupIds

Returns:

  • (Array<Fixnum>)


1787
1788
1789
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1787

def creative_group_ids
  @creative_group_ids
end

#creative_optimization_configurationGoogle::Apis::DfareportingV5::CreativeOptimizationConfiguration

Creative optimization settings. Corresponds to the JSON property creativeOptimizationConfiguration



1792
1793
1794
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1792

def creative_optimization_configuration
  @creative_optimization_configuration
end

#default_click_through_event_tag_propertiesGoogle::Apis::DfareportingV5::DefaultClickThroughEventTagProperties

Properties of inheriting and overriding the default click-through event tag. A campaign may override the event tag defined at the advertiser level, and an ad may also override the campaign's setting further. Corresponds to the JSON property defaultClickThroughEventTagProperties



1799
1800
1801
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1799

def default_click_through_event_tag_properties
  @default_click_through_event_tag_properties
end

#default_landing_page_idFixnum

The default landing page ID for this campaign. Corresponds to the JSON property defaultLandingPageId

Returns:

  • (Fixnum)


1804
1805
1806
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1804

def default_landing_page_id
  @default_landing_page_id
end

#end_dateDate

Corresponds to the JSON property endDate

Returns:

  • (Date)


1809
1810
1811
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1809

def end_date
  @end_date
end

#eu_political_ads_declarationString

Optional. Whether the campaign has EU political ads. Campaign Manager 360 doesn't allow campaigns with EU political ads to serve in the EU. They can still serve in other regions. Corresponds to the JSON property euPoliticalAdsDeclaration

Returns:

  • (String)


1816
1817
1818
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1816

def eu_political_ads_declaration
  @eu_political_ads_declaration
end

#event_tag_overridesArray<Google::Apis::DfareportingV5::EventTagOverride>

Overrides that can be used to activate or deactivate advertiser event tags. Corresponds to the JSON property eventTagOverrides



1821
1822
1823
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1821

def event_tag_overrides
  @event_tag_overrides
end

#external_idString

External ID for this campaign. Corresponds to the JSON property externalId

Returns:

  • (String)


1826
1827
1828
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1826

def external_id
  @external_id
end

#idFixnum

ID of this campaign. This is a read-only auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


1831
1832
1833
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1831

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



1836
1837
1838
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1836

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#campaign". Corresponds to the JSON property kind

Returns:

  • (String)


1842
1843
1844
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1842

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



1847
1848
1849
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1847

def last_modified_info
  @last_modified_info
end

Measurement partner campaign link for tag wrapping. Corresponds to the JSON property measurementPartnerLink



1852
1853
1854
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1852

def measurement_partner_link
  @measurement_partner_link
end

#nameString

Name of this campaign. This is a required field and must be less than 512 characters long and unique among campaigns of the same advertiser. Corresponds to the JSON property name

Returns:

  • (String)


1858
1859
1860
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1858

def name
  @name
end

#start_dateDate

Corresponds to the JSON property startDate

Returns:

  • (Date)


1863
1864
1865
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1863

def start_date
  @start_date
end

#subaccount_idFixnum

Subaccount ID of this campaign. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


1869
1870
1871
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1869

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1876

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @ad_blocking_configuration = args[:ad_blocking_configuration] if args.key?(:ad_blocking_configuration)
  @additional_creative_optimization_configurations = args[:additional_creative_optimization_configurations] if args.key?(:additional_creative_optimization_configurations)
  @advertiser_group_id = args[:advertiser_group_id] if args.key?(:advertiser_group_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @archived = args[:archived] if args.key?(:archived)
  @audience_segment_groups = args[:audience_segment_groups] if args.key?(:audience_segment_groups)
  @billing_invoice_code = args[:billing_invoice_code] if args.key?(:billing_invoice_code)
  @click_through_url_suffix_properties = args[:click_through_url_suffix_properties] if args.key?(:click_through_url_suffix_properties)
  @comment = args[:comment] if args.key?(:comment)
  @create_info = args[:create_info] if args.key?(:create_info)
  @creative_group_ids = args[:creative_group_ids] if args.key?(:creative_group_ids)
  @creative_optimization_configuration = args[:creative_optimization_configuration] if args.key?(:creative_optimization_configuration)
  @default_click_through_event_tag_properties = args[:default_click_through_event_tag_properties] if args.key?(:default_click_through_event_tag_properties)
  @default_landing_page_id = args[:default_landing_page_id] if args.key?(:default_landing_page_id)
  @end_date = args[:end_date] if args.key?(:end_date)
  @eu_political_ads_declaration = args[:eu_political_ads_declaration] if args.key?(:eu_political_ads_declaration)
  @event_tag_overrides = args[:event_tag_overrides] if args.key?(:event_tag_overrides)
  @external_id = args[:external_id] if args.key?(:external_id)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @measurement_partner_link = args[:measurement_partner_link] if args.key?(:measurement_partner_link)
  @name = args[:name] if args.key?(:name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end