Class: Google::Apis::DfareportingV5::CampaignCreativeAssociationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::CampaignCreativeAssociationsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Campaign Creative Association List Response
Instance Attribute Summary collapse
-
#campaign_creative_associations ⇒ Array<Google::Apis::DfareportingV5::CampaignCreativeAssociation>
Campaign creative association collection Corresponds to the JSON property
campaignCreativeAssociations. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CampaignCreativeAssociationsListResponse
constructor
A new instance of CampaignCreativeAssociationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CampaignCreativeAssociationsListResponse
Returns a new instance of CampaignCreativeAssociationsListResponse.
1954 1955 1956 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign_creative_associations ⇒ Array<Google::Apis::DfareportingV5::CampaignCreativeAssociation>
Campaign creative association collection
Corresponds to the JSON property campaignCreativeAssociations
1941 1942 1943 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1941 def campaign_creative_associations @campaign_creative_associations end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#campaignCreativeAssociationsListResponse".
Corresponds to the JSON property kind
1947 1948 1949 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1947 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
1952 1953 1954 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1952 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1959 1960 1961 1962 1963 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1959 def update!(**args) @campaign_creative_associations = args[:campaign_creative_associations] if args.key?(:campaign_creative_associations) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |