Class: Google::Apis::DfareportingV5::ChangeLog

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Describes a change that a user has made to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChangeLog

Returns a new instance of ChangeLog.



2200
2201
2202
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of the modified object. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


2129
2130
2131
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2129

def 
  @account_id
end

#actionString

Action which caused the change. Corresponds to the JSON property action

Returns:

  • (String)


2134
2135
2136
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2134

def action
  @action
end

#change_timeDateTime

Corresponds to the JSON property changeTime

Returns:

  • (DateTime)


2139
2140
2141
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2139

def change_time
  @change_time
end

#field_nameString

Field name of the object which changed. Corresponds to the JSON property fieldName

Returns:

  • (String)


2144
2145
2146
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2144

def field_name
  @field_name
end

#idFixnum

ID of this change log. Corresponds to the JSON property id

Returns:

  • (Fixnum)


2149
2150
2151
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2149

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#changeLog". Corresponds to the JSON property kind

Returns:

  • (String)


2155
2156
2157
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2155

def kind
  @kind
end

#new_valueString

New value of the object field. Corresponds to the JSON property newValue

Returns:

  • (String)


2160
2161
2162
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2160

def new_value
  @new_value
end

#object_id_propFixnum

ID of the object of this change log. The object could be a campaign, placement, ad, or other type. Corresponds to the JSON property objectId

Returns:

  • (Fixnum)


2166
2167
2168
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2166

def object_id_prop
  @object_id_prop
end

#object_typeString

Object type of the change log. Corresponds to the JSON property objectType

Returns:

  • (String)


2171
2172
2173
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2171

def object_type
  @object_type
end

#old_valueString

Old value of the object field. Corresponds to the JSON property oldValue

Returns:

  • (String)


2176
2177
2178
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2176

def old_value
  @old_value
end

#subaccount_idFixnum

Subaccount ID of the modified object. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


2181
2182
2183
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2181

def subaccount_id
  @subaccount_id
end

#transaction_idFixnum

Transaction ID of this change log. When a single API call results in many changes, each change will have a separate ID in the change log but will share the same transactionId. Corresponds to the JSON property transactionId

Returns:

  • (Fixnum)


2188
2189
2190
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2188

def transaction_id
  @transaction_id
end

#user_profile_idFixnum

ID of the user who modified the object. Corresponds to the JSON property userProfileId

Returns:

  • (Fixnum)


2193
2194
2195
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2193

def 
  @user_profile_id
end

#user_profile_nameString

User profile name of the user who modified the object. Corresponds to the JSON property userProfileName

Returns:

  • (String)


2198
2199
2200
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2198

def 
  @user_profile_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2205

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @action = args[:action] if args.key?(:action)
  @change_time = args[:change_time] if args.key?(:change_time)
  @field_name = args[:field_name] if args.key?(:field_name)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @new_value = args[:new_value] if args.key?(:new_value)
  @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
  @object_type = args[:object_type] if args.key?(:object_type)
  @old_value = args[:old_value] if args.key?(:old_value)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @transaction_id = args[:transaction_id] if args.key?(:transaction_id)
  @user_profile_id = args[:user_profile_id] if args.key?(:user_profile_id)
  @user_profile_name = args[:user_profile_name] if args.key?(:user_profile_name)
end