Class: Google::Apis::DfareportingV5::City
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::City
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains information about a city that can be targeted by ads.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Country code of the country to which this city belongs.
-
#country_dart_id ⇒ Fixnum
DART ID of the country to which this city belongs.
-
#dart_id ⇒ Fixnum
DART ID of this city.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#metro_code ⇒ String
Metro region code of the metro region (DMA) to which this city belongs.
-
#metro_dma_id ⇒ Fixnum
ID of the metro region (DMA) to which this city belongs.
-
#name ⇒ String
Name of this city.
-
#region_code ⇒ String
Region code of the region to which this city belongs.
-
#region_dart_id ⇒ Fixnum
DART ID of the region to which this city belongs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ City
constructor
A new instance of City.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ City
Returns a new instance of City.
2331 2332 2333 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Country code of the country to which this city belongs.
Corresponds to the JSON property countryCode
2288 2289 2290 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2288 def country_code @country_code end |
#country_dart_id ⇒ Fixnum
DART ID of the country to which this city belongs.
Corresponds to the JSON property countryDartId
2293 2294 2295 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2293 def country_dart_id @country_dart_id end |
#dart_id ⇒ Fixnum
DART ID of this city. This is the ID used for targeting and generating reports.
Corresponds to the JSON property dartId
2298 2299 2300 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2298 def dart_id @dart_id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#city".
Corresponds to the JSON property kind
2304 2305 2306 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2304 def kind @kind end |
#metro_code ⇒ String
Metro region code of the metro region (DMA) to which this city belongs.
Corresponds to the JSON property metroCode
2309 2310 2311 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2309 def metro_code @metro_code end |
#metro_dma_id ⇒ Fixnum
ID of the metro region (DMA) to which this city belongs.
Corresponds to the JSON property metroDmaId
2314 2315 2316 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2314 def metro_dma_id @metro_dma_id end |
#name ⇒ String
Name of this city.
Corresponds to the JSON property name
2319 2320 2321 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2319 def name @name end |
#region_code ⇒ String
Region code of the region to which this city belongs.
Corresponds to the JSON property regionCode
2324 2325 2326 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2324 def region_code @region_code end |
#region_dart_id ⇒ Fixnum
DART ID of the region to which this city belongs.
Corresponds to the JSON property regionDartId
2329 2330 2331 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2329 def region_dart_id @region_dart_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 2346 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2336 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @country_dart_id = args[:country_dart_id] if args.key?(:country_dart_id) @dart_id = args[:dart_id] if args.key?(:dart_id) @kind = args[:kind] if args.key?(:kind) @metro_code = args[:metro_code] if args.key?(:metro_code) @metro_dma_id = args[:metro_dma_id] if args.key?(:metro_dma_id) @name = args[:name] if args.key?(:name) @region_code = args[:region_code] if args.key?(:region_code) @region_dart_id = args[:region_dart_id] if args.key?(:region_dart_id) end |