Class: Google::Apis::DfareportingV5::ContentSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains the content source of the dynamic feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentSource

Returns a new instance of ContentSource.



2750
2751
2752
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2750

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_source_nameString

Optional. The name of the content source. It is defaulted to content source file name if not provided. Corresponds to the JSON property contentSourceName

Returns:

  • (String)


2723
2724
2725
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2723

def content_source_name
  @content_source_name
end

#create_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



2728
2729
2730
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2728

def create_info
  @create_info
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



2733
2734
2735
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2733

def last_modified_info
  @last_modified_info
end

#meta_dataGoogle::Apis::DfareportingV5::ContentSourceMetaData

Contains the meta data of the content source. This is a read-only field. Corresponds to the JSON property metaData



2738
2739
2740
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2738

def 
  @meta_data
end

Required. The link to the file of the content source. Corresponds to the JSON property resourceLink

Returns:

  • (String)


2743
2744
2745
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2743

def resource_link
  @resource_link
end

#resource_typeString

Required. The resource type of the content source. Corresponds to the JSON property resourceType

Returns:

  • (String)


2748
2749
2750
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2748

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2755
2756
2757
2758
2759
2760
2761
2762
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2755

def update!(**args)
  @content_source_name = args[:content_source_name] if args.key?(:content_source_name)
  @create_info = args[:create_info] if args.key?(:create_info)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @meta_data = args[:meta_data] if args.key?(:meta_data)
  @resource_link = args[:resource_link] if args.key?(:resource_link)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end