Class: Google::Apis::DfareportingV5::ConversionStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

The original conversion that was inserted or updated and whether there were any errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversionStatus

Returns a new instance of ConversionStatus.



3092
3093
3094
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversionGoogle::Apis::DfareportingV5::Conversion

A Conversion represents when a user successfully performs a desired action after seeing an ad. Corresponds to the JSON property conversion



3079
3080
3081
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3079

def conversion
  @conversion
end

#errorsArray<Google::Apis::DfareportingV5::ConversionError>

A list of errors related to this conversion. Corresponds to the JSON property errors



3084
3085
3086
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3084

def errors
  @errors
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#conversionStatus". Corresponds to the JSON property kind

Returns:

  • (String)


3090
3091
3092
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3090

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3097
3098
3099
3100
3101
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3097

def update!(**args)
  @conversion = args[:conversion] if args.key?(:conversion)
  @errors = args[:errors] if args.key?(:errors)
  @kind = args[:kind] if args.key?(:kind)
end