Class: Google::Apis::DfareportingV5::ConversionsBatchInsertResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Insert Conversions Response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversionsBatchInsertResponse

Returns a new instance of ConversionsBatchInsertResponse.



3183
3184
3185
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#has_failuresBoolean Also known as: has_failures?

Indicates that some or all conversions failed to insert. Corresponds to the JSON property hasFailures

Returns:

  • (Boolean)


3168
3169
3170
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3168

def has_failures
  @has_failures
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#conversionsBatchInsertResponse". Corresponds to the JSON property kind

Returns:

  • (String)


3175
3176
3177
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3175

def kind
  @kind
end

#statusArray<Google::Apis::DfareportingV5::ConversionStatus>

The insert status of each conversion. Statuses are returned in the same order that conversions are inserted. Corresponds to the JSON property status



3181
3182
3183
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3181

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3188
3189
3190
3191
3192
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3188

def update!(**args)
  @has_failures = args[:has_failures] if args.key?(:has_failures)
  @kind = args[:kind] if args.key?(:kind)
  @status = args[:status] if args.key?(:status)
end