Class: Google::Apis::DfareportingV5::ConversionsBatchUpdateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Update Conversions Response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversionsBatchUpdateResponse

Returns a new instance of ConversionsBatchUpdateResponse.



3249
3250
3251
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#has_failuresBoolean Also known as: has_failures?

Indicates that some or all conversions failed to update. Corresponds to the JSON property hasFailures

Returns:

  • (Boolean)


3234
3235
3236
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3234

def has_failures
  @has_failures
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#conversionsBatchUpdateResponse". Corresponds to the JSON property kind

Returns:

  • (String)


3241
3242
3243
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3241

def kind
  @kind
end

#statusArray<Google::Apis::DfareportingV5::ConversionStatus>

The update status of each conversion. Statuses are returned in the same order that conversions are updated. Corresponds to the JSON property status



3247
3248
3249
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3247

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3254
3255
3256
3257
3258
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3254

def update!(**args)
  @has_failures = args[:has_failures] if args.key?(:has_failures)
  @kind = args[:kind] if args.key?(:kind)
  @status = args[:status] if args.key?(:status)
end