Class: Google::Apis::DfareportingV5::Country

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains information about a country that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Country

Returns a new instance of Country.



3324
3325
3326
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Country code. Corresponds to the JSON property countryCode

Returns:

  • (String)


3294
3295
3296
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3294

def country_code
  @country_code
end

#dart_idFixnum

DART ID of this country. This is the ID used for targeting and generating reports. Corresponds to the JSON property dartId

Returns:

  • (Fixnum)


3300
3301
3302
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3300

def dart_id
  @dart_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#country". Corresponds to the JSON property kind

Returns:

  • (String)


3306
3307
3308
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3306

def kind
  @kind
end

#nameString

Name of this country. Corresponds to the JSON property name

Returns:

  • (String)


3311
3312
3313
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3311

def name
  @name
end

#ssl_enabledBoolean Also known as: ssl_enabled?

Whether ad serving supports secure servers in this country. Corresponds to the JSON property sslEnabled

Returns:

  • (Boolean)


3316
3317
3318
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3316

def ssl_enabled
  @ssl_enabled
end

#tv_data_providersArray<String>

Output only. The TV data providers supported in this country. Corresponds to the JSON property tvDataProviders

Returns:

  • (Array<String>)


3322
3323
3324
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3322

def tv_data_providers
  @tv_data_providers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3329
3330
3331
3332
3333
3334
3335
3336
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3329

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @dart_id = args[:dart_id] if args.key?(:dart_id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ssl_enabled = args[:ssl_enabled] if args.key?(:ssl_enabled)
  @tv_data_providers = args[:tv_data_providers] if args.key?(:tv_data_providers)
end