Class: Google::Apis::DfareportingV5::Creative

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a Creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Creative

Returns a new instance of Creative.



3797
3798
3799
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this creative. This field, if left unset, will be auto-generated for both insert and update operations. Applicable to all creative types. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


3347
3348
3349
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3347

def 
  @account_id
end

#activeBoolean Also known as: active?

Whether the creative is active. Applicable to all creative types. Corresponds to the JSON property active

Returns:

  • (Boolean)


3352
3353
3354
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3352

def active
  @active
end

#ad_parametersString

Ad parameters user for VPAID creative. This is a read-only field. Applicable to the following creative types: all VPAID. Corresponds to the JSON property adParameters

Returns:

  • (String)


3359
3360
3361
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3359

def ad_parameters
  @ad_parameters
end

#ad_tag_keysArray<String>

Keywords for a Rich Media creative. Keywords let you customize the creative settings of a Rich Media ad running on your site without having to contact the advertiser. You can use keywords to dynamically change the look or functionality of a creative. Applicable to the following creative types: all RICH_MEDIA, and all VPAID. Corresponds to the JSON property adTagKeys

Returns:

  • (Array<String>)


3368
3369
3370
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3368

def ad_tag_keys
  @ad_tag_keys
end

#additional_sizesArray<Google::Apis::DfareportingV5::Size>

Additional sizes associated with a responsive creative. When inserting or updating a creative either the size ID field or size width and height fields can be used. Applicable to DISPLAY creatives when the primary asset type is HTML_IMAGE. Corresponds to the JSON property additionalSizes



3376
3377
3378
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3376

def additional_sizes
  @additional_sizes
end

#advertiser_idFixnum

Required. Advertiser ID of this creative. This is a required field. Applicable to all creative types. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


3382
3383
3384
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3382

def advertiser_id
  @advertiser_id
end

#allow_script_accessBoolean Also known as: allow_script_access?

Whether script access is allowed for this creative. This is a read-only and deprecated field which will automatically be set to true on update. Applicable to the following creative types: FLASH_INPAGE. Corresponds to the JSON property allowScriptAccess

Returns:

  • (Boolean)


3389
3390
3391
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3389

def allow_script_access
  @allow_script_access
end

#archivedBoolean Also known as: archived?

Whether the creative is archived. Applicable to all creative types. Corresponds to the JSON property archived

Returns:

  • (Boolean)


3395
3396
3397
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3395

def archived
  @archived
end

#artwork_typeString

Type of artwork used for the creative. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA, and all VPAID. Corresponds to the JSON property artworkType

Returns:

  • (String)


3402
3403
3404
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3402

def artwork_type
  @artwork_type
end

#authoring_sourceString

Source application where creative was authored. Presently, only DBM authored creatives will have this field set. Applicable to all creative types. Corresponds to the JSON property authoringSource

Returns:

  • (String)


3408
3409
3410
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3408

def authoring_source
  @authoring_source
end

#authoring_toolString

Authoring tool for HTML5 banner creatives. This is a read-only field. Applicable to the following creative types: HTML5_BANNER. Corresponds to the JSON property authoringTool

Returns:

  • (String)


3414
3415
3416
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3414

def authoring_tool
  @authoring_tool
end

#auto_advance_imagesBoolean Also known as: auto_advance_images?

Whether images are automatically advanced for image gallery creatives. Applicable to the following creative types: DISPLAY_IMAGE_GALLERY. Corresponds to the JSON property autoAdvanceImages

Returns:

  • (Boolean)


3420
3421
3422
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3420

def auto_advance_images
  @auto_advance_images
end

#background_colorString

The 6-character HTML color code, beginning with #, for the background of the window area where the Flash file is displayed. Default is white. Applicable to the following creative types: FLASH_INPAGE. Corresponds to the JSON property backgroundColor

Returns:

  • (String)


3428
3429
3430
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3428

def background_color
  @background_color
end

#backup_image_click_through_urlGoogle::Apis::DfareportingV5::CreativeClickThroughUrl

Click-through URL Corresponds to the JSON property backupImageClickThroughUrl



3433
3434
3435
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3433

def backup_image_click_through_url
  @backup_image_click_through_url
end

#backup_image_featuresArray<String>

List of feature dependencies that will cause a backup image to be served if the browser that serves the ad does not support them. Feature dependencies are features that a browser must be able to support in order to render your HTML5 creative asset correctly. This field is initially auto-generated to contain all features detected by Campaign Manager for all the assets of this creative and can then be modified by the client. To reset this field, copy over all the creativeAssets' detected features. Applicable to the following creative types: HTML5_BANNER. Applicable to DISPLAY when the primary asset type is not HTML_IMAGE. Corresponds to the JSON property backupImageFeatures

Returns:

  • (Array<String>)


3446
3447
3448
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3446

def backup_image_features
  @backup_image_features
end

#backup_image_reporting_labelString

Reporting label used for HTML5 banner backup image. Applicable to the following creative types: DISPLAY when the primary asset type is not HTML_IMAGE. Corresponds to the JSON property backupImageReportingLabel

Returns:

  • (String)


3453
3454
3455
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3453

def backup_image_reporting_label
  @backup_image_reporting_label
end

#backup_image_target_windowGoogle::Apis::DfareportingV5::TargetWindow

Target Window. Corresponds to the JSON property backupImageTargetWindow



3458
3459
3460
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3458

def backup_image_target_window
  @backup_image_target_window
end

#click_tagsArray<Google::Apis::DfareportingV5::ClickTag>

Click tags of the creative. For DISPLAY, FLASH_INPAGE, and HTML5_BANNER creatives, this is a subset of detected click tags for the assets associated with this creative. After creating a flash asset, detected click tags will be returned in the creativeAssetMetadata. When inserting the creative, populate the creative clickTags field using the creativeAssetMetadata.clickTags field. For DISPLAY_IMAGE_GALLERY creatives, there should be exactly one entry in this list for each image creative asset. A click tag is matched with a corresponding creative asset by matching the clickTag.name field with the creativeAsset.assetIdentifier.name field. Applicable to the following creative types: DISPLAY_IMAGE_GALLERY, FLASH_INPAGE, HTML5_BANNER. Applicable to DISPLAY when the primary asset type is not HTML_IMAGE. Corresponds to the JSON property clickTags



3473
3474
3475
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3473

def click_tags
  @click_tags
end

#commercial_idString

Industry standard ID assigned to creative for reach and frequency. Applicable to INSTREAM_VIDEO_REDIRECT creatives. Corresponds to the JSON property commercialId

Returns:

  • (String)


3479
3480
3481
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3479

def commercial_id
  @commercial_id
end

#companion_creativesArray<Fixnum>

List of companion creatives assigned to an in-Stream video creative. Acceptable values include IDs of existing flash and image creatives. Applicable to the following creative types: all VPAID, all INSTREAM_AUDIO and all INSTREAM_VIDEO with dynamicAssetSelection set to false. Corresponds to the JSON property companionCreatives

Returns:

  • (Array<Fixnum>)


3487
3488
3489
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3487

def companion_creatives
  @companion_creatives
end

#compatibilityArray<String>

Compatibilities associated with this creative. This is a read-only field. DISPLAY and DISPLAY_INTERSTITIAL refer to rendering either on desktop or on mobile devices or in mobile apps for regular or interstitial ads, respectively. APP and APP_INTERSTITIAL are for rendering in mobile apps. Only pre-existing creatives may have these compatibilities since new creatives will either be assigned DISPLAY or DISPLAY_INTERSTITIAL instead. IN_STREAM_VIDEO refers to rendering in in-stream video ads developed with the VAST standard. IN_STREAM_AUDIO refers to rendering in in-stream audio ads developed with the VAST standard. Applicable to all creative types. Acceptable values are: - "APP"

  • "APP_INTERSTITIAL" - "IN_STREAM_VIDEO" - "IN_STREAM_AUDIO" - "DISPLAY" - " DISPLAY_INTERSTITIAL" Corresponds to the JSON property compatibility

Returns:

  • (Array<String>)


3502
3503
3504
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3502

def compatibility
  @compatibility
end

#convert_flash_to_html5Boolean Also known as: convert_flash_to_html5?

Whether Flash assets associated with the creative need to be automatically converted to HTML5. This flag is enabled by default and users can choose to disable it if they don't want the system to generate and use HTML5 asset for this creative. Applicable to the following creative type: FLASH_INPAGE. Applicable to DISPLAY when the primary asset type is not HTML_IMAGE. Corresponds to the JSON property convertFlashToHtml5

Returns:

  • (Boolean)


3511
3512
3513
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3511

def convert_flash_to_html5
  @convert_flash_to_html5
end

#counter_custom_eventsArray<Google::Apis::DfareportingV5::CreativeCustomEvent>

List of counter events configured for the creative. For DISPLAY_IMAGE_GALLERY creatives, these are read-only and auto-generated from clickTags. Applicable to the following creative types: DISPLAY_IMAGE_GALLERY, all RICH_MEDIA, and all VPAID. Corresponds to the JSON property counterCustomEvents



3520
3521
3522
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3520

def counter_custom_events
  @counter_custom_events
end

#creative_assetsArray<Google::Apis::DfareportingV5::CreativeAsset>

Assets associated with a creative. Applicable to all but the following creative types: INTERNAL_REDIRECT, INTERSTITIAL_INTERNAL_REDIRECT, and REDIRECT Corresponds to the JSON property creativeAssets



3527
3528
3529
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3527

def creative_assets
  @creative_assets
end

#creative_field_assignmentsArray<Google::Apis::DfareportingV5::CreativeFieldAssignment>

Creative field assignments for this creative. Applicable to all creative types. Corresponds to the JSON property creativeFieldAssignments



3532
3533
3534
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3532

def creative_field_assignments
  @creative_field_assignments
end

#custom_key_valuesArray<String>

Custom key-values for a Rich Media creative. Key-values let you customize the creative settings of a Rich Media ad running on your site without having to contact the advertiser. You can use key-values to dynamically change the look or functionality of a creative. Applicable to the following creative types: all RICH_MEDIA, and all VPAID. Corresponds to the JSON property customKeyValues

Returns:

  • (Array<String>)


3541
3542
3543
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3541

def custom_key_values
  @custom_key_values
end

#exit_custom_eventsArray<Google::Apis::DfareportingV5::CreativeCustomEvent>

List of exit events configured for the creative. For DISPLAY and DISPLAY_IMAGE_GALLERY creatives, these are read-only and auto-generated from clickTags, For DISPLAY, an event is also created from the backupImageReportingLabel. Applicable to the following creative types: DISPLAY_IMAGE_GALLERY, all RICH_MEDIA, and all VPAID. Applicable to DISPLAY when the primary asset type is not HTML_IMAGE. Corresponds to the JSON property exitCustomEvents



3551
3552
3553
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3551

def exit_custom_events
  @exit_custom_events
end

#fs_commandGoogle::Apis::DfareportingV5::FsCommand

FsCommand. Corresponds to the JSON property fsCommand



3556
3557
3558
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3556

def fs_command
  @fs_command
end

#html_codeString

HTML code for the creative. This is a required field when applicable. This field is ignored if htmlCodeLocked is true. Applicable to the following creative types: all CUSTOM, FLASH_INPAGE, and HTML5_BANNER, and all RICH_MEDIA. Corresponds to the JSON property htmlCode

Returns:

  • (String)


3563
3564
3565
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3563

def html_code
  @html_code
end

#html_code_lockedBoolean Also known as: html_code_locked?

Whether HTML code is generated by Campaign Manager or manually entered. Set to true to ignore changes to htmlCode. Applicable to the following creative types: FLASH_INPAGE and HTML5_BANNER. Corresponds to the JSON property htmlCodeLocked

Returns:

  • (Boolean)


3570
3571
3572
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3570

def html_code_locked
  @html_code_locked
end

#idFixnum

ID of this creative. This is a read-only, auto-generated field. Applicable to all creative types. Corresponds to the JSON property id

Returns:

  • (Fixnum)


3577
3578
3579
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3577

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



3582
3583
3584
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3582

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#creative". Corresponds to the JSON property kind

Returns:

  • (String)


3588
3589
3590
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3588

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



3593
3594
3595
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3593

def last_modified_info
  @last_modified_info
end

#latest_trafficked_creative_idFixnum

Latest Studio trafficked creative ID associated with rich media and VPAID creatives. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA, and all VPAID. Corresponds to the JSON property latestTraffickedCreativeId

Returns:

  • (Fixnum)


3600
3601
3602
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3600

def latest_trafficked_creative_id
  @latest_trafficked_creative_id
end

#media_descriptionString

Description of the audio or video ad. Applicable to the following creative types: all INSTREAM_VIDEO, INSTREAM_AUDIO, and all VPAID. Corresponds to the JSON property mediaDescription

Returns:

  • (String)


3606
3607
3608
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3606

def media_description
  @media_description
end

#media_durationFloat

Creative audio or video duration in seconds. This is a read-only field. Applicable to the following creative types: INSTREAM_VIDEO, INSTREAM_AUDIO, all RICH_MEDIA, and all VPAID. Corresponds to the JSON property mediaDuration

Returns:

  • (Float)


3613
3614
3615
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3613

def media_duration
  @media_duration
end

#nameString

Required. Name of the creative. This must be less than 256 characters long. Applicable to all creative types. Corresponds to the JSON property name

Returns:

  • (String)


3619
3620
3621
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3619

def name
  @name
end

#oba_iconGoogle::Apis::DfareportingV5::ObaIcon

Online Behavioral Advertiser icon. Corresponds to the JSON property obaIcon



3624
3625
3626
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3624

def oba_icon
  @oba_icon
end

#override_cssString

Override CSS value for rich media creatives. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property overrideCss

Returns:

  • (String)


3630
3631
3632
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3630

def override_css
  @override_css
end

#progress_offsetGoogle::Apis::DfareportingV5::VideoOffset

Video Offset Corresponds to the JSON property progressOffset



3635
3636
3637
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3635

def progress_offset
  @progress_offset
end

#redirect_urlString

URL of hosted image or hosted video or another ad tag. For INSTREAM_VIDEO_REDIRECT creatives this is the in-stream video redirect URL. The standard for a VAST (Video Ad Serving Template) ad response allows for a redirect link to another VAST 2.0 or 3.0 call. This is a required field when applicable. Applicable to the following creative types: DISPLAY_REDIRECT, INTERNAL_REDIRECT, INTERSTITIAL_INTERNAL_REDIRECT, and INSTREAM_VIDEO_REDIRECT Corresponds to the JSON property redirectUrl

Returns:

  • (String)


3645
3646
3647
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3645

def redirect_url
  @redirect_url
end

#rendering_idFixnum

ID of current rendering version. This is a read-only field. Applicable to all creative types. Corresponds to the JSON property renderingId

Returns:

  • (Fixnum)


3651
3652
3653
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3651

def rendering_id
  @rendering_id
end

#rendering_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property renderingIdDimensionValue



3656
3657
3658
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3656

def rendering_id_dimension_value
  @rendering_id_dimension_value
end

#required_flash_plugin_versionString

The minimum required Flash plugin version for this creative. For example, 11.2. 202.235. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA, and all VPAID. Corresponds to the JSON property requiredFlashPluginVersion

Returns:

  • (String)


3663
3664
3665
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3663

def required_flash_plugin_version
  @required_flash_plugin_version
end

#required_flash_versionFixnum

The internal Flash version for this creative as calculated by Studio. This is a read-only field. Applicable to the following creative types: FLASH_INPAGE all RICH_MEDIA, and all VPAID. Applicable to DISPLAY when the primary asset type is not HTML_IMAGE. Corresponds to the JSON property requiredFlashVersion

Returns:

  • (Fixnum)


3671
3672
3673
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3671

def required_flash_version
  @required_flash_version
end

#sizeGoogle::Apis::DfareportingV5::Size

Represents the dimensions of ads, placements, creatives, or creative assets. Corresponds to the JSON property size



3676
3677
3678
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3676

def size
  @size
end

#skip_offsetGoogle::Apis::DfareportingV5::VideoOffset

Video Offset Corresponds to the JSON property skipOffset



3681
3682
3683
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3681

def skip_offset
  @skip_offset
end

#skippableBoolean Also known as: skippable?

Whether the user can choose to skip the creative. Applicable to the following creative types: all INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property skippable

Returns:

  • (Boolean)


3687
3688
3689
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3687

def skippable
  @skippable
end

#ssl_compliantBoolean Also known as: ssl_compliant?

Whether the creative is SSL-compliant. This is a read-only field. Applicable to all creative types. Corresponds to the JSON property sslCompliant

Returns:

  • (Boolean)


3694
3695
3696
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3694

def ssl_compliant
  @ssl_compliant
end

#ssl_overrideBoolean Also known as: ssl_override?

Whether creative should be treated as SSL compliant even if the system scan shows it's not. Applicable to all creative types. Corresponds to the JSON property sslOverride

Returns:

  • (Boolean)


3701
3702
3703
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3701

def ssl_override
  @ssl_override
end

#studio_advertiser_idFixnum

Studio advertiser ID associated with rich media and VPAID creatives. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA, and all VPAID. Corresponds to the JSON property studioAdvertiserId

Returns:

  • (Fixnum)


3709
3710
3711
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3709

def studio_advertiser_id
  @studio_advertiser_id
end

#studio_creative_idFixnum

Studio creative ID associated with rich media and VPAID creatives. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA, and all VPAID. Corresponds to the JSON property studioCreativeId

Returns:

  • (Fixnum)


3716
3717
3718
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3716

def studio_creative_id
  @studio_creative_id
end

#studio_trafficked_creative_idFixnum

Studio trafficked creative ID associated with rich media and VPAID creatives. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA, and all VPAID. Corresponds to the JSON property studioTraffickedCreativeId

Returns:

  • (Fixnum)


3723
3724
3725
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3723

def studio_trafficked_creative_id
  @studio_trafficked_creative_id
end

#subaccount_idFixnum

Subaccount ID of this creative. This field, if left unset, will be auto- generated for both insert and update operations. Applicable to all creative types. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


3730
3731
3732
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3730

def subaccount_id
  @subaccount_id
end

#synthetic_content_attestation_statusString

Optional. Whether to add a label to the creative as created or edited using AI when served in regions with local AI labeling regulations. Learn more about labeling requirements in AI regulations. Corresponds to the JSON property syntheticContentAttestationStatus

Returns:

  • (String)


3738
3739
3740
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3738

def synthetic_content_attestation_status
  @synthetic_content_attestation_status
end

#third_party_backup_image_impressions_urlString

Third-party URL used to record backup image impressions. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property thirdPartyBackupImageImpressionsUrl

Returns:

  • (String)


3744
3745
3746
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3744

def third_party_backup_image_impressions_url
  @third_party_backup_image_impressions_url
end

#third_party_rich_media_impressions_urlString

Third-party URL used to record rich media impressions. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property thirdPartyRichMediaImpressionsUrl

Returns:

  • (String)


3750
3751
3752
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3750

def third_party_rich_media_impressions_url
  @third_party_rich_media_impressions_url
end

#third_party_urlsArray<Google::Apis::DfareportingV5::ThirdPartyTrackingUrl>

Third-party URLs for tracking in-stream creative events. Applicable to the following creative types: all INSTREAM_VIDEO, all INSTREAM_AUDIO, and all VPAID. Corresponds to the JSON property thirdPartyUrls



3757
3758
3759
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3757

def third_party_urls
  @third_party_urls
end

#timer_custom_eventsArray<Google::Apis::DfareportingV5::CreativeCustomEvent>

List of timer events configured for the creative. For DISPLAY_IMAGE_GALLERY creatives, these are read-only and auto-generated from clickTags. Applicable to the following creative types: DISPLAY_IMAGE_GALLERY, all RICH_MEDIA, and all VPAID. Applicable to DISPLAY when the primary asset is not HTML_IMAGE. Corresponds to the JSON property timerCustomEvents



3765
3766
3767
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3765

def timer_custom_events
  @timer_custom_events
end

#total_file_sizeFixnum

Combined size of all creative assets. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA, and all VPAID. Corresponds to the JSON property totalFileSize

Returns:

  • (Fixnum)


3771
3772
3773
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3771

def total_file_size
  @total_file_size
end

#typeString

Required. Type of this creative. Applicable to all creative types. Note: FLASH_INPAGE, HTML5_BANNER, and IMAGE are only used for existing creatives. New creatives should use DISPLAY as a replacement for these types. Corresponds to the JSON property type

Returns:

  • (String)


3778
3779
3780
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3778

def type
  @type
end

#universal_ad_idGoogle::Apis::DfareportingV5::UniversalAdId

A Universal Ad ID as per the VAST 4.0 spec. Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and VPAID. Corresponds to the JSON property universalAdId



3784
3785
3786
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3784

def universal_ad_id
  @universal_ad_id
end

#versionFixnum

The version number helps you keep track of multiple versions of your creative in your reports. The version number will always be auto-generated during insert operations to start at 1. For tracking creatives the version cannot be incremented and will always remain at 1. For all other creative types the version can be incremented only by 1 during update operations. In addition, the version will be automatically incremented by 1 when undergoing Rich Media creative merging. Applicable to all creative types. Corresponds to the JSON property version

Returns:

  • (Fixnum)


3795
3796
3797
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3795

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3802

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @active = args[:active] if args.key?(:active)
  @ad_parameters = args[:ad_parameters] if args.key?(:ad_parameters)
  @ad_tag_keys = args[:ad_tag_keys] if args.key?(:ad_tag_keys)
  @additional_sizes = args[:additional_sizes] if args.key?(:additional_sizes)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @allow_script_access = args[:allow_script_access] if args.key?(:allow_script_access)
  @archived = args[:archived] if args.key?(:archived)
  @artwork_type = args[:artwork_type] if args.key?(:artwork_type)
  @authoring_source = args[:authoring_source] if args.key?(:authoring_source)
  @authoring_tool = args[:authoring_tool] if args.key?(:authoring_tool)
  @auto_advance_images = args[:auto_advance_images] if args.key?(:auto_advance_images)
  @background_color = args[:background_color] if args.key?(:background_color)
  @backup_image_click_through_url = args[:backup_image_click_through_url] if args.key?(:backup_image_click_through_url)
  @backup_image_features = args[:backup_image_features] if args.key?(:backup_image_features)
  @backup_image_reporting_label = args[:backup_image_reporting_label] if args.key?(:backup_image_reporting_label)
  @backup_image_target_window = args[:backup_image_target_window] if args.key?(:backup_image_target_window)
  @click_tags = args[:click_tags] if args.key?(:click_tags)
  @commercial_id = args[:commercial_id] if args.key?(:commercial_id)
  @companion_creatives = args[:companion_creatives] if args.key?(:companion_creatives)
  @compatibility = args[:compatibility] if args.key?(:compatibility)
  @convert_flash_to_html5 = args[:convert_flash_to_html5] if args.key?(:convert_flash_to_html5)
  @counter_custom_events = args[:counter_custom_events] if args.key?(:counter_custom_events)
  @creative_assets = args[:creative_assets] if args.key?(:creative_assets)
  @creative_field_assignments = args[:creative_field_assignments] if args.key?(:creative_field_assignments)
  @custom_key_values = args[:custom_key_values] if args.key?(:custom_key_values)
  @exit_custom_events = args[:exit_custom_events] if args.key?(:exit_custom_events)
  @fs_command = args[:fs_command] if args.key?(:fs_command)
  @html_code = args[:html_code] if args.key?(:html_code)
  @html_code_locked = args[:html_code_locked] if args.key?(:html_code_locked)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @latest_trafficked_creative_id = args[:latest_trafficked_creative_id] if args.key?(:latest_trafficked_creative_id)
  @media_description = args[:media_description] if args.key?(:media_description)
  @media_duration = args[:media_duration] if args.key?(:media_duration)
  @name = args[:name] if args.key?(:name)
  @oba_icon = args[:oba_icon] if args.key?(:oba_icon)
  @override_css = args[:override_css] if args.key?(:override_css)
  @progress_offset = args[:progress_offset] if args.key?(:progress_offset)
  @redirect_url = args[:redirect_url] if args.key?(:redirect_url)
  @rendering_id = args[:rendering_id] if args.key?(:rendering_id)
  @rendering_id_dimension_value = args[:rendering_id_dimension_value] if args.key?(:rendering_id_dimension_value)
  @required_flash_plugin_version = args[:required_flash_plugin_version] if args.key?(:required_flash_plugin_version)
  @required_flash_version = args[:required_flash_version] if args.key?(:required_flash_version)
  @size = args[:size] if args.key?(:size)
  @skip_offset = args[:skip_offset] if args.key?(:skip_offset)
  @skippable = args[:skippable] if args.key?(:skippable)
  @ssl_compliant = args[:ssl_compliant] if args.key?(:ssl_compliant)
  @ssl_override = args[:ssl_override] if args.key?(:ssl_override)
  @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id)
  @studio_creative_id = args[:studio_creative_id] if args.key?(:studio_creative_id)
  @studio_trafficked_creative_id = args[:studio_trafficked_creative_id] if args.key?(:studio_trafficked_creative_id)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @synthetic_content_attestation_status = args[:synthetic_content_attestation_status] if args.key?(:synthetic_content_attestation_status)
  @third_party_backup_image_impressions_url = args[:third_party_backup_image_impressions_url] if args.key?(:third_party_backup_image_impressions_url)
  @third_party_rich_media_impressions_url = args[:third_party_rich_media_impressions_url] if args.key?(:third_party_rich_media_impressions_url)
  @third_party_urls = args[:third_party_urls] if args.key?(:third_party_urls)
  @timer_custom_events = args[:timer_custom_events] if args.key?(:timer_custom_events)
  @total_file_size = args[:total_file_size] if args.key?(:total_file_size)
  @type = args[:type] if args.key?(:type)
  @universal_ad_id = args[:universal_ad_id] if args.key?(:universal_ad_id)
  @version = args[:version] if args.key?(:version)
end