Class: Google::Apis::DfareportingV5::CreativeAssetId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Creative Asset ID.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeAssetId

Returns a new instance of CreativeAssetId.



4268
4269
4270
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the creative asset. This is a required field while inserting an asset. After insertion, this assetIdentifier is used to identify the uploaded asset. Characters in the name must be alphanumeric or one of the following: ".-_ ". Spaces are allowed. Corresponds to the JSON property name

Returns:

  • (String)


4260
4261
4262
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4260

def name
  @name
end

#typeString

Type of asset to upload. This is a required field. FLASH and IMAGE are no longer supported for new uploads. All image assets should use HTML_IMAGE. Corresponds to the JSON property type

Returns:

  • (String)


4266
4267
4268
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4266

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4273
4274
4275
4276
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4273

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end