Class: Google::Apis::DfareportingV5::CreativeAssignment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Creative Assignment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeAssignment

Returns a new instance of CreativeAssignment.



4500
4501
4502
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Whether this creative assignment is active. When true, the creative will be included in the ad's rotation. Corresponds to the JSON property active

Returns:

  • (Boolean)


4421
4422
4423
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4421

def active
  @active
end

#apply_event_tagsBoolean Also known as: apply_event_tags?

Whether applicable event tags should fire when this creative assignment is rendered. If this value is unset when the ad is inserted or updated, it will default to true for all creative types EXCEPT for INTERNAL_REDIRECT, INTERSTITIAL_INTERNAL_REDIRECT, and INSTREAM_VIDEO. Corresponds to the JSON property applyEventTags

Returns:

  • (Boolean)


4430
4431
4432
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4430

def apply_event_tags
  @apply_event_tags
end

#click_through_urlGoogle::Apis::DfareportingV5::ClickThroughUrl

Click-through URL Corresponds to the JSON property clickThroughUrl



4436
4437
4438
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4436

def click_through_url
  @click_through_url
end

#companion_creative_overridesArray<Google::Apis::DfareportingV5::CompanionClickThroughOverride>

Companion creative overrides for this creative assignment. Applicable to video ads. Corresponds to the JSON property companionCreativeOverrides



4442
4443
4444
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4442

def companion_creative_overrides
  @companion_creative_overrides
end

#creative_group_assignmentsArray<Google::Apis::DfareportingV5::CreativeGroupAssignment>

Creative group assignments for this creative assignment. Only one assignment per creative group number is allowed for a maximum of two assignments. Corresponds to the JSON property creativeGroupAssignments



4448
4449
4450
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4448

def creative_group_assignments
  @creative_group_assignments
end

#creative_idFixnum

ID of the creative to be assigned. This is a required field. Corresponds to the JSON property creativeId

Returns:

  • (Fixnum)


4453
4454
4455
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4453

def creative_id
  @creative_id
end

#creative_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property creativeIdDimensionValue



4458
4459
4460
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4458

def creative_id_dimension_value
  @creative_id_dimension_value
end

#end_timeDateTime

Corresponds to the JSON property endTime

Returns:

  • (DateTime)


4463
4464
4465
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4463

def end_time
  @end_time
end

#rich_media_exit_overridesArray<Google::Apis::DfareportingV5::RichMediaExitOverride>

Rich media exit overrides for this creative assignment. Applicable when the creative type is any of the following: - DISPLAY - RICH_MEDIA_INPAGE - RICH_MEDIA_INPAGE_FLOATING - RICH_MEDIA_IM_EXPAND - RICH_MEDIA_EXPANDING - RICH_MEDIA_INTERSTITIAL_FLOAT - RICH_MEDIA_MOBILE_IN_APP - RICH_MEDIA_MULTI_FLOATING - RICH_MEDIA_PEEL_DOWN - VPAID_LINEAR - VPAID_NON_LINEAR Corresponds to the JSON property richMediaExitOverrides



4473
4474
4475
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4473

def rich_media_exit_overrides
  @rich_media_exit_overrides
end

#sequenceFixnum

Sequence number of the creative assignment, applicable when the rotation type is CREATIVE_ROTATION_TYPE_SEQUENTIAL. Acceptable values are 1 to 65535, inclusive. Corresponds to the JSON property sequence

Returns:

  • (Fixnum)


4480
4481
4482
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4480

def sequence
  @sequence
end

#ssl_compliantBoolean Also known as: ssl_compliant?

Whether the creative to be assigned is SSL-compliant. This is a read-only field that is auto-generated when the ad is inserted or updated. Corresponds to the JSON property sslCompliant

Returns:

  • (Boolean)


4486
4487
4488
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4486

def ssl_compliant
  @ssl_compliant
end

#start_timeDateTime

Corresponds to the JSON property startTime

Returns:

  • (DateTime)


4492
4493
4494
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4492

def start_time
  @start_time
end

#weightFixnum

Weight of the creative assignment, applicable when the rotation type is CREATIVE_ROTATION_TYPE_RANDOM. Value must be greater than or equal to 1. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


4498
4499
4500
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4498

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4505
4506
4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
4519
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4505

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @apply_event_tags = args[:apply_event_tags] if args.key?(:apply_event_tags)
  @click_through_url = args[:click_through_url] if args.key?(:click_through_url)
  @companion_creative_overrides = args[:companion_creative_overrides] if args.key?(:companion_creative_overrides)
  @creative_group_assignments = args[:creative_group_assignments] if args.key?(:creative_group_assignments)
  @creative_id = args[:creative_id] if args.key?(:creative_id)
  @creative_id_dimension_value = args[:creative_id_dimension_value] if args.key?(:creative_id_dimension_value)
  @end_time = args[:end_time] if args.key?(:end_time)
  @rich_media_exit_overrides = args[:rich_media_exit_overrides] if args.key?(:rich_media_exit_overrides)
  @sequence = args[:sequence] if args.key?(:sequence)
  @ssl_compliant = args[:ssl_compliant] if args.key?(:ssl_compliant)
  @start_time = args[:start_time] if args.key?(:start_time)
  @weight = args[:weight] if args.key?(:weight)
end