Class: Google::Apis::DfareportingV5::CreativeField
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::CreativeField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of a creative field.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this creative field.
-
#advertiser_id ⇒ Fixnum
Advertiser ID of this creative field.
-
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#id ⇒ Fixnum
ID of this creative field.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this creative field.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this creative field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreativeField
constructor
A new instance of CreativeField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreativeField
Returns a new instance of CreativeField.
4642 4643 4644 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this creative field. This is a read-only field that can be left
blank.
Corresponds to the JSON property accountId
4607 4608 4609 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4607 def account_id @account_id end |
#advertiser_id ⇒ Fixnum
Advertiser ID of this creative field. This is a required field on insertion.
Corresponds to the JSON property advertiserId
4612 4613 4614 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4612 def advertiser_id @advertiser_id end |
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property advertiserIdDimensionValue
4617 4618 4619 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4617 def advertiser_id_dimension_value @advertiser_id_dimension_value end |
#id ⇒ Fixnum
ID of this creative field. This is a read-only, auto-generated field.
Corresponds to the JSON property id
4622 4623 4624 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4622 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#creativeField".
Corresponds to the JSON property kind
4628 4629 4630 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4628 def kind @kind end |
#name ⇒ String
Name of this creative field. This is a required field and must be less than
256 characters long and unique among creative fields of the same advertiser.
Corresponds to the JSON property name
4634 4635 4636 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4634 def name @name end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this creative field. This is a read-only field that can be
left blank.
Corresponds to the JSON property subaccountId
4640 4641 4642 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4640 def subaccount_id @subaccount_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4647 4648 4649 4650 4651 4652 4653 4654 4655 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4647 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) end |