Class: Google::Apis::DfareportingV5::CreativeGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a creative group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeGroup

Returns a new instance of CreativeGroup.



4865
4866
4867
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this creative group. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


4822
4823
4824
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4822

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this creative group. This is a required field on insertion. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


4827
4828
4829
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4827

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



4832
4833
4834
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4832

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#group_numberFixnum

Subgroup of the creative group. Assign your creative groups to a subgroup in order to filter or manage them more easily. This field is required on insertion and is read-only after insertion. Acceptable values are 1 to 2, inclusive. Corresponds to the JSON property groupNumber

Returns:

  • (Fixnum)


4840
4841
4842
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4840

def group_number
  @group_number
end

#idFixnum

ID of this creative group. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


4845
4846
4847
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4845

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#creativeGroup". Corresponds to the JSON property kind

Returns:

  • (String)


4851
4852
4853
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4851

def kind
  @kind
end

#nameString

Name of this creative group. This is a required field and must be less than 256 characters long and unique among creative groups of the same advertiser. Corresponds to the JSON property name

Returns:

  • (String)


4857
4858
4859
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4857

def name
  @name
end

#subaccount_idFixnum

Subaccount ID of this creative group. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


4863
4864
4865
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4863

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4870

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @group_number = args[:group_number] if args.key?(:group_number)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end