Class: Google::Apis::DfareportingV5::CreativeGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::CreativeGroupsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Creative Group List Response
Instance Attribute Summary collapse
-
#creative_groups ⇒ Array<Google::Apis::DfareportingV5::CreativeGroup>
Creative group collection.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreativeGroupsListResponse
constructor
A new instance of CreativeGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreativeGroupsListResponse
Returns a new instance of CreativeGroupsListResponse.
4893 4894 4895 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creative_groups ⇒ Array<Google::Apis::DfareportingV5::CreativeGroup>
Creative group collection.
Corresponds to the JSON property creativeGroups
4880 4881 4882 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4880 def creative_groups @creative_groups end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#creativeGroupsListResponse".
Corresponds to the JSON property kind
4886 4887 4888 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4886 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
4891 4892 4893 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4891 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4898 4899 4900 4901 4902 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4898 def update!(**args) @creative_groups = args[:creative_groups] if args.key?(:creative_groups) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |