Class: Google::Apis::DfareportingV5::CustomFloodlightVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

A custom floodlight variable. Can be used in both batchinsert and batchupdate. Adding this in batchupdate will update or append the variable to the existing list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomFloodlightVariable

Returns a new instance of CustomFloodlightVariable.



5166
5167
5168
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#customFloodlightVariable". Corresponds to the JSON property kind

Returns:

  • (String)


5152
5153
5154
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5152

def kind
  @kind
end

#typeString

The type of custom floodlight variable to supply a value for. These map to the "u[1-100]=" in the tags. Corresponds to the JSON property type

Returns:

  • (String)


5158
5159
5160
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5158

def type
  @type
end

#valueString

The value of the custom floodlight variable. The length of string must not exceed 100 characters. Corresponds to the JSON property value

Returns:

  • (String)


5164
5165
5166
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5164

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5171
5172
5173
5174
5175
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5171

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end