Class: Google::Apis::DfareportingV5::CustomViewabilityMetricConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

The attributes, like playtime and percent onscreen, that define the Custom Viewability Metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomViewabilityMetricConfiguration

Returns a new instance of CustomViewabilityMetricConfiguration.



5323
5324
5325
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audibleBoolean Also known as: audible?

Whether the video must be audible to count an impression. Corresponds to the JSON property audible

Returns:

  • (Boolean)


5300
5301
5302
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5300

def audible
  @audible
end

#time_millisFixnum

The time in milliseconds the video must play for the Custom Viewability Metric to count an impression. If both this and timePercent are specified, the earlier of the two will be used. Corresponds to the JSON property timeMillis

Returns:

  • (Fixnum)


5308
5309
5310
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5308

def time_millis
  @time_millis
end

#time_percentFixnum

The percentage of video that must play for the Custom Viewability Metric to count an impression. If both this and timeMillis are specified, the earlier of the two will be used. Corresponds to the JSON property timePercent

Returns:

  • (Fixnum)


5315
5316
5317
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5315

def time_percent
  @time_percent
end

#viewability_percentFixnum

The percentage of video that must be on screen for the Custom Viewability Metric to count an impression. Corresponds to the JSON property viewabilityPercent

Returns:

  • (Fixnum)


5321
5322
5323
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5321

def viewability_percent
  @viewability_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5328
5329
5330
5331
5332
5333
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5328

def update!(**args)
  @audible = args[:audible] if args.key?(:audible)
  @time_millis = args[:time_millis] if args.key?(:time_millis)
  @time_percent = args[:time_percent] if args.key?(:time_percent)
  @viewability_percent = args[:viewability_percent] if args.key?(:viewability_percent)
end