Class: Google::Apis::DfareportingV5::DateRange
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DateRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents a date range.
Instance Attribute Summary collapse
-
#end_date ⇒ Date
Corresponds to the JSON property
endDate. -
#kind ⇒ String
The kind of resource this is, in this case dfareporting#dateRange.
-
#relative_date_range ⇒ String
The date range relative to the date of when the report is run.
-
#start_date ⇒ Date
Corresponds to the JSON property
startDate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DateRange
constructor
A new instance of DateRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DateRange
Returns a new instance of DateRange.
5360 5361 5362 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5360 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Date
Corresponds to the JSON property endDate
5343 5344 5345 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5343 def end_date @end_date end |
#kind ⇒ String
The kind of resource this is, in this case dfareporting#dateRange.
Corresponds to the JSON property kind
5348 5349 5350 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5348 def kind @kind end |
#relative_date_range ⇒ String
The date range relative to the date of when the report is run.
Corresponds to the JSON property relativeDateRange
5353 5354 5355 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5353 def relative_date_range @relative_date_range end |
#start_date ⇒ Date
Corresponds to the JSON property startDate
5358 5359 5360 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5358 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5365 5366 5367 5368 5369 5370 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5365 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @kind = args[:kind] if args.key?(:kind) @relative_date_range = args[:relative_date_range] if args.key?(:relative_date_range) @start_date = args[:start_date] if args.key?(:start_date) end |