Class: Google::Apis::DfareportingV5::DeliverySchedule
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DeliverySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Delivery Schedule.
Instance Attribute Summary collapse
-
#frequency_cap ⇒ Google::Apis::DfareportingV5::FrequencyCap
Frequency Cap.
-
#hard_cutoff ⇒ Boolean
(also: #hard_cutoff?)
Whether or not hard cutoff is enabled.
-
#impression_ratio ⇒ Fixnum
Impression ratio for this ad.
-
#priority ⇒ String
Serving priority of an ad, with respect to other ads.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeliverySchedule
constructor
A new instance of DeliverySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeliverySchedule
Returns a new instance of DeliverySchedule.
5518 5519 5520 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frequency_cap ⇒ Google::Apis::DfareportingV5::FrequencyCap
Frequency Cap.
Corresponds to the JSON property frequencyCap
5494 5495 5496 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5494 def frequency_cap @frequency_cap end |
#hard_cutoff ⇒ Boolean Also known as: hard_cutoff?
Whether or not hard cutoff is enabled. If true, the ad will not serve after
the end date and time. Otherwise the ad will continue to be served until it
has reached its delivery goals.
Corresponds to the JSON property hardCutoff
5501 5502 5503 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5501 def hard_cutoff @hard_cutoff end |
#impression_ratio ⇒ Fixnum
Impression ratio for this ad. This ratio determines how often each ad is
served relative to the others. For example, if ad A has an impression ratio of
1 and ad B has an impression ratio of 3, then Campaign Manager will serve ad B
three times as often as ad A. Acceptable values are 1 to 10, inclusive.
Corresponds to the JSON property impressionRatio
5510 5511 5512 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5510 def impression_ratio @impression_ratio end |
#priority ⇒ String
Serving priority of an ad, with respect to other ads. The lower the priority
number, the greater the priority with which it is served.
Corresponds to the JSON property priority
5516 5517 5518 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5516 def priority @priority end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5523 5524 5525 5526 5527 5528 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5523 def update!(**args) @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap) @hard_cutoff = args[:hard_cutoff] if args.key?(:hard_cutoff) @impression_ratio = args[:impression_ratio] if args.key?(:impression_ratio) @priority = args[:priority] if args.key?(:priority) end |