Class: Google::Apis::DfareportingV5::Dimension
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Dimension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents a dimension.
Instance Attribute Summary collapse
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting#dimension.
-
#name ⇒ String
The dimension name, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Dimension
constructor
A new instance of Dimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Dimension
Returns a new instance of Dimension.
5621 5622 5623 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
The kind of resource this is, in this case dfareporting#dimension.
Corresponds to the JSON property kind
5614 5615 5616 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5614 def kind @kind end |
#name ⇒ String
The dimension name, e.g. advertiser
Corresponds to the JSON property name
5619 5620 5621 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5619 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5626 5627 5628 5629 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5626 def update!(**args) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) end |