Class: Google::Apis::DfareportingV5::DimensionValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents a DimensionValue resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DimensionValue

Returns a new instance of DimensionValue.



5735
5736
5737
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_nameString

The name of the dimension. Corresponds to the JSON property dimensionName

Returns:

  • (String)


5704
5705
5706
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5704

def dimension_name
  @dimension_name
end

#etagString

The eTag of this response for caching purposes. Corresponds to the JSON property etag

Returns:

  • (String)


5709
5710
5711
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5709

def etag
  @etag
end

#idString

The ID associated with the value if available. Corresponds to the JSON property id

Returns:

  • (String)


5714
5715
5716
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5714

def id
  @id
end

#kindString

The kind of resource this is, in this case dfareporting#dimensionValue. Corresponds to the JSON property kind

Returns:

  • (String)


5719
5720
5721
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5719

def kind
  @kind
end

#match_typeString

Determines how the 'value' field is matched when filtering. If not specified, defaults to EXACT. If set to WILDCARD_EXPRESSION, '' is allowed as a placeholder for variable length character sequences, and it can be escaped with a backslash. Note, only paid search dimensions ('dfa:paidSearch') allow a matchType other than EXACT. Corresponds to the JSON property matchType

Returns:

  • (String)


5728
5729
5730
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5728

def match_type
  @match_type
end

#valueString

The value of the dimension. Corresponds to the JSON property value

Returns:

  • (String)


5733
5734
5735
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5733

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5740
5741
5742
5743
5744
5745
5746
5747
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5740

def update!(**args)
  @dimension_name = args[:dimension_name] if args.key?(:dimension_name)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @match_type = args[:match_type] if args.key?(:match_type)
  @value = args[:value] if args.key?(:value)
end