Class: Google::Apis::DfareportingV5::DimensionValueRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents a DimensionValuesRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DimensionValueRequest

Returns a new instance of DimensionValueRequest.



5819
5820
5821
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_nameString

The name of the dimension for which values should be requested. Corresponds to the JSON property dimensionName

Returns:

  • (String)


5797
5798
5799
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5797

def dimension_name
  @dimension_name
end

#end_dateDate

Corresponds to the JSON property endDate

Returns:

  • (Date)


5802
5803
5804
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5802

def end_date
  @end_date
end

#filtersArray<Google::Apis::DfareportingV5::DimensionFilter>

The list of filters by which to filter values. The filters are ANDed. Corresponds to the JSON property filters



5807
5808
5809
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5807

def filters
  @filters
end

#kindString

The kind of request this is, in this case dfareporting#dimensionValueRequest . Corresponds to the JSON property kind

Returns:

  • (String)


5812
5813
5814
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5812

def kind
  @kind
end

#start_dateDate

Corresponds to the JSON property startDate

Returns:

  • (Date)


5817
5818
5819
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5817

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5824
5825
5826
5827
5828
5829
5830
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5824

def update!(**args)
  @dimension_name = args[:dimension_name] if args.key?(:dimension_name)
  @end_date = args[:end_date] if args.key?(:end_date)
  @filters = args[:filters] if args.key?(:filters)
  @kind = args[:kind] if args.key?(:kind)
  @start_date = args[:start_date] if args.key?(:start_date)
end