Class: Google::Apis::DfareportingV5::DirectorySite
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DirectorySite
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
DirectorySites contains properties of a website from the Site Directory. Sites need to be added to an account via the Sites resource before they can be assigned to a placement.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
ID of this directory site.
-
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#inpage_tag_formats ⇒ Array<String>
Tag types for regular placements.
-
#interstitial_tag_formats ⇒ Array<String>
Tag types for interstitial placements.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this directory site.
-
#publisher_specification_id ⇒ Fixnum
Output only.
-
#settings ⇒ Google::Apis::DfareportingV5::DirectorySiteSettings
Directory Site Settings Corresponds to the JSON property
settings. -
#url ⇒ String
URL of this directory site.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DirectorySite
constructor
A new instance of DirectorySite.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DirectorySite
Returns a new instance of DirectorySite.
5862 5863 5864 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
ID of this directory site. This is a read-only, auto-generated field.
Corresponds to the JSON property id
5808 5809 5810 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5808 def id @id end |
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property idDimensionValue
5813 5814 5815 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5813 def id_dimension_value @id_dimension_value end |
#inpage_tag_formats ⇒ Array<String>
Tag types for regular placements. Acceptable values are: - "STANDARD" - "
IFRAME_JAVASCRIPT_INPAGE" - "INTERNAL_REDIRECT_INPAGE" - "JAVASCRIPT_INPAGE"
Corresponds to the JSON property inpageTagFormats
5819 5820 5821 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5819 def inpage_tag_formats @inpage_tag_formats end |
#interstitial_tag_formats ⇒ Array<String>
Tag types for interstitial placements. Acceptable values are: - "
IFRAME_JAVASCRIPT_INTERSTITIAL" - "INTERNAL_REDIRECT_INTERSTITIAL" - "
JAVASCRIPT_INTERSTITIAL"
Corresponds to the JSON property interstitialTagFormats
5826 5827 5828 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5826 def interstitial_tag_formats @interstitial_tag_formats end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#directorySite".
Corresponds to the JSON property kind
5832 5833 5834 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5832 def kind @kind end |
#name ⇒ String
Name of this directory site.
Corresponds to the JSON property name
5837 5838 5839 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5837 def name @name end |
#publisher_specification_id ⇒ Fixnum
Output only. Default publisher specification ID of video placements under this
directory site. Possible values are: * 1, Hulu * 2, NBC * 3, CBS * 4,
CBS Desktop * 5, Discovery * 6, VEVO HD * 7, VEVO Vertical * 8, Fox *
9, CW Network * 10, Disney * 11, IGN * 12, NFL.com * 13, Turner
Broadcasting * 14, Tubi on Fox * 15, Hearst Corporation * 16, Twitch
Desktop * 17, ABC * 18, Univision * 19, MLB.com * 20, MLB.com Mobile *
21, MLB.com OTT * 22, Polsat * 23, TVN * 24, Mediaset * 25, Antena 3
26, Mediamond *27, Sky Italia *28, Tubi on CBS *29, Spotify *30, Paramount *31, Max Corresponds to the JSON propertypublisherSpecificationId
5850 5851 5852 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5850 def publisher_specification_id @publisher_specification_id end |
#settings ⇒ Google::Apis::DfareportingV5::DirectorySiteSettings
Directory Site Settings
Corresponds to the JSON property settings
5855 5856 5857 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5855 def settings @settings end |
#url ⇒ String
URL of this directory site.
Corresponds to the JSON property url
5860 5861 5862 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5860 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5867 5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5867 def update!(**args) @id = args[:id] if args.key?(:id) @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value) @inpage_tag_formats = args[:inpage_tag_formats] if args.key?(:inpage_tag_formats) @interstitial_tag_formats = args[:interstitial_tag_formats] if args.key?(:interstitial_tag_formats) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @publisher_specification_id = args[:publisher_specification_id] if args.key?(:publisher_specification_id) @settings = args[:settings] if args.key?(:settings) @url = args[:url] if args.key?(:url) end |