Class: Google::Apis::DfareportingV5::DynamicFeedsInsertRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Dynamic profile ID is required for dynamic feed insert as the current GPA API only can create a dynamic feed under profile context,even though the dynamic feed itself don't need the dynamic profile id.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DynamicFeedsInsertRequest

Returns a new instance of DynamicFeedsInsertRequest.



6096
6097
6098
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_feedGoogle::Apis::DfareportingV5::DynamicFeed

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains dynamic feed information. Corresponds to the JSON property dynamicFeed



6089
6090
6091
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6089

def dynamic_feed
  @dynamic_feed
end

#dynamic_profile_idFixnum

Required. Dynamic profile ID of the inserted dynamic feed. Corresponds to the JSON property dynamicProfileId

Returns:

  • (Fixnum)


6094
6095
6096
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6094

def dynamic_profile_id
  @dynamic_profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6101
6102
6103
6104
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6101

def update!(**args)
  @dynamic_feed = args[:dynamic_feed] if args.key?(:dynamic_feed)
  @dynamic_profile_id = args[:dynamic_profile_id] if args.key?(:dynamic_profile_id)
end