Class: Google::Apis::DfareportingV5::DynamicProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains dynamic profile information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DynamicProfile

Returns a new instance of DynamicProfile.



6172
6173
6174
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeGoogle::Apis::DfareportingV5::DynamicProfileVersion

Contains dynamic profile version information. Corresponds to the JSON property active



6116
6117
6118
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6116

def active
  @active
end

#archive_statusString

Optional. Archive status of this dynamic profile. Corresponds to the JSON property archiveStatus

Returns:

  • (String)


6121
6122
6123
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6121

def archive_status
  @archive_status
end

#create_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



6126
6127
6128
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6126

def create_info
  @create_info
end

#descriptionString

Optional. Description of this dynamic profile. Corresponds to the JSON property description

Returns:

  • (String)


6131
6132
6133
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6131

def description
  @description
end

#draftGoogle::Apis::DfareportingV5::DynamicProfileVersion

Contains dynamic profile version information. Corresponds to the JSON property draft



6136
6137
6138
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6136

def draft
  @draft
end

#dynamic_profile_idFixnum

Output only. Unique ID of this dynamic profile. This is a read-only, auto- generated field. Corresponds to the JSON property dynamicProfileId

Returns:

  • (Fixnum)


6142
6143
6144
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6142

def dynamic_profile_id
  @dynamic_profile_id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "dfareporting#dynamicProfile". Corresponds to the JSON property kind

Returns:

  • (String)


6148
6149
6150
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6148

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



6153
6154
6155
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6153

def last_modified_info
  @last_modified_info
end

#nameString

Required. Identifier. Name of this dynamic profile. This is a required field and must be less than 256 characters long. Corresponds to the JSON property name

Returns:

  • (String)


6159
6160
6161
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6159

def name
  @name
end

#statusString

Optional. Status of this dynamic profile. Corresponds to the JSON property status

Returns:

  • (String)


6164
6165
6166
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6164

def status
  @status
end

#studio_advertiser_idFixnum

Required. Advertiser ID of this dynamic profile. This is a required field on insertion. Corresponds to the JSON property studioAdvertiserId

Returns:

  • (Fixnum)


6170
6171
6172
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6170

def studio_advertiser_id
  @studio_advertiser_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6177

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @archive_status = args[:archive_status] if args.key?(:archive_status)
  @create_info = args[:create_info] if args.key?(:create_info)
  @description = args[:description] if args.key?(:description)
  @draft = args[:draft] if args.key?(:draft)
  @dynamic_profile_id = args[:dynamic_profile_id] if args.key?(:dynamic_profile_id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id)
end