Class: Google::Apis::DfareportingV5::Element

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains the element of the dynamic feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Element

Returns a new instance of Element.



6482
6483
6484
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_field_idFixnum

Optional. The field ID to specify the active field in the feed. Corresponds to the JSON property activeFieldId

Returns:

  • (Fixnum)


6415
6416
6417
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6415

def active_field_id
  @active_field_id
end

#create_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



6420
6421
6422
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6420

def create_info
  @create_info
end

#default_field_idFixnum

Optional. The field ID to specify the field that represents the default field in the feed. Corresponds to the JSON property defaultFieldId

Returns:

  • (Fixnum)


6426
6427
6428
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6426

def default_field_id
  @default_field_id
end

#element_nameString

Optional. The name of the element. It is defaulted to resource file name if not provided. Corresponds to the JSON property elementName

Returns:

  • (String)


6432
6433
6434
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6432

def element_name
  @element_name
end

#end_timestamp_field_idFixnum

Optional. The field ID to specify the field that represents the end timestamp. Only applicable if you're planning to use scheduling in your dynamic creative. Corresponds to the JSON property endTimestampFieldId

Returns:

  • (Fixnum)


6438
6439
6440
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6438

def end_timestamp_field_id
  @end_timestamp_field_id
end

#external_id_field_idFixnum

Required. The field ID to specify the field used for uniquely identifying the feed row. This is a required field. Corresponds to the JSON property externalIdFieldId

Returns:

  • (Fixnum)


6444
6445
6446
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6444

def external_id_field_id
  @external_id_field_id
end

#feed_fieldsArray<Google::Apis::DfareportingV5::FeedField>

Required. The list of fields of the element. The field order and name should match the meta data in the content source source. Corresponds to the JSON property feedFields



6450
6451
6452
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6450

def feed_fields
  @feed_fields
end

#is_local_timestampBoolean Also known as: is_local_timestamp?

Optional. Whether the start and end timestamp is local timestamp. The default value is false which means start and end timestamp is in UTC. Corresponds to the JSON property isLocalTimestamp

Returns:

  • (Boolean)


6456
6457
6458
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6456

def is_local_timestamp
  @is_local_timestamp
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



6462
6463
6464
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6462

def last_modified_info
  @last_modified_info
end

#proximity_targeting_field_idFixnum

Optional. The field ID that specify field used for proximity targeting. Corresponds to the JSON property proximityTargetingFieldId

Returns:

  • (Fixnum)


6467
6468
6469
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6467

def proximity_targeting_field_id
  @proximity_targeting_field_id
end

#reporting_label_field_idFixnum

Required. The field ID to specify the field used for dynamic reporting in Campaign Manager 360. Corresponds to the JSON property reportingLabelFieldId

Returns:

  • (Fixnum)


6473
6474
6475
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6473

def reporting_label_field_id
  @reporting_label_field_id
end

#start_timestamp_field_idFixnum

Optional. The field ID to specify the field that represents the start timestamp. Only applicable if you're planning to use scheduling in your dynamic creative. Corresponds to the JSON property startTimestampFieldId

Returns:

  • (Fixnum)


6480
6481
6482
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6480

def start_timestamp_field_id
  @start_timestamp_field_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6487
6488
6489
6490
6491
6492
6493
6494
6495
6496
6497
6498
6499
6500
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6487

def update!(**args)
  @active_field_id = args[:active_field_id] if args.key?(:active_field_id)
  @create_info = args[:create_info] if args.key?(:create_info)
  @default_field_id = args[:default_field_id] if args.key?(:default_field_id)
  @element_name = args[:element_name] if args.key?(:element_name)
  @end_timestamp_field_id = args[:end_timestamp_field_id] if args.key?(:end_timestamp_field_id)
  @external_id_field_id = args[:external_id_field_id] if args.key?(:external_id_field_id)
  @feed_fields = args[:feed_fields] if args.key?(:feed_fields)
  @is_local_timestamp = args[:is_local_timestamp] if args.key?(:is_local_timestamp)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @proximity_targeting_field_id = args[:proximity_targeting_field_id] if args.key?(:proximity_targeting_field_id)
  @reporting_label_field_id = args[:reporting_label_field_id] if args.key?(:reporting_label_field_id)
  @start_timestamp_field_id = args[:start_timestamp_field_id] if args.key?(:start_timestamp_field_id)
end