Class: Google::Apis::DfareportingV5::EncryptionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

A description of how user IDs are encrypted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionInfo

Returns a new instance of EncryptionInfo.



6497
6498
6499
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encryption_entity_idFixnum

The encryption entity ID. This should match the encryption configuration for ad serving or Data Transfer. Corresponds to the JSON property encryptionEntityId

Returns:

  • (Fixnum)


6477
6478
6479
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6477

def encryption_entity_id
  @encryption_entity_id
end

#encryption_entity_typeString

The encryption entity type. This should match the encryption configuration for ad serving or Data Transfer. Corresponds to the JSON property encryptionEntityType

Returns:

  • (String)


6483
6484
6485
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6483

def encryption_entity_type
  @encryption_entity_type
end

#encryption_sourceString

Describes whether the encrypted cookie was received from ad serving (the %m macro) or from Data Transfer. Corresponds to the JSON property encryptionSource

Returns:

  • (String)


6489
6490
6491
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6489

def encryption_source
  @encryption_source
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#encryptionInfo". Corresponds to the JSON property kind

Returns:

  • (String)


6495
6496
6497
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6495

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6502
6503
6504
6505
6506
6507
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6502

def update!(**args)
  @encryption_entity_id = args[:encryption_entity_id] if args.key?(:encryption_entity_id)
  @encryption_entity_type = args[:encryption_entity_type] if args.key?(:encryption_entity_type)
  @encryption_source = args[:encryption_source] if args.key?(:encryption_source)
  @kind = args[:kind] if args.key?(:kind)
end