Class: Google::Apis::DfareportingV5::FeedField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Each field of the element. This is a required field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeedField

Returns a new instance of FeedField.



6793
6794
6795
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueString

Optional. The default value of the field. Corresponds to the JSON property defaultValue

Returns:

  • (String)


6745
6746
6747
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6745

def default_value
  @default_value
end

#filterableBoolean Also known as: filterable?

Optional. Whether the field is filterable. Could be set as true when the field type is any of the following and is not renderable: - STRING - BOOL - COUNTRY_CODE_ISO - CM360_SITE_ID - CM360_KEYWORD - CM360_CREATIVE_ID - CM360_PLACEMENT_ID - CM360_AD_ID - CM360_ADVERTISER_ID - CM360_CAMPAIGN_ID - CITY - REGION - POSTAL_CODE - METRO - CUSTOM_VALUE - REMARKETING_VALUE - GEO_CANONICAL - STRING_LIST - CREATIVE_DIMENSION - USERLIST_ID - CM360_DYNAMIC_TARGETING_KEY - DV360_LINE_ITEM_ID Corresponds to the JSON property filterable

Returns:

  • (Boolean)


6756
6757
6758
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6756

def filterable
  @filterable
end

#idFixnum

Required. The ID of the field. The ID is based on the column index starting from 0, and it should match the column index in the resource link. Corresponds to the JSON property id

Returns:

  • (Fixnum)


6763
6764
6765
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6763

def id
  @id
end

#nameString

Required. The name of the field. Corresponds to the JSON property name

Returns:

  • (String)


6768
6769
6770
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6768

def name
  @name
end

#renderableBoolean Also known as: renderable?

Optional. Whether the field is able to display. Could be set as true when the field type is not in any of the following and the field is not filterable: - COUNTRY_CODE_ISO - CITY - REGION - POSTAL_CODE - METRO - GEO_CANONICAL - USERLIST_ID - CONTEXTUAL_KEYWORD - CM360_DYNAMIC_TARGETING_KEY - WEIGHT Corresponds to the JSON property renderable

Returns:

  • (Boolean)


6776
6777
6778
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6776

def renderable
  @renderable
end

#requiredBoolean Also known as: required?

Optional. Whether the field is required and should not be empty in the feed. Could be set as true when the field type is any of the following: - GPA_SERVED_IMAGE_URL - GPA_SERVED_ASSET_URL - ASSET_LIBRARY_HANDLE - ASSET_LIBRARY_VIDEO_HANDLE - ASSET_LIBRARY_DIRECTORY_HANDLE Corresponds to the JSON property required

Returns:

  • (Boolean)


6785
6786
6787
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6785

def required
  @required
end

#typeString

Required. The type of the field. Corresponds to the JSON property type

Returns:

  • (String)


6791
6792
6793
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6791

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6798
6799
6800
6801
6802
6803
6804
6805
6806
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6798

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @filterable = args[:filterable] if args.key?(:filterable)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @renderable = args[:renderable] if args.key?(:renderable)
  @required = args[:required] if args.key?(:required)
  @type = args[:type] if args.key?(:type)
end