Class: Google::Apis::DfareportingV5::File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents a File resource. A file contains the metadata for a report run. It shows the status of the run and holds the URLs to the generated report data if the run is finished and the status is "REPORT_AVAILABLE".

Defined Under Namespace

Classes: Urls

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ File

Returns a new instance of File.



7017
7018
7019
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_rangeGoogle::Apis::DfareportingV5::DateRange

Represents a date range. Corresponds to the JSON property dateRange



6969
6970
6971
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6969

def date_range
  @date_range
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


6974
6975
6976
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6974

def etag
  @etag
end

#file_nameString

The filename of the file. Corresponds to the JSON property fileName

Returns:

  • (String)


6979
6980
6981
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6979

def file_name
  @file_name
end

#formatString

The output format of the report. Only available once the file is available. Corresponds to the JSON property format

Returns:

  • (String)


6984
6985
6986
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6984

def format
  @format
end

#idFixnum

The unique ID of this report file. Corresponds to the JSON property id

Returns:

  • (Fixnum)


6989
6990
6991
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6989

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#file". Corresponds to the JSON property kind

Returns:

  • (String)


6995
6996
6997
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6995

def kind
  @kind
end

#last_modified_timeFixnum

The timestamp in milliseconds since epoch when this file was last modified. Corresponds to the JSON property lastModifiedTime

Returns:

  • (Fixnum)


7000
7001
7002
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7000

def last_modified_time
  @last_modified_time
end

#report_idFixnum

The ID of the report this file was generated from. Corresponds to the JSON property reportId

Returns:

  • (Fixnum)


7005
7006
7007
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7005

def report_id
  @report_id
end

#statusString

The status of the report file. Corresponds to the JSON property status

Returns:

  • (String)


7010
7011
7012
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7010

def status
  @status
end

#urlsGoogle::Apis::DfareportingV5::File::Urls

The URLs where the completed report file can be downloaded. Corresponds to the JSON property urls



7015
7016
7017
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7015

def urls
  @urls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7022

def update!(**args)
  @date_range = args[:date_range] if args.key?(:date_range)
  @etag = args[:etag] if args.key?(:etag)
  @file_name = args[:file_name] if args.key?(:file_name)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @report_id = args[:report_id] if args.key?(:report_id)
  @status = args[:status] if args.key?(:status)
  @urls = args[:urls] if args.key?(:urls)
end