Class: Google::Apis::DfareportingV5::FileList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

List of files for a report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileList

Returns a new instance of FileList.



7123
7124
7125
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7102
7103
7104
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7102

def etag
  @etag
end

#itemsArray<Google::Apis::DfareportingV5::File>

The files returned in this response. Corresponds to the JSON property items



7107
7108
7109
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7107

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#fileList". Corresponds to the JSON property kind

Returns:

  • (String)


7113
7114
7115
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7113

def kind
  @kind
end

#next_page_tokenString

Continuation token used to page through files. To retrieve the next page of results, set the next request's "pageToken" to the value of this field. The page token is only valid for a limited amount of time and should not be persisted. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7121
7122
7123
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7121

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7128
7129
7130
7131
7132
7133
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7128

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end