Class: Google::Apis::DfareportingV5::FloodlightActivityGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::FloodlightActivityGroupsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Floodlight Activity Group List Response
Instance Attribute Summary collapse
-
#floodlight_activity_groups ⇒ Array<Google::Apis::DfareportingV5::FloodlightActivityGroup>
Floodlight activity group collection.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloodlightActivityGroupsListResponse
constructor
A new instance of FloodlightActivityGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloodlightActivityGroupsListResponse
Returns a new instance of FloodlightActivityGroupsListResponse.
7544 7545 7546 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#floodlight_activity_groups ⇒ Array<Google::Apis::DfareportingV5::FloodlightActivityGroup>
Floodlight activity group collection.
Corresponds to the JSON property floodlightActivityGroups
7531 7532 7533 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7531 def floodlight_activity_groups @floodlight_activity_groups end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#floodlightActivityGroupsListResponse".
Corresponds to the JSON property kind
7537 7538 7539 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7537 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
7542 7543 7544 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7542 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7549 7550 7551 7552 7553 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7549 def update!(**args) @floodlight_activity_groups = args[:floodlight_activity_groups] if args.key?(:floodlight_activity_groups) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |