Class: Google::Apis::DfareportingV5::FloodlightReportCompatibleFields
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::FloodlightReportCompatibleFields
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents fields that are compatible to be selected for a report of type " FlOODLIGHT".
Instance Attribute Summary collapse
-
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Dimensions which are compatible to be selected in the "dimensionFilters" section of the report.
-
#dimensions ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Dimensions which are compatible to be selected in the "dimensions" section of the report.
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting# floodlightReportCompatibleFields.
-
#metrics ⇒ Array<Google::Apis::DfareportingV5::Metric>
Metrics which are compatible to be selected in the "metricNames" section of the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloodlightReportCompatibleFields
constructor
A new instance of FloodlightReportCompatibleFields.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloodlightReportCompatibleFields
Returns a new instance of FloodlightReportCompatibleFields.
7793 7794 7795 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Dimensions which are compatible to be selected in the "dimensionFilters"
section of the report.
Corresponds to the JSON property dimensionFilters
7773 7774 7775 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7773 def dimension_filters @dimension_filters end |
#dimensions ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Dimensions which are compatible to be selected in the "dimensions" section of
the report.
Corresponds to the JSON property dimensions
7779 7780 7781 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7779 def dimensions @dimensions end |
#kind ⇒ String
The kind of resource this is, in this case dfareporting#
floodlightReportCompatibleFields.
Corresponds to the JSON property kind
7785 7786 7787 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7785 def kind @kind end |
#metrics ⇒ Array<Google::Apis::DfareportingV5::Metric>
Metrics which are compatible to be selected in the "metricNames" section of
the report.
Corresponds to the JSON property metrics
7791 7792 7793 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7791 def metrics @metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7798 7799 7800 7801 7802 7803 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7798 def update!(**args) @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters) @dimensions = args[:dimensions] if args.key?(:dimensions) @kind = args[:kind] if args.key?(:kind) @metrics = args[:metrics] if args.key?(:metrics) end |