Class: Google::Apis::DfareportingV5::FrequencyCap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Frequency Cap.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FrequencyCap

Returns a new instance of FrequencyCap.



7856
7857
7858
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationFixnum

Duration of time, in seconds, for this frequency cap. The maximum duration is 90 days. Acceptable values are 1 to 7776000, inclusive. Corresponds to the JSON property duration

Returns:

  • (Fixnum)


7848
7849
7850
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7848

def duration
  @duration
end

#impressionsFixnum

Number of times an individual user can be served the ad within the specified duration. Acceptable values are 1 to 15, inclusive. Corresponds to the JSON property impressions

Returns:

  • (Fixnum)


7854
7855
7856
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7854

def impressions
  @impressions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7861
7862
7863
7864
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7861

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @impressions = args[:impressions] if args.key?(:impressions)
end