Class: Google::Apis::DfareportingV5::FsCommand
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::FsCommand
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
FsCommand.
Instance Attribute Summary collapse
-
#left ⇒ Fixnum
Distance from the left of the browser.Applicable when positionOption is DISTANCE_FROM_TOP_LEFT_CORNER.
-
#position_option ⇒ String
Position in the browser where the window will open.
-
#top ⇒ Fixnum
Distance from the top of the browser.
-
#window_height ⇒ Fixnum
Height of the window.
-
#window_width ⇒ Fixnum
Width of the window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FsCommand
constructor
A new instance of FsCommand.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FsCommand
Returns a new instance of FsCommand.
7898 7899 7900 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#left ⇒ Fixnum
Distance from the left of the browser.Applicable when positionOption is
DISTANCE_FROM_TOP_LEFT_CORNER.
Corresponds to the JSON property left
7875 7876 7877 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7875 def left @left end |
#position_option ⇒ String
Position in the browser where the window will open.
Corresponds to the JSON property positionOption
7880 7881 7882 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7880 def position_option @position_option end |
#top ⇒ Fixnum
Distance from the top of the browser. Applicable when positionOption is
DISTANCE_FROM_TOP_LEFT_CORNER.
Corresponds to the JSON property top
7886 7887 7888 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7886 def top @top end |
#window_height ⇒ Fixnum
Height of the window.
Corresponds to the JSON property windowHeight
7891 7892 7893 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7891 def window_height @window_height end |
#window_width ⇒ Fixnum
Width of the window.
Corresponds to the JSON property windowWidth
7896 7897 7898 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7896 def window_width @window_width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7903 7904 7905 7906 7907 7908 7909 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7903 def update!(**args) @left = args[:left] if args.key?(:left) @position_option = args[:position_option] if args.key?(:position_option) @top = args[:top] if args.key?(:top) @window_height = args[:window_height] if args.key?(:window_height) @window_width = args[:window_width] if args.key?(:window_width) end |