Class: Google::Apis::DfareportingV5::GeoTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Geographical Targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeoTargeting

Returns a new instance of GeoTargeting.



7963
7964
7965
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#citiesArray<Google::Apis::DfareportingV5::City>

Cities to be targeted. For each city only dartId is required. The other fields are populated automatically when the ad is inserted or updated. If targeting a city, do not target or exclude the country of the city, and do not target the metro or region of the city. Corresponds to the JSON property cities



7922
7923
7924
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7922

def cities
  @cities
end

#countriesArray<Google::Apis::DfareportingV5::Country>

Countries to be targeted or excluded from targeting, depending on the setting of the excludeCountries field. For each country only dartId is required. The other fields are populated automatically when the ad is inserted or updated. If targeting or excluding a country, do not target regions, cities, metros, or postal codes in the same country. Corresponds to the JSON property countries



7931
7932
7933
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7931

def countries
  @countries
end

#exclude_countriesBoolean Also known as: exclude_countries?

Whether or not to exclude the countries in the countries field from targeting. If false, the countries field refers to countries which will be targeted by the ad. Corresponds to the JSON property excludeCountries

Returns:

  • (Boolean)


7938
7939
7940
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7938

def exclude_countries
  @exclude_countries
end

#metrosArray<Google::Apis::DfareportingV5::Metro>

Metros to be targeted. For each metro only dmaId is required. The other fields are populated automatically when the ad is inserted or updated. If targeting a metro, do not target or exclude the country of the metro. Corresponds to the JSON property metros



7946
7947
7948
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7946

def metros
  @metros
end

#postal_codesArray<Google::Apis::DfareportingV5::PostalCode>

Postal codes to be targeted. For each postal code only id is required. The other fields are populated automatically when the ad is inserted or updated. If targeting a postal code, do not target or exclude the country of the postal code. Corresponds to the JSON property postalCodes



7954
7955
7956
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7954

def postal_codes
  @postal_codes
end

#regionsArray<Google::Apis::DfareportingV5::Region>

Regions to be targeted. For each region only dartId is required. The other fields are populated automatically when the ad is inserted or updated. If targeting a region, do not target or exclude the country of the region. Corresponds to the JSON property regions



7961
7962
7963
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7961

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7968
7969
7970
7971
7972
7973
7974
7975
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7968

def update!(**args)
  @cities = args[:cities] if args.key?(:cities)
  @countries = args[:countries] if args.key?(:countries)
  @exclude_countries = args[:exclude_countries] if args.key?(:exclude_countries)
  @metros = args[:metros] if args.key?(:metros)
  @postal_codes = args[:postal_codes] if args.key?(:postal_codes)
  @regions = args[:regions] if args.key?(:regions)
end