Class: Google::Apis::DfareportingV5::IngestionErrorRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains the ingestion error record of the dynamic feed. limited to 100 records.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestionErrorRecord

Returns a new instance of IngestionErrorRecord.



7993
7994
7995
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::DfareportingV5::FieldError>

Output only. The list of field errors of the ingestion error record. Corresponds to the JSON property errors



7986
7987
7988
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7986

def errors
  @errors
end

#record_idString

Output only. The record ID of the ingestion error record. Corresponds to the JSON property recordId

Returns:

  • (String)


7991
7992
7993
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7991

def record_id
  @record_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7998
7999
8000
8001
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7998

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
  @record_id = args[:record_id] if args.key?(:record_id)
end