Class: Google::Apis::DfareportingV5::LandingPage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains information about where a user's browser is taken after the user clicks an ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LandingPage

Returns a new instance of LandingPage.



8240
8241
8242
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Advertiser ID of this landing page. This is a required field. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


8205
8206
8207
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8205

def advertiser_id
  @advertiser_id
end

#archivedBoolean Also known as: archived?

Whether this landing page has been archived. Corresponds to the JSON property archived

Returns:

  • (Boolean)


8210
8211
8212
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8210

def archived
  @archived
end

Links that will direct the user to a mobile app, if installed. Corresponds to the JSON property deepLinks



8216
8217
8218
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8216

def deep_links
  @deep_links
end

#idFixnum

ID of this landing page. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


8221
8222
8223
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8221

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#landingPage". Corresponds to the JSON property kind

Returns:

  • (String)


8227
8228
8229
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8227

def kind
  @kind
end

#nameString

Name of this landing page. This is a required field. It must be less than 256 characters long. Corresponds to the JSON property name

Returns:

  • (String)


8233
8234
8235
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8233

def name
  @name
end

#urlString

URL of this landing page. This is a required field. Corresponds to the JSON property url

Returns:

  • (String)


8238
8239
8240
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8238

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8245
8246
8247
8248
8249
8250
8251
8252
8253
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8245

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @archived = args[:archived] if args.key?(:archived)
  @deep_links = args[:deep_links] if args.key?(:deep_links)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @url = args[:url] if args.key?(:url)
end