Class: Google::Apis::DfareportingV5::Language

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains information about a language that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Language

Returns a new instance of Language.



8250
8251
8252
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Language ID of this language. This is the ID used for targeting and generating reports. Corresponds to the JSON property id

Returns:

  • (Fixnum)


8230
8231
8232
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8230

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#language". Corresponds to the JSON property kind

Returns:

  • (String)


8236
8237
8238
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8236

def kind
  @kind
end

#language_codeString

Format of language code is an ISO 639 two-letter language code optionally followed by an underscore followed by an ISO 3166 code. Examples are "en" for English or "zh_CN" for Simplified Chinese. Corresponds to the JSON property languageCode

Returns:

  • (String)


8243
8244
8245
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8243

def language_code
  @language_code
end

#nameString

Name of this language. Corresponds to the JSON property name

Returns:

  • (String)


8248
8249
8250
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8248

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8255
8256
8257
8258
8259
8260
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8255

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @language_code = args[:language_code] if args.key?(:language_code)
  @name = args[:name] if args.key?(:name)
end