Class: Google::Apis::DfareportingV5::ListPopulationClause

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

A group clause made up of list population terms representing constraints joined by ORs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPopulationClause

Returns a new instance of ListPopulationClause.



8374
8375
8376
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#termsArray<Google::Apis::DfareportingV5::ListPopulationTerm>

Terms of this list population clause. Each clause is made up of list population terms representing constraints and are joined by ORs. Corresponds to the JSON property terms



8372
8373
8374
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8372

def terms
  @terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8379
8380
8381
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8379

def update!(**args)
  @terms = args[:terms] if args.key?(:terms)
end