Class: Google::Apis::DfareportingV5::ListPopulationRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Remarketing List Population Rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPopulationRule

Returns a new instance of ListPopulationRule.



8406
8407
8408
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activity_idFixnum

Floodlight activity ID associated with this rule. This field can be left blank. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


8391
8392
8393
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8391

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_activity_nameString

Name of floodlight activity associated with this rule. This is a read-only, auto-generated field. Corresponds to the JSON property floodlightActivityName

Returns:

  • (String)


8397
8398
8399
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8397

def floodlight_activity_name
  @floodlight_activity_name
end

#list_population_clausesArray<Google::Apis::DfareportingV5::ListPopulationClause>

Clauses that make up this list population rule. Clauses are joined by ANDs, and the clauses themselves are made up of list population terms which are joined by ORs. Corresponds to the JSON property listPopulationClauses



8404
8405
8406
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8404

def list_population_clauses
  @list_population_clauses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8411
8412
8413
8414
8415
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8411

def update!(**args)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_activity_name = args[:floodlight_activity_name] if args.key?(:floodlight_activity_name)
  @list_population_clauses = args[:list_population_clauses] if args.key?(:list_population_clauses)
end