Class: Google::Apis::DfareportingV5::LookbackConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Lookback configuration settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LookbackConfiguration

Returns a new instance of LookbackConfiguration.



8534
8535
8536
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#click_durationFixnum

Lookback window, in days, from the last time a given user clicked on one of your ads. If you enter 0, clicks will not be considered as triggering events for floodlight tracking. If you leave this field blank, the default value for your account will be used. Acceptable values are 0 to 90, inclusive. Corresponds to the JSON property clickDuration

Returns:

  • (Fixnum)


8524
8525
8526
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8524

def click_duration
  @click_duration
end

#post_impression_activities_durationFixnum

Lookback window, in days, from the last time a given user viewed one of your ads. If you enter 0, impressions will not be considered as triggering events for floodlight tracking. If you leave this field blank, the default value for your account will be used. Acceptable values are 0 to 90, inclusive. Corresponds to the JSON property postImpressionActivitiesDuration

Returns:

  • (Fixnum)


8532
8533
8534
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8532

def post_impression_activities_duration
  @post_impression_activities_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8539
8540
8541
8542
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8539

def update!(**args)
  @click_duration = args[:click_duration] if args.key?(:click_duration)
  @post_impression_activities_duration = args[:post_impression_activities_duration] if args.key?(:post_impression_activities_duration)
end