Class: Google::Apis::DfareportingV5::Metro

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains information about a metro region that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Metro

Returns a new instance of Metro.



8710
8711
8712
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Country code of the country to which this metro region belongs. Corresponds to the JSON property countryCode

Returns:

  • (String)


8676
8677
8678
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8676

def country_code
  @country_code
end

#country_dart_idFixnum

DART ID of the country to which this metro region belongs. Corresponds to the JSON property countryDartId

Returns:

  • (Fixnum)


8681
8682
8683
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8681

def country_dart_id
  @country_dart_id
end

#dart_idFixnum

DART ID of this metro region. Corresponds to the JSON property dartId

Returns:

  • (Fixnum)


8686
8687
8688
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8686

def dart_id
  @dart_id
end

#dma_idFixnum

DMA ID of this metro region. This is the ID used for targeting and generating reports, and is equivalent to metro_code. Corresponds to the JSON property dmaId

Returns:

  • (Fixnum)


8692
8693
8694
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8692

def dma_id
  @dma_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#metro". Corresponds to the JSON property kind

Returns:

  • (String)


8698
8699
8700
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8698

def kind
  @kind
end

#metro_codeString

Metro code of this metro region. This is equivalent to dma_id. Corresponds to the JSON property metroCode

Returns:

  • (String)


8703
8704
8705
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8703

def metro_code
  @metro_code
end

#nameString

Name of this metro region. Corresponds to the JSON property name

Returns:

  • (String)


8708
8709
8710
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8708

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8715
8716
8717
8718
8719
8720
8721
8722
8723
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8715

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @country_dart_id = args[:country_dart_id] if args.key?(:country_dart_id)
  @dart_id = args[:dart_id] if args.key?(:dart_id)
  @dma_id = args[:dma_id] if args.key?(:dma_id)
  @kind = args[:kind] if args.key?(:kind)
  @metro_code = args[:metro_code] if args.key?(:metro_code)
  @name = args[:name] if args.key?(:name)
end