Class: Google::Apis::DfareportingV5::MobileCarrier
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::MobileCarrier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains information about a mobile carrier that can be targeted by ads.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Country code of the country to which this mobile carrier belongs.
-
#country_dart_id ⇒ Fixnum
DART ID of the country to which this mobile carrier belongs.
-
#id ⇒ Fixnum
ID of this mobile carrier.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this mobile carrier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MobileCarrier
constructor
A new instance of MobileCarrier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MobileCarrier
Returns a new instance of MobileCarrier.
8858 8859 8860 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Country code of the country to which this mobile carrier belongs.
Corresponds to the JSON property countryCode
8835 8836 8837 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8835 def country_code @country_code end |
#country_dart_id ⇒ Fixnum
DART ID of the country to which this mobile carrier belongs.
Corresponds to the JSON property countryDartId
8840 8841 8842 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8840 def country_dart_id @country_dart_id end |
#id ⇒ Fixnum
ID of this mobile carrier.
Corresponds to the JSON property id
8845 8846 8847 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8845 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#mobileCarrier".
Corresponds to the JSON property kind
8851 8852 8853 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8851 def kind @kind end |
#name ⇒ String
Name of this mobile carrier.
Corresponds to the JSON property name
8856 8857 8858 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8856 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8863 8864 8865 8866 8867 8868 8869 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8863 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @country_dart_id = args[:country_dart_id] if args.key?(:country_dart_id) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) end |