Class: Google::Apis::DfareportingV5::ObaIcon
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::ObaIcon
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Online Behavioral Advertiser icon.
Instance Attribute Summary collapse
-
#icon_click_through_url ⇒ String
URL to redirect to when an OBA icon is clicked.
-
#icon_click_tracking_url ⇒ String
URL to track click when an OBA icon is clicked.
-
#icon_view_tracking_url ⇒ String
URL to track view when an OBA icon is clicked.
-
#program ⇒ String
Identifies the industry initiative that the icon supports.
-
#resource_url ⇒ String
OBA icon resource URL.
-
#size ⇒ Google::Apis::DfareportingV5::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#x_position ⇒ String
OBA icon x coordinate position.
-
#y_position ⇒ String
OBA icon y coordinate position.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObaIcon
constructor
A new instance of ObaIcon.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObaIcon
Returns a new instance of ObaIcon.
8910 8911 8912 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#icon_click_through_url ⇒ String
URL to redirect to when an OBA icon is clicked.
Corresponds to the JSON property iconClickThroughUrl
8871 8872 8873 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8871 def icon_click_through_url @icon_click_through_url end |
#icon_click_tracking_url ⇒ String
URL to track click when an OBA icon is clicked.
Corresponds to the JSON property iconClickTrackingUrl
8876 8877 8878 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8876 def icon_click_tracking_url @icon_click_tracking_url end |
#icon_view_tracking_url ⇒ String
URL to track view when an OBA icon is clicked.
Corresponds to the JSON property iconViewTrackingUrl
8881 8882 8883 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8881 def icon_view_tracking_url @icon_view_tracking_url end |
#program ⇒ String
Identifies the industry initiative that the icon supports. For example,
AdChoices.
Corresponds to the JSON property program
8887 8888 8889 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8887 def program @program end |
#resource_url ⇒ String
OBA icon resource URL. Campaign Manager only supports image and JavaScript
icons. Learn more
Corresponds to the JSON property resourceUrl
8893 8894 8895 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8893 def resource_url @resource_url end |
#size ⇒ Google::Apis::DfareportingV5::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property size
8898 8899 8900 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8898 def size @size end |
#x_position ⇒ String
OBA icon x coordinate position. Accepted values are left or right.
Corresponds to the JSON property xPosition
8903 8904 8905 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8903 def x_position @x_position end |
#y_position ⇒ String
OBA icon y coordinate position. Accepted values are top or bottom.
Corresponds to the JSON property yPosition
8908 8909 8910 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8908 def y_position @y_position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8915 def update!(**args) @icon_click_through_url = args[:icon_click_through_url] if args.key?(:icon_click_through_url) @icon_click_tracking_url = args[:icon_click_tracking_url] if args.key?(:icon_click_tracking_url) @icon_view_tracking_url = args[:icon_view_tracking_url] if args.key?(:icon_view_tracking_url) @program = args[:program] if args.key?(:program) @resource_url = args[:resource_url] if args.key?(:resource_url) @size = args[:size] if args.key?(:size) @x_position = args[:x_position] if args.key?(:x_position) @y_position = args[:y_position] if args.key?(:y_position) end |