Class: Google::Apis::DfareportingV5::OfflineUserAddressInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Identify a user by name and address.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OfflineUserAddressInfo

Returns a new instance of OfflineUserAddressInfo.



9038
9039
9040
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cityString

City of the address. Corresponds to the JSON property city

Returns:

  • (String)


9003
9004
9005
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9003

def city
  @city
end

#country_codeString

2-letter country code in ISO-3166-1 alpha-2 of the user's address. Corresponds to the JSON property countryCode

Returns:

  • (String)


9008
9009
9010
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9008

def country_code
  @country_code
end

#hashed_first_nameString

First name of the user, which is hashed as SHA-256 after normalized (Lowercase all characters; Remove any extra spaces before, after, and in between). Corresponds to the JSON property hashedFirstName

Returns:

  • (String)


9014
9015
9016
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9014

def hashed_first_name
  @hashed_first_name
end

#hashed_last_nameString

Last name of the user, which is hashed as SHA-256 after normalized (lower case only and no punctuation). Corresponds to the JSON property hashedLastName

Returns:

  • (String)


9020
9021
9022
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9020

def hashed_last_name
  @hashed_last_name
end

#hashed_street_addressString

The street address of the user hashed using SHA-256 hash function after normalization (lower case only). Corresponds to the JSON property hashedStreetAddress

Returns:

  • (String)


9026
9027
9028
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9026

def hashed_street_address
  @hashed_street_address
end

#postal_codeString

Postal code of the user's address. Corresponds to the JSON property postalCode

Returns:

  • (String)


9031
9032
9033
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9031

def postal_code
  @postal_code
end

#stateString

State code of the address. Corresponds to the JSON property state

Returns:

  • (String)


9036
9037
9038
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9036

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9043

def update!(**args)
  @city = args[:city] if args.key?(:city)
  @country_code = args[:country_code] if args.key?(:country_code)
  @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name)
  @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name)
  @hashed_street_address = args[:hashed_street_address] if args.key?(:hashed_street_address)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @state = args[:state] if args.key?(:state)
end