Class: Google::Apis::DfareportingV5::OffsetPosition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Offset Position.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OffsetPosition

Returns a new instance of OffsetPosition.



9068
9069
9070
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#leftFixnum

Offset distance from left side of an asset or a window. Corresponds to the JSON property left

Returns:

  • (Fixnum)


9061
9062
9063
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9061

def left
  @left
end

#topFixnum

Offset distance from top side of an asset or a window. Corresponds to the JSON property top

Returns:

  • (Fixnum)


9066
9067
9068
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9066

def top
  @top
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9073
9074
9075
9076
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9073

def update!(**args)
  @left = args[:left] if args.key?(:left)
  @top = args[:top] if args.key?(:top)
end