Class: Google::Apis::DfareportingV5::OperatingSystemVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains information about a particular version of an operating system that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperatingSystemVersion

Returns a new instance of OperatingSystemVersion.



9156
9157
9158
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

ID of this operating system version. Corresponds to the JSON property id

Returns:

  • (Fixnum)


9128
9129
9130
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9128

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#operatingSystemVersion". Corresponds to the JSON property kind

Returns:

  • (String)


9134
9135
9136
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9134

def kind
  @kind
end

#major_versionString

Major version (leftmost number) of this operating system version. Corresponds to the JSON property majorVersion

Returns:

  • (String)


9139
9140
9141
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9139

def major_version
  @major_version
end

#minor_versionString

Minor version (number after the first dot) of this operating system version. Corresponds to the JSON property minorVersion

Returns:

  • (String)


9144
9145
9146
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9144

def minor_version
  @minor_version
end

#nameString

Name of this operating system version. Corresponds to the JSON property name

Returns:

  • (String)


9149
9150
9151
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9149

def name
  @name
end

#operating_systemGoogle::Apis::DfareportingV5::OperatingSystem

Contains information about an operating system that can be targeted by ads. Corresponds to the JSON property operatingSystem



9154
9155
9156
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9154

def operating_system
  @operating_system
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9161
9162
9163
9164
9165
9166
9167
9168
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9161

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @major_version = args[:major_version] if args.key?(:major_version)
  @minor_version = args[:minor_version] if args.key?(:minor_version)
  @name = args[:name] if args.key?(:name)
  @operating_system = args[:operating_system] if args.key?(:operating_system)
end