Class: Google::Apis::DfareportingV5::OptimizationActivity
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::OptimizationActivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Creative optimization activity.
Instance Attribute Summary collapse
-
#floodlight_activity_id ⇒ Fixnum
Floodlight activity ID of this optimization activity.
-
#floodlight_activity_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#weight ⇒ Fixnum
Weight associated with this optimization.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OptimizationActivity
constructor
A new instance of OptimizationActivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OptimizationActivity
Returns a new instance of OptimizationActivity.
9278 9279 9280 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#floodlight_activity_id ⇒ Fixnum
Floodlight activity ID of this optimization activity. This is a required field.
Corresponds to the JSON property floodlightActivityId
9264 9265 9266 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9264 def floodlight_activity_id @floodlight_activity_id end |
#floodlight_activity_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property floodlightActivityIdDimensionValue
9269 9270 9271 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9269 def floodlight_activity_id_dimension_value @floodlight_activity_id_dimension_value end |
#weight ⇒ Fixnum
Weight associated with this optimization. The weight assigned will be
understood in proportion to the weights assigned to the other optimization
activities. Value must be greater than or equal to 1.
Corresponds to the JSON property weight
9276 9277 9278 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9276 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9283 9284 9285 9286 9287 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9283 def update!(**args) @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id) @floodlight_activity_id_dimension_value = args[:floodlight_activity_id_dimension_value] if args.key?(:floodlight_activity_id_dimension_value) @weight = args[:weight] if args.key?(:weight) end |