Class: Google::Apis::DfareportingV5::PlacementGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a package or roadblock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlacementGroup

Returns a new instance of PlacementGroup.



9910
9911
9912
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this placement group. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


9765
9766
9767
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9765

def 
  @account_id
end

#active_statusString

Whether this placement group is active, inactive, archived or permanently archived. Corresponds to the JSON property activeStatus

Returns:

  • (String)


9771
9772
9773
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9771

def active_status
  @active_status
end

#advertiser_idFixnum

Advertiser ID of this placement group. This is a required field on insertion. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


9776
9777
9778
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9776

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



9781
9782
9783
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9781

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#campaign_idFixnum

Campaign ID of this placement group. This field is required on insertion. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


9786
9787
9788
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9786

def campaign_id
  @campaign_id
end

#campaign_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property campaignIdDimensionValue



9791
9792
9793
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9791

def campaign_id_dimension_value
  @campaign_id_dimension_value
end

#child_placement_idsArray<Fixnum>

IDs of placements which are assigned to this placement group. This is a read- only, auto-generated field. Corresponds to the JSON property childPlacementIds

Returns:

  • (Array<Fixnum>)


9797
9798
9799
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9797

def child_placement_ids
  @child_placement_ids
end

#commentString

Comments for this placement group. Corresponds to the JSON property comment

Returns:

  • (String)


9802
9803
9804
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9802

def comment
  @comment
end

#content_category_idFixnum

ID of the content category assigned to this placement group. Corresponds to the JSON property contentCategoryId

Returns:

  • (Fixnum)


9807
9808
9809
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9807

def 
  @content_category_id
end

#create_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



9812
9813
9814
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9812

def create_info
  @create_info
end

#directory_site_idFixnum

Directory site ID associated with this placement group. On insert, you must set either this field or the site_id field to specify the site associated with this placement group. This is a required field that is read-only after insertion. Corresponds to the JSON property directorySiteId

Returns:

  • (Fixnum)


9820
9821
9822
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9820

def directory_site_id
  @directory_site_id
end

#directory_site_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property directorySiteIdDimensionValue



9825
9826
9827
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9825

def directory_site_id_dimension_value
  @directory_site_id_dimension_value
end

#external_idString

External ID for this placement. Corresponds to the JSON property externalId

Returns:

  • (String)


9830
9831
9832
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9830

def external_id
  @external_id
end

#idFixnum

ID of this placement group. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


9835
9836
9837
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9835

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



9840
9841
9842
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9840

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#placementGroup". Corresponds to the JSON property kind

Returns:

  • (String)


9846
9847
9848
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9846

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



9851
9852
9853
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9851

def last_modified_info
  @last_modified_info
end

#nameString

Name of this placement group. This is a required field and must be less than 256 characters long. Corresponds to the JSON property name

Returns:

  • (String)


9857
9858
9859
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9857

def name
  @name
end

#placement_group_typeString

Type of this placement group. A package is a simple group of placements that acts as a single pricing point for a group of tags. A roadblock is a group of placements that not only acts as a single pricing point, but also assumes that all the tags in it will be served at the same time. A roadblock requires one of its assigned placements to be marked as primary for reporting. This field is required on insertion. Corresponds to the JSON property placementGroupType

Returns:

  • (String)


9867
9868
9869
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9867

def placement_group_type
  @placement_group_type
end

#placement_strategy_idFixnum

ID of the placement strategy assigned to this placement group. Corresponds to the JSON property placementStrategyId

Returns:

  • (Fixnum)


9872
9873
9874
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9872

def placement_strategy_id
  @placement_strategy_id
end

#pricing_scheduleGoogle::Apis::DfareportingV5::PricingSchedule

Pricing Schedule Corresponds to the JSON property pricingSchedule



9877
9878
9879
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9877

def pricing_schedule
  @pricing_schedule
end

#primary_placement_idFixnum

ID of the primary placement, used to calculate the media cost of a roadblock ( placement group). Modifying this field will automatically modify the primary field on all affected roadblock child placements. Corresponds to the JSON property primaryPlacementId

Returns:

  • (Fixnum)


9884
9885
9886
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9884

def primary_placement_id
  @primary_placement_id
end

#primary_placement_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property primaryPlacementIdDimensionValue



9889
9890
9891
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9889

def primary_placement_id_dimension_value
  @primary_placement_id_dimension_value
end

#site_idFixnum

Site ID associated with this placement group. On insert, you must set either this field or the directorySiteId field to specify the site associated with this placement group. This is a required field that is read-only after insertion. Corresponds to the JSON property siteId

Returns:

  • (Fixnum)


9897
9898
9899
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9897

def site_id
  @site_id
end

#site_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property siteIdDimensionValue



9902
9903
9904
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9902

def site_id_dimension_value
  @site_id_dimension_value
end

#subaccount_idFixnum

Subaccount ID of this placement group. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


9908
9909
9910
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9908

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9915
9916
9917
9918
9919
9920
9921
9922
9923
9924
9925
9926
9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9915

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @active_status = args[:active_status] if args.key?(:active_status)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @campaign_id_dimension_value = args[:campaign_id_dimension_value] if args.key?(:campaign_id_dimension_value)
  @child_placement_ids = args[:child_placement_ids] if args.key?(:child_placement_ids)
  @comment = args[:comment] if args.key?(:comment)
  @content_category_id = args[:content_category_id] if args.key?(:content_category_id)
  @create_info = args[:create_info] if args.key?(:create_info)
  @directory_site_id = args[:directory_site_id] if args.key?(:directory_site_id)
  @directory_site_id_dimension_value = args[:directory_site_id_dimension_value] if args.key?(:directory_site_id_dimension_value)
  @external_id = args[:external_id] if args.key?(:external_id)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @placement_group_type = args[:placement_group_type] if args.key?(:placement_group_type)
  @placement_strategy_id = args[:placement_strategy_id] if args.key?(:placement_strategy_id)
  @pricing_schedule = args[:pricing_schedule] if args.key?(:pricing_schedule)
  @primary_placement_id = args[:primary_placement_id] if args.key?(:primary_placement_id)
  @primary_placement_id_dimension_value = args[:primary_placement_id_dimension_value] if args.key?(:primary_placement_id_dimension_value)
  @site_id = args[:site_id] if args.key?(:site_id)
  @site_id_dimension_value = args[:site_id_dimension_value] if args.key?(:site_id_dimension_value)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end