Class: Google::Apis::DfareportingV5::PopupWindowProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Popup Window Properties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PopupWindowProperties

Returns a new instance of PopupWindowProperties.



10270
10271
10272
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionGoogle::Apis::DfareportingV5::Size

Represents the dimensions of ads, placements, creatives, or creative assets. Corresponds to the JSON property dimension



10223
10224
10225
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10223

def dimension
  @dimension
end

#offsetGoogle::Apis::DfareportingV5::OffsetPosition

Offset Position. Corresponds to the JSON property offset



10228
10229
10230
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10228

def offset
  @offset
end

#position_typeString

Popup window position either centered or at specific coordinate. Corresponds to the JSON property positionType

Returns:

  • (String)


10233
10234
10235
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10233

def position_type
  @position_type
end

#show_address_barBoolean Also known as: show_address_bar?

Whether to display the browser address bar. Corresponds to the JSON property showAddressBar

Returns:

  • (Boolean)


10238
10239
10240
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10238

def show_address_bar
  @show_address_bar
end

#show_menu_barBoolean Also known as: show_menu_bar?

Whether to display the browser menu bar. Corresponds to the JSON property showMenuBar

Returns:

  • (Boolean)


10244
10245
10246
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10244

def show_menu_bar
  @show_menu_bar
end

#show_scroll_barBoolean Also known as: show_scroll_bar?

Whether to display the browser scroll bar. Corresponds to the JSON property showScrollBar

Returns:

  • (Boolean)


10250
10251
10252
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10250

def show_scroll_bar
  @show_scroll_bar
end

#show_status_barBoolean Also known as: show_status_bar?

Whether to display the browser status bar. Corresponds to the JSON property showStatusBar

Returns:

  • (Boolean)


10256
10257
10258
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10256

def show_status_bar
  @show_status_bar
end

#show_tool_barBoolean Also known as: show_tool_bar?

Whether to display the browser tool bar. Corresponds to the JSON property showToolBar

Returns:

  • (Boolean)


10262
10263
10264
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10262

def show_tool_bar
  @show_tool_bar
end

#titleString

Title of popup window. Corresponds to the JSON property title

Returns:

  • (String)


10268
10269
10270
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10268

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10275
10276
10277
10278
10279
10280
10281
10282
10283
10284
10285
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10275

def update!(**args)
  @dimension = args[:dimension] if args.key?(:dimension)
  @offset = args[:offset] if args.key?(:offset)
  @position_type = args[:position_type] if args.key?(:position_type)
  @show_address_bar = args[:show_address_bar] if args.key?(:show_address_bar)
  @show_menu_bar = args[:show_menu_bar] if args.key?(:show_menu_bar)
  @show_scroll_bar = args[:show_scroll_bar] if args.key?(:show_scroll_bar)
  @show_status_bar = args[:show_status_bar] if args.key?(:show_status_bar)
  @show_tool_bar = args[:show_tool_bar] if args.key?(:show_tool_bar)
  @title = args[:title] if args.key?(:title)
end