Class: Google::Apis::DfareportingV5::PricingSchedulePricingPeriod
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::PricingSchedulePricingPeriod
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Pricing Period
Instance Attribute Summary collapse
-
#end_date ⇒ Date
Corresponds to the JSON property
endDate. -
#pricing_comment ⇒ String
Comments for this pricing period.
-
#rate_or_cost_nanos ⇒ Fixnum
Rate or cost of this pricing period in nanos (i.e., multiplied by 1000000000).
-
#start_date ⇒ Date
Corresponds to the JSON property
startDate. -
#units ⇒ Fixnum
Units of this pricing period.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PricingSchedulePricingPeriod
constructor
A new instance of PricingSchedulePricingPeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PricingSchedulePricingPeriod
Returns a new instance of PricingSchedulePricingPeriod.
10453 10454 10455 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Date
Corresponds to the JSON property endDate
10429 10430 10431 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10429 def end_date @end_date end |
#pricing_comment ⇒ String
Comments for this pricing period.
Corresponds to the JSON property pricingComment
10434 10435 10436 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10434 def pricing_comment @pricing_comment end |
#rate_or_cost_nanos ⇒ Fixnum
Rate or cost of this pricing period in nanos (i.e., multiplied by 1000000000).
Acceptable values are 0 to 1000000000000000000, inclusive.
Corresponds to the JSON property rateOrCostNanos
10440 10441 10442 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10440 def rate_or_cost_nanos @rate_or_cost_nanos end |
#start_date ⇒ Date
Corresponds to the JSON property startDate
10445 10446 10447 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10445 def start_date @start_date end |
#units ⇒ Fixnum
Units of this pricing period. Acceptable values are 0 to 10000000000,
inclusive.
Corresponds to the JSON property units
10451 10452 10453 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10451 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10458 10459 10460 10461 10462 10463 10464 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10458 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @pricing_comment = args[:pricing_comment] if args.key?(:pricing_comment) @rate_or_cost_nanos = args[:rate_or_cost_nanos] if args.key?(:rate_or_cost_nanos) @start_date = args[:start_date] if args.key?(:start_date) @units = args[:units] if args.key?(:units) end |