Class: Google::Apis::DfareportingV5::ReachReportCompatibleFields

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents fields that are compatible to be selected for a report of type " REACH".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReachReportCompatibleFields

Returns a new instance of ReachReportCompatibleFields.



10511
10512
10513
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_filtersArray<Google::Apis::DfareportingV5::Dimension>

Dimensions which are compatible to be selected in the "dimensionFilters" section of the report. Corresponds to the JSON property dimensionFilters



10479
10480
10481
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10479

def dimension_filters
  @dimension_filters
end

#dimensionsArray<Google::Apis::DfareportingV5::Dimension>

Dimensions which are compatible to be selected in the "dimensions" section of the report. Corresponds to the JSON property dimensions



10485
10486
10487
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10485

def dimensions
  @dimensions
end

#kindString

The kind of resource this is, in this case dfareporting# reachReportCompatibleFields. Corresponds to the JSON property kind

Returns:

  • (String)


10491
10492
10493
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10491

def kind
  @kind
end

#metricsArray<Google::Apis::DfareportingV5::Metric>

Metrics which are compatible to be selected in the "metricNames" section of the report. Corresponds to the JSON property metrics



10497
10498
10499
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10497

def metrics
  @metrics
end

#pivoted_activity_metricsArray<Google::Apis::DfareportingV5::Metric>

Metrics which are compatible to be selected as activity metrics to pivot on in the "activities" section of the report. Corresponds to the JSON property pivotedActivityMetrics



10503
10504
10505
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10503

def pivoted_activity_metrics
  @pivoted_activity_metrics
end

#reach_by_frequency_metricsArray<Google::Apis::DfareportingV5::Metric>

Metrics which are compatible to be selected in the " reachByFrequencyMetricNames" section of the report. Corresponds to the JSON property reachByFrequencyMetrics



10509
10510
10511
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10509

def reach_by_frequency_metrics
  @reach_by_frequency_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10516
10517
10518
10519
10520
10521
10522
10523
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10516

def update!(**args)
  @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @kind = args[:kind] if args.key?(:kind)
  @metrics = args[:metrics] if args.key?(:metrics)
  @pivoted_activity_metrics = args[:pivoted_activity_metrics] if args.key?(:pivoted_activity_metrics)
  @reach_by_frequency_metrics = args[:reach_by_frequency_metrics] if args.key?(:reach_by_frequency_metrics)
end