Class: Google::Apis::DfareportingV5::Recipient
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Recipient
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents a recipient.
Instance Attribute Summary collapse
-
#delivery_type ⇒ String
The delivery type for the recipient.
-
#email ⇒ String
The email address of the recipient.
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting#recipient.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Recipient
constructor
A new instance of Recipient.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Recipient
Returns a new instance of Recipient.
10545 10546 10547 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delivery_type ⇒ String
The delivery type for the recipient.
Corresponds to the JSON property deliveryType
10533 10534 10535 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10533 def delivery_type @delivery_type end |
#email ⇒ String
The email address of the recipient.
Corresponds to the JSON property email
10538 10539 10540 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10538 def email @email end |
#kind ⇒ String
The kind of resource this is, in this case dfareporting#recipient.
Corresponds to the JSON property kind
10543 10544 10545 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10543 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10550 10551 10552 10553 10554 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10550 def update!(**args) @delivery_type = args[:delivery_type] if args.key?(:delivery_type) @email = args[:email] if args.key?(:email) @kind = args[:kind] if args.key?(:kind) end |