Class: Google::Apis::DfareportingV5::Region

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains information about a region that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Region

Returns a new instance of Region.



10626
10627
10628
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Country code of the country to which this region belongs. Corresponds to the JSON property countryCode

Returns:

  • (String)


10598
10599
10600
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10598

def country_code
  @country_code
end

#country_dart_idFixnum

DART ID of the country to which this region belongs. Corresponds to the JSON property countryDartId

Returns:

  • (Fixnum)


10603
10604
10605
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10603

def country_dart_id
  @country_dart_id
end

#dart_idFixnum

DART ID of this region. Corresponds to the JSON property dartId

Returns:

  • (Fixnum)


10608
10609
10610
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10608

def dart_id
  @dart_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#region". Corresponds to the JSON property kind

Returns:

  • (String)


10614
10615
10616
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10614

def kind
  @kind
end

#nameString

Name of this region. Corresponds to the JSON property name

Returns:

  • (String)


10619
10620
10621
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10619

def name
  @name
end

#region_codeString

Region code. Corresponds to the JSON property regionCode

Returns:

  • (String)


10624
10625
10626
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10624

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10631
10632
10633
10634
10635
10636
10637
10638
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10631

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @country_dart_id = args[:country_dart_id] if args.key?(:country_dart_id)
  @dart_id = args[:dart_id] if args.key?(:dart_id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region_code = args[:region_code] if args.key?(:region_code)
end