Class: Google::Apis::DfareportingV5::RemarketingListShare

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a remarketing list's sharing information. Sharing allows other accounts or advertisers to target to your remarketing lists. This resource can be used to manage remarketing list sharing to other accounts and advertisers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemarketingListShare

Returns a new instance of RemarketingListShare.



10798
10799
10800
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#remarketingListShare". Corresponds to the JSON property kind

Returns:

  • (String)


10781
10782
10783
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10781

def kind
  @kind
end

#remarketing_list_idFixnum

Remarketing list ID. This is a read-only, auto-generated field. Corresponds to the JSON property remarketingListId

Returns:

  • (Fixnum)


10786
10787
10788
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10786

def remarketing_list_id
  @remarketing_list_id
end

#shared_account_idsArray<Fixnum>

Accounts that the remarketing list is shared with. Corresponds to the JSON property sharedAccountIds

Returns:

  • (Array<Fixnum>)


10791
10792
10793
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10791

def 
  @shared_account_ids
end

#shared_advertiser_idsArray<Fixnum>

Advertisers that the remarketing list is shared with. Corresponds to the JSON property sharedAdvertiserIds

Returns:

  • (Array<Fixnum>)


10796
10797
10798
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10796

def shared_advertiser_ids
  @shared_advertiser_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10803
10804
10805
10806
10807
10808
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10803

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @remarketing_list_id = args[:remarketing_list_id] if args.key?(:remarketing_list_id)
  @shared_account_ids = args[:shared_account_ids] if args.key?(:shared_account_ids)
  @shared_advertiser_ids = args[:shared_advertiser_ids] if args.key?(:shared_advertiser_ids)
end