Class: Google::Apis::DfareportingV5::RemarketingListsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::RemarketingListsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Remarketing list response
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
-
#remarketing_lists ⇒ Array<Google::Apis::DfareportingV5::RemarketingList>
Remarketing list collection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemarketingListsListResponse
constructor
A new instance of RemarketingListsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemarketingListsListResponse
Returns a new instance of RemarketingListsListResponse.
10797 10798 10799 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10797 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#remarketingListsListResponse".
Corresponds to the JSON property kind
10785 10786 10787 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10785 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
10790 10791 10792 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10790 def next_page_token @next_page_token end |
#remarketing_lists ⇒ Array<Google::Apis::DfareportingV5::RemarketingList>
Remarketing list collection.
Corresponds to the JSON property remarketingLists
10795 10796 10797 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10795 def remarketing_lists @remarketing_lists end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10802 10803 10804 10805 10806 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10802 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @remarketing_lists = args[:remarketing_lists] if args.key?(:remarketing_lists) end |