Class: Google::Apis::DfareportingV5::Report::PathToConversionCriteria::ReportProperties
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Report::PathToConversionCriteria::ReportProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
The properties of the report.
Instance Attribute Summary collapse
-
#clicks_lookback_window ⇒ Fixnum
CM360 checks to see if a click interaction occurred within the specified period of time before a conversion.
-
#impressions_lookback_window ⇒ Fixnum
CM360 checks to see if an impression interaction occurred within the specified period of time before a conversion.
-
#include_attributed_ip_conversions ⇒ Boolean
(also: #include_attributed_ip_conversions?)
Deprecated: has no effect.
-
#include_unattributed_cookie_conversions ⇒ Boolean
(also: #include_unattributed_cookie_conversions?)
Include conversions of users with a DoubleClick cookie but without an exposure.
-
#include_unattributed_ip_conversions ⇒ Boolean
(also: #include_unattributed_ip_conversions?)
Include conversions that have no associated cookies and no exposures.
-
#maximum_click_interactions ⇒ Fixnum
The maximum number of click interactions to include in the report.
-
#maximum_impression_interactions ⇒ Fixnum
The maximum number of click interactions to include in the report.
-
#maximum_interaction_gap ⇒ Fixnum
The maximum amount of time that can take place between interactions (clicks or impressions) by the same user.
-
#pivot_on_interaction_path ⇒ Boolean
(also: #pivot_on_interaction_path?)
Enable pivoting on interaction path.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportProperties
constructor
A new instance of ReportProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportProperties
Returns a new instance of ReportProperties.
11350 11351 11352 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clicks_lookback_window ⇒ Fixnum
CM360 checks to see if a click interaction occurred within the specified
period of time before a conversion. By default the value is pulled from
Floodlight or you can manually enter a custom value. Valid values: 1-90.
Corresponds to the JSON property clicksLookbackWindow
11291 11292 11293 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11291 def clicks_lookback_window @clicks_lookback_window end |
#impressions_lookback_window ⇒ Fixnum
CM360 checks to see if an impression interaction occurred within the specified
period of time before a conversion. By default the value is pulled from
Floodlight or you can manually enter a custom value. Valid values: 1-90.
Corresponds to the JSON property impressionsLookbackWindow
11298 11299 11300 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11298 def impressions_lookback_window @impressions_lookback_window end |
#include_attributed_ip_conversions ⇒ Boolean Also known as: include_attributed_ip_conversions?
Deprecated: has no effect.
Corresponds to the JSON property includeAttributedIPConversions
11303 11304 11305 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11303 def include_attributed_ip_conversions @include_attributed_ip_conversions end |
#include_unattributed_cookie_conversions ⇒ Boolean Also known as:
Include conversions of users with a DoubleClick cookie but without an exposure.
That means the user did not click or see an ad from the advertiser within the
Floodlight group, or that the interaction happened outside the lookback window.
Corresponds to the JSON property includeUnattributedCookieConversions
11311 11312 11313 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11311 def @include_unattributed_cookie_conversions end |
#include_unattributed_ip_conversions ⇒ Boolean Also known as: include_unattributed_ip_conversions?
Include conversions that have no associated cookies and no exposures. It’s
therefore impossible to know how the user was exposed to your ads during the
lookback window prior to a conversion.
Corresponds to the JSON property includeUnattributedIPConversions
11319 11320 11321 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11319 def include_unattributed_ip_conversions @include_unattributed_ip_conversions end |
#maximum_click_interactions ⇒ Fixnum
The maximum number of click interactions to include in the report. Advertisers
currently paying for E2C reports get up to 200 (100 clicks, 100 impressions).
If another advertiser in your network is paying for E2C, you can have up to 5
total exposures per report.
Corresponds to the JSON property maximumClickInteractions
11328 11329 11330 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11328 def maximum_click_interactions @maximum_click_interactions end |
#maximum_impression_interactions ⇒ Fixnum
The maximum number of click interactions to include in the report. Advertisers
currently paying for E2C reports get up to 200 (100 clicks, 100 impressions).
If another advertiser in your network is paying for E2C, you can have up to 5
total exposures per report.
Corresponds to the JSON property maximumImpressionInteractions
11336 11337 11338 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11336 def maximum_impression_interactions @maximum_impression_interactions end |
#maximum_interaction_gap ⇒ Fixnum
The maximum amount of time that can take place between interactions (clicks or
impressions) by the same user. Valid values: 1-90.
Corresponds to the JSON property maximumInteractionGap
11342 11343 11344 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11342 def maximum_interaction_gap @maximum_interaction_gap end |
#pivot_on_interaction_path ⇒ Boolean Also known as: pivot_on_interaction_path?
Enable pivoting on interaction path.
Corresponds to the JSON property pivotOnInteractionPath
11347 11348 11349 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11347 def pivot_on_interaction_path @pivot_on_interaction_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11355 11356 11357 11358 11359 11360 11361 11362 11363 11364 11365 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11355 def update!(**args) @clicks_lookback_window = args[:clicks_lookback_window] if args.key?(:clicks_lookback_window) @impressions_lookback_window = args[:impressions_lookback_window] if args.key?(:impressions_lookback_window) @include_attributed_ip_conversions = args[:include_attributed_ip_conversions] if args.key?(:include_attributed_ip_conversions) @include_unattributed_cookie_conversions = args[:include_unattributed_cookie_conversions] if args.key?(:include_unattributed_cookie_conversions) @include_unattributed_ip_conversions = args[:include_unattributed_ip_conversions] if args.key?(:include_unattributed_ip_conversions) @maximum_click_interactions = args[:maximum_click_interactions] if args.key?(:maximum_click_interactions) @maximum_impression_interactions = args[:maximum_impression_interactions] if args.key?(:maximum_impression_interactions) @maximum_interaction_gap = args[:maximum_interaction_gap] if args.key?(:maximum_interaction_gap) @pivot_on_interaction_path = args[:pivot_on_interaction_path] if args.key?(:pivot_on_interaction_path) end |