Class: Google::Apis::DfareportingV5::Report::ReachCriteria
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Report::ReachCriteria
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
The report criteria for a report of type "REACH".
Instance Attribute Summary collapse
-
#activities ⇒ Google::Apis::DfareportingV5::Activities
Represents an activity group.
-
#custom_rich_media_events ⇒ Google::Apis::DfareportingV5::CustomRichMediaEvents
Represents a Custom Rich Media Events group.
-
#date_range ⇒ Google::Apis::DfareportingV5::DateRange
Represents a date range.
-
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of filters on which dimensions are filtered.
-
#dimensions ⇒ Array<Google::Apis::DfareportingV5::SortedDimension>
The list of dimensions the report should include.
-
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
-
#reach_by_frequency_metric_names ⇒ Array<String>
The list of names of Reach By Frequency metrics the report should include.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReachCriteria
constructor
A new instance of ReachCriteria.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReachCriteria
Returns a new instance of ReachCriteria.
11410 11411 11412 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activities ⇒ Google::Apis::DfareportingV5::Activities
Represents an activity group.
Corresponds to the JSON property activities
11376 11377 11378 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11376 def activities @activities end |
#custom_rich_media_events ⇒ Google::Apis::DfareportingV5::CustomRichMediaEvents
Represents a Custom Rich Media Events group.
Corresponds to the JSON property customRichMediaEvents
11381 11382 11383 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11381 def custom_rich_media_events @custom_rich_media_events end |
#date_range ⇒ Google::Apis::DfareportingV5::DateRange
Represents a date range.
Corresponds to the JSON property dateRange
11386 11387 11388 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11386 def date_range @date_range end |
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of filters on which dimensions are filtered. Filters for different
dimensions are ANDed, filters for the same dimension are grouped together and
ORed.
Corresponds to the JSON property dimensionFilters
11393 11394 11395 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11393 def dimension_filters @dimension_filters end |
#dimensions ⇒ Array<Google::Apis::DfareportingV5::SortedDimension>
The list of dimensions the report should include.
Corresponds to the JSON property dimensions
11398 11399 11400 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11398 def dimensions @dimensions end |
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
Corresponds to the JSON property metricNames
11403 11404 11405 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11403 def metric_names @metric_names end |
#reach_by_frequency_metric_names ⇒ Array<String>
The list of names of Reach By Frequency metrics the report should include.
Corresponds to the JSON property reachByFrequencyMetricNames
11408 11409 11410 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11408 def reach_by_frequency_metric_names @reach_by_frequency_metric_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11415 11416 11417 11418 11419 11420 11421 11422 11423 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11415 def update!(**args) @activities = args[:activities] if args.key?(:activities) @custom_rich_media_events = args[:custom_rich_media_events] if args.key?(:custom_rich_media_events) @date_range = args[:date_range] if args.key?(:date_range) @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters) @dimensions = args[:dimensions] if args.key?(:dimensions) @metric_names = args[:metric_names] if args.key?(:metric_names) @reach_by_frequency_metric_names = args[:reach_by_frequency_metric_names] if args.key?(:reach_by_frequency_metric_names) end |