Class: Google::Apis::DfareportingV5::ReportCompatibleFields
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::ReportCompatibleFields
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents fields that are compatible to be selected for a report of type " STANDARD".
Instance Attribute Summary collapse
-
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Dimensions which are compatible to be selected in the "dimensionFilters" section of the report.
-
#dimensions ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Dimensions which are compatible to be selected in the "dimensions" section of the report.
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting#reportCompatibleFields.
-
#metrics ⇒ Array<Google::Apis::DfareportingV5::Metric>
Metrics which are compatible to be selected in the "metricNames" section of the report.
-
#pivoted_activity_metrics ⇒ Array<Google::Apis::DfareportingV5::Metric>
Metrics which are compatible to be selected as activity metrics to pivot on in the "activities" section of the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportCompatibleFields
constructor
A new instance of ReportCompatibleFields.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportCompatibleFields
Returns a new instance of ReportCompatibleFields.
11499 11500 11501 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Dimensions which are compatible to be selected in the "dimensionFilters"
section of the report.
Corresponds to the JSON property dimensionFilters
11474 11475 11476 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11474 def dimension_filters @dimension_filters end |
#dimensions ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Dimensions which are compatible to be selected in the "dimensions" section of
the report.
Corresponds to the JSON property dimensions
11480 11481 11482 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11480 def dimensions @dimensions end |
#kind ⇒ String
The kind of resource this is, in this case dfareporting#reportCompatibleFields.
Corresponds to the JSON property kind
11485 11486 11487 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11485 def kind @kind end |
#metrics ⇒ Array<Google::Apis::DfareportingV5::Metric>
Metrics which are compatible to be selected in the "metricNames" section of
the report.
Corresponds to the JSON property metrics
11491 11492 11493 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11491 def metrics @metrics end |
#pivoted_activity_metrics ⇒ Array<Google::Apis::DfareportingV5::Metric>
Metrics which are compatible to be selected as activity metrics to pivot on in
the "activities" section of the report.
Corresponds to the JSON property pivotedActivityMetrics
11497 11498 11499 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11497 def pivoted_activity_metrics @pivoted_activity_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11504 11505 11506 11507 11508 11509 11510 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11504 def update!(**args) @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters) @dimensions = args[:dimensions] if args.key?(:dimensions) @kind = args[:kind] if args.key?(:kind) @metrics = args[:metrics] if args.key?(:metrics) @pivoted_activity_metrics = args[:pivoted_activity_metrics] if args.key?(:pivoted_activity_metrics) end |