Class: Google::Apis::DfareportingV5::ReportDataRow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

A row of report data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportDataRow

Returns a new instance of ReportDataRow.



11654
11655
11656
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#valuesArray<String>

Output only. A single sequential list of all cell values matching column_headers indices exactly. - Metric cells that are suppressed due to Minimum Reporting Standard (MRS) privacy protection constraints return "-". Corresponds to the JSON property values

Returns:

  • (Array<String>)


11652
11653
11654
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11652

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11659
11660
11661
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11659

def update!(**args)
  @values = args[:values] if args.key?(:values)
end