Class: Google::Apis::DfareportingV5::ReportList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents the list of reports.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportList

Returns a new instance of ReportList.



11691
11692
11693
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

The eTag of this response for caching purposes. Corresponds to the JSON property etag

Returns:

  • (String)


11671
11672
11673
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11671

def etag
  @etag
end

#itemsArray<Google::Apis::DfareportingV5::Report>

The reports returned in this response. Corresponds to the JSON property items



11676
11677
11678
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11676

def items
  @items
end

#kindString

The kind of list this is, in this case dfareporting#reportList. Corresponds to the JSON property kind

Returns:

  • (String)


11681
11682
11683
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11681

def kind
  @kind
end

#next_page_tokenString

Continuation token used to page through reports. To retrieve the next page of results, set the next request's "pageToken" to the value of this field. The page token is only valid for a limited amount of time and should not be persisted. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11689
11690
11691
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11689

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11696
11697
11698
11699
11700
11701
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11696

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end