Class: Google::Apis::DfareportingV5::RichMediaExitOverride
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::RichMediaExitOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Rich Media Exit Override.
Instance Attribute Summary collapse
-
#click_through_url ⇒ Google::Apis::DfareportingV5::ClickThroughUrl
Click-through URL Corresponds to the JSON property
clickThroughUrl. -
#enabled ⇒ Boolean
(also: #enabled?)
Whether to use the clickThroughUrl.
-
#exit_id ⇒ Fixnum
ID for the override to refer to a specific exit in the creative.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RichMediaExitOverride
constructor
A new instance of RichMediaExitOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RichMediaExitOverride
Returns a new instance of RichMediaExitOverride.
11806 11807 11808 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#click_through_url ⇒ Google::Apis::DfareportingV5::ClickThroughUrl
Click-through URL
Corresponds to the JSON property clickThroughUrl
11792 11793 11794 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11792 def click_through_url @click_through_url end |
#enabled ⇒ Boolean Also known as: enabled?
Whether to use the clickThroughUrl. If false, the creative-level exit will be
used.
Corresponds to the JSON property enabled
11798 11799 11800 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11798 def enabled @enabled end |
#exit_id ⇒ Fixnum
ID for the override to refer to a specific exit in the creative.
Corresponds to the JSON property exitId
11804 11805 11806 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11804 def exit_id @exit_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11811 11812 11813 11814 11815 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11811 def update!(**args) @click_through_url = args[:click_through_url] if args.key?(:click_through_url) @enabled = args[:enabled] if args.key?(:enabled) @exit_id = args[:exit_id] if args.key?(:exit_id) end |