Class: Google::Apis::DfareportingV5::Site

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a site.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Site

Returns a new instance of Site.



11926
11927
11928
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this site. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


11844
11845
11846
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11844

def 
  @account_id
end

#ad_serving_platform_idFixnum

Optional. Ad serving platform ID to identify the ad serving platform used by the site. Measurement partners can use this field to add ad-server specific macros. If set, this value acts as the default during placement creation. Possible values are: * 1, Adelphic * 2, Adform * 3, Adobe * 4, Amobee * 5, Basis (Centro) * 6, Beeswax * 7, Amazon * 8, DV360 (DBM) * 9, Innovid * 10, MediaMath * 11, Roku OneView DSP * 12, TabMo Hawk * 13, The Trade Desk * 14, Xandr Invest DSP * 15, Yahoo DSP * 16, Zeta Global * 17, Scaleout * 18, Bidtellect * 19, Unicorn * 20, Teads * 21, Quantcast * 22, Cognitiv * 23, AdTheorent * 24, DeepIntent * 25, Pulsepoint Corresponds to the JSON property adServingPlatformId

Returns:

  • (Fixnum)


11858
11859
11860
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11858

def ad_serving_platform_id
  @ad_serving_platform_id
end

#approvedBoolean Also known as: approved?

Whether this site is approved. Corresponds to the JSON property approved

Returns:

  • (Boolean)


11863
11864
11865
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11863

def approved
  @approved
end

#directory_site_idFixnum

Directory site associated with this site. This is a required field that is read-only after insertion. Corresponds to the JSON property directorySiteId

Returns:

  • (Fixnum)


11870
11871
11872
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11870

def directory_site_id
  @directory_site_id
end

#directory_site_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property directorySiteIdDimensionValue



11875
11876
11877
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11875

def directory_site_id_dimension_value
  @directory_site_id_dimension_value
end

#idFixnum

ID of this site. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


11880
11881
11882
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11880

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



11885
11886
11887
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11885

def id_dimension_value
  @id_dimension_value
end

#key_nameString

Key name of this site. This is a read-only, auto-generated field. Corresponds to the JSON property keyName

Returns:

  • (String)


11890
11891
11892
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11890

def key_name
  @key_name
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#site". Corresponds to the JSON property kind

Returns:

  • (String)


11896
11897
11898
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11896

def kind
  @kind
end

#nameString

Name of this site.This is a required field. Must be less than 128 characters long. If this site is under a subaccount, the name must be unique among sites of the same subaccount. Otherwise, this site is a top-level site, and the name must be unique among top-level sites of the same account. Corresponds to the JSON property name

Returns:

  • (String)


11904
11905
11906
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11904

def name
  @name
end

#site_contactsArray<Google::Apis::DfareportingV5::SiteContact>

Site contacts. Corresponds to the JSON property siteContacts



11909
11910
11911
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11909

def site_contacts
  @site_contacts
end

#site_settingsGoogle::Apis::DfareportingV5::SiteSettings

Site Settings Corresponds to the JSON property siteSettings



11914
11915
11916
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11914

def site_settings
  @site_settings
end

#subaccount_idFixnum

Subaccount ID of this site. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


11919
11920
11921
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11919

def subaccount_id
  @subaccount_id
end

#video_settingsGoogle::Apis::DfareportingV5::SiteVideoSettings

Video Settings Corresponds to the JSON property videoSettings



11924
11925
11926
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11924

def video_settings
  @video_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11931
11932
11933
11934
11935
11936
11937
11938
11939
11940
11941
11942
11943
11944
11945
11946
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11931

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @ad_serving_platform_id = args[:ad_serving_platform_id] if args.key?(:ad_serving_platform_id)
  @approved = args[:approved] if args.key?(:approved)
  @directory_site_id = args[:directory_site_id] if args.key?(:directory_site_id)
  @directory_site_id_dimension_value = args[:directory_site_id_dimension_value] if args.key?(:directory_site_id_dimension_value)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @key_name = args[:key_name] if args.key?(:key_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @site_contacts = args[:site_contacts] if args.key?(:site_contacts)
  @site_settings = args[:site_settings] if args.key?(:site_settings)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @video_settings = args[:video_settings] if args.key?(:video_settings)
end