Class: Google::Apis::DfareportingV5::SiteSkippableSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::SiteSkippableSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Skippable Settings
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#progress_offset ⇒ Google::Apis::DfareportingV5::VideoOffset
Video Offset Corresponds to the JSON property
progressOffset. -
#skip_offset ⇒ Google::Apis::DfareportingV5::VideoOffset
Video Offset Corresponds to the JSON property
skipOffset. -
#skippable ⇒ Boolean
(also: #skippable?)
Whether the user can skip creatives served to this site.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SiteSkippableSetting
constructor
A new instance of SiteSkippableSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SiteSkippableSetting
Returns a new instance of SiteSkippableSetting.
12144 12145 12146 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#siteSkippableSetting".
Corresponds to the JSON property kind
12125 12126 12127 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12125 def kind @kind end |
#progress_offset ⇒ Google::Apis::DfareportingV5::VideoOffset
Video Offset
Corresponds to the JSON property progressOffset
12130 12131 12132 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12130 def progress_offset @progress_offset end |
#skip_offset ⇒ Google::Apis::DfareportingV5::VideoOffset
Video Offset
Corresponds to the JSON property skipOffset
12135 12136 12137 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12135 def skip_offset @skip_offset end |
#skippable ⇒ Boolean Also known as: skippable?
Whether the user can skip creatives served to this site. This will act as
default for new placements created under this site.
Corresponds to the JSON property skippable
12141 12142 12143 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12141 def skippable @skippable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12149 12150 12151 12152 12153 12154 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12149 def update!(**args) @kind = args[:kind] if args.key?(:kind) @progress_offset = args[:progress_offset] if args.key?(:progress_offset) @skip_offset = args[:skip_offset] if args.key?(:skip_offset) @skippable = args[:skippable] if args.key?(:skippable) end |