Class: Google::Apis::DfareportingV5::SiteTranscodeSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::SiteTranscodeSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Transcode Settings
Instance Attribute Summary collapse
-
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this site template.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SiteTranscodeSetting
constructor
A new instance of SiteTranscodeSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SiteTranscodeSetting
Returns a new instance of SiteTranscodeSetting.
12173 12174 12175 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this site template. Set this list
to null or empty to serve all video formats.
Corresponds to the JSON property enabledVideoFormats
12165 12166 12167 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12165 def enabled_video_formats @enabled_video_formats end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#siteTranscodeSetting".
Corresponds to the JSON property kind
12171 12172 12173 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12171 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12178 12179 12180 12181 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12178 def update!(**args) @enabled_video_formats = args[:enabled_video_formats] if args.key?(:enabled_video_formats) @kind = args[:kind] if args.key?(:kind) end |