Class: Google::Apis::DfareportingV5::SkippableSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::SkippableSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Skippable Settings
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#progress_offset ⇒ Google::Apis::DfareportingV5::VideoOffset
Video Offset Corresponds to the JSON property
progressOffset. -
#skip_offset ⇒ Google::Apis::DfareportingV5::VideoOffset
Video Offset Corresponds to the JSON property
skipOffset. -
#skippable ⇒ Boolean
(also: #skippable?)
Whether the user can skip creatives served to this placement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SkippableSetting
constructor
A new instance of SkippableSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SkippableSetting
Returns a new instance of SkippableSetting.
12236 12237 12238 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#skippableSetting".
Corresponds to the JSON property kind
12218 12219 12220 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12218 def kind @kind end |
#progress_offset ⇒ Google::Apis::DfareportingV5::VideoOffset
Video Offset
Corresponds to the JSON property progressOffset
12223 12224 12225 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12223 def progress_offset @progress_offset end |
#skip_offset ⇒ Google::Apis::DfareportingV5::VideoOffset
Video Offset
Corresponds to the JSON property skipOffset
12228 12229 12230 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12228 def skip_offset @skip_offset end |
#skippable ⇒ Boolean Also known as: skippable?
Whether the user can skip creatives served to this placement.
Corresponds to the JSON property skippable
12233 12234 12235 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12233 def skippable @skippable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12241 12242 12243 12244 12245 12246 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12241 def update!(**args) @kind = args[:kind] if args.key?(:kind) @progress_offset = args[:progress_offset] if args.key?(:progress_offset) @skip_offset = args[:skip_offset] if args.key?(:skip_offset) @skippable = args[:skippable] if args.key?(:skippable) end |