Class: Google::Apis::DfareportingV5::SortBy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Specifies the sort configuration for a specific field in the report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SortBy

Returns a new instance of SortBy.



12414
12415
12416
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The dimension or metric field name to sort on. Corresponds to the JSON property name

Returns:

  • (String)


12407
12408
12409
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12407

def name
  @name
end

#sort_orderString

Optional. The sort order of this column. Corresponds to the JSON property sortOrder

Returns:

  • (String)


12412
12413
12414
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12412

def sort_order
  @sort_order
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12419
12420
12421
12422
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12419

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @sort_order = args[:sort_order] if args.key?(:sort_order)
end