Class: Google::Apis::DfareportingV5::SortedDimension
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::SortedDimension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents a sorted dimension.
Instance Attribute Summary collapse
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting#sortedDimension.
-
#name ⇒ String
The name of the dimension.
-
#sort_order ⇒ String
An optional sort order for the dimension column.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SortedDimension
constructor
A new instance of SortedDimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SortedDimension
Returns a new instance of SortedDimension.
12268 12269 12270 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
The kind of resource this is, in this case dfareporting#sortedDimension.
Corresponds to the JSON property kind
12256 12257 12258 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12256 def kind @kind end |
#name ⇒ String
The name of the dimension.
Corresponds to the JSON property name
12261 12262 12263 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12261 def name @name end |
#sort_order ⇒ String
An optional sort order for the dimension column.
Corresponds to the JSON property sortOrder
12266 12267 12268 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12266 def sort_order @sort_order end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12273 12274 12275 12276 12277 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12273 def update!(**args) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @sort_order = args[:sort_order] if args.key?(:sort_order) end |