Class: Google::Apis::DfareportingV5::StudioCreative

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains studio creative information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StudioCreative

Returns a new instance of StudioCreative.



12534
12535
12536
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_idsArray<Fixnum>

List of assets associated with this studio creative. It is a required field on insertion. Corresponds to the JSON property assetIds

Returns:

  • (Array<Fixnum>)


12466
12467
12468
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12466

def asset_ids
  @asset_ids
end

#backup_image_asset_idFixnum

Backup image asset ID of this studio creative. It is a required field on insertion. Corresponds to the JSON property backupImageAssetId

Returns:

  • (Fixnum)


12472
12473
12474
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12472

def backup_image_asset_id
  @backup_image_asset_id
end

#created_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createdInfo



12477
12478
12479
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12477

def created_info
  @created_info
end

#dimensionGoogle::Apis::DfareportingV5::StudioCreativeDimension

Dimension information for a studio creative. Corresponds to the JSON property dimension



12482
12483
12484
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12482

def dimension
  @dimension
end

#dynamic_profile_idFixnum

Dynamic profile ID of this studio creative. Corresponds to the JSON property dynamicProfileId

Returns:

  • (Fixnum)


12487
12488
12489
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12487

def dynamic_profile_id
  @dynamic_profile_id
end

#formatString

Format of this studio creative. This is a required field on insertion. Corresponds to the JSON property format

Returns:

  • (String)


12492
12493
12494
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12492

def format
  @format
end

#idFixnum

Output only. Unique ID of this studio creative. This is a read-only, auto- generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12498
12499
12500
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12498

def id
  @id
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



12503
12504
12505
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12503

def last_modified_info
  @last_modified_info
end

#nameString

Identifier. Name of this studio creative. This is a required field on insertion. Corresponds to the JSON property name

Returns:

  • (String)


12509
12510
12511
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12509

def name
  @name
end

#statusString

Output only. Status of this studio creative. It is a read-only field. Corresponds to the JSON property status

Returns:

  • (String)


12514
12515
12516
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12514

def status
  @status
end

#studio_account_idFixnum

Studio account ID of this creative. This field, if left unset, will be auto- populated. Corresponds to the JSON property studioAccountId

Returns:

  • (Fixnum)


12520
12521
12522
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12520

def 
  @studio_account_id
end

#studio_advertiser_idFixnum

Studio advertiser ID of this studio creative. This is a required field on insertion. Corresponds to the JSON property studioAdvertiserId

Returns:

  • (Fixnum)


12526
12527
12528
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12526

def studio_advertiser_id
  @studio_advertiser_id
end

#studio_campaign_idFixnum

Studio campaign ID of this studio creative. This is a required field on insertion. Corresponds to the JSON property studioCampaignId

Returns:

  • (Fixnum)


12532
12533
12534
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12532

def studio_campaign_id
  @studio_campaign_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
12550
12551
12552
12553
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12539

def update!(**args)
  @asset_ids = args[:asset_ids] if args.key?(:asset_ids)
  @backup_image_asset_id = args[:backup_image_asset_id] if args.key?(:backup_image_asset_id)
  @created_info = args[:created_info] if args.key?(:created_info)
  @dimension = args[:dimension] if args.key?(:dimension)
  @dynamic_profile_id = args[:dynamic_profile_id] if args.key?(:dynamic_profile_id)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @studio_account_id = args[:studio_account_id] if args.key?(:studio_account_id)
  @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id)
  @studio_campaign_id = args[:studio_campaign_id] if args.key?(:studio_campaign_id)
end