Class: Google::Apis::DfareportingV5::StudioCreativeAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains studio creative asset information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StudioCreativeAsset

Returns a new instance of StudioCreativeAsset.



12617
12618
12619
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



12565
12566
12567
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12565

def create_info
  @create_info
end

#filenameString

The filename of the studio creative asset. It is default to the original filename of the asset. Corresponds to the JSON property filename

Returns:

  • (String)


12571
12572
12573
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12571

def filename
  @filename
end

#filesizeFixnum

The filesize of the studio creative asset. This is a read-only field. Corresponds to the JSON property filesize

Returns:

  • (Fixnum)


12576
12577
12578
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12576

def filesize
  @filesize
end

#idFixnum

Output only. Unique ID of this studio creative asset. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12582
12583
12584
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12582

def id
  @id
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



12587
12588
12589
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12587

def last_modified_info
  @last_modified_info
end

#studio_account_idFixnum

Studio account ID of this studio creative asset. This field, if left unset, will be auto-populated.. Corresponds to the JSON property studioAccountId

Returns:

  • (Fixnum)


12593
12594
12595
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12593

def 
  @studio_account_id
end

#studio_advertiser_idFixnum

Studio advertiser ID of this studio creative asset. This is a required field on insertion. Corresponds to the JSON property studioAdvertiserId

Returns:

  • (Fixnum)


12599
12600
12601
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12599

def studio_advertiser_id
  @studio_advertiser_id
end

#studio_creative_idFixnum

Studio creative ID of this studio creative asset. The asset will be associated to the creative if creative id is set. Corresponds to the JSON property studioCreativeId

Returns:

  • (Fixnum)


12605
12606
12607
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12605

def studio_creative_id
  @studio_creative_id
end

#typeString

The type of the studio creative asset. It is a auto-generated, read-only field. Corresponds to the JSON property type

Returns:

  • (String)


12610
12611
12612
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12610

def type
  @type
end

#video_processing_dataGoogle::Apis::DfareportingV5::VideoProcessingData

Contains processing data for a video asset. Corresponds to the JSON property videoProcessingData



12615
12616
12617
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12615

def video_processing_data
  @video_processing_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12622
12623
12624
12625
12626
12627
12628
12629
12630
12631
12632
12633
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12622

def update!(**args)
  @create_info = args[:create_info] if args.key?(:create_info)
  @filename = args[:filename] if args.key?(:filename)
  @filesize = args[:filesize] if args.key?(:filesize)
  @id = args[:id] if args.key?(:id)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @studio_account_id = args[:studio_account_id] if args.key?(:studio_account_id)
  @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id)
  @studio_creative_id = args[:studio_creative_id] if args.key?(:studio_creative_id)
  @type = args[:type] if args.key?(:type)
  @video_processing_data = args[:video_processing_data] if args.key?(:video_processing_data)
end