Class: Google::Apis::DfareportingV5::TargetableRemarketingList
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::TargetableRemarketingList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of a targetable remarketing list. Remarketing enables you to create lists of users who have performed specific actions on a site, then target ads to members of those lists. This resource is a read-only view of a remarketing list to be used to facilitate targeting ads to specific lists. Remarketing lists that are owned by your advertisers and those that are shared to your advertisers or account are accessible via this resource. To manage remarketing lists that are owned by your advertisers, use the RemarketingLists resource.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this remarketing list.
-
#active ⇒ Boolean
(also: #active?)
Whether this targetable remarketing list is active.
-
#advertiser_id ⇒ Fixnum
Dimension value for the advertiser ID that owns this targetable remarketing list.
-
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#description ⇒ String
Targetable remarketing list description.
-
#id ⇒ Fixnum
Targetable remarketing list ID.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#life_span ⇒ Fixnum
Number of days that a user should remain in the targetable remarketing list without an impression.
-
#list_size ⇒ Fixnum
Number of users currently in the list.
-
#list_source ⇒ String
Product from which this targetable remarketing list was originated.
-
#name ⇒ String
Name of the targetable remarketing list.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this remarketing list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetableRemarketingList
constructor
A new instance of TargetableRemarketingList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetableRemarketingList
Returns a new instance of TargetableRemarketingList.
12988 12989 12990 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this remarketing list. This is a read-only, auto-generated field
that is only returned in GET requests.
Corresponds to the JSON property accountId
12925 12926 12927 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12925 def account_id @account_id end |
#active ⇒ Boolean Also known as: active?
Whether this targetable remarketing list is active.
Corresponds to the JSON property active
12930 12931 12932 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12930 def active @active end |
#advertiser_id ⇒ Fixnum
Dimension value for the advertiser ID that owns this targetable remarketing
list.
Corresponds to the JSON property advertiserId
12937 12938 12939 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12937 def advertiser_id @advertiser_id end |
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property advertiserIdDimensionValue
12942 12943 12944 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12942 def advertiser_id_dimension_value @advertiser_id_dimension_value end |
#description ⇒ String
Targetable remarketing list description.
Corresponds to the JSON property description
12947 12948 12949 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12947 def description @description end |
#id ⇒ Fixnum
Targetable remarketing list ID.
Corresponds to the JSON property id
12952 12953 12954 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12952 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#targetableRemarketingList".
Corresponds to the JSON property kind
12958 12959 12960 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12958 def kind @kind end |
#life_span ⇒ Fixnum
Number of days that a user should remain in the targetable remarketing list
without an impression.
Corresponds to the JSON property lifeSpan
12964 12965 12966 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12964 def life_span @life_span end |
#list_size ⇒ Fixnum
Number of users currently in the list. This is a read-only field.
Corresponds to the JSON property listSize
12969 12970 12971 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12969 def list_size @list_size end |
#list_source ⇒ String
Product from which this targetable remarketing list was originated.
Corresponds to the JSON property listSource
12974 12975 12976 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12974 def list_source @list_source end |
#name ⇒ String
Name of the targetable remarketing list. Is no greater than 128 characters
long.
Corresponds to the JSON property name
12980 12981 12982 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12980 def name @name end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this remarketing list. This is a read-only, auto-generated
field that is only returned in GET requests.
Corresponds to the JSON property subaccountId
12986 12987 12988 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12986 def subaccount_id @subaccount_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12993 12994 12995 12996 12997 12998 12999 13000 13001 13002 13003 13004 13005 13006 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12993 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @active = args[:active] if args.key?(:active) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @life_span = args[:life_span] if args.key?(:life_span) @list_size = args[:list_size] if args.key?(:list_size) @list_source = args[:list_source] if args.key?(:list_source) @name = args[:name] if args.key?(:name) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) end |