Class: Google::Apis::DfareportingV5::TargetingTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a targeting template. A targeting template encapsulates targeting information which can be reused across multiple ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetingTemplate

Returns a new instance of TargetingTemplate.



13121
13122
13123
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this targeting template. This field, if left unset, will be auto- generated on insert and is read-only after insert. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


13050
13051
13052
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13050

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this targeting template. This is a required field on insert and is read-only after insert. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


13056
13057
13058
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13056

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



13061
13062
13063
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13061

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#contextual_keyword_targetingGoogle::Apis::DfareportingV5::ContextualKeywordTargeting

Contextual Keyword Targeting. Corresponds to the JSON property contextualKeywordTargeting



13066
13067
13068
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13066

def contextual_keyword_targeting
  @contextual_keyword_targeting
end

#day_part_targetingGoogle::Apis::DfareportingV5::DayPartTargeting

Day Part Targeting. Corresponds to the JSON property dayPartTargeting



13071
13072
13073
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13071

def day_part_targeting
  @day_part_targeting
end

#geo_targetingGoogle::Apis::DfareportingV5::GeoTargeting

Geographical Targeting. Corresponds to the JSON property geoTargeting



13076
13077
13078
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13076

def geo_targeting
  @geo_targeting
end

#idFixnum

ID of this targeting template. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13081
13082
13083
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13081

def id
  @id
end

#key_value_targeting_expressionGoogle::Apis::DfareportingV5::KeyValueTargetingExpression

Key Value Targeting Expression. Corresponds to the JSON property keyValueTargetingExpression



13086
13087
13088
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13086

def key_value_targeting_expression
  @key_value_targeting_expression
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#targetingTemplate". Corresponds to the JSON property kind

Returns:

  • (String)


13092
13093
13094
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13092

def kind
  @kind
end

#language_targetingGoogle::Apis::DfareportingV5::LanguageTargeting

Language Targeting. Corresponds to the JSON property languageTargeting



13097
13098
13099
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13097

def language_targeting
  @language_targeting
end

#list_targeting_expressionGoogle::Apis::DfareportingV5::ListTargetingExpression

Remarketing List Targeting Expression. Corresponds to the JSON property listTargetingExpression



13102
13103
13104
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13102

def list_targeting_expression
  @list_targeting_expression
end

#nameString

Name of this targeting template. This field is required. It must be less than 256 characters long and unique within an advertiser. Corresponds to the JSON property name

Returns:

  • (String)


13108
13109
13110
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13108

def name
  @name
end

#subaccount_idFixnum

Subaccount ID of this targeting template. This field, if left unset, will be auto-generated on insert and is read-only after insert. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


13114
13115
13116
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13114

def subaccount_id
  @subaccount_id
end

#technology_targetingGoogle::Apis::DfareportingV5::TechnologyTargeting

Technology Targeting. Corresponds to the JSON property technologyTargeting



13119
13120
13121
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13119

def technology_targeting
  @technology_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13126

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @contextual_keyword_targeting = args[:contextual_keyword_targeting] if args.key?(:contextual_keyword_targeting)
  @day_part_targeting = args[:day_part_targeting] if args.key?(:day_part_targeting)
  @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting)
  @id = args[:id] if args.key?(:id)
  @key_value_targeting_expression = args[:key_value_targeting_expression] if args.key?(:key_value_targeting_expression)
  @kind = args[:kind] if args.key?(:kind)
  @language_targeting = args[:language_targeting] if args.key?(:language_targeting)
  @list_targeting_expression = args[:list_targeting_expression] if args.key?(:list_targeting_expression)
  @name = args[:name] if args.key?(:name)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @technology_targeting = args[:technology_targeting] if args.key?(:technology_targeting)
end