Class: Google::Apis::DfareportingV5::TranscodeSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::TranscodeSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Transcode Settings
Instance Attribute Summary collapse
-
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this placement.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TranscodeSetting
constructor
A new instance of TranscodeSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TranscodeSetting
Returns a new instance of TranscodeSetting.
13310 13311 13312 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13310 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this placement. Set this list to
null or empty to serve all video formats.
Corresponds to the JSON property enabledVideoFormats
13302 13303 13304 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13302 def enabled_video_formats @enabled_video_formats end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#transcodeSetting".
Corresponds to the JSON property kind
13308 13309 13310 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13308 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13315 13316 13317 13318 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13315 def update!(**args) @enabled_video_formats = args[:enabled_video_formats] if args.key?(:enabled_video_formats) @kind = args[:kind] if args.key?(:kind) end |