Class: Google::Apis::DfareportingV5::TvCampaignTimepoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

A single data point for TvCampaignDetail, which holds information about the TV campaign for a specific start date and date window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TvCampaignTimepoint

Returns a new instance of TvCampaignTimepoint.



13470
13471
13472
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_windowString

The date window of the timepoint. Corresponds to the JSON property dateWindow

Returns:

  • (String)


13458
13459
13460
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13458

def date_window
  @date_window
end

#spendFloat

The spend within the time range of the timepoint. Corresponds to the JSON property spend

Returns:

  • (Float)


13463
13464
13465
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13463

def spend
  @spend
end

#start_dateString

The start date of the timepoint. A string in the format of "yyyy-MM-dd". Corresponds to the JSON property startDate

Returns:

  • (String)


13468
13469
13470
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13468

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13475
13476
13477
13478
13479
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13475

def update!(**args)
  @date_window = args[:date_window] if args.key?(:date_window)
  @spend = args[:spend] if args.key?(:spend)
  @start_date = args[:start_date] if args.key?(:start_date)
end