Class: Google::Apis::DfareportingV5::UserDefinedVariableConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

User Defined Variable configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserDefinedVariableConfiguration

Returns a new instance of UserDefinedVariableConfiguration.



13531
13532
13533
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_typeString

Data type for the variable. This is a required field. Corresponds to the JSON property dataType

Returns:

  • (String)


13517
13518
13519
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13517

def data_type
  @data_type
end

#report_nameString

User-friendly name for the variable which will appear in reports. This is a required field, must be less than 64 characters long, and cannot contain the following characters: ""<>". Corresponds to the JSON property reportName

Returns:

  • (String)


13524
13525
13526
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13524

def report_name
  @report_name
end

#variable_typeString

Variable name in the tag. This is a required field. Corresponds to the JSON property variableType

Returns:

  • (String)


13529
13530
13531
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13529

def variable_type
  @variable_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13536
13537
13538
13539
13540
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13536

def update!(**args)
  @data_type = args[:data_type] if args.key?(:data_type)
  @report_name = args[:report_name] if args.key?(:report_name)
  @variable_type = args[:variable_type] if args.key?(:variable_type)
end