Class: Google::Apis::DfareportingV5::UserProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

A UserProfile resource lets you list all DFA user profiles that are associated with a Google user account. The profile_id needs to be specified in other API requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserProfile

Returns a new instance of UserProfile.



13622
13623
13624
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

The account ID to which this profile belongs. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


13584
13585
13586
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13584

def 
  @account_id
end

#account_nameString

The account name this profile belongs to. Corresponds to the JSON property accountName

Returns:

  • (String)


13589
13590
13591
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13589

def 
  @account_name
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


13594
13595
13596
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13594

def etag
  @etag
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#userProfile". Corresponds to the JSON property kind

Returns:

  • (String)


13600
13601
13602
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13600

def kind
  @kind
end

#profile_idFixnum

The unique ID of the user profile. Corresponds to the JSON property profileId

Returns:

  • (Fixnum)


13605
13606
13607
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13605

def profile_id
  @profile_id
end

#sub_account_idFixnum

The sub account ID this profile belongs to if applicable. Corresponds to the JSON property subAccountId

Returns:

  • (Fixnum)


13610
13611
13612
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13610

def 
  @sub_account_id
end

#sub_account_nameString

The sub account name this profile belongs to if applicable. Corresponds to the JSON property subAccountName

Returns:

  • (String)


13615
13616
13617
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13615

def 
  @sub_account_name
end

#user_nameString

The user name. Corresponds to the JSON property userName

Returns:

  • (String)


13620
13621
13622
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13620

def user_name
  @user_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13627
13628
13629
13630
13631
13632
13633
13634
13635
13636
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13627

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @account_name = args[:account_name] if args.key?(:account_name)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @profile_id = args[:profile_id] if args.key?(:profile_id)
  @sub_account_id = args[:sub_account_id] if args.key?(:sub_account_id)
  @sub_account_name = args[:sub_account_name] if args.key?(:sub_account_name)
  @user_name = args[:user_name] if args.key?(:user_name)
end