Class: Google::Apis::DfareportingV5::UserRole
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::UserRole
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of auser role, which is used to manage user access.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this user role.
-
#default_user_role ⇒ Boolean
(also: #default_user_role?)
Whether this is a default user role.
-
#id ⇒ Fixnum
ID of this user role.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this user role.
-
#parent_user_role_id ⇒ Fixnum
ID of the user role that this user role is based on or copied from.
-
#permissions ⇒ Array<Google::Apis::DfareportingV5::UserRolePermission>
List of permissions associated with this user role.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this user role.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserRole
constructor
A new instance of UserRole.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserRole
Returns a new instance of UserRole.
13725 13726 13727 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this user role. This is a read-only field that can be left blank.
Corresponds to the JSON property accountId
13678 13679 13680 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13678 def account_id @account_id end |
#default_user_role ⇒ Boolean Also known as: default_user_role?
Whether this is a default user role. Default user roles are created by the
system for the account/subaccount and cannot be modified or deleted. Each
default user role comes with a basic set of preassigned permissions.
Corresponds to the JSON property defaultUserRole
13685 13686 13687 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13685 def default_user_role @default_user_role end |
#id ⇒ Fixnum
ID of this user role. This is a read-only, auto-generated field.
Corresponds to the JSON property id
13691 13692 13693 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13691 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#userRole".
Corresponds to the JSON property kind
13697 13698 13699 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13697 def kind @kind end |
#name ⇒ String
Name of this user role. This is a required field. Must be less than 256
characters long. If this user role is under a subaccount, the name must be
unique among sites of the same subaccount. Otherwise, this user role is a top-
level user role, and the name must be unique among top-level user roles of the
same account.
Corresponds to the JSON property name
13706 13707 13708 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13706 def name @name end |
#parent_user_role_id ⇒ Fixnum
ID of the user role that this user role is based on or copied from. This is a
required field.
Corresponds to the JSON property parentUserRoleId
13712 13713 13714 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13712 def parent_user_role_id @parent_user_role_id end |
#permissions ⇒ Array<Google::Apis::DfareportingV5::UserRolePermission>
List of permissions associated with this user role.
Corresponds to the JSON property permissions
13717 13718 13719 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13717 def @permissions end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this user role. This is a read-only field that can be left
blank.
Corresponds to the JSON property subaccountId
13723 13724 13725 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13723 def subaccount_id @subaccount_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13730 13731 13732 13733 13734 13735 13736 13737 13738 13739 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13730 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @default_user_role = args[:default_user_role] if args.key?(:default_user_role) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @parent_user_role_id = args[:parent_user_role_id] if args.key?(:parent_user_role_id) @permissions = args[:permissions] if args.key?(:permissions) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) end |