Class: Google::Apis::DfareportingV5::UserRolePermission
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::UserRolePermission
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of a user role permission.
Instance Attribute Summary collapse
-
#availability ⇒ String
Levels of availability for a user role permission.
-
#id ⇒ Fixnum
ID of this user role permission.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this user role permission.
-
#permission_group_id ⇒ Fixnum
ID of the permission group that this user role permission belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserRolePermission
constructor
A new instance of UserRolePermission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserRolePermission
Returns a new instance of UserRolePermission.
13596 13597 13598 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13596 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability ⇒ String
Levels of availability for a user role permission.
Corresponds to the JSON property availability
13573 13574 13575 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13573 def availability @availability end |
#id ⇒ Fixnum
ID of this user role permission.
Corresponds to the JSON property id
13578 13579 13580 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13578 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#userRolePermission".
Corresponds to the JSON property kind
13584 13585 13586 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13584 def kind @kind end |
#name ⇒ String
Name of this user role permission.
Corresponds to the JSON property name
13589 13590 13591 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13589 def name @name end |
#permission_group_id ⇒ Fixnum
ID of the permission group that this user role permission belongs to.
Corresponds to the JSON property permissionGroupId
13594 13595 13596 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13594 def @permission_group_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13601 13602 13603 13604 13605 13606 13607 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13601 def update!(**args) @availability = args[:availability] if args.key?(:availability) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @permission_group_id = args[:permission_group_id] if args.key?(:permission_group_id) end |