Class: Google::Apis::DfareportingV5::VideoFormat
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::VideoFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains information about supported video formats.
Instance Attribute Summary collapse
-
#file_type ⇒ String
File type of the video format.
-
#id ⇒ Fixnum
ID of the video format.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#resolution ⇒ Google::Apis::DfareportingV5::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#target_bit_rate ⇒ Fixnum
The target bit rate of this video format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoFormat
constructor
A new instance of VideoFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoFormat
Returns a new instance of VideoFormat.
13932 13933 13934 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_type ⇒ String
File type of the video format.
Corresponds to the JSON property fileType
13909 13910 13911 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13909 def file_type @file_type end |
#id ⇒ Fixnum
ID of the video format.
Corresponds to the JSON property id
13914 13915 13916 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13914 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#videoFormat".
Corresponds to the JSON property kind
13920 13921 13922 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13920 def kind @kind end |
#resolution ⇒ Google::Apis::DfareportingV5::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property resolution
13925 13926 13927 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13925 def resolution @resolution end |
#target_bit_rate ⇒ Fixnum
The target bit rate of this video format.
Corresponds to the JSON property targetBitRate
13930 13931 13932 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13930 def target_bit_rate @target_bit_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13937 13938 13939 13940 13941 13942 13943 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13937 def update!(**args) @file_type = args[:file_type] if args.key?(:file_type) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @resolution = args[:resolution] if args.key?(:resolution) @target_bit_rate = args[:target_bit_rate] if args.key?(:target_bit_rate) end |