Class: Google::Apis::DfareportingV5::Advertiser
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Advertiser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of a Campaign Manager advertiser.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this advertiser.This is a read-only field that can be left blank.
-
#advertiser_group_id ⇒ Fixnum
ID of the advertiser group this advertiser belongs to.
-
#click_through_url_suffix ⇒ String
Suffix added to click-through URL of ad creative associations under this advertiser.
-
#default_click_through_event_tag_id ⇒ Fixnum
ID of the click-through event tag to apply by default to the landing pages of this advertiser's campaigns.
-
#default_email ⇒ String
Default email address used in sender field for tag emails.
-
#eu_political_ads_declaration ⇒ String
Optional.
-
#floodlight_configuration_id ⇒ Fixnum
Floodlight configuration ID of this advertiser.
-
#floodlight_configuration_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#id ⇒ Fixnum
ID of this advertiser.
-
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#measurement_partner_link ⇒ Google::Apis::DfareportingV5::MeasurementPartnerAdvertiserLink
Measurement partner advertiser link for tag wrapping.
-
#name ⇒ String
Name of this advertiser.
-
#original_floodlight_configuration_id ⇒ Fixnum
Original floodlight configuration before any sharing occurred.
-
#status ⇒ String
Status of this advertiser.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this advertiser.This is a read-only field that can be left blank.
-
#suspended ⇒ Boolean
(also: #suspended?)
Suspension status of this advertiser.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Advertiser
constructor
A new instance of Advertiser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Advertiser
Returns a new instance of Advertiser.
1023 1024 1025 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1023 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this advertiser.This is a read-only field that can be left blank.
Corresponds to the JSON property accountId
921 922 923 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 921 def account_id @account_id end |
#advertiser_group_id ⇒ Fixnum
ID of the advertiser group this advertiser belongs to. You can group
advertisers for reporting purposes, allowing you to see aggregated information
for all advertisers in each group.
Corresponds to the JSON property advertiserGroupId
928 929 930 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 928 def advertiser_group_id @advertiser_group_id end |
#click_through_url_suffix ⇒ String
Suffix added to click-through URL of ad creative associations under this
advertiser. Must be less than 129 characters long.
Corresponds to the JSON property clickThroughUrlSuffix
934 935 936 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 934 def click_through_url_suffix @click_through_url_suffix end |
#default_click_through_event_tag_id ⇒ Fixnum
ID of the click-through event tag to apply by default to the landing pages of
this advertiser's campaigns.
Corresponds to the JSON property defaultClickThroughEventTagId
940 941 942 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 940 def default_click_through_event_tag_id @default_click_through_event_tag_id end |
#default_email ⇒ String
Default email address used in sender field for tag emails.
Corresponds to the JSON property defaultEmail
945 946 947 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 945 def default_email @default_email end |
#eu_political_ads_declaration ⇒ String
Optional. Whether the advertiser plans to serve EU political ads.
Corresponds to the JSON property euPoliticalAdsDeclaration
950 951 952 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 950 def eu_political_ads_declaration @eu_political_ads_declaration end |
#floodlight_configuration_id ⇒ Fixnum
Floodlight configuration ID of this advertiser. The floodlight configuration
ID will be created automatically, so on insert this field should be left blank.
This field can be set to another advertiser's floodlight configuration ID in
order to share that advertiser's floodlight configuration with this advertiser,
so long as: - This advertiser's original floodlight configuration is not
already associated with floodlight activities or floodlight activity groups. -
This advertiser's original floodlight configuration is not already shared with
another advertiser.
Corresponds to the JSON property floodlightConfigurationId
962 963 964 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 962 def floodlight_configuration_id @floodlight_configuration_id end |
#floodlight_configuration_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property floodlightConfigurationIdDimensionValue
967 968 969 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 967 def floodlight_configuration_id_dimension_value @floodlight_configuration_id_dimension_value end |
#id ⇒ Fixnum
ID of this advertiser. This is a read-only, auto-generated field.
Corresponds to the JSON property id
972 973 974 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 972 def id @id end |
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property idDimensionValue
977 978 979 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 977 def id_dimension_value @id_dimension_value end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#advertiser".
Corresponds to the JSON property kind
983 984 985 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 983 def kind @kind end |
#measurement_partner_link ⇒ Google::Apis::DfareportingV5::MeasurementPartnerAdvertiserLink
Measurement partner advertiser link for tag wrapping.
Corresponds to the JSON property measurementPartnerLink
988 989 990 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 988 def measurement_partner_link @measurement_partner_link end |
#name ⇒ String
Name of this advertiser. This is a required field and must be less than 256
characters long and unique among advertisers of the same account.
Corresponds to the JSON property name
994 995 996 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 994 def name @name end |
#original_floodlight_configuration_id ⇒ Fixnum
Original floodlight configuration before any sharing occurred. Set the
floodlightConfigurationId of this advertiser to
originalFloodlightConfigurationId to unshare the advertiser's current
floodlight configuration. You cannot unshare an advertiser's floodlight
configuration if the shared configuration has activities associated with any
campaign or placement.
Corresponds to the JSON property originalFloodlightConfigurationId
1004 1005 1006 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1004 def original_floodlight_configuration_id @original_floodlight_configuration_id end |
#status ⇒ String
Status of this advertiser.
Corresponds to the JSON property status
1009 1010 1011 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1009 def status @status end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this advertiser.This is a read-only field that can be left
blank.
Corresponds to the JSON property subaccountId
1015 1016 1017 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1015 def subaccount_id @subaccount_id end |
#suspended ⇒ Boolean Also known as: suspended?
Suspension status of this advertiser.
Corresponds to the JSON property suspended
1020 1021 1022 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1020 def suspended @suspended end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1028 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @advertiser_group_id = args[:advertiser_group_id] if args.key?(:advertiser_group_id) @click_through_url_suffix = args[:click_through_url_suffix] if args.key?(:click_through_url_suffix) @default_click_through_event_tag_id = args[:default_click_through_event_tag_id] if args.key?(:default_click_through_event_tag_id) @default_email = args[:default_email] if args.key?(:default_email) @eu_political_ads_declaration = args[:eu_political_ads_declaration] if args.key?(:eu_political_ads_declaration) @floodlight_configuration_id = args[:floodlight_configuration_id] if args.key?(:floodlight_configuration_id) @floodlight_configuration_id_dimension_value = args[:floodlight_configuration_id_dimension_value] if args.key?(:floodlight_configuration_id_dimension_value) @id = args[:id] if args.key?(:id) @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value) @kind = args[:kind] if args.key?(:kind) @measurement_partner_link = args[:measurement_partner_link] if args.key?(:measurement_partner_link) @name = args[:name] if args.key?(:name) @original_floodlight_configuration_id = args[:original_floodlight_configuration_id] if args.key?(:original_floodlight_configuration_id) @status = args[:status] if args.key?(:status) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) @suspended = args[:suspended] if args.key?(:suspended) end |