Class: Google::Apis::DfareportingV5::Browser
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Browser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains information about a browser that can be targeted by ads.
Instance Attribute Summary collapse
-
#browser_version_id ⇒ Fixnum
ID referring to this grouping of browser and version numbers.
-
#dart_id ⇒ Fixnum
DART ID of this browser.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#major_version ⇒ String
Major version number (leftmost number) of this browser.
-
#minor_version ⇒ String
Minor version number (number after first dot on left) of this browser.
-
#name ⇒ String
Name of this browser.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Browser
constructor
A new instance of Browser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Browser
Returns a new instance of Browser.
1676 1677 1678 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1676 def initialize(**args) update!(**args) end |
Instance Attribute Details
#browser_version_id ⇒ Fixnum
ID referring to this grouping of browser and version numbers. This is the ID
used for targeting.
Corresponds to the JSON property browserVersionId
1635 1636 1637 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1635 def browser_version_id @browser_version_id end |
#dart_id ⇒ Fixnum
DART ID of this browser. This is the ID used when generating reports.
Corresponds to the JSON property dartId
1640 1641 1642 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1640 def dart_id @dart_id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#browser".
Corresponds to the JSON property kind
1646 1647 1648 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1646 def kind @kind end |
#major_version ⇒ String
Major version number (leftmost number) of this browser. For example, for
Chrome 5.0.376.86 beta, this field should be set to 5. An asterisk () may be
used to target any version number, and a question mark (?) may be used to
target cases where the version number cannot be identified. For example,
Chrome *. targets any version of Chrome: 1.2, 2.5, 3.5, and so on. Chrome 3.*
targets Chrome 3.1, 3.5, but not 4.0. Firefox ?.? targets cases where the ad
server knows the browser is Firefox but can't tell which version it is.
Corresponds to the JSON property majorVersion
1657 1658 1659 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1657 def major_version @major_version end |
#minor_version ⇒ String
Minor version number (number after first dot on left) of this browser. For
example, for Chrome 5.0.375.86 beta, this field should be set to 0. An
asterisk () may be used to target any version number, and a question mark (?)
may be used to target cases where the version number cannot be identified. For
example, Chrome *. targets any version of Chrome: 1.2, 2.5, 3.5, and so on.
Chrome 3.* targets Chrome 3.1, 3.5, but not 4.0. Firefox ?.? targets cases
where the ad server knows the browser is Firefox but can't tell which version
it is.
Corresponds to the JSON property minorVersion
1669 1670 1671 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1669 def minor_version @minor_version end |
#name ⇒ String
Name of this browser.
Corresponds to the JSON property name
1674 1675 1676 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1674 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1681 1682 1683 1684 1685 1686 1687 1688 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1681 def update!(**args) @browser_version_id = args[:browser_version_id] if args.key?(:browser_version_id) @dart_id = args[:dart_id] if args.key?(:dart_id) @kind = args[:kind] if args.key?(:kind) @major_version = args[:major_version] if args.key?(:major_version) @minor_version = args[:minor_version] if args.key?(:minor_version) @name = args[:name] if args.key?(:name) end |