Class: Google::Apis::DfareportingV5::CampaignSummary
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::CampaignSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents a summarized campaign information associated with this invoice.
Instance Attribute Summary collapse
-
#billing_invoice_code ⇒ String
Campaign billing invoice code.
-
#campaign_id ⇒ Fixnum
Campaign ID.
-
#pre_tax_amount_micros ⇒ Fixnum
The pre-tax amount for this campaign, in micros of the invoice's currency.
-
#tax_amount_micros ⇒ Fixnum
The tax amount for this campaign, in micros of the invoice's currency.
-
#total_amount_micros ⇒ Fixnum
The total amount of charges for this campaign, in micros of the invoice's currency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CampaignSummary
constructor
A new instance of CampaignSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CampaignSummary
Returns a new instance of CampaignSummary.
1996 1997 1998 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_invoice_code ⇒ String
Campaign billing invoice code.
Corresponds to the JSON property billingInvoiceCode
1973 1974 1975 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1973 def billing_invoice_code @billing_invoice_code end |
#campaign_id ⇒ Fixnum
Campaign ID.
Corresponds to the JSON property campaignId
1978 1979 1980 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1978 def campaign_id @campaign_id end |
#pre_tax_amount_micros ⇒ Fixnum
The pre-tax amount for this campaign, in micros of the invoice's currency.
Corresponds to the JSON property preTaxAmountMicros
1983 1984 1985 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1983 def pre_tax_amount_micros @pre_tax_amount_micros end |
#tax_amount_micros ⇒ Fixnum
The tax amount for this campaign, in micros of the invoice's currency.
Corresponds to the JSON property taxAmountMicros
1988 1989 1990 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1988 def tax_amount_micros @tax_amount_micros end |
#total_amount_micros ⇒ Fixnum
The total amount of charges for this campaign, in micros of the invoice's
currency.
Corresponds to the JSON property totalAmountMicros
1994 1995 1996 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 1994 def total_amount_micros @total_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2001 2002 2003 2004 2005 2006 2007 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2001 def update!(**args) @billing_invoice_code = args[:billing_invoice_code] if args.key?(:billing_invoice_code) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @pre_tax_amount_micros = args[:pre_tax_amount_micros] if args.key?(:pre_tax_amount_micros) @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros) @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros) end |