Class: Google::Apis::DfareportingV5::CartData
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::CartData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains additional information about cart data. This field may only be used when calling batchinsert; it is not supported by batchupdate. Cart data reporting is only supported in SA360. Learn more
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::DfareportingV5::CartDataItem>
Data of the items purchased.
-
#merchant_feed_label ⇒ String
The feed labels associated with the feed where your items are uploaded.
-
#merchant_feed_language ⇒ String
The language associated with the feed where your items are uploaded.
-
#merchant_id ⇒ Fixnum
The Merchant Center ID where the items are uploaded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CartData
constructor
A new instance of CartData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CartData
Returns a new instance of CartData.
2075 2076 2077 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::DfareportingV5::CartDataItem>
Data of the items purchased.
Corresponds to the JSON property items
2052 2053 2054 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2052 def items @items end |
#merchant_feed_label ⇒ String
The feed labels associated with the feed where your items are uploaded. For
more information, please refer to https://support.google.com/merchants/
answer/12453549. Providing the feed label reduces ambiguity in identifying the
right offer details.
Corresponds to the JSON property merchantFeedLabel
2060 2061 2062 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2060 def merchant_feed_label @merchant_feed_label end |
#merchant_feed_language ⇒ String
The language associated with the feed where your items are uploaded. Use ISO
639-1 language codes. Providing the feed language reduces ambiguity in
identifying the right offer details.
Corresponds to the JSON property merchantFeedLanguage
2067 2068 2069 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2067 def merchant_feed_language @merchant_feed_language end |
#merchant_id ⇒ Fixnum
The Merchant Center ID where the items are uploaded. Providing Merchant Center
ID reduces ambiguity in identifying the right offer details.
Corresponds to the JSON property merchantId
2073 2074 2075 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2073 def merchant_id @merchant_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2080 2081 2082 2083 2084 2085 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2080 def update!(**args) @items = args[:items] if args.key?(:items) @merchant_feed_label = args[:merchant_feed_label] if args.key?(:merchant_feed_label) @merchant_feed_language = args[:merchant_feed_language] if args.key?(:merchant_feed_language) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) end |