Class: Google::Apis::DfareportingV5::CompanionSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::CompanionSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Companion Settings
Instance Attribute Summary collapse
-
#companions_disabled ⇒ Boolean
(also: #companions_disabled?)
Whether companions are disabled for this placement.
-
#enabled_sizes ⇒ Array<Google::Apis::DfareportingV5::Size>
Allowlist of companion sizes to be served to this placement.
-
#image_only ⇒ Boolean
(also: #image_only?)
Whether to serve only static images as companions.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompanionSetting
constructor
A new instance of CompanionSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompanionSetting
Returns a new instance of CompanionSetting.
2510 2511 2512 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#companions_disabled ⇒ Boolean Also known as: companions_disabled?
Whether companions are disabled for this placement.
Corresponds to the JSON property companionsDisabled
2489 2490 2491 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2489 def companions_disabled @companions_disabled end |
#enabled_sizes ⇒ Array<Google::Apis::DfareportingV5::Size>
Allowlist of companion sizes to be served to this placement. Set this list to
null or empty to serve all companion sizes.
Corresponds to the JSON property enabledSizes
2496 2497 2498 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2496 def enabled_sizes @enabled_sizes end |
#image_only ⇒ Boolean Also known as: image_only?
Whether to serve only static images as companions.
Corresponds to the JSON property imageOnly
2501 2502 2503 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2501 def image_only @image_only end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#companionSetting".
Corresponds to the JSON property kind
2508 2509 2510 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2508 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2515 2516 2517 2518 2519 2520 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2515 def update!(**args) @companions_disabled = args[:companions_disabled] if args.key?(:companions_disabled) @enabled_sizes = args[:enabled_sizes] if args.key?(:enabled_sizes) @image_only = args[:image_only] if args.key?(:image_only) @kind = args[:kind] if args.key?(:kind) end |