Class: Google::Apis::DfareportingV5::CompatibleFields

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents a response to the queryCompatibleFields method. Next ID: 10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompatibleFields

Returns a new instance of CompatibleFields.



2568
2569
2570
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cross_dimension_reach_report_compatible_fieldsGoogle::Apis::DfareportingV5::CrossDimensionReachReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " CROSS_DIMENSION_REACH". Corresponds to the JSON property crossDimensionReachReportCompatibleFields



2531
2532
2533
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2531

def cross_dimension_reach_report_compatible_fields
  @cross_dimension_reach_report_compatible_fields
end

#cross_media_reach_report_compatible_fieldsGoogle::Apis::DfareportingV5::CrossMediaReachReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " CROSS_MEDIA_REACH". Corresponds to the JSON property crossMediaReachReportCompatibleFields



2537
2538
2539
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2537

def cross_media_reach_report_compatible_fields
  @cross_media_reach_report_compatible_fields
end

#floodlight_report_compatible_fieldsGoogle::Apis::DfareportingV5::FloodlightReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " FlOODLIGHT". Corresponds to the JSON property floodlightReportCompatibleFields



2543
2544
2545
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2543

def floodlight_report_compatible_fields
  @floodlight_report_compatible_fields
end

#kindString

The kind of resource this is, in this case dfareporting#compatibleFields. Corresponds to the JSON property kind

Returns:

  • (String)


2548
2549
2550
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2548

def kind
  @kind
end

#path_to_conversion_report_compatible_fieldsGoogle::Apis::DfareportingV5::PathToConversionReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " PATH_TO_CONVERSION". Corresponds to the JSON property pathToConversionReportCompatibleFields



2554
2555
2556
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2554

def path_to_conversion_report_compatible_fields
  @path_to_conversion_report_compatible_fields
end

#reach_report_compatible_fieldsGoogle::Apis::DfareportingV5::ReachReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " REACH". Corresponds to the JSON property reachReportCompatibleFields



2560
2561
2562
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2560

def reach_report_compatible_fields
  @reach_report_compatible_fields
end

#report_compatible_fieldsGoogle::Apis::DfareportingV5::ReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " STANDARD". Corresponds to the JSON property reportCompatibleFields



2566
2567
2568
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2566

def report_compatible_fields
  @report_compatible_fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2573
2574
2575
2576
2577
2578
2579
2580
2581
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2573

def update!(**args)
  @cross_dimension_reach_report_compatible_fields = args[:cross_dimension_reach_report_compatible_fields] if args.key?(:cross_dimension_reach_report_compatible_fields)
  @cross_media_reach_report_compatible_fields = args[:cross_media_reach_report_compatible_fields] if args.key?(:cross_media_reach_report_compatible_fields)
  @floodlight_report_compatible_fields = args[:floodlight_report_compatible_fields] if args.key?(:floodlight_report_compatible_fields)
  @kind = args[:kind] if args.key?(:kind)
  @path_to_conversion_report_compatible_fields = args[:path_to_conversion_report_compatible_fields] if args.key?(:path_to_conversion_report_compatible_fields)
  @reach_report_compatible_fields = args[:reach_report_compatible_fields] if args.key?(:reach_report_compatible_fields)
  @report_compatible_fields = args[:report_compatible_fields] if args.key?(:report_compatible_fields)
end