Class: Google::Apis::DfareportingV5::ContentCategory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentCategory

Returns a new instance of ContentCategory.



2702
2703
2704
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this content category. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


2683
2684
2685
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2683

def 
  @account_id
end

#idFixnum

ID of this content category. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


2688
2689
2690
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2688

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#contentCategory". Corresponds to the JSON property kind

Returns:

  • (String)


2694
2695
2696
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2694

def kind
  @kind
end

#nameString

Name of this content category. This is a required field and must be less than 256 characters long and unique among content categories of the same account. Corresponds to the JSON property name

Returns:

  • (String)


2700
2701
2702
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2700

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2707
2708
2709
2710
2711
2712
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2707

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
end