Class: Google::Apis::DfareportingV5::Conversion
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Conversion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
A Conversion represents when a user successfully performs a desired action after seeing an ad.
Instance Attribute Summary collapse
-
#ad_user_data_consent ⇒ String
This represents consent for ad user data.
-
#cart_data ⇒ Google::Apis::DfareportingV5::CartData
Contains additional information about cart data.
-
#child_directed_treatment ⇒ Boolean
(also: #child_directed_treatment?)
Whether this particular request may come from a user under the age of 13, under COPPA compliance.
-
#custom_variables ⇒ Array<Google::Apis::DfareportingV5::CustomFloodlightVariable>
Custom floodlight variables.
-
#dclid ⇒ String
The display click ID.
-
#encrypted_user_id ⇒ String
The alphanumeric encrypted user ID.
-
#encrypted_user_id_candidates ⇒ Array<String>
A list of the alphanumeric encrypted user IDs.
-
#floodlight_activity_id ⇒ Fixnum
Floodlight Activity ID of this conversion.
-
#floodlight_configuration_id ⇒ Fixnum
Floodlight Configuration ID of this conversion.
-
#gclid ⇒ String
The Google click ID.
-
#impression_id ⇒ String
The impression ID.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#limit_ad_tracking ⇒ Boolean
(also: #limit_ad_tracking?)
Whether Limit Ad Tracking is enabled.
-
#match_id ⇒ String
The match ID field.
-
#mobile_device_id ⇒ String
The mobile device ID.
-
#non_personalized_ad ⇒ Boolean
(also: #non_personalized_ad?)
Whether the conversion was for a non personalized ad.
-
#ordinal ⇒ String
The ordinal of the conversion.
-
#quantity ⇒ Fixnum
The quantity of the conversion.
-
#session_attributes_encoded ⇒ String
Session attributes for the conversion, encoded as based64 bytes.
-
#timestamp_micros ⇒ Fixnum
The timestamp of conversion, in Unix epoch micros.
-
#treatment_for_underage ⇒ Boolean
(also: #treatment_for_underage?)
Whether this particular request may come from a user under the age of 16 (may differ by country), under compliance with the European Union's General Data Protection Regulation (GDPR).
-
#user_identifiers ⇒ Array<Google::Apis::DfareportingV5::UserIdentifier>
The user identifiers to enhance the conversion.
-
#value ⇒ Float
The value of the conversion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Conversion
constructor
A new instance of Conversion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Conversion
Returns a new instance of Conversion.
3005 3006 3007 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_user_data_consent ⇒ String
This represents consent for ad user data.
Corresponds to the JSON property adUserDataConsent
2848 2849 2850 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2848 def @ad_user_data_consent end |
#cart_data ⇒ Google::Apis::DfareportingV5::CartData
Contains additional information about cart data. This field may only be used
when calling batchinsert; it is not supported by batchupdate. Cart data
reporting is only supported in SA360. Learn more
Corresponds to the JSON property cartData
2856 2857 2858 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2856 def cart_data @cart_data end |
#child_directed_treatment ⇒ Boolean Also known as: child_directed_treatment?
Whether this particular request may come from a user under the age of 13,
under COPPA compliance.
Corresponds to the JSON property childDirectedTreatment
2862 2863 2864 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2862 def child_directed_treatment @child_directed_treatment end |
#custom_variables ⇒ Array<Google::Apis::DfareportingV5::CustomFloodlightVariable>
Custom floodlight variables.
Corresponds to the JSON property customVariables
2868 2869 2870 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2868 def custom_variables @custom_variables end |
#dclid ⇒ String
The display click ID. This field is mutually exclusive with encryptedUserId,
encryptedUserIdCandidates[], matchId, mobileDeviceId, gclid, and impressionId.
This or encryptedUserId or encryptedUserIdCandidates[] or matchId or
mobileDeviceId or gclid or impressionId is a required field.
Corresponds to the JSON property dclid
2876 2877 2878 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2876 def dclid @dclid end |
#encrypted_user_id ⇒ String
The alphanumeric encrypted user ID. When set, encryptionInfo should also be
specified. This field is mutually exclusive with encryptedUserIdCandidates[],
matchId, mobileDeviceId, gclid, dclid, and impressionId. This or
encryptedUserIdCandidates[] or matchId or mobileDeviceId or gclid or dclid or
impressionId is a required field.
Corresponds to the JSON property encryptedUserId
2885 2886 2887 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2885 def encrypted_user_id @encrypted_user_id end |
#encrypted_user_id_candidates ⇒ Array<String>
A list of the alphanumeric encrypted user IDs. Any user ID with exposure prior
to the conversion timestamp will be used in the inserted conversion. If no
such user ID is found then the conversion will be rejected with
INVALID_ARGUMENT error. When set, encryptionInfo should also be specified.
This field may only be used when calling batchinsert; it is not supported by
batchupdate. This field is mutually exclusive with encryptedUserId, matchId,
mobileDeviceId, gclid dclid, and impressionId. This or encryptedUserId or
matchId or mobileDeviceId or gclid or dclid or impressionId is a required
field.
Corresponds to the JSON property encryptedUserIdCandidates
2898 2899 2900 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2898 def encrypted_user_id_candidates @encrypted_user_id_candidates end |
#floodlight_activity_id ⇒ Fixnum
Floodlight Activity ID of this conversion. This is a required field.
Corresponds to the JSON property floodlightActivityId
2903 2904 2905 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2903 def floodlight_activity_id @floodlight_activity_id end |
#floodlight_configuration_id ⇒ Fixnum
Floodlight Configuration ID of this conversion. This is a required field.
Corresponds to the JSON property floodlightConfigurationId
2908 2909 2910 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2908 def floodlight_configuration_id @floodlight_configuration_id end |
#gclid ⇒ String
The Google click ID. This field is mutually exclusive with encryptedUserId,
encryptedUserIdCandidates[], matchId, mobileDeviceId, dclid, and impressionId.
This or encryptedUserId or encryptedUserIdCandidates[] or matchId or
mobileDeviceId or dclid or impressionId is a required field.
Corresponds to the JSON property gclid
2916 2917 2918 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2916 def gclid @gclid end |
#impression_id ⇒ String
The impression ID. This field is mutually exclusive with encryptedUserId,
encryptedUserIdCandidates[], matchId, mobileDeviceId, and gclid. One of these
identifiers must be set.
Corresponds to the JSON property impressionId
2923 2924 2925 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2923 def impression_id @impression_id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#conversion".
Corresponds to the JSON property kind
2929 2930 2931 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2929 def kind @kind end |
#limit_ad_tracking ⇒ Boolean Also known as: limit_ad_tracking?
Whether Limit Ad Tracking is enabled. When set to true, the conversion will be
used for reporting but not targeting. This will prevent remarketing.
Corresponds to the JSON property limitAdTracking
2935 2936 2937 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2935 def limit_ad_tracking @limit_ad_tracking end |
#match_id ⇒ String
The match ID field. A match ID is your own first-party identifier that has
been synced with Google using the match ID feature in Floodlight. This field
is mutually exclusive with encryptedUserId, encryptedUserIdCandidates[],
mobileDeviceId, gclid, dclid, and impressionId. This or encryptedUserId
orencryptedUserIdCandidates[] or mobileDeviceId or gclid or dclid or
impressionIdis a required field.
Corresponds to the JSON property matchId
2946 2947 2948 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2946 def match_id @match_id end |
#mobile_device_id ⇒ String
The mobile device ID. This field is mutually exclusive with encryptedUserId,
encryptedUserIdCandidates[], matchId, gclid, dclid, and impressionId. This or
encryptedUserId or encryptedUserIdCandidates[] or matchId or gclid or dclid or
impressionId is a required field.
Corresponds to the JSON property mobileDeviceId
2954 2955 2956 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2954 def mobile_device_id @mobile_device_id end |
#non_personalized_ad ⇒ Boolean Also known as: non_personalized_ad?
Whether the conversion was for a non personalized ad.
Corresponds to the JSON property nonPersonalizedAd
2959 2960 2961 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2959 def non_personalized_ad @non_personalized_ad end |
#ordinal ⇒ String
The ordinal of the conversion. Use this field to control how conversions of
the same user and day are de-duplicated. This is a required field.
Corresponds to the JSON property ordinal
2966 2967 2968 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2966 def ordinal @ordinal end |
#quantity ⇒ Fixnum
The quantity of the conversion. This is a required field.
Corresponds to the JSON property quantity
2971 2972 2973 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2971 def quantity @quantity end |
#session_attributes_encoded ⇒ String
Session attributes for the conversion, encoded as based64 bytes. This field
may only be used when calling batchinsert; it is not supported by batchupdate.
Corresponds to the JSON property sessionAttributesEncoded
NOTE: Values are automatically base64 encoded/decoded in the client library.
2978 2979 2980 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2978 def session_attributes_encoded @session_attributes_encoded end |
#timestamp_micros ⇒ Fixnum
The timestamp of conversion, in Unix epoch micros. This is a required field.
Corresponds to the JSON property timestampMicros
2983 2984 2985 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2983 def @timestamp_micros end |
#treatment_for_underage ⇒ Boolean Also known as: treatment_for_underage?
Whether this particular request may come from a user under the age of 16 (may
differ by country), under compliance with the European Union's General Data
Protection Regulation (GDPR).
Corresponds to the JSON property treatmentForUnderage
2990 2991 2992 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2990 def treatment_for_underage @treatment_for_underage end |
#user_identifiers ⇒ Array<Google::Apis::DfareportingV5::UserIdentifier>
The user identifiers to enhance the conversion. The maximum number of user
identifiers for each conversion is 5.
Corresponds to the JSON property userIdentifiers
2997 2998 2999 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 2997 def user_identifiers @user_identifiers end |
#value ⇒ Float
The value of the conversion. Interpreted in CM360 Floodlight config parent
advertiser's currency code. This is a required field.
Corresponds to the JSON property value
3003 3004 3005 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3003 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3010 def update!(**args) @ad_user_data_consent = args[:ad_user_data_consent] if args.key?(:ad_user_data_consent) @cart_data = args[:cart_data] if args.key?(:cart_data) @child_directed_treatment = args[:child_directed_treatment] if args.key?(:child_directed_treatment) @custom_variables = args[:custom_variables] if args.key?(:custom_variables) @dclid = args[:dclid] if args.key?(:dclid) @encrypted_user_id = args[:encrypted_user_id] if args.key?(:encrypted_user_id) @encrypted_user_id_candidates = args[:encrypted_user_id_candidates] if args.key?(:encrypted_user_id_candidates) @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id) @floodlight_configuration_id = args[:floodlight_configuration_id] if args.key?(:floodlight_configuration_id) @gclid = args[:gclid] if args.key?(:gclid) @impression_id = args[:impression_id] if args.key?(:impression_id) @kind = args[:kind] if args.key?(:kind) @limit_ad_tracking = args[:limit_ad_tracking] if args.key?(:limit_ad_tracking) @match_id = args[:match_id] if args.key?(:match_id) @mobile_device_id = args[:mobile_device_id] if args.key?(:mobile_device_id) @non_personalized_ad = args[:non_personalized_ad] if args.key?(:non_personalized_ad) @ordinal = args[:ordinal] if args.key?(:ordinal) @quantity = args[:quantity] if args.key?(:quantity) @session_attributes_encoded = args[:session_attributes_encoded] if args.key?(:session_attributes_encoded) @timestamp_micros = args[:timestamp_micros] if args.key?(:timestamp_micros) @treatment_for_underage = args[:treatment_for_underage] if args.key?(:treatment_for_underage) @user_identifiers = args[:user_identifiers] if args.key?(:user_identifiers) @value = args[:value] if args.key?(:value) end |