Class: Google::Apis::DfareportingV5::Country

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains information about a country that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Country

Returns a new instance of Country.



3299
3300
3301
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Country code. Corresponds to the JSON property countryCode

Returns:

  • (String)


3269
3270
3271
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3269

def country_code
  @country_code
end

#dart_idFixnum

DART ID of this country. This is the ID used for targeting and generating reports. Corresponds to the JSON property dartId

Returns:

  • (Fixnum)


3275
3276
3277
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3275

def dart_id
  @dart_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#country". Corresponds to the JSON property kind

Returns:

  • (String)


3281
3282
3283
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3281

def kind
  @kind
end

#nameString

Name of this country. Corresponds to the JSON property name

Returns:

  • (String)


3286
3287
3288
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3286

def name
  @name
end

#ssl_enabledBoolean Also known as: ssl_enabled?

Whether ad serving supports secure servers in this country. Corresponds to the JSON property sslEnabled

Returns:

  • (Boolean)


3291
3292
3293
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3291

def ssl_enabled
  @ssl_enabled
end

#tv_data_providersArray<String>

Output only. The TV data providers supported in this country. Corresponds to the JSON property tvDataProviders

Returns:

  • (Array<String>)


3297
3298
3299
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3297

def tv_data_providers
  @tv_data_providers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3304
3305
3306
3307
3308
3309
3310
3311
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3304

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @dart_id = args[:dart_id] if args.key?(:dart_id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ssl_enabled = args[:ssl_enabled] if args.key?(:ssl_enabled)
  @tv_data_providers = args[:tv_data_providers] if args.key?(:tv_data_providers)
end