Class: Google::Apis::DfareportingV5::Country
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Country
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains information about a country that can be targeted by ads.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Country code.
-
#dart_id ⇒ Fixnum
DART ID of this country.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this country.
-
#ssl_enabled ⇒ Boolean
(also: #ssl_enabled?)
Whether ad serving supports secure servers in this country.
-
#tv_data_providers ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Country
constructor
A new instance of Country.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Country
Returns a new instance of Country.
3299 3300 3301 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Country code.
Corresponds to the JSON property countryCode
3269 3270 3271 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3269 def country_code @country_code end |
#dart_id ⇒ Fixnum
DART ID of this country. This is the ID used for targeting and generating
reports.
Corresponds to the JSON property dartId
3275 3276 3277 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3275 def dart_id @dart_id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#country".
Corresponds to the JSON property kind
3281 3282 3283 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3281 def kind @kind end |
#name ⇒ String
Name of this country.
Corresponds to the JSON property name
3286 3287 3288 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3286 def name @name end |
#ssl_enabled ⇒ Boolean Also known as: ssl_enabled?
Whether ad serving supports secure servers in this country.
Corresponds to the JSON property sslEnabled
3291 3292 3293 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3291 def ssl_enabled @ssl_enabled end |
#tv_data_providers ⇒ Array<String>
Output only. The TV data providers supported in this country.
Corresponds to the JSON property tvDataProviders
3297 3298 3299 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3297 def tv_data_providers @tv_data_providers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3304 3305 3306 3307 3308 3309 3310 3311 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3304 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @dart_id = args[:dart_id] if args.key?(:dart_id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @ssl_enabled = args[:ssl_enabled] if args.key?(:ssl_enabled) @tv_data_providers = args[:tv_data_providers] if args.key?(:tv_data_providers) end |