Class: Google::Apis::DfareportingV5::CreativeAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Creative Asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeAsset

Returns a new instance of CreativeAsset.



4191
4192
4193
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_script3Boolean Also known as: action_script3?

Whether ActionScript3 is enabled for the flash asset. This is a read-only field. Applicable to the following creative type: FLASH_INPAGE. Applicable to DISPLAY when the primary asset type is not HTML_IMAGE. Corresponds to the JSON property actionScript3

Returns:

  • (Boolean)


3845
3846
3847
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3845

def action_script3
  @action_script3
end

#activeBoolean Also known as: active?

Whether the video or audio asset is active. This is a read-only field for VPAID_NON_LINEAR_VIDEO assets. Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property active

Returns:

  • (Boolean)


3853
3854
3855
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3853

def active
  @active
end

#additional_sizesArray<Google::Apis::DfareportingV5::Size>

Additional sizes associated with this creative asset. HTML5 asset generated by compatible software such as GWD will be able to support more sizes this creative asset can render. Corresponds to the JSON property additionalSizes



3861
3862
3863
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3861

def additional_sizes
  @additional_sizes
end

#alignmentString

Possible alignments for an asset. This is a read-only field. Applicable to the following creative types: RICH_MEDIA_DISPLAY_MULTI_FLOATING_INTERSTITIAL . Corresponds to the JSON property alignment

Returns:

  • (String)


3867
3868
3869
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3867

def alignment
  @alignment
end

#artwork_typeString

Artwork type of rich media creative. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property artworkType

Returns:

  • (String)


3873
3874
3875
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3873

def artwork_type
  @artwork_type
end

#asset_identifierGoogle::Apis::DfareportingV5::CreativeAssetId

Creative Asset ID. Corresponds to the JSON property assetIdentifier



3878
3879
3880
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3878

def asset_identifier
  @asset_identifier
end

#audio_bit_rateFixnum

Audio stream bit rate in kbps. This is a read-only field. Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property audioBitRate

Returns:

  • (Fixnum)


3884
3885
3886
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3884

def audio_bit_rate
  @audio_bit_rate
end

#audio_sample_rateFixnum

Audio sample bit rate in hertz. This is a read-only field. Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property audioSampleRate

Returns:

  • (Fixnum)


3890
3891
3892
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3890

def audio_sample_rate
  @audio_sample_rate
end

#backup_image_exitGoogle::Apis::DfareportingV5::CreativeCustomEvent

Creative Custom Event. Corresponds to the JSON property backupImageExit



3895
3896
3897
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3895

def backup_image_exit
  @backup_image_exit
end

#bit_rateFixnum

Detected bit-rate for audio or video asset. This is a read-only field. Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property bitRate

Returns:

  • (Fixnum)


3902
3903
3904
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3902

def bit_rate
  @bit_rate
end

#child_asset_typeString

Rich media child asset type. This is a read-only field. Applicable to the following creative types: all VPAID. Corresponds to the JSON property childAssetType

Returns:

  • (String)


3908
3909
3910
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3908

def child_asset_type
  @child_asset_type
end

#collapsed_sizeGoogle::Apis::DfareportingV5::Size

Represents the dimensions of ads, placements, creatives, or creative assets. Corresponds to the JSON property collapsedSize



3913
3914
3915
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3913

def collapsed_size
  @collapsed_size
end

#companion_creative_idsArray<Fixnum>

List of companion creatives assigned to an in-stream video creative asset. Acceptable values include IDs of existing flash and image creatives. Applicable to INSTREAM_VIDEO creative type with dynamicAssetSelection set to true. Corresponds to the JSON property companionCreativeIds

Returns:

  • (Array<Fixnum>)


3921
3922
3923
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3921

def companion_creative_ids
  @companion_creative_ids
end

#custom_start_time_valueFixnum

Custom start time in seconds for making the asset visible. Applicable to the following creative types: all RICH_MEDIA. Value must be greater than or equal to 0. Corresponds to the JSON property customStartTimeValue

Returns:

  • (Fixnum)


3928
3929
3930
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3928

def custom_start_time_value
  @custom_start_time_value
end

#detected_featuresArray<String>

List of feature dependencies for the creative asset that are detected by Campaign Manager. Feature dependencies are features that a browser must be able to support in order to render your HTML5 creative correctly. This is a read-only, auto-generated field. Applicable to the following creative types: HTML5_BANNER. Applicable to DISPLAY when the primary asset type is not HTML_IMAGE. Corresponds to the JSON property detectedFeatures

Returns:

  • (Array<String>)


3938
3939
3940
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3938

def detected_features
  @detected_features
end

#display_typeString

Type of rich media asset. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property displayType

Returns:

  • (String)


3944
3945
3946
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3944

def display_type
  @display_type
end

#durationFixnum

Duration in seconds for which an asset will be displayed. Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and VPAID_LINEAR_VIDEO. Value must be greater than or equal to 1. Corresponds to the JSON property duration

Returns:

  • (Fixnum)


3951
3952
3953
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3951

def duration
  @duration
end

#duration_typeString

Duration type for which an asset will be displayed. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property durationType

Returns:

  • (String)


3957
3958
3959
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3957

def duration_type
  @duration_type
end

#expanded_dimensionGoogle::Apis::DfareportingV5::Size

Represents the dimensions of ads, placements, creatives, or creative assets. Corresponds to the JSON property expandedDimension



3962
3963
3964
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3962

def expanded_dimension
  @expanded_dimension
end

#file_sizeFixnum

File size associated with this creative asset. This is a read-only field. Applicable to all but the following creative types: all REDIRECT and TRACKING_TEXT. Corresponds to the JSON property fileSize

Returns:

  • (Fixnum)


3969
3970
3971
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3969

def file_size
  @file_size
end

#flash_versionFixnum

Flash version of the asset. This is a read-only field. Applicable to the following creative types: FLASH_INPAGE, all RICH_MEDIA, and all VPAID. Applicable to DISPLAY when the primary asset type is not HTML_IMAGE. Corresponds to the JSON property flashVersion

Returns:

  • (Fixnum)


3976
3977
3978
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3976

def flash_version
  @flash_version
end

#frame_rateFloat

Video frame rate for video asset in frames per second. This is a read-only field. Applicable to the following creative types: INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property frameRate

Returns:

  • (Float)


3983
3984
3985
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3983

def frame_rate
  @frame_rate
end

#hide_flash_objectsBoolean Also known as: hide_flash_objects?

Whether to hide Flash objects flag for an asset. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property hideFlashObjects

Returns:

  • (Boolean)


3989
3990
3991
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3989

def hide_flash_objects
  @hide_flash_objects
end

#hide_selection_boxesBoolean Also known as: hide_selection_boxes?

Whether to hide selection boxes flag for an asset. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property hideSelectionBoxes

Returns:

  • (Boolean)


3996
3997
3998
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 3996

def hide_selection_boxes
  @hide_selection_boxes
end

#horizontally_lockedBoolean Also known as: horizontally_locked?

Whether the asset is horizontally locked. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property horizontallyLocked

Returns:

  • (Boolean)


4003
4004
4005
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4003

def horizontally_locked
  @horizontally_locked
end

#idFixnum

Numeric ID of this creative asset. This is a required field and should not be modified. Applicable to all but the following creative types: all REDIRECT and TRACKING_TEXT. Corresponds to the JSON property id

Returns:

  • (Fixnum)


4011
4012
4013
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4011

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



4016
4017
4018
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4016

def id_dimension_value
  @id_dimension_value
end

#media_durationFloat

Detected duration for audio or video asset. This is a read-only field. Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property mediaDuration

Returns:

  • (Float)


4023
4024
4025
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4023

def media_duration
  @media_duration
end

#mime_typeString

Detected MIME type for audio or video asset. This is a read-only field. Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property mimeType

Returns:

  • (String)


4030
4031
4032
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4030

def mime_type
  @mime_type
end

#offsetGoogle::Apis::DfareportingV5::OffsetPosition

Offset Position. Corresponds to the JSON property offset



4035
4036
4037
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4035

def offset
  @offset
end

#orientationString

Orientation of video asset. This is a read-only, auto-generated field. Corresponds to the JSON property orientation

Returns:

  • (String)


4040
4041
4042
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4040

def orientation
  @orientation
end

#original_backupBoolean Also known as: original_backup?

Whether the backup asset is original or changed by the user in Campaign Manager. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property originalBackup

Returns:

  • (Boolean)


4046
4047
4048
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4046

def original_backup
  @original_backup
end

#polite_loadBoolean Also known as: polite_load?

Whether this asset is used as a polite load asset. Corresponds to the JSON property politeLoad

Returns:

  • (Boolean)


4052
4053
4054
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4052

def polite_load
  @polite_load
end

#positionGoogle::Apis::DfareportingV5::OffsetPosition

Offset Position. Corresponds to the JSON property position



4058
4059
4060
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4058

def position
  @position
end

#position_left_unitString

Offset left unit for an asset. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property positionLeftUnit

Returns:

  • (String)


4064
4065
4066
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4064

def position_left_unit
  @position_left_unit
end

#position_top_unitString

Offset top unit for an asset. This is a read-only field if the asset displayType is ASSET_DISPLAY_TYPE_OVERLAY. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property positionTopUnit

Returns:

  • (String)


4071
4072
4073
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4071

def position_top_unit
  @position_top_unit
end

#progressive_serving_urlString

Progressive URL for video asset. This is a read-only field. Applicable to the following creative types: INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property progressiveServingUrl

Returns:

  • (String)


4077
4078
4079
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4077

def progressive_serving_url
  @progressive_serving_url
end

#pushdownBoolean Also known as: pushdown?

Whether the asset pushes down other content. Applicable to the following creative types: all RICH_MEDIA. Additionally, only applicable when the asset offsets are 0, the collapsedSize.width matches size.width, and the collapsedSize.height is less than size.height. Corresponds to the JSON property pushdown

Returns:

  • (Boolean)


4085
4086
4087
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4085

def pushdown
  @pushdown
end

#pushdown_durationFloat

Pushdown duration in seconds for an asset. Applicable to the following creative types: all RICH_MEDIA.Additionally, only applicable when the asset pushdown field is true, the offsets are 0, the collapsedSize.width matches size.width, and the collapsedSize.height is less than size.height. Acceptable values are 0 to 9.99, inclusive. Corresponds to the JSON property pushdownDuration

Returns:

  • (Float)


4095
4096
4097
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4095

def pushdown_duration
  @pushdown_duration
end

#roleString

Role of the asset in relation to creative. Applicable to all but the following creative types: all REDIRECT and TRACKING_TEXT. This is a required field. PRIMARY applies to DISPLAY, FLASH_INPAGE, HTML5_BANNER, IMAGE, DISPLAY_IMAGE_GALLERY, all RICH_MEDIA (which may contain multiple primary assets), and all VPAID creatives. BACKUP_IMAGE applies to FLASH_INPAGE, HTML5_BANNER, all RICH_MEDIA, and all VPAID creatives. Applicable to DISPLAY when the primary asset type is not HTML_IMAGE. ADDITIONAL_IMAGE and ADDITIONAL_FLASH apply to FLASH_INPAGE creatives. OTHER refers to assets from sources other than Campaign Manager, such as Studio uploaded assets, applicable to all RICH_MEDIA and all VPAID creatives. PARENT_VIDEO refers to videos uploaded by the user in Campaign Manager and is applicable to INSTREAM_VIDEO and VPAID_LINEAR_VIDEO creatives. TRANSCODED_VIDEO refers to videos transcoded by Campaign Manager from PARENT_VIDEO assets and is applicable to INSTREAM_VIDEO and VPAID_LINEAR_VIDEO creatives. ALTERNATE_VIDEO refers to the Campaign Manager representation of child asset videos from Studio, and is applicable to VPAID_LINEAR_VIDEO creatives. These cannot be added or removed within Campaign Manager. For VPAID_LINEAR_VIDEO creatives, PARENT_VIDEO, TRANSCODED_VIDEO and ALTERNATE_VIDEO assets that are marked active serve as backup in case the VPAID creative cannot be served. Only PARENT_VIDEO assets can be added or removed for an INSTREAM_VIDEO or VPAID_LINEAR_VIDEO creative. PARENT_AUDIO refers to audios uploaded by the user in Campaign Manager and is applicable to INSTREAM_AUDIO creatives. TRANSCODED_AUDIO refers to audios transcoded by Campaign Manager from PARENT_AUDIO assets and is applicable to INSTREAM_AUDIO creatives. Corresponds to the JSON property role

Returns:

  • (String)


4123
4124
4125
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4123

def role
  @role
end

#sizeGoogle::Apis::DfareportingV5::Size

Represents the dimensions of ads, placements, creatives, or creative assets. Corresponds to the JSON property size



4128
4129
4130
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4128

def size
  @size
end

#ssl_compliantBoolean Also known as: ssl_compliant?

Whether the asset is SSL-compliant. This is a read-only field. Applicable to all but the following creative types: all REDIRECT and TRACKING_TEXT. Corresponds to the JSON property sslCompliant

Returns:

  • (Boolean)


4134
4135
4136
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4134

def ssl_compliant
  @ssl_compliant
end

#start_time_typeString

Initial wait time type before making the asset visible. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property startTimeType

Returns:

  • (String)


4141
4142
4143
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4141

def start_time_type
  @start_time_type
end

#streaming_serving_urlString

Streaming URL for video asset. This is a read-only field. Applicable to the following creative types: INSTREAM_VIDEO and all VPAID. Corresponds to the JSON property streamingServingUrl

Returns:

  • (String)


4147
4148
4149
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4147

def streaming_serving_url
  @streaming_serving_url
end

#transparencyBoolean Also known as: transparency?

Whether the asset is transparent. Applicable to the following creative types: all RICH_MEDIA. Additionally, only applicable to HTML5 assets. Corresponds to the JSON property transparency

Returns:

  • (Boolean)


4153
4154
4155
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4153

def transparency
  @transparency
end

#vertically_lockedBoolean Also known as: vertically_locked?

Whether the asset is vertically locked. This is a read-only field. Applicable to the following creative types: all RICH_MEDIA. Corresponds to the JSON property verticallyLocked

Returns:

  • (Boolean)


4160
4161
4162
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4160

def vertically_locked
  @vertically_locked
end

#window_modeString

Window mode options for flash assets. Applicable to the following creative types: FLASH_INPAGE, RICH_MEDIA_DISPLAY_EXPANDING, RICH_MEDIA_IM_EXPAND, RICH_MEDIA_DISPLAY_BANNER, and RICH_MEDIA_INPAGE_FLOATING. Corresponds to the JSON property windowMode

Returns:

  • (String)


4168
4169
4170
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4168

def window_mode
  @window_mode
end

#z_indexFixnum

zIndex value of an asset. Applicable to the following creative types: all RICH_MEDIA.Additionally, only applicable to assets whose displayType is NOT one of the following types: ASSET_DISPLAY_TYPE_INPAGE or ASSET_DISPLAY_TYPE_OVERLAY. Acceptable values are -999999999 to 999999999, inclusive. Corresponds to the JSON property zIndex

Returns:

  • (Fixnum)


4177
4178
4179
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4177

def z_index
  @z_index
end

#zip_filenameString

File name of zip file. This is a read-only field. Applicable to the following creative types: HTML5_BANNER. Corresponds to the JSON property zipFilename

Returns:

  • (String)


4183
4184
4185
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4183

def zip_filename
  @zip_filename
end

#zip_filesizeString

Size of zip file. This is a read-only field. Applicable to the following creative types: HTML5_BANNER. Corresponds to the JSON property zipFilesize

Returns:

  • (String)


4189
4190
4191
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4189

def zip_filesize
  @zip_filesize
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4196
4197
4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
4212
4213
4214
4215
4216
4217
4218
4219
4220
4221
4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4196

def update!(**args)
  @action_script3 = args[:action_script3] if args.key?(:action_script3)
  @active = args[:active] if args.key?(:active)
  @additional_sizes = args[:additional_sizes] if args.key?(:additional_sizes)
  @alignment = args[:alignment] if args.key?(:alignment)
  @artwork_type = args[:artwork_type] if args.key?(:artwork_type)
  @asset_identifier = args[:asset_identifier] if args.key?(:asset_identifier)
  @audio_bit_rate = args[:audio_bit_rate] if args.key?(:audio_bit_rate)
  @audio_sample_rate = args[:audio_sample_rate] if args.key?(:audio_sample_rate)
  @backup_image_exit = args[:backup_image_exit] if args.key?(:backup_image_exit)
  @bit_rate = args[:bit_rate] if args.key?(:bit_rate)
  @child_asset_type = args[:child_asset_type] if args.key?(:child_asset_type)
  @collapsed_size = args[:collapsed_size] if args.key?(:collapsed_size)
  @companion_creative_ids = args[:companion_creative_ids] if args.key?(:companion_creative_ids)
  @custom_start_time_value = args[:custom_start_time_value] if args.key?(:custom_start_time_value)
  @detected_features = args[:detected_features] if args.key?(:detected_features)
  @display_type = args[:display_type] if args.key?(:display_type)
  @duration = args[:duration] if args.key?(:duration)
  @duration_type = args[:duration_type] if args.key?(:duration_type)
  @expanded_dimension = args[:expanded_dimension] if args.key?(:expanded_dimension)
  @file_size = args[:file_size] if args.key?(:file_size)
  @flash_version = args[:flash_version] if args.key?(:flash_version)
  @frame_rate = args[:frame_rate] if args.key?(:frame_rate)
  @hide_flash_objects = args[:hide_flash_objects] if args.key?(:hide_flash_objects)
  @hide_selection_boxes = args[:hide_selection_boxes] if args.key?(:hide_selection_boxes)
  @horizontally_locked = args[:horizontally_locked] if args.key?(:horizontally_locked)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @media_duration = args[:media_duration] if args.key?(:media_duration)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @offset = args[:offset] if args.key?(:offset)
  @orientation = args[:orientation] if args.key?(:orientation)
  @original_backup = args[:original_backup] if args.key?(:original_backup)
  @polite_load = args[:polite_load] if args.key?(:polite_load)
  @position = args[:position] if args.key?(:position)
  @position_left_unit = args[:position_left_unit] if args.key?(:position_left_unit)
  @position_top_unit = args[:position_top_unit] if args.key?(:position_top_unit)
  @progressive_serving_url = args[:progressive_serving_url] if args.key?(:progressive_serving_url)
  @pushdown = args[:pushdown] if args.key?(:pushdown)
  @pushdown_duration = args[:pushdown_duration] if args.key?(:pushdown_duration)
  @role = args[:role] if args.key?(:role)
  @size = args[:size] if args.key?(:size)
  @ssl_compliant = args[:ssl_compliant] if args.key?(:ssl_compliant)
  @start_time_type = args[:start_time_type] if args.key?(:start_time_type)
  @streaming_serving_url = args[:streaming_serving_url] if args.key?(:streaming_serving_url)
  @transparency = args[:transparency] if args.key?(:transparency)
  @vertically_locked = args[:vertically_locked] if args.key?(:vertically_locked)
  @window_mode = args[:window_mode] if args.key?(:window_mode)
  @z_index = args[:z_index] if args.key?(:z_index)
  @zip_filename = args[:zip_filename] if args.key?(:zip_filename)
  @zip_filesize = args[:zip_filesize] if args.key?(:zip_filesize)
end