Class: Google::Apis::DfareportingV5::CreativeCustomEvent
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::CreativeCustomEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Creative Custom Event.
Instance Attribute Summary collapse
-
#advertiser_custom_event_id ⇒ Fixnum
Unique ID of this event used by Reporting and Data Transfer.
-
#advertiser_custom_event_name ⇒ String
User-entered name for the event.
-
#advertiser_custom_event_type ⇒ String
Type of the event.
-
#artwork_label ⇒ String
Artwork label column, used to link events in Campaign Manager back to events in Studio.
-
#artwork_type ⇒ String
Artwork type used by the creative.This is a read-only field.
-
#exit_click_through_url ⇒ Google::Apis::DfareportingV5::CreativeClickThroughUrl
Click-through URL Corresponds to the JSON property
exitClickThroughUrl. -
#id ⇒ Fixnum
ID of this event.
-
#popup_window_properties ⇒ Google::Apis::DfareportingV5::PopupWindowProperties
Popup Window Properties.
-
#target_type ⇒ String
Target type used by the event.
-
#video_reporting_id ⇒ String
Video reporting ID, used to differentiate multiple videos in a single creative.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreativeCustomEvent
constructor
A new instance of CreativeCustomEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreativeCustomEvent
Returns a new instance of CreativeCustomEvent.
4614 4615 4616 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_custom_event_id ⇒ Fixnum
Unique ID of this event used by Reporting and Data Transfer. This is a read-
only field.
Corresponds to the JSON property advertiserCustomEventId
4564 4565 4566 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4564 def advertiser_custom_event_id @advertiser_custom_event_id end |
#advertiser_custom_event_name ⇒ String
User-entered name for the event.
Corresponds to the JSON property advertiserCustomEventName
4569 4570 4571 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4569 def advertiser_custom_event_name @advertiser_custom_event_name end |
#advertiser_custom_event_type ⇒ String
Type of the event. This is a read-only field.
Corresponds to the JSON property advertiserCustomEventType
4574 4575 4576 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4574 def advertiser_custom_event_type @advertiser_custom_event_type end |
#artwork_label ⇒ String
Artwork label column, used to link events in Campaign Manager back to events
in Studio. This is a required field and should not be modified after insertion.
Corresponds to the JSON property artworkLabel
4580 4581 4582 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4580 def artwork_label @artwork_label end |
#artwork_type ⇒ String
Artwork type used by the creative.This is a read-only field.
Corresponds to the JSON property artworkType
4585 4586 4587 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4585 def artwork_type @artwork_type end |
#exit_click_through_url ⇒ Google::Apis::DfareportingV5::CreativeClickThroughUrl
Click-through URL
Corresponds to the JSON property exitClickThroughUrl
4590 4591 4592 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4590 def exit_click_through_url @exit_click_through_url end |
#id ⇒ Fixnum
ID of this event. This is a required field and should not be modified after
insertion.
Corresponds to the JSON property id
4596 4597 4598 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4596 def id @id end |
#popup_window_properties ⇒ Google::Apis::DfareportingV5::PopupWindowProperties
Popup Window Properties.
Corresponds to the JSON property popupWindowProperties
4601 4602 4603 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4601 def popup_window_properties @popup_window_properties end |
#target_type ⇒ String
Target type used by the event.
Corresponds to the JSON property targetType
4606 4607 4608 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4606 def target_type @target_type end |
#video_reporting_id ⇒ String
Video reporting ID, used to differentiate multiple videos in a single creative.
This is a read-only field.
Corresponds to the JSON property videoReportingId
4612 4613 4614 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4612 def video_reporting_id @video_reporting_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4619 def update!(**args) @advertiser_custom_event_id = args[:advertiser_custom_event_id] if args.key?(:advertiser_custom_event_id) @advertiser_custom_event_name = args[:advertiser_custom_event_name] if args.key?(:advertiser_custom_event_name) @advertiser_custom_event_type = args[:advertiser_custom_event_type] if args.key?(:advertiser_custom_event_type) @artwork_label = args[:artwork_label] if args.key?(:artwork_label) @artwork_type = args[:artwork_type] if args.key?(:artwork_type) @exit_click_through_url = args[:exit_click_through_url] if args.key?(:exit_click_through_url) @id = args[:id] if args.key?(:id) @popup_window_properties = args[:popup_window_properties] if args.key?(:popup_window_properties) @target_type = args[:target_type] if args.key?(:target_type) @video_reporting_id = args[:video_reporting_id] if args.key?(:video_reporting_id) end |