Class: Google::Apis::DfareportingV5::CreativeCustomEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Creative Custom Event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeCustomEvent

Returns a new instance of CreativeCustomEvent.



4580
4581
4582
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_custom_event_idFixnum

Unique ID of this event used by Reporting and Data Transfer. This is a read- only field. Corresponds to the JSON property advertiserCustomEventId

Returns:

  • (Fixnum)


4530
4531
4532
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4530

def advertiser_custom_event_id
  @advertiser_custom_event_id
end

#advertiser_custom_event_nameString

User-entered name for the event. Corresponds to the JSON property advertiserCustomEventName

Returns:

  • (String)


4535
4536
4537
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4535

def advertiser_custom_event_name
  @advertiser_custom_event_name
end

#advertiser_custom_event_typeString

Type of the event. This is a read-only field. Corresponds to the JSON property advertiserCustomEventType

Returns:

  • (String)


4540
4541
4542
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4540

def advertiser_custom_event_type
  @advertiser_custom_event_type
end

#artwork_labelString

Artwork label column, used to link events in Campaign Manager back to events in Studio. This is a required field and should not be modified after insertion. Corresponds to the JSON property artworkLabel

Returns:

  • (String)


4546
4547
4548
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4546

def artwork_label
  @artwork_label
end

#artwork_typeString

Artwork type used by the creative.This is a read-only field. Corresponds to the JSON property artworkType

Returns:

  • (String)


4551
4552
4553
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4551

def artwork_type
  @artwork_type
end

#exit_click_through_urlGoogle::Apis::DfareportingV5::CreativeClickThroughUrl

Click-through URL Corresponds to the JSON property exitClickThroughUrl



4556
4557
4558
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4556

def exit_click_through_url
  @exit_click_through_url
end

#idFixnum

ID of this event. This is a required field and should not be modified after insertion. Corresponds to the JSON property id

Returns:

  • (Fixnum)


4562
4563
4564
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4562

def id
  @id
end

Popup Window Properties. Corresponds to the JSON property popupWindowProperties



4567
4568
4569
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4567

def popup_window_properties
  @popup_window_properties
end

#target_typeString

Target type used by the event. Corresponds to the JSON property targetType

Returns:

  • (String)


4572
4573
4574
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4572

def target_type
  @target_type
end

#video_reporting_idString

Video reporting ID, used to differentiate multiple videos in a single creative. This is a read-only field. Corresponds to the JSON property videoReportingId

Returns:

  • (String)


4578
4579
4580
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4578

def video_reporting_id
  @video_reporting_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4585
4586
4587
4588
4589
4590
4591
4592
4593
4594
4595
4596
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4585

def update!(**args)
  @advertiser_custom_event_id = args[:advertiser_custom_event_id] if args.key?(:advertiser_custom_event_id)
  @advertiser_custom_event_name = args[:advertiser_custom_event_name] if args.key?(:advertiser_custom_event_name)
  @advertiser_custom_event_type = args[:advertiser_custom_event_type] if args.key?(:advertiser_custom_event_type)
  @artwork_label = args[:artwork_label] if args.key?(:artwork_label)
  @artwork_type = args[:artwork_type] if args.key?(:artwork_type)
  @exit_click_through_url = args[:exit_click_through_url] if args.key?(:exit_click_through_url)
  @id = args[:id] if args.key?(:id)
  @popup_window_properties = args[:popup_window_properties] if args.key?(:popup_window_properties)
  @target_type = args[:target_type] if args.key?(:target_type)
  @video_reporting_id = args[:video_reporting_id] if args.key?(:video_reporting_id)
end