Class: Google::Apis::DfareportingV5::CreativeGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a creative group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeGroup

Returns a new instance of CreativeGroup.



4831
4832
4833
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this creative group. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


4788
4789
4790
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4788

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this creative group. This is a required field on insertion. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


4793
4794
4795
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4793

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



4798
4799
4800
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4798

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#group_numberFixnum

Subgroup of the creative group. Assign your creative groups to a subgroup in order to filter or manage them more easily. This field is required on insertion and is read-only after insertion. Acceptable values are 1 to 2, inclusive. Corresponds to the JSON property groupNumber

Returns:

  • (Fixnum)


4806
4807
4808
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4806

def group_number
  @group_number
end

#idFixnum

ID of this creative group. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


4811
4812
4813
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4811

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#creativeGroup". Corresponds to the JSON property kind

Returns:

  • (String)


4817
4818
4819
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4817

def kind
  @kind
end

#nameString

Name of this creative group. This is a required field and must be less than 256 characters long and unique among creative groups of the same advertiser. Corresponds to the JSON property name

Returns:

  • (String)


4823
4824
4825
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4823

def name
  @name
end

#subaccount_idFixnum

Subaccount ID of this creative group. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


4829
4830
4831
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4829

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4836

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @group_number = args[:group_number] if args.key?(:group_number)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end