Class: Google::Apis::DfareportingV5::CreativeRotation
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::CreativeRotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Creative Rotation.
Instance Attribute Summary collapse
-
#creative_assignments ⇒ Array<Google::Apis::DfareportingV5::CreativeAssignment>
Creative assignments in this creative rotation.
-
#creative_optimization_configuration_id ⇒ Fixnum
Creative optimization configuration that is used by this ad.
-
#type ⇒ String
Type of creative rotation.
-
#weight_calculation_strategy ⇒ String
Strategy for calculating weights.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreativeRotation
constructor
A new instance of CreativeRotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreativeRotation
Returns a new instance of CreativeRotation.
5006 5007 5008 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creative_assignments ⇒ Array<Google::Apis::DfareportingV5::CreativeAssignment>
Creative assignments in this creative rotation.
Corresponds to the JSON property creativeAssignments
4985 4986 4987 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4985 def creative_assignments @creative_assignments end |
#creative_optimization_configuration_id ⇒ Fixnum
Creative optimization configuration that is used by this ad. It should refer
to one of the existing optimization configurations in the ad's campaign. If it
is unset or set to 0, then the campaign's default optimization configuration
will be used for this ad.
Corresponds to the JSON property creativeOptimizationConfigurationId
4993 4994 4995 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4993 def creative_optimization_configuration_id @creative_optimization_configuration_id end |
#type ⇒ String
Type of creative rotation. Can be used to specify whether to use sequential or
random rotation.
Corresponds to the JSON property type
4999 5000 5001 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4999 def type @type end |
#weight_calculation_strategy ⇒ String
Strategy for calculating weights. Used with CREATIVE_ROTATION_TYPE_RANDOM.
Corresponds to the JSON property weightCalculationStrategy
5004 5005 5006 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5004 def weight_calculation_strategy @weight_calculation_strategy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5011 5012 5013 5014 5015 5016 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5011 def update!(**args) @creative_assignments = args[:creative_assignments] if args.key?(:creative_assignments) @creative_optimization_configuration_id = args[:creative_optimization_configuration_id] if args.key?(:creative_optimization_configuration_id) @type = args[:type] if args.key?(:type) @weight_calculation_strategy = args[:weight_calculation_strategy] if args.key?(:weight_calculation_strategy) end |