Class: Google::Apis::DfareportingV5::CreativeRotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Creative Rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeRotation

Returns a new instance of CreativeRotation.



4972
4973
4974
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creative_assignmentsArray<Google::Apis::DfareportingV5::CreativeAssignment>

Creative assignments in this creative rotation. Corresponds to the JSON property creativeAssignments



4951
4952
4953
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4951

def creative_assignments
  @creative_assignments
end

#creative_optimization_configuration_idFixnum

Creative optimization configuration that is used by this ad. It should refer to one of the existing optimization configurations in the ad's campaign. If it is unset or set to 0, then the campaign's default optimization configuration will be used for this ad. Corresponds to the JSON property creativeOptimizationConfigurationId

Returns:

  • (Fixnum)


4959
4960
4961
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4959

def creative_optimization_configuration_id
  @creative_optimization_configuration_id
end

#typeString

Type of creative rotation. Can be used to specify whether to use sequential or random rotation. Corresponds to the JSON property type

Returns:

  • (String)


4965
4966
4967
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4965

def type
  @type
end

#weight_calculation_strategyString

Strategy for calculating weights. Used with CREATIVE_ROTATION_TYPE_RANDOM. Corresponds to the JSON property weightCalculationStrategy

Returns:

  • (String)


4970
4971
4972
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4970

def weight_calculation_strategy
  @weight_calculation_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4977
4978
4979
4980
4981
4982
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 4977

def update!(**args)
  @creative_assignments = args[:creative_assignments] if args.key?(:creative_assignments)
  @creative_optimization_configuration_id = args[:creative_optimization_configuration_id] if args.key?(:creative_optimization_configuration_id)
  @type = args[:type] if args.key?(:type)
  @weight_calculation_strategy = args[:weight_calculation_strategy] if args.key?(:weight_calculation_strategy)
end