Class: Google::Apis::DfareportingV5::CrossDimensionReachReportCompatibleFields

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents fields that are compatible to be selected for a report of type " CROSS_DIMENSION_REACH".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossDimensionReachReportCompatibleFields

Returns a new instance of CrossDimensionReachReportCompatibleFields.



5052
5053
5054
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#breakdownArray<Google::Apis::DfareportingV5::Dimension>

Dimensions which are compatible to be selected in the "breakdown" section of the report. Corresponds to the JSON property breakdown



5026
5027
5028
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5026

def breakdown
  @breakdown
end

#dimension_filtersArray<Google::Apis::DfareportingV5::Dimension>

Dimensions which are compatible to be selected in the "dimensionFilters" section of the report. Corresponds to the JSON property dimensionFilters



5032
5033
5034
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5032

def dimension_filters
  @dimension_filters
end

#kindString

The kind of resource this is, in this case dfareporting# crossDimensionReachReportCompatibleFields. Corresponds to the JSON property kind

Returns:

  • (String)


5038
5039
5040
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5038

def kind
  @kind
end

#metricsArray<Google::Apis::DfareportingV5::Metric>

Metrics which are compatible to be selected in the "metricNames" section of the report. Corresponds to the JSON property metrics



5044
5045
5046
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5044

def metrics
  @metrics
end

#overlap_metricsArray<Google::Apis::DfareportingV5::Metric>

Metrics which are compatible to be selected in the "overlapMetricNames" section of the report. Corresponds to the JSON property overlapMetrics



5050
5051
5052
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5050

def overlap_metrics
  @overlap_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5057
5058
5059
5060
5061
5062
5063
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5057

def update!(**args)
  @breakdown = args[:breakdown] if args.key?(:breakdown)
  @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters)
  @kind = args[:kind] if args.key?(:kind)
  @metrics = args[:metrics] if args.key?(:metrics)
  @overlap_metrics = args[:overlap_metrics] if args.key?(:overlap_metrics)
end