Class: Google::Apis::DfareportingV5::CustomFloodlightVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

A custom floodlight variable. Can be used in both batchinsert and batchupdate. Adding this in batchupdate will update or append the variable to the existing list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomFloodlightVariable

Returns a new instance of CustomFloodlightVariable.



5132
5133
5134
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#customFloodlightVariable". Corresponds to the JSON property kind

Returns:

  • (String)


5118
5119
5120
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5118

def kind
  @kind
end

#typeString

The type of custom floodlight variable to supply a value for. These map to the "u[1-100]=" in the tags. Corresponds to the JSON property type

Returns:

  • (String)


5124
5125
5126
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5124

def type
  @type
end

#valueString

The value of the custom floodlight variable. The length of string must not exceed 100 characters. Corresponds to the JSON property value

Returns:

  • (String)


5130
5131
5132
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5130

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5137
5138
5139
5140
5141
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5137

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end