Class: Google::Apis::DfareportingV5::CustomViewabilityMetricConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::CustomViewabilityMetricConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
The attributes, like playtime and percent onscreen, that define the Custom Viewability Metric.
Instance Attribute Summary collapse
-
#audible ⇒ Boolean
(also: #audible?)
Whether the video must be audible to count an impression.
-
#time_millis ⇒ Fixnum
The time in milliseconds the video must play for the Custom Viewability Metric to count an impression.
-
#time_percent ⇒ Fixnum
The percentage of video that must play for the Custom Viewability Metric to count an impression.
-
#viewability_percent ⇒ Fixnum
The percentage of video that must be on screen for the Custom Viewability Metric to count an impression.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomViewabilityMetricConfiguration
constructor
A new instance of CustomViewabilityMetricConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomViewabilityMetricConfiguration
Returns a new instance of CustomViewabilityMetricConfiguration.
5289 5290 5291 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audible ⇒ Boolean Also known as: audible?
Whether the video must be audible to count an impression.
Corresponds to the JSON property audible
5266 5267 5268 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5266 def audible @audible end |
#time_millis ⇒ Fixnum
The time in milliseconds the video must play for the Custom Viewability Metric
to count an impression. If both this and timePercent are specified, the
earlier of the two will be used.
Corresponds to the JSON property timeMillis
5274 5275 5276 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5274 def time_millis @time_millis end |
#time_percent ⇒ Fixnum
The percentage of video that must play for the Custom Viewability Metric to
count an impression. If both this and timeMillis are specified, the earlier of
the two will be used.
Corresponds to the JSON property timePercent
5281 5282 5283 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5281 def time_percent @time_percent end |
#viewability_percent ⇒ Fixnum
The percentage of video that must be on screen for the Custom Viewability
Metric to count an impression.
Corresponds to the JSON property viewabilityPercent
5287 5288 5289 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5287 def viewability_percent @viewability_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5294 5295 5296 5297 5298 5299 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5294 def update!(**args) @audible = args[:audible] if args.key?(:audible) @time_millis = args[:time_millis] if args.key?(:time_millis) @time_percent = args[:time_percent] if args.key?(:time_percent) @viewability_percent = args[:viewability_percent] if args.key?(:viewability_percent) end |