Class: Google::Apis::DfareportingV5::DateRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents a date range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DateRange

Returns a new instance of DateRange.



5326
5327
5328
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dateDate

Corresponds to the JSON property endDate

Returns:

  • (Date)


5309
5310
5311
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5309

def end_date
  @end_date
end

#kindString

The kind of resource this is, in this case dfareporting#dateRange. Corresponds to the JSON property kind

Returns:

  • (String)


5314
5315
5316
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5314

def kind
  @kind
end

#relative_date_rangeString

The date range relative to the date of when the report is run. Corresponds to the JSON property relativeDateRange

Returns:

  • (String)


5319
5320
5321
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5319

def relative_date_range
  @relative_date_range
end

#start_dateDate

Corresponds to the JSON property startDate

Returns:

  • (Date)


5324
5325
5326
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5324

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5331
5332
5333
5334
5335
5336
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5331

def update!(**args)
  @end_date = args[:end_date] if args.key?(:end_date)
  @kind = args[:kind] if args.key?(:kind)
  @relative_date_range = args[:relative_date_range] if args.key?(:relative_date_range)
  @start_date = args[:start_date] if args.key?(:start_date)
end