Class: Google::Apis::DfareportingV5::DayPartTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Day Part Targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DayPartTargeting

Returns a new instance of DayPartTargeting.



5366
5367
5368
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#days_of_weekArray<String>

Days of the week when the ad will serve. Acceptable values are: - "SUNDAY" - " MONDAY" - "TUESDAY" - "WEDNESDAY" - "THURSDAY" - "FRIDAY" - "SATURDAY" Corresponds to the JSON property daysOfWeek

Returns:

  • (Array<String>)


5347
5348
5349
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5347

def days_of_week
  @days_of_week
end

#hours_of_dayArray<Fixnum>

Hours of the day when the ad will serve, where 0 is midnight to 1 AM and 23 is 11 PM to midnight. Can be specified with days of week, in which case the ad would serve during these hours on the specified days. For example if Monday, Wednesday, Friday are the days of week specified and 9-10am, 3-5pm (hours 9, 15, and 16) is specified, the ad would serve Monday, Wednesdays, and Fridays at 9-10am and 3-5pm. Acceptable values are 0 to 23, inclusive. Corresponds to the JSON property hoursOfDay

Returns:

  • (Array<Fixnum>)


5357
5358
5359
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5357

def hours_of_day
  @hours_of_day
end

#user_local_timeBoolean Also known as: user_local_time?

Whether or not to use the user's local time. If false, the America/New York time zone applies. Corresponds to the JSON property userLocalTime

Returns:

  • (Boolean)


5363
5364
5365
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5363

def user_local_time
  @user_local_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5371
5372
5373
5374
5375
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5371

def update!(**args)
  @days_of_week = args[:days_of_week] if args.key?(:days_of_week)
  @hours_of_day = args[:hours_of_day] if args.key?(:hours_of_day)
  @user_local_time = args[:user_local_time] if args.key?(:user_local_time)
end