Class: Google::Apis::DfareportingV5::DeepLink
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DeepLink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains information about a landing page deep link.
Instance Attribute Summary collapse
-
#app_url ⇒ String
The URL of the mobile app being linked to.
-
#fallback_url ⇒ String
The fallback URL.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#mobile_app ⇒ Google::Apis::DfareportingV5::MobileApp
Contains information about a mobile app.
-
#remarketing_list_ids ⇒ Array<Fixnum>
Ads served to users on these remarketing lists will use this deep link.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeepLink
constructor
A new instance of DeepLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeepLink
Returns a new instance of DeepLink.
5410 5411 5412 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_url ⇒ String
The URL of the mobile app being linked to.
Corresponds to the JSON property appUrl
5385 5386 5387 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5385 def app_url @app_url end |
#fallback_url ⇒ String
The fallback URL. This URL will be served to users who do not have the mobile
app installed.
Corresponds to the JSON property fallbackUrl
5391 5392 5393 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5391 def fallback_url @fallback_url end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#deepLink".
Corresponds to the JSON property kind
5397 5398 5399 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5397 def kind @kind end |
#mobile_app ⇒ Google::Apis::DfareportingV5::MobileApp
Contains information about a mobile app. Used as a landing page deep link.
Corresponds to the JSON property mobileApp
5402 5403 5404 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5402 def mobile_app @mobile_app end |
#remarketing_list_ids ⇒ Array<Fixnum>
Ads served to users on these remarketing lists will use this deep link.
Applicable when mobileApp.directory is APPLE_APP_STORE.
Corresponds to the JSON property remarketingListIds
5408 5409 5410 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5408 def remarketing_list_ids @remarketing_list_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5415 5416 5417 5418 5419 5420 5421 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5415 def update!(**args) @app_url = args[:app_url] if args.key?(:app_url) @fallback_url = args[:fallback_url] if args.key?(:fallback_url) @kind = args[:kind] if args.key?(:kind) @mobile_app = args[:mobile_app] if args.key?(:mobile_app) @remarketing_list_ids = args[:remarketing_list_ids] if args.key?(:remarketing_list_ids) end |