Class: Google::Apis::DfareportingV5::DimensionValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents a DimensionValue resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DimensionValue

Returns a new instance of DimensionValue.



5701
5702
5703
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_nameString

The name of the dimension. Corresponds to the JSON property dimensionName

Returns:

  • (String)


5670
5671
5672
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5670

def dimension_name
  @dimension_name
end

#etagString

The eTag of this response for caching purposes. Corresponds to the JSON property etag

Returns:

  • (String)


5675
5676
5677
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5675

def etag
  @etag
end

#idString

The ID associated with the value if available. Corresponds to the JSON property id

Returns:

  • (String)


5680
5681
5682
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5680

def id
  @id
end

#kindString

The kind of resource this is, in this case dfareporting#dimensionValue. Corresponds to the JSON property kind

Returns:

  • (String)


5685
5686
5687
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5685

def kind
  @kind
end

#match_typeString

Determines how the 'value' field is matched when filtering. If not specified, defaults to EXACT. If set to WILDCARD_EXPRESSION, '' is allowed as a placeholder for variable length character sequences, and it can be escaped with a backslash. Note, only paid search dimensions ('dfa:paidSearch') allow a matchType other than EXACT. Corresponds to the JSON property matchType

Returns:

  • (String)


5694
5695
5696
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5694

def match_type
  @match_type
end

#valueString

The value of the dimension. Corresponds to the JSON property value

Returns:

  • (String)


5699
5700
5701
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5699

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5706
5707
5708
5709
5710
5711
5712
5713
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5706

def update!(**args)
  @dimension_name = args[:dimension_name] if args.key?(:dimension_name)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @match_type = args[:match_type] if args.key?(:match_type)
  @value = args[:value] if args.key?(:value)
end