Class: Google::Apis::DfareportingV5::DimensionValueList
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DimensionValueList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents the list of DimensionValue resources.
Instance Attribute Summary collapse
-
#etag ⇒ String
The eTag of this response for caching purposes.
-
#items ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The dimension values returned in this response.
-
#kind ⇒ String
The kind of list this is, in this case dfareporting#dimensionValueList.
-
#next_page_token ⇒ String
Continuation token used to page through dimension values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DimensionValueList
constructor
A new instance of DimensionValueList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DimensionValueList
Returns a new instance of DimensionValueList.
5777 5778 5779 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
The eTag of this response for caching purposes.
Corresponds to the JSON property etag
5757 5758 5759 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5757 def etag @etag end |
#items ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The dimension values returned in this response.
Corresponds to the JSON property items
5762 5763 5764 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5762 def items @items end |
#kind ⇒ String
The kind of list this is, in this case dfareporting#dimensionValueList.
Corresponds to the JSON property kind
5767 5768 5769 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5767 def kind @kind end |
#next_page_token ⇒ String
Continuation token used to page through dimension values. To retrieve the next
page of results, set the next request's "pageToken" to the value of this field.
The page token is only valid for a limited amount of time and should not be
persisted.
Corresponds to the JSON property nextPageToken
5775 5776 5777 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5775 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5782 5783 5784 5785 5786 5787 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5782 def update!(**args) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |