Class: Google::Apis::DfareportingV5::DimensionValueList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents the list of DimensionValue resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DimensionValueList

Returns a new instance of DimensionValueList.



5743
5744
5745
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

The eTag of this response for caching purposes. Corresponds to the JSON property etag

Returns:

  • (String)


5723
5724
5725
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5723

def etag
  @etag
end

#itemsArray<Google::Apis::DfareportingV5::DimensionValue>

The dimension values returned in this response. Corresponds to the JSON property items



5728
5729
5730
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5728

def items
  @items
end

#kindString

The kind of list this is, in this case dfareporting#dimensionValueList. Corresponds to the JSON property kind

Returns:

  • (String)


5733
5734
5735
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5733

def kind
  @kind
end

#next_page_tokenString

Continuation token used to page through dimension values. To retrieve the next page of results, set the next request's "pageToken" to the value of this field. The page token is only valid for a limited amount of time and should not be persisted. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5741
5742
5743
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5741

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5748
5749
5750
5751
5752
5753
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5748

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end