Class: Google::Apis::DfareportingV5::DimensionValueRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents a DimensionValuesRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DimensionValueRequest

Returns a new instance of DimensionValueRequest.



5785
5786
5787
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_nameString

The name of the dimension for which values should be requested. Corresponds to the JSON property dimensionName

Returns:

  • (String)


5763
5764
5765
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5763

def dimension_name
  @dimension_name
end

#end_dateDate

Corresponds to the JSON property endDate

Returns:

  • (Date)


5768
5769
5770
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5768

def end_date
  @end_date
end

#filtersArray<Google::Apis::DfareportingV5::DimensionFilter>

The list of filters by which to filter values. The filters are ANDed. Corresponds to the JSON property filters



5773
5774
5775
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5773

def filters
  @filters
end

#kindString

The kind of request this is, in this case dfareporting#dimensionValueRequest . Corresponds to the JSON property kind

Returns:

  • (String)


5778
5779
5780
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5778

def kind
  @kind
end

#start_dateDate

Corresponds to the JSON property startDate

Returns:

  • (Date)


5783
5784
5785
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5783

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5790
5791
5792
5793
5794
5795
5796
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5790

def update!(**args)
  @dimension_name = args[:dimension_name] if args.key?(:dimension_name)
  @end_date = args[:end_date] if args.key?(:end_date)
  @filters = args[:filters] if args.key?(:filters)
  @kind = args[:kind] if args.key?(:kind)
  @start_date = args[:start_date] if args.key?(:start_date)
end