Class: Google::Apis::DfareportingV5::DynamicFeed
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DynamicFeed
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains dynamic feed information.
Instance Attribute Summary collapse
-
#content_source ⇒ Google::Apis::DfareportingV5::ContentSource
Contains the content source of the dynamic feed.
-
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#dynamic_feed_id ⇒ Fixnum
Output only.
-
#dynamic_feed_name ⇒ String
Optional.
-
#element ⇒ Google::Apis::DfareportingV5::Element
Contains the element of the dynamic feed.
-
#feed_ingestion_status ⇒ Google::Apis::DfareportingV5::FeedIngestionStatus
Contains the ingestion status of the dynamic feed.
-
#feed_schedule ⇒ Google::Apis::DfareportingV5::FeedSchedule
Contains the schedule of the dynamic feed.
-
#has_published ⇒ Boolean
(also: #has_published?)
Output only.
-
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#status ⇒ String
Output only.
-
#studio_advertiser_id ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DynamicFeed
constructor
A new instance of DynamicFeed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DynamicFeed
Returns a new instance of DynamicFeed.
6058 6059 6060 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6058 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_source ⇒ Google::Apis::DfareportingV5::ContentSource
Contains the content source of the dynamic feed.
Corresponds to the JSON property contentSource
5995 5996 5997 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5995 def content_source @content_source end |
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property createInfo
6000 6001 6002 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6000 def create_info @create_info end |
#dynamic_feed_id ⇒ Fixnum
Output only. Unique ID of this dynamic feed. This is a read-only, auto-
generated field.
Corresponds to the JSON property dynamicFeedId
6006 6007 6008 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6006 def dynamic_feed_id @dynamic_feed_id end |
#dynamic_feed_name ⇒ String
Optional. Name of this dynamic feed. It is defaulted to content source file
name if not provided.
Corresponds to the JSON property dynamicFeedName
6012 6013 6014 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6012 def dynamic_feed_name @dynamic_feed_name end |
#element ⇒ Google::Apis::DfareportingV5::Element
Contains the element of the dynamic feed.
Corresponds to the JSON property element
6017 6018 6019 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6017 def element @element end |
#feed_ingestion_status ⇒ Google::Apis::DfareportingV5::FeedIngestionStatus
Contains the ingestion status of the dynamic feed. Feed ingestion is an
asynchronous process. If the feed create request is successful, feed ingestion
will be processed in the background, including validation, assets retrieval,
and saving the data from the resource link. The processing time is dependent
on the data size in the resource link. This read-only status field contains
the current stage of that processing and its ingestion state.
Corresponds to the JSON property feedIngestionStatus
6027 6028 6029 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6027 def feed_ingestion_status @feed_ingestion_status end |
#feed_schedule ⇒ Google::Apis::DfareportingV5::FeedSchedule
Contains the schedule of the dynamic feed.
Corresponds to the JSON property feedSchedule
6032 6033 6034 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6032 def feed_schedule @feed_schedule end |
#has_published ⇒ Boolean Also known as: has_published?
Output only. Indicates whether the dynamic feed has a published version. This
is a read-only field.
Corresponds to the JSON property hasPublished
6038 6039 6040 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6038 def has_published @has_published end |
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property lastModifiedInfo
6044 6045 6046 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6044 def last_modified_info @last_modified_info end |
#status ⇒ String
Output only. The status of the feed. It is a read-only field that depends on
the the feed ingestion status. The default value is INACTIVE, and it will be
updated to ACTIVE once the feed is ingested successfully.
Corresponds to the JSON property status
6051 6052 6053 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6051 def status @status end |
#studio_advertiser_id ⇒ Fixnum
Required. Advertiser ID of this dynamic feed. This is a required field.
Corresponds to the JSON property studioAdvertiserId
6056 6057 6058 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6056 def studio_advertiser_id @studio_advertiser_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6063 def update!(**args) @content_source = args[:content_source] if args.key?(:content_source) @create_info = args[:create_info] if args.key?(:create_info) @dynamic_feed_id = args[:dynamic_feed_id] if args.key?(:dynamic_feed_id) @dynamic_feed_name = args[:dynamic_feed_name] if args.key?(:dynamic_feed_name) @element = args[:element] if args.key?(:element) @feed_ingestion_status = args[:feed_ingestion_status] if args.key?(:feed_ingestion_status) @feed_schedule = args[:feed_schedule] if args.key?(:feed_schedule) @has_published = args[:has_published] if args.key?(:has_published) @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info) @status = args[:status] if args.key?(:status) @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id) end |