Class: Google::Apis::DfareportingV5::DynamicFeed
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DynamicFeed
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains dynamic feed information.
Instance Attribute Summary collapse
-
#content_source ⇒ Google::Apis::DfareportingV5::ContentSource
Contains the content source of the dynamic feed.
-
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#dynamic_feed_id ⇒ Fixnum
Output only.
-
#dynamic_feed_name ⇒ String
Optional.
-
#element ⇒ Google::Apis::DfareportingV5::Element
Contains the element of the dynamic feed.
-
#feed_ingestion_status ⇒ Google::Apis::DfareportingV5::FeedIngestionStatus
Contains the ingestion status of the dynamic feed.
-
#feed_schedule ⇒ Google::Apis::DfareportingV5::FeedSchedule
Contains the schedule of the dynamic feed.
-
#has_published ⇒ Boolean
(also: #has_published?)
Output only.
-
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#status ⇒ String
Output only.
-
#studio_advertiser_id ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DynamicFeed
constructor
A new instance of DynamicFeed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DynamicFeed
Returns a new instance of DynamicFeed.
6024 6025 6026 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_source ⇒ Google::Apis::DfareportingV5::ContentSource
Contains the content source of the dynamic feed.
Corresponds to the JSON property contentSource
5961 5962 5963 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5961 def content_source @content_source end |
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property createInfo
5966 5967 5968 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5966 def create_info @create_info end |
#dynamic_feed_id ⇒ Fixnum
Output only. Unique ID of this dynamic feed. This is a read-only, auto-
generated field.
Corresponds to the JSON property dynamicFeedId
5972 5973 5974 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5972 def dynamic_feed_id @dynamic_feed_id end |
#dynamic_feed_name ⇒ String
Optional. Name of this dynamic feed. It is defaulted to content source file
name if not provided.
Corresponds to the JSON property dynamicFeedName
5978 5979 5980 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5978 def dynamic_feed_name @dynamic_feed_name end |
#element ⇒ Google::Apis::DfareportingV5::Element
Contains the element of the dynamic feed.
Corresponds to the JSON property element
5983 5984 5985 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5983 def element @element end |
#feed_ingestion_status ⇒ Google::Apis::DfareportingV5::FeedIngestionStatus
Contains the ingestion status of the dynamic feed. Feed ingestion is an
asynchronous process. If the feed create request is successful, feed ingestion
will be processed in the background, including validation, assets retrieval,
and saving the data from the resource link. The processing time is dependent
on the data size in the resource link. This read-only status field contains
the current stage of that processing and its ingestion state.
Corresponds to the JSON property feedIngestionStatus
5993 5994 5995 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5993 def feed_ingestion_status @feed_ingestion_status end |
#feed_schedule ⇒ Google::Apis::DfareportingV5::FeedSchedule
Contains the schedule of the dynamic feed.
Corresponds to the JSON property feedSchedule
5998 5999 6000 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 5998 def feed_schedule @feed_schedule end |
#has_published ⇒ Boolean Also known as: has_published?
Output only. Indicates whether the dynamic feed has a published version. This
is a read-only field.
Corresponds to the JSON property hasPublished
6004 6005 6006 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6004 def has_published @has_published end |
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property lastModifiedInfo
6010 6011 6012 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6010 def last_modified_info @last_modified_info end |
#status ⇒ String
Output only. The status of the feed. It is a read-only field that depends on
the the feed ingestion status. The default value is INACTIVE, and it will be
updated to ACTIVE once the feed is ingested successfully.
Corresponds to the JSON property status
6017 6018 6019 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6017 def status @status end |
#studio_advertiser_id ⇒ Fixnum
Required. Advertiser ID of this dynamic feed. This is a required field.
Corresponds to the JSON property studioAdvertiserId
6022 6023 6024 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6022 def studio_advertiser_id @studio_advertiser_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6029 6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6029 def update!(**args) @content_source = args[:content_source] if args.key?(:content_source) @create_info = args[:create_info] if args.key?(:create_info) @dynamic_feed_id = args[:dynamic_feed_id] if args.key?(:dynamic_feed_id) @dynamic_feed_name = args[:dynamic_feed_name] if args.key?(:dynamic_feed_name) @element = args[:element] if args.key?(:element) @feed_ingestion_status = args[:feed_ingestion_status] if args.key?(:feed_ingestion_status) @feed_schedule = args[:feed_schedule] if args.key?(:feed_schedule) @has_published = args[:has_published] if args.key?(:has_published) @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info) @status = args[:status] if args.key?(:status) @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id) end |