Class: Google::Apis::DfareportingV5::DynamicFeedsInsertRequest
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DynamicFeedsInsertRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Dynamic profile ID is required for dynamic feed insert as the current GPA API only can create a dynamic feed under profile context,even though the dynamic feed itself don't need the dynamic profile id.
Instance Attribute Summary collapse
-
#dynamic_feed ⇒ Google::Apis::DfareportingV5::DynamicFeed
Beta: This API resource is available only to a very limited number of customers.
-
#dynamic_profile_id ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DynamicFeedsInsertRequest
constructor
A new instance of DynamicFeedsInsertRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DynamicFeedsInsertRequest
Returns a new instance of DynamicFeedsInsertRequest.
6062 6063 6064 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6062 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dynamic_feed ⇒ Google::Apis::DfareportingV5::DynamicFeed
Beta: This API resource is available only to a very limited number of
customers. If you'd like to use this resource, please reach out to your Google
sales representative. Contains dynamic feed information.
Corresponds to the JSON property dynamicFeed
6055 6056 6057 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6055 def dynamic_feed @dynamic_feed end |
#dynamic_profile_id ⇒ Fixnum
Required. Dynamic profile ID of the inserted dynamic feed.
Corresponds to the JSON property dynamicProfileId
6060 6061 6062 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6060 def dynamic_profile_id @dynamic_profile_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6067 6068 6069 6070 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6067 def update!(**args) @dynamic_feed = args[:dynamic_feed] if args.key?(:dynamic_feed) @dynamic_profile_id = args[:dynamic_profile_id] if args.key?(:dynamic_profile_id) end |