Class: Google::Apis::DfareportingV5::DynamicProfile
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DynamicProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains dynamic profile information.
Instance Attribute Summary collapse
-
#active ⇒ Google::Apis::DfareportingV5::DynamicProfileVersion
Contains dynamic profile version information.
-
#archive_status ⇒ String
Optional.
-
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#description ⇒ String
Optional.
-
#draft ⇒ Google::Apis::DfareportingV5::DynamicProfileVersion
Contains dynamic profile version information.
-
#dynamic_profile_id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#name ⇒ String
Required.
-
#status ⇒ String
Optional.
-
#studio_advertiser_id ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DynamicProfile
constructor
A new instance of DynamicProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DynamicProfile
Returns a new instance of DynamicProfile.
6138 6139 6140 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Google::Apis::DfareportingV5::DynamicProfileVersion
Contains dynamic profile version information.
Corresponds to the JSON property active
6082 6083 6084 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6082 def active @active end |
#archive_status ⇒ String
Optional. Archive status of this dynamic profile.
Corresponds to the JSON property archiveStatus
6087 6088 6089 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6087 def archive_status @archive_status end |
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property createInfo
6092 6093 6094 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6092 def create_info @create_info end |
#description ⇒ String
Optional. Description of this dynamic profile.
Corresponds to the JSON property description
6097 6098 6099 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6097 def description @description end |
#draft ⇒ Google::Apis::DfareportingV5::DynamicProfileVersion
Contains dynamic profile version information.
Corresponds to the JSON property draft
6102 6103 6104 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6102 def draft @draft end |
#dynamic_profile_id ⇒ Fixnum
Output only. Unique ID of this dynamic profile. This is a read-only, auto-
generated field.
Corresponds to the JSON property dynamicProfileId
6108 6109 6110 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6108 def dynamic_profile_id @dynamic_profile_id end |
#kind ⇒ String
Output only. Identifies what kind of resource this is. Value: the fixed string
"dfareporting#dynamicProfile".
Corresponds to the JSON property kind
6114 6115 6116 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6114 def kind @kind end |
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property lastModifiedInfo
6119 6120 6121 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6119 def last_modified_info @last_modified_info end |
#name ⇒ String
Required. Identifier. Name of this dynamic profile. This is a required field
and must be less than 256 characters long.
Corresponds to the JSON property name
6125 6126 6127 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6125 def name @name end |
#status ⇒ String
Optional. Status of this dynamic profile.
Corresponds to the JSON property status
6130 6131 6132 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6130 def status @status end |
#studio_advertiser_id ⇒ Fixnum
Required. Advertiser ID of this dynamic profile. This is a required field on
insertion.
Corresponds to the JSON property studioAdvertiserId
6136 6137 6138 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6136 def studio_advertiser_id @studio_advertiser_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6143 def update!(**args) @active = args[:active] if args.key?(:active) @archive_status = args[:archive_status] if args.key?(:archive_status) @create_info = args[:create_info] if args.key?(:create_info) @description = args[:description] if args.key?(:description) @draft = args[:draft] if args.key?(:draft) @dynamic_profile_id = args[:dynamic_profile_id] if args.key?(:dynamic_profile_id) @kind = args[:kind] if args.key?(:kind) @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id) end |