Class: Google::Apis::DfareportingV5::DynamicProfileFeedSettings
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DynamicProfileFeedSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains dynamic profile specific settings for an associated dynamic feed.
Instance Attribute Summary collapse
-
#dynamic_feed_id ⇒ Fixnum
Optional.
-
#dynamic_rules ⇒ Google::Apis::DfareportingV5::DynamicRules
Contains dynamic rules information.
-
#quantity ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DynamicProfileFeedSettings
constructor
A new instance of DynamicProfileFeedSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DynamicProfileFeedSettings
Returns a new instance of DynamicProfileFeedSettings.
6178 6179 6180 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dynamic_feed_id ⇒ Fixnum
Optional. Dynamic feed ID associated with dynamic profile version.
Corresponds to the JSON property dynamicFeedId
6165 6166 6167 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6165 def dynamic_feed_id @dynamic_feed_id end |
#dynamic_rules ⇒ Google::Apis::DfareportingV5::DynamicRules
Contains dynamic rules information.
Corresponds to the JSON property dynamicRules
6170 6171 6172 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6170 def dynamic_rules @dynamic_rules end |
#quantity ⇒ Fixnum
Optional. The number of this dynamic feed rows needed by the dynamic profile,
default value is 1. Acceptable values are between 1 to 99, inclusive.
Corresponds to the JSON property quantity
6176 6177 6178 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6176 def quantity @quantity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6183 6184 6185 6186 6187 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6183 def update!(**args) @dynamic_feed_id = args[:dynamic_feed_id] if args.key?(:dynamic_feed_id) @dynamic_rules = args[:dynamic_rules] if args.key?(:dynamic_rules) @quantity = args[:quantity] if args.key?(:quantity) end |