Class: Google::Apis::DfareportingV5::DynamicRules
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DynamicRules
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains dynamic rules information.
Instance Attribute Summary collapse
-
#auto_targeted_field_ids ⇒ Array<Fixnum>
Optional.
-
#custom_rules ⇒ Array<Google::Apis::DfareportingV5::CustomRule>
Optional.
-
#custom_value_fields ⇒ Array<Google::Apis::DfareportingV5::CustomValueField>
Optional.
-
#proximity_filter ⇒ Google::Apis::DfareportingV5::ProximityFilter
Contains proximity filter information.
-
#remarketing_value_attributes ⇒ Array<Google::Apis::DfareportingV5::RemarketingValueAttribute>
Optional.
-
#rotation_type ⇒ String
Optional.
-
#rule_type ⇒ String
Optional.
-
#weight_field_id ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DynamicRules
constructor
A new instance of DynamicRules.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DynamicRules
Returns a new instance of DynamicRules.
6320 6321 6322 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_targeted_field_ids ⇒ Array<Fixnum>
Optional. List of field IDs in this element that should be auto-targeted.
Applicable when rule type is AUTO.
Corresponds to the JSON property autoTargetedFieldIds
6278 6279 6280 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6278 def auto_targeted_field_ids @auto_targeted_field_ids end |
#custom_rules ⇒ Array<Google::Apis::DfareportingV5::CustomRule>
Optional. The custom rules of the dynamic feed, only applicable when rule type
is CUSTOM.
Corresponds to the JSON property customRules
6284 6285 6286 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6284 def custom_rules @custom_rules end |
#custom_value_fields ⇒ Array<Google::Apis::DfareportingV5::CustomValueField>
Optional. Mapping between field ID and custom key that are used to match for
auto filtering.
Corresponds to the JSON property customValueFields
6290 6291 6292 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6290 def custom_value_fields @custom_value_fields end |
#proximity_filter ⇒ Google::Apis::DfareportingV5::ProximityFilter
Contains proximity filter information.
Corresponds to the JSON property proximityFilter
6295 6296 6297 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6295 def proximity_filter @proximity_filter end |
#remarketing_value_attributes ⇒ Array<Google::Apis::DfareportingV5::RemarketingValueAttribute>
Optional. The link between an element field ID and a list of user attribute
IDs.
Corresponds to the JSON property remarketingValueAttributes
6301 6302 6303 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6301 def remarketing_value_attributes @remarketing_value_attributes end |
#rotation_type ⇒ String
Optional. The rotation type to select from eligible rows. Rotation type only
apply when the filtering rule results in more than one eligible rows.
Corresponds to the JSON property rotationType
6307 6308 6309 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6307 def rotation_type @rotation_type end |
#rule_type ⇒ String
Optional. The type of the rule, the default value is OPEN.
Corresponds to the JSON property ruleType
6312 6313 6314 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6312 def rule_type @rule_type end |
#weight_field_id ⇒ Fixnum
Optional. The field ID for the feed that will be used for weighted rotation,
only applicable when rotation type is WEIGHTED.
Corresponds to the JSON property weightFieldId
6318 6319 6320 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6318 def weight_field_id @weight_field_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6325 def update!(**args) @auto_targeted_field_ids = args[:auto_targeted_field_ids] if args.key?(:auto_targeted_field_ids) @custom_rules = args[:custom_rules] if args.key?(:custom_rules) @custom_value_fields = args[:custom_value_fields] if args.key?(:custom_value_fields) @proximity_filter = args[:proximity_filter] if args.key?(:proximity_filter) @remarketing_value_attributes = args[:remarketing_value_attributes] if args.key?(:remarketing_value_attributes) @rotation_type = args[:rotation_type] if args.key?(:rotation_type) @rule_type = args[:rule_type] if args.key?(:rule_type) @weight_field_id = args[:weight_field_id] if args.key?(:weight_field_id) end |