Class: Google::Apis::DfareportingV5::DynamicTargetingKey
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::DynamicTargetingKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of a dynamic targeting key. Dynamic targeting keys are unique, user-friendly labels, created at the advertiser level in DCM, that can be assigned to ads, creatives, and placements and used for targeting with Studio dynamic creatives. Use these labels instead of numeric Campaign Manager IDs (such as placement IDs) to save time and avoid errors in your dynamic feeds.
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this dynamic targeting key.
-
#object_id_prop ⇒ Fixnum
ID of the object of this dynamic targeting key.
-
#object_type ⇒ String
Type of the object of this dynamic targeting key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DynamicTargetingKey
constructor
A new instance of DynamicTargetingKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DynamicTargetingKey
Returns a new instance of DynamicTargetingKey.
6335 6336 6337 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#dynamicTargetingKey".
Corresponds to the JSON property kind
6316 6317 6318 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6316 def kind @kind end |
#name ⇒ String
Name of this dynamic targeting key. This is a required field. Must be less
than 256 characters long and cannot contain commas. All characters are
converted to lowercase.
Corresponds to the JSON property name
6323 6324 6325 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6323 def name @name end |
#object_id_prop ⇒ Fixnum
ID of the object of this dynamic targeting key. This is a required field.
Corresponds to the JSON property objectId
6328 6329 6330 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6328 def object_id_prop @object_id_prop end |
#object_type ⇒ String
Type of the object of this dynamic targeting key. This is a required field.
Corresponds to the JSON property objectType
6333 6334 6335 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6333 def object_type @object_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6340 6341 6342 6343 6344 6345 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6340 def update!(**args) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @object_type = args[:object_type] if args.key?(:object_type) end |