Class: Google::Apis::DfareportingV5::Element

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains the element of the dynamic feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Element

Returns a new instance of Element.



6448
6449
6450
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_field_idFixnum

Optional. The field ID to specify the active field in the feed. Corresponds to the JSON property activeFieldId

Returns:

  • (Fixnum)


6381
6382
6383
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6381

def active_field_id
  @active_field_id
end

#create_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



6386
6387
6388
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6386

def create_info
  @create_info
end

#default_field_idFixnum

Optional. The field ID to specify the field that represents the default field in the feed. Corresponds to the JSON property defaultFieldId

Returns:

  • (Fixnum)


6392
6393
6394
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6392

def default_field_id
  @default_field_id
end

#element_nameString

Optional. The name of the element. It is defaulted to resource file name if not provided. Corresponds to the JSON property elementName

Returns:

  • (String)


6398
6399
6400
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6398

def element_name
  @element_name
end

#end_timestamp_field_idFixnum

Optional. The field ID to specify the field that represents the end timestamp. Only applicable if you're planning to use scheduling in your dynamic creative. Corresponds to the JSON property endTimestampFieldId

Returns:

  • (Fixnum)


6404
6405
6406
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6404

def end_timestamp_field_id
  @end_timestamp_field_id
end

#external_id_field_idFixnum

Required. The field ID to specify the field used for uniquely identifying the feed row. This is a required field. Corresponds to the JSON property externalIdFieldId

Returns:

  • (Fixnum)


6410
6411
6412
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6410

def external_id_field_id
  @external_id_field_id
end

#feed_fieldsArray<Google::Apis::DfareportingV5::FeedField>

Required. The list of fields of the element. The field order and name should match the meta data in the content source source. Corresponds to the JSON property feedFields



6416
6417
6418
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6416

def feed_fields
  @feed_fields
end

#is_local_timestampBoolean Also known as: is_local_timestamp?

Optional. Whether the start and end timestamp is local timestamp. The default value is false which means start and end timestamp is in UTC. Corresponds to the JSON property isLocalTimestamp

Returns:

  • (Boolean)


6422
6423
6424
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6422

def is_local_timestamp
  @is_local_timestamp
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



6428
6429
6430
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6428

def last_modified_info
  @last_modified_info
end

#proximity_targeting_field_idFixnum

Optional. The field ID that specify field used for proximity targeting. Corresponds to the JSON property proximityTargetingFieldId

Returns:

  • (Fixnum)


6433
6434
6435
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6433

def proximity_targeting_field_id
  @proximity_targeting_field_id
end

#reporting_label_field_idFixnum

Required. The field ID to specify the field used for dynamic reporting in Campaign Manager 360. Corresponds to the JSON property reportingLabelFieldId

Returns:

  • (Fixnum)


6439
6440
6441
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6439

def reporting_label_field_id
  @reporting_label_field_id
end

#start_timestamp_field_idFixnum

Optional. The field ID to specify the field that represents the start timestamp. Only applicable if you're planning to use scheduling in your dynamic creative. Corresponds to the JSON property startTimestampFieldId

Returns:

  • (Fixnum)


6446
6447
6448
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6446

def start_timestamp_field_id
  @start_timestamp_field_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6453

def update!(**args)
  @active_field_id = args[:active_field_id] if args.key?(:active_field_id)
  @create_info = args[:create_info] if args.key?(:create_info)
  @default_field_id = args[:default_field_id] if args.key?(:default_field_id)
  @element_name = args[:element_name] if args.key?(:element_name)
  @end_timestamp_field_id = args[:end_timestamp_field_id] if args.key?(:end_timestamp_field_id)
  @external_id_field_id = args[:external_id_field_id] if args.key?(:external_id_field_id)
  @feed_fields = args[:feed_fields] if args.key?(:feed_fields)
  @is_local_timestamp = args[:is_local_timestamp] if args.key?(:is_local_timestamp)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @proximity_targeting_field_id = args[:proximity_targeting_field_id] if args.key?(:proximity_targeting_field_id)
  @reporting_label_field_id = args[:reporting_label_field_id] if args.key?(:reporting_label_field_id)
  @start_timestamp_field_id = args[:start_timestamp_field_id] if args.key?(:start_timestamp_field_id)
end