Class: Google::Apis::DfareportingV5::FeedIngestionStatus
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::FeedIngestionStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains the ingestion status of the dynamic feed. Feed ingestion is an asynchronous process. If the feed create request is successful, feed ingestion will be processed in the background, including validation, assets retrieval, and saving the data from the resource link. The processing time is dependent on the data size in the resource link. This read-only status field contains the current stage of that processing and its ingestion state.
Instance Attribute Summary collapse
-
#ingestion_error_records ⇒ Array<Google::Apis::DfareportingV5::IngestionErrorRecord>
Output only.
-
#ingestion_status ⇒ Google::Apis::DfareportingV5::IngestionStatus
Contains the ingestion status of the dynamic feed.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FeedIngestionStatus
constructor
A new instance of FeedIngestionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FeedIngestionStatus
Returns a new instance of FeedIngestionStatus.
6799 6800 6801 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ingestion_error_records ⇒ Array<Google::Apis::DfareportingV5::IngestionErrorRecord>
Output only. The ingestion error records of the feed.
Corresponds to the JSON property ingestionErrorRecords
6787 6788 6789 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6787 def ingestion_error_records @ingestion_error_records end |
#ingestion_status ⇒ Google::Apis::DfareportingV5::IngestionStatus
Contains the ingestion status of the dynamic feed.
Corresponds to the JSON property ingestionStatus
6792 6793 6794 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6792 def ingestion_status @ingestion_status end |
#state ⇒ String
Output only. The processing state of the feed.
Corresponds to the JSON property state
6797 6798 6799 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6797 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6804 6805 6806 6807 6808 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6804 def update!(**args) @ingestion_error_records = args[:ingestion_error_records] if args.key?(:ingestion_error_records) @ingestion_status = args[:ingestion_status] if args.key?(:ingestion_status) @state = args[:state] if args.key?(:state) end |