Class: Google::Apis::DfareportingV5::FeedSchedule
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::FeedSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains the schedule of the dynamic feed.
Instance Attribute Summary collapse
-
#repeat_value ⇒ Fixnum
Optional.
-
#schedule_enabled ⇒ Boolean
(also: #schedule_enabled?)
Optional.
-
#start_hour ⇒ String
Optional.
-
#start_minute ⇒ String
Optional.
-
#time_zone ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FeedSchedule
constructor
A new instance of FeedSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FeedSchedule
Returns a new instance of FeedSchedule.
6880 6881 6882 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6880 def initialize(**args) update!(**args) end |
Instance Attribute Details
#repeat_value ⇒ Fixnum
Optional. The number of times the feed retransforms within one day. This is a
required field if the schedule is enabled. Acceptable values are between 1 to
6, inclusive.
Corresponds to the JSON property repeatValue
6854 6855 6856 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6854 def repeat_value @repeat_value end |
#schedule_enabled ⇒ Boolean Also known as: schedule_enabled?
Optional. Whether the schedule is enabled.
Corresponds to the JSON property scheduleEnabled
6859 6860 6861 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6859 def schedule_enabled @schedule_enabled end |
#start_hour ⇒ String
Optional. The hour of the day to start the feed. It is applicable if the
repeat value is equal to 1. Default value is 0.
Corresponds to the JSON property startHour
6866 6867 6868 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6866 def start_hour @start_hour end |
#start_minute ⇒ String
Optional. The minute of the hour to start the feed. It is applicable if the
repeat value is equal to 1. Default value is 0.
Corresponds to the JSON property startMinute
6872 6873 6874 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6872 def start_minute @start_minute end |
#time_zone ⇒ String
Optional. The time zone to schedule the feed. It is applicable if the repeat
value is equal to 1. Default value is "America/Los_Angeles".
Corresponds to the JSON property timeZone
6878 6879 6880 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6878 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6885 6886 6887 6888 6889 6890 6891 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6885 def update!(**args) @repeat_value = args[:repeat_value] if args.key?(:repeat_value) @schedule_enabled = args[:schedule_enabled] if args.key?(:schedule_enabled) @start_hour = args[:start_hour] if args.key?(:start_hour) @start_minute = args[:start_minute] if args.key?(:start_minute) @time_zone = args[:time_zone] if args.key?(:time_zone) end |