Class: Google::Apis::DfareportingV5::FeedSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains the schedule of the dynamic feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeedSchedule

Returns a new instance of FeedSchedule.



6846
6847
6848
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#repeat_valueFixnum

Optional. The number of times the feed retransforms within one day. This is a required field if the schedule is enabled. Acceptable values are between 1 to 6, inclusive. Corresponds to the JSON property repeatValue

Returns:

  • (Fixnum)


6820
6821
6822
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6820

def repeat_value
  @repeat_value
end

#schedule_enabledBoolean Also known as: schedule_enabled?

Optional. Whether the schedule is enabled. Corresponds to the JSON property scheduleEnabled

Returns:

  • (Boolean)


6825
6826
6827
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6825

def schedule_enabled
  @schedule_enabled
end

#start_hourString

Optional. The hour of the day to start the feed. It is applicable if the repeat value is equal to 1. Default value is 0. Corresponds to the JSON property startHour

Returns:

  • (String)


6832
6833
6834
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6832

def start_hour
  @start_hour
end

#start_minuteString

Optional. The minute of the hour to start the feed. It is applicable if the repeat value is equal to 1. Default value is 0. Corresponds to the JSON property startMinute

Returns:

  • (String)


6838
6839
6840
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6838

def start_minute
  @start_minute
end

#time_zoneString

Optional. The time zone to schedule the feed. It is applicable if the repeat value is equal to 1. Default value is "America/Los_Angeles". Corresponds to the JSON property timeZone

Returns:

  • (String)


6844
6845
6846
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6844

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6851
6852
6853
6854
6855
6856
6857
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 6851

def update!(**args)
  @repeat_value = args[:repeat_value] if args.key?(:repeat_value)
  @schedule_enabled = args[:schedule_enabled] if args.key?(:schedule_enabled)
  @start_hour = args[:start_hour] if args.key?(:start_hour)
  @start_minute = args[:start_minute] if args.key?(:start_minute)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end