Class: Google::Apis::DfareportingV5::FileList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

List of files for a report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileList

Returns a new instance of FileList.



7089
7090
7091
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7068
7069
7070
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7068

def etag
  @etag
end

#itemsArray<Google::Apis::DfareportingV5::File>

The files returned in this response. Corresponds to the JSON property items



7073
7074
7075
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7073

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#fileList". Corresponds to the JSON property kind

Returns:

  • (String)


7079
7080
7081
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7079

def kind
  @kind
end

#next_page_tokenString

Continuation token used to page through files. To retrieve the next page of results, set the next request's "pageToken" to the value of this field. The page token is only valid for a limited amount of time and should not be persisted. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7087
7088
7089
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7087

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7094
7095
7096
7097
7098
7099
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7094

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end