Class: Google::Apis::DfareportingV5::FloodlightActivity
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::FloodlightActivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of a Floodlight activity.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this floodlight activity.
-
#advertiser_id ⇒ Fixnum
Advertiser ID of this floodlight activity.
-
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#attribution_enabled ⇒ Boolean
(also: #attribution_enabled?)
Whether the activity is enabled for attribution.
-
#cache_busting_type ⇒ String
Code type used for cache busting in the generated tag.
-
#conversion_category ⇒ String
Required.
-
#counting_method ⇒ String
Counting method for conversions for this floodlight activity.
-
#default_tags ⇒ Array<Google::Apis::DfareportingV5::FloodlightActivityDynamicTag>
Dynamic floodlight tags.
-
#expected_url ⇒ String
URL where this tag will be deployed.
-
#floodlight_activity_group_id ⇒ Fixnum
Floodlight activity group ID of this floodlight activity.
-
#floodlight_activity_group_name ⇒ String
Name of the associated floodlight activity group.
-
#floodlight_activity_group_tag_string ⇒ String
Tag string of the associated floodlight activity group.
-
#floodlight_activity_group_type ⇒ String
Type of the associated floodlight activity group.
-
#floodlight_configuration_id ⇒ Fixnum
Floodlight configuration ID of this floodlight activity.
-
#floodlight_configuration_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#floodlight_tag_type ⇒ String
The type of Floodlight tag this activity will generate.
-
#id ⇒ Fixnum
ID of this floodlight activity.
-
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this floodlight activity.
-
#notes ⇒ String
General notes or implementation instructions for the tag.
-
#publisher_tags ⇒ Array<Google::Apis::DfareportingV5::FloodlightActivityPublisherDynamicTag>
Publisher dynamic floodlight tags.
-
#secure ⇒ Boolean
(also: #secure?)
Whether this tag should use SSL.
-
#ssl_compliant ⇒ Boolean
(also: #ssl_compliant?)
Whether the floodlight activity is SSL-compliant.
-
#ssl_required ⇒ Boolean
(also: #ssl_required?)
Whether this floodlight activity must be SSL-compliant.
-
#status ⇒ String
The status of the activity.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this floodlight activity.
-
#tag_format ⇒ String
Tag format type for the floodlight activity.
-
#tag_string ⇒ String
Value of the cat= parameter in the floodlight tag, which the ad servers use to identify the activity.
-
#user_defined_variable_types ⇒ Array<String>
List of the user-defined variables used by this conversion tag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloodlightActivity
constructor
A new instance of FloodlightActivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloodlightActivity
Returns a new instance of FloodlightActivity.
7389 7390 7391 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this floodlight activity. This is a read-only field that can be
left blank.
Corresponds to the JSON property accountId
7211 7212 7213 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7211 def account_id @account_id end |
#advertiser_id ⇒ Fixnum
Advertiser ID of this floodlight activity. If this field is left blank, the
value will be copied over either from the activity group's advertiser or the
existing activity's advertiser.
Corresponds to the JSON property advertiserId
7218 7219 7220 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7218 def advertiser_id @advertiser_id end |
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property advertiserIdDimensionValue
7223 7224 7225 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7223 def advertiser_id_dimension_value @advertiser_id_dimension_value end |
#attribution_enabled ⇒ Boolean Also known as: attribution_enabled?
Whether the activity is enabled for attribution.
Corresponds to the JSON property attributionEnabled
7228 7229 7230 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7228 def attribution_enabled @attribution_enabled end |
#cache_busting_type ⇒ String
Code type used for cache busting in the generated tag. Applicable only when
floodlightActivityGroupType is COUNTER and countingMethod is STANDARD_COUNTING
or UNIQUE_COUNTING.
Corresponds to the JSON property cacheBustingType
7236 7237 7238 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7236 def cache_busting_type @cache_busting_type end |
#conversion_category ⇒ String
Required. The conversion category of the activity.
Corresponds to the JSON property conversionCategory
7241 7242 7243 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7241 def conversion_category @conversion_category end |
#counting_method ⇒ String
Counting method for conversions for this floodlight activity. This is a
required field.
Corresponds to the JSON property countingMethod
7247 7248 7249 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7247 def counting_method @counting_method end |
#default_tags ⇒ Array<Google::Apis::DfareportingV5::FloodlightActivityDynamicTag>
Dynamic floodlight tags.
Corresponds to the JSON property defaultTags
7252 7253 7254 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7252 def @default_tags end |
#expected_url ⇒ String
URL where this tag will be deployed. If specified, must be less than 256
characters long.
Corresponds to the JSON property expectedUrl
7258 7259 7260 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7258 def expected_url @expected_url end |
#floodlight_activity_group_id ⇒ Fixnum
Floodlight activity group ID of this floodlight activity. This is a required
field.
Corresponds to the JSON property floodlightActivityGroupId
7264 7265 7266 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7264 def floodlight_activity_group_id @floodlight_activity_group_id end |
#floodlight_activity_group_name ⇒ String
Name of the associated floodlight activity group. This is a read-only field.
Corresponds to the JSON property floodlightActivityGroupName
7269 7270 7271 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7269 def floodlight_activity_group_name @floodlight_activity_group_name end |
#floodlight_activity_group_tag_string ⇒ String
Tag string of the associated floodlight activity group. This is a read-only
field.
Corresponds to the JSON property floodlightActivityGroupTagString
7275 7276 7277 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7275 def floodlight_activity_group_tag_string @floodlight_activity_group_tag_string end |
#floodlight_activity_group_type ⇒ String
Type of the associated floodlight activity group. This is a read-only field.
Corresponds to the JSON property floodlightActivityGroupType
7280 7281 7282 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7280 def floodlight_activity_group_type @floodlight_activity_group_type end |
#floodlight_configuration_id ⇒ Fixnum
Floodlight configuration ID of this floodlight activity. If this field is left
blank, the value will be copied over either from the activity group's
floodlight configuration or from the existing activity's floodlight
configuration.
Corresponds to the JSON property floodlightConfigurationId
7288 7289 7290 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7288 def floodlight_configuration_id @floodlight_configuration_id end |
#floodlight_configuration_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property floodlightConfigurationIdDimensionValue
7293 7294 7295 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7293 def floodlight_configuration_id_dimension_value @floodlight_configuration_id_dimension_value end |
#floodlight_tag_type ⇒ String
The type of Floodlight tag this activity will generate. This is a required
field.
Corresponds to the JSON property floodlightTagType
7299 7300 7301 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7299 def floodlight_tag_type @floodlight_tag_type end |
#id ⇒ Fixnum
ID of this floodlight activity. This is a read-only, auto-generated field.
Corresponds to the JSON property id
7304 7305 7306 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7304 def id @id end |
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property idDimensionValue
7309 7310 7311 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7309 def id_dimension_value @id_dimension_value end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#floodlightActivity".
Corresponds to the JSON property kind
7315 7316 7317 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7315 def kind @kind end |
#name ⇒ String
Name of this floodlight activity. This is a required field. Must be less than
129 characters long and cannot contain quotes.
Corresponds to the JSON property name
7321 7322 7323 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7321 def name @name end |
#notes ⇒ String
General notes or implementation instructions for the tag.
Corresponds to the JSON property notes
7326 7327 7328 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7326 def notes @notes end |
#publisher_tags ⇒ Array<Google::Apis::DfareportingV5::FloodlightActivityPublisherDynamicTag>
Publisher dynamic floodlight tags.
Corresponds to the JSON property publisherTags
7331 7332 7333 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7331 def @publisher_tags end |
#secure ⇒ Boolean Also known as: secure?
Whether this tag should use SSL.
Corresponds to the JSON property secure
7336 7337 7338 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7336 def secure @secure end |
#ssl_compliant ⇒ Boolean Also known as: ssl_compliant?
Whether the floodlight activity is SSL-compliant. This is a read-only field,
its value detected by the system from the floodlight tags.
Corresponds to the JSON property sslCompliant
7343 7344 7345 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7343 def ssl_compliant @ssl_compliant end |
#ssl_required ⇒ Boolean Also known as: ssl_required?
Whether this floodlight activity must be SSL-compliant.
Corresponds to the JSON property sslRequired
7349 7350 7351 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7349 def ssl_required @ssl_required end |
#status ⇒ String
The status of the activity. This can only be set to ACTIVE or
ARCHIVED_AND_DISABLED. The ARCHIVED status is no longer supported and cannot
be set for Floodlight activities. The DISABLED_POLICY status indicates that a
Floodlight activity is violating Google policy. Contact your account manager
for more information.
Corresponds to the JSON property status
7359 7360 7361 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7359 def status @status end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this floodlight activity. This is a read-only field that can
be left blank.
Corresponds to the JSON property subaccountId
7365 7366 7367 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7365 def subaccount_id @subaccount_id end |
#tag_format ⇒ String
Tag format type for the floodlight activity. If left blank, the tag format
will default to HTML.
Corresponds to the JSON property tagFormat
7371 7372 7373 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7371 def tag_format @tag_format end |
#tag_string ⇒ String
Value of the cat= parameter in the floodlight tag, which the ad servers use to
identify the activity. This is optional: if empty, a new tag string will be
generated for you. This string must be 1 to 8 characters long, with valid
characters being a-z0-9[ _ ]. This tag string must also be unique among
activities of the same activity group. This field is read-only after insertion.
Corresponds to the JSON property tagString
7380 7381 7382 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7380 def tag_string @tag_string end |
#user_defined_variable_types ⇒ Array<String>
List of the user-defined variables used by this conversion tag. These map to
the "u[1-100]=" in the tags. Each of these can have a user defined type.
Acceptable values are U1 to U100, inclusive.
Corresponds to the JSON property userDefinedVariableTypes
7387 7388 7389 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7387 def user_defined_variable_types @user_defined_variable_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7394 7395 7396 7397 7398 7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 7424 7425 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7394 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value) @attribution_enabled = args[:attribution_enabled] if args.key?(:attribution_enabled) @cache_busting_type = args[:cache_busting_type] if args.key?(:cache_busting_type) @conversion_category = args[:conversion_category] if args.key?(:conversion_category) @counting_method = args[:counting_method] if args.key?(:counting_method) @default_tags = args[:default_tags] if args.key?(:default_tags) @expected_url = args[:expected_url] if args.key?(:expected_url) @floodlight_activity_group_id = args[:floodlight_activity_group_id] if args.key?(:floodlight_activity_group_id) @floodlight_activity_group_name = args[:floodlight_activity_group_name] if args.key?(:floodlight_activity_group_name) @floodlight_activity_group_tag_string = args[:floodlight_activity_group_tag_string] if args.key?(:floodlight_activity_group_tag_string) @floodlight_activity_group_type = args[:floodlight_activity_group_type] if args.key?(:floodlight_activity_group_type) @floodlight_configuration_id = args[:floodlight_configuration_id] if args.key?(:floodlight_configuration_id) @floodlight_configuration_id_dimension_value = args[:floodlight_configuration_id_dimension_value] if args.key?(:floodlight_configuration_id_dimension_value) @floodlight_tag_type = args[:floodlight_tag_type] if args.key?(:floodlight_tag_type) @id = args[:id] if args.key?(:id) @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @publisher_tags = args[:publisher_tags] if args.key?(:publisher_tags) @secure = args[:secure] if args.key?(:secure) @ssl_compliant = args[:ssl_compliant] if args.key?(:ssl_compliant) @ssl_required = args[:ssl_required] if args.key?(:ssl_required) @status = args[:status] if args.key?(:status) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) @tag_format = args[:tag_format] if args.key?(:tag_format) @tag_string = args[:tag_string] if args.key?(:tag_string) @user_defined_variable_types = args[:user_defined_variable_types] if args.key?(:user_defined_variable_types) end |