Class: Google::Apis::DfareportingV5::FloodlightActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a Floodlight activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightActivity

Returns a new instance of FloodlightActivity.



7355
7356
7357
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this floodlight activity. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


7177
7178
7179
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7177

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this floodlight activity. If this field is left blank, the value will be copied over either from the activity group's advertiser or the existing activity's advertiser. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7184
7185
7186
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7184

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



7189
7190
7191
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7189

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#attribution_enabledBoolean Also known as: attribution_enabled?

Whether the activity is enabled for attribution. Corresponds to the JSON property attributionEnabled

Returns:

  • (Boolean)


7194
7195
7196
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7194

def attribution_enabled
  @attribution_enabled
end

#cache_busting_typeString

Code type used for cache busting in the generated tag. Applicable only when floodlightActivityGroupType is COUNTER and countingMethod is STANDARD_COUNTING or UNIQUE_COUNTING. Corresponds to the JSON property cacheBustingType

Returns:

  • (String)


7202
7203
7204
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7202

def cache_busting_type
  @cache_busting_type
end

#conversion_categoryString

Required. The conversion category of the activity. Corresponds to the JSON property conversionCategory

Returns:

  • (String)


7207
7208
7209
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7207

def conversion_category
  @conversion_category
end

#counting_methodString

Counting method for conversions for this floodlight activity. This is a required field. Corresponds to the JSON property countingMethod

Returns:

  • (String)


7213
7214
7215
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7213

def counting_method
  @counting_method
end

#default_tagsArray<Google::Apis::DfareportingV5::FloodlightActivityDynamicTag>

Dynamic floodlight tags. Corresponds to the JSON property defaultTags



7218
7219
7220
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7218

def default_tags
  @default_tags
end

#expected_urlString

URL where this tag will be deployed. If specified, must be less than 256 characters long. Corresponds to the JSON property expectedUrl

Returns:

  • (String)


7224
7225
7226
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7224

def expected_url
  @expected_url
end

#floodlight_activity_group_idFixnum

Floodlight activity group ID of this floodlight activity. This is a required field. Corresponds to the JSON property floodlightActivityGroupId

Returns:

  • (Fixnum)


7230
7231
7232
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7230

def floodlight_activity_group_id
  @floodlight_activity_group_id
end

#floodlight_activity_group_nameString

Name of the associated floodlight activity group. This is a read-only field. Corresponds to the JSON property floodlightActivityGroupName

Returns:

  • (String)


7235
7236
7237
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7235

def floodlight_activity_group_name
  @floodlight_activity_group_name
end

#floodlight_activity_group_tag_stringString

Tag string of the associated floodlight activity group. This is a read-only field. Corresponds to the JSON property floodlightActivityGroupTagString

Returns:

  • (String)


7241
7242
7243
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7241

def floodlight_activity_group_tag_string
  @floodlight_activity_group_tag_string
end

#floodlight_activity_group_typeString

Type of the associated floodlight activity group. This is a read-only field. Corresponds to the JSON property floodlightActivityGroupType

Returns:

  • (String)


7246
7247
7248
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7246

def floodlight_activity_group_type
  @floodlight_activity_group_type
end

#floodlight_configuration_idFixnum

Floodlight configuration ID of this floodlight activity. If this field is left blank, the value will be copied over either from the activity group's floodlight configuration or from the existing activity's floodlight configuration. Corresponds to the JSON property floodlightConfigurationId

Returns:

  • (Fixnum)


7254
7255
7256
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7254

def floodlight_configuration_id
  @floodlight_configuration_id
end

#floodlight_configuration_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightConfigurationIdDimensionValue



7259
7260
7261
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7259

def floodlight_configuration_id_dimension_value
  @floodlight_configuration_id_dimension_value
end

#floodlight_tag_typeString

The type of Floodlight tag this activity will generate. This is a required field. Corresponds to the JSON property floodlightTagType

Returns:

  • (String)


7265
7266
7267
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7265

def floodlight_tag_type
  @floodlight_tag_type
end

#idFixnum

ID of this floodlight activity. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7270
7271
7272
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7270

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



7275
7276
7277
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7275

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#floodlightActivity". Corresponds to the JSON property kind

Returns:

  • (String)


7281
7282
7283
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7281

def kind
  @kind
end

#nameString

Name of this floodlight activity. This is a required field. Must be less than 129 characters long and cannot contain quotes. Corresponds to the JSON property name

Returns:

  • (String)


7287
7288
7289
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7287

def name
  @name
end

#notesString

General notes or implementation instructions for the tag. Corresponds to the JSON property notes

Returns:

  • (String)


7292
7293
7294
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7292

def notes
  @notes
end

#publisher_tagsArray<Google::Apis::DfareportingV5::FloodlightActivityPublisherDynamicTag>

Publisher dynamic floodlight tags. Corresponds to the JSON property publisherTags



7297
7298
7299
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7297

def publisher_tags
  @publisher_tags
end

#secureBoolean Also known as: secure?

Whether this tag should use SSL. Corresponds to the JSON property secure

Returns:

  • (Boolean)


7302
7303
7304
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7302

def secure
  @secure
end

#ssl_compliantBoolean Also known as: ssl_compliant?

Whether the floodlight activity is SSL-compliant. This is a read-only field, its value detected by the system from the floodlight tags. Corresponds to the JSON property sslCompliant

Returns:

  • (Boolean)


7309
7310
7311
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7309

def ssl_compliant
  @ssl_compliant
end

#ssl_requiredBoolean Also known as: ssl_required?

Whether this floodlight activity must be SSL-compliant. Corresponds to the JSON property sslRequired

Returns:

  • (Boolean)


7315
7316
7317
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7315

def ssl_required
  @ssl_required
end

#statusString

The status of the activity. This can only be set to ACTIVE or ARCHIVED_AND_DISABLED. The ARCHIVED status is no longer supported and cannot be set for Floodlight activities. The DISABLED_POLICY status indicates that a Floodlight activity is violating Google policy. Contact your account manager for more information. Corresponds to the JSON property status

Returns:

  • (String)


7325
7326
7327
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7325

def status
  @status
end

#subaccount_idFixnum

Subaccount ID of this floodlight activity. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


7331
7332
7333
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7331

def subaccount_id
  @subaccount_id
end

#tag_formatString

Tag format type for the floodlight activity. If left blank, the tag format will default to HTML. Corresponds to the JSON property tagFormat

Returns:

  • (String)


7337
7338
7339
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7337

def tag_format
  @tag_format
end

#tag_stringString

Value of the cat= parameter in the floodlight tag, which the ad servers use to identify the activity. This is optional: if empty, a new tag string will be generated for you. This string must be 1 to 8 characters long, with valid characters being a-z0-9[ _ ]. This tag string must also be unique among activities of the same activity group. This field is read-only after insertion. Corresponds to the JSON property tagString

Returns:

  • (String)


7346
7347
7348
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7346

def tag_string
  @tag_string
end

#user_defined_variable_typesArray<String>

List of the user-defined variables used by this conversion tag. These map to the "u[1-100]=" in the tags. Each of these can have a user defined type. Acceptable values are U1 to U100, inclusive. Corresponds to the JSON property userDefinedVariableTypes

Returns:

  • (Array<String>)


7353
7354
7355
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7353

def user_defined_variable_types
  @user_defined_variable_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7360

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @attribution_enabled = args[:attribution_enabled] if args.key?(:attribution_enabled)
  @cache_busting_type = args[:cache_busting_type] if args.key?(:cache_busting_type)
  @conversion_category = args[:conversion_category] if args.key?(:conversion_category)
  @counting_method = args[:counting_method] if args.key?(:counting_method)
  @default_tags = args[:default_tags] if args.key?(:default_tags)
  @expected_url = args[:expected_url] if args.key?(:expected_url)
  @floodlight_activity_group_id = args[:floodlight_activity_group_id] if args.key?(:floodlight_activity_group_id)
  @floodlight_activity_group_name = args[:floodlight_activity_group_name] if args.key?(:floodlight_activity_group_name)
  @floodlight_activity_group_tag_string = args[:floodlight_activity_group_tag_string] if args.key?(:floodlight_activity_group_tag_string)
  @floodlight_activity_group_type = args[:floodlight_activity_group_type] if args.key?(:floodlight_activity_group_type)
  @floodlight_configuration_id = args[:floodlight_configuration_id] if args.key?(:floodlight_configuration_id)
  @floodlight_configuration_id_dimension_value = args[:floodlight_configuration_id_dimension_value] if args.key?(:floodlight_configuration_id_dimension_value)
  @floodlight_tag_type = args[:floodlight_tag_type] if args.key?(:floodlight_tag_type)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @publisher_tags = args[:publisher_tags] if args.key?(:publisher_tags)
  @secure = args[:secure] if args.key?(:secure)
  @ssl_compliant = args[:ssl_compliant] if args.key?(:ssl_compliant)
  @ssl_required = args[:ssl_required] if args.key?(:ssl_required)
  @status = args[:status] if args.key?(:status)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @tag_format = args[:tag_format] if args.key?(:tag_format)
  @tag_string = args[:tag_string] if args.key?(:tag_string)
  @user_defined_variable_types = args[:user_defined_variable_types] if args.key?(:user_defined_variable_types)
end