Class: Google::Apis::DfareportingV5::FloodlightActivityGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a Floodlight activity group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightActivityGroup

Returns a new instance of FloodlightActivityGroup.



7503
7504
7505
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7503

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this floodlight activity group. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


7433
7434
7435
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7433

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this floodlight activity group. If this field is left blank, the value will be copied over either from the floodlight configuration's advertiser or from the existing activity group's advertiser. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7440
7441
7442
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7440

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



7445
7446
7447
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7445

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#floodlight_configuration_idFixnum

Floodlight configuration ID of this floodlight activity group. This is a required field. Corresponds to the JSON property floodlightConfigurationId

Returns:

  • (Fixnum)


7451
7452
7453
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7451

def floodlight_configuration_id
  @floodlight_configuration_id
end

#floodlight_configuration_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightConfigurationIdDimensionValue



7456
7457
7458
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7456

def floodlight_configuration_id_dimension_value
  @floodlight_configuration_id_dimension_value
end

#idFixnum

ID of this floodlight activity group. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7462
7463
7464
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7462

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



7467
7468
7469
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7467

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#floodlightActivityGroup". Corresponds to the JSON property kind

Returns:

  • (String)


7473
7474
7475
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7473

def kind
  @kind
end

#nameString

Name of this floodlight activity group. This is a required field. Must be less than 65 characters long and cannot contain quotes. Corresponds to the JSON property name

Returns:

  • (String)


7479
7480
7481
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7479

def name
  @name
end

#subaccount_idFixnum

Subaccount ID of this floodlight activity group. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


7485
7486
7487
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7485

def subaccount_id
  @subaccount_id
end

#tag_stringString

Value of the type= parameter in the floodlight tag, which the ad servers use to identify the activity group that the activity belongs to. This is optional: if empty, a new tag string will be generated for you. This string must be 1 to 8 characters long, with valid characters being a-z0-9[ _ ]. This tag string must also be unique among activity groups of the same floodlight configuration. This field is read-only after insertion. Corresponds to the JSON property tagString

Returns:

  • (String)


7495
7496
7497
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7495

def tag_string
  @tag_string
end

#typeString

Type of the floodlight activity group. This is a required field that is read- only after insertion. Corresponds to the JSON property type

Returns:

  • (String)


7501
7502
7503
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7501

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7508
7509
7510
7511
7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7508

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @floodlight_configuration_id = args[:floodlight_configuration_id] if args.key?(:floodlight_configuration_id)
  @floodlight_configuration_id_dimension_value = args[:floodlight_configuration_id_dimension_value] if args.key?(:floodlight_configuration_id_dimension_value)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @tag_string = args[:tag_string] if args.key?(:tag_string)
  @type = args[:type] if args.key?(:type)
end