Class: Google::Apis::DfareportingV5::FloodlightConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::FloodlightConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of a Floodlight configuration.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this floodlight configuration.
-
#advertiser_id ⇒ Fixnum
Advertiser ID of the parent advertiser of this floodlight configuration.
-
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#analytics_data_sharing_enabled ⇒ Boolean
(also: #analytics_data_sharing_enabled?)
Whether advertiser data is shared with Google Analytics.
-
#custom_viewability_metric ⇒ Google::Apis::DfareportingV5::CustomViewabilityMetric
Custom Viewability Metric Corresponds to the JSON property
customViewabilityMetric. -
#exposure_to_conversion_enabled ⇒ Boolean
(also: #exposure_to_conversion_enabled?)
Whether the exposure-to-conversion report is enabled.
-
#first_day_of_week ⇒ String
Corresponds to the JSON property
firstDayOfWeek. -
#id ⇒ Fixnum
ID of this floodlight configuration.
-
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#in_app_attribution_tracking_enabled ⇒ Boolean
(also: #in_app_attribution_tracking_enabled?)
Whether in-app attribution tracking is enabled.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#lookback_configuration ⇒ Google::Apis::DfareportingV5::LookbackConfiguration
Lookback configuration settings.
-
#natural_search_conversion_attribution_option ⇒ String
Types of attribution options for natural search conversions.
-
#omniture_settings ⇒ Google::Apis::DfareportingV5::OmnitureSettings
Omniture Integration Settings.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this floodlight configuration.
-
#tag_settings ⇒ Google::Apis::DfareportingV5::TagSettings
Dynamic and Image Tag Settings.
-
#third_party_authentication_tokens ⇒ Array<Google::Apis::DfareportingV5::ThirdPartyAuthenticationToken>
List of third-party authentication tokens enabled for this configuration.
-
#user_defined_variable_configurations ⇒ Array<Google::Apis::DfareportingV5::UserDefinedVariableConfiguration>
List of user defined variables enabled for this configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloodlightConfiguration
constructor
A new instance of FloodlightConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloodlightConfiguration
Returns a new instance of FloodlightConfiguration.
7711 7712 7713 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this floodlight configuration. This is a read-only field that
can be left blank.
Corresponds to the JSON property accountId
7617 7618 7619 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7617 def account_id @account_id end |
#advertiser_id ⇒ Fixnum
Advertiser ID of the parent advertiser of this floodlight configuration.
Corresponds to the JSON property advertiserId
7622 7623 7624 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7622 def advertiser_id @advertiser_id end |
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property advertiserIdDimensionValue
7627 7628 7629 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7627 def advertiser_id_dimension_value @advertiser_id_dimension_value end |
#analytics_data_sharing_enabled ⇒ Boolean Also known as: analytics_data_sharing_enabled?
Whether advertiser data is shared with Google Analytics.
Corresponds to the JSON property analyticsDataSharingEnabled
7632 7633 7634 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7632 def analytics_data_sharing_enabled @analytics_data_sharing_enabled end |
#custom_viewability_metric ⇒ Google::Apis::DfareportingV5::CustomViewabilityMetric
Custom Viewability Metric
Corresponds to the JSON property customViewabilityMetric
7638 7639 7640 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7638 def custom_viewability_metric @custom_viewability_metric end |
#exposure_to_conversion_enabled ⇒ Boolean Also known as: exposure_to_conversion_enabled?
Whether the exposure-to-conversion report is enabled. This report shows
detailed pathway information on up to 10 of the most recent ad exposures seen
by a user before converting.
Corresponds to the JSON property exposureToConversionEnabled
7645 7646 7647 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7645 def exposure_to_conversion_enabled @exposure_to_conversion_enabled end |
#first_day_of_week ⇒ String
Corresponds to the JSON property firstDayOfWeek
7651 7652 7653 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7651 def first_day_of_week @first_day_of_week end |
#id ⇒ Fixnum
ID of this floodlight configuration. This is a read-only, auto-generated field.
Corresponds to the JSON property id
7656 7657 7658 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7656 def id @id end |
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property idDimensionValue
7661 7662 7663 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7661 def id_dimension_value @id_dimension_value end |
#in_app_attribution_tracking_enabled ⇒ Boolean Also known as: in_app_attribution_tracking_enabled?
Whether in-app attribution tracking is enabled.
Corresponds to the JSON property inAppAttributionTrackingEnabled
7666 7667 7668 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7666 def in_app_attribution_tracking_enabled @in_app_attribution_tracking_enabled end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#floodlightConfiguration".
Corresponds to the JSON property kind
7673 7674 7675 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7673 def kind @kind end |
#lookback_configuration ⇒ Google::Apis::DfareportingV5::LookbackConfiguration
Lookback configuration settings.
Corresponds to the JSON property lookbackConfiguration
7678 7679 7680 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7678 def lookback_configuration @lookback_configuration end |
#natural_search_conversion_attribution_option ⇒ String
Types of attribution options for natural search conversions.
Corresponds to the JSON property naturalSearchConversionAttributionOption
7683 7684 7685 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7683 def natural_search_conversion_attribution_option @natural_search_conversion_attribution_option end |
#omniture_settings ⇒ Google::Apis::DfareportingV5::OmnitureSettings
Omniture Integration Settings.
Corresponds to the JSON property omnitureSettings
7688 7689 7690 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7688 def omniture_settings @omniture_settings end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this floodlight configuration. This is a read-only field that
can be left blank.
Corresponds to the JSON property subaccountId
7694 7695 7696 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7694 def subaccount_id @subaccount_id end |
#tag_settings ⇒ Google::Apis::DfareportingV5::TagSettings
Dynamic and Image Tag Settings.
Corresponds to the JSON property tagSettings
7699 7700 7701 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7699 def tag_settings @tag_settings end |
#third_party_authentication_tokens ⇒ Array<Google::Apis::DfareportingV5::ThirdPartyAuthenticationToken>
List of third-party authentication tokens enabled for this configuration.
Corresponds to the JSON property thirdPartyAuthenticationTokens
7704 7705 7706 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7704 def third_party_authentication_tokens @third_party_authentication_tokens end |
#user_defined_variable_configurations ⇒ Array<Google::Apis::DfareportingV5::UserDefinedVariableConfiguration>
List of user defined variables enabled for this configuration.
Corresponds to the JSON property userDefinedVariableConfigurations
7709 7710 7711 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7709 def user_defined_variable_configurations @user_defined_variable_configurations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7716 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value) @analytics_data_sharing_enabled = args[:analytics_data_sharing_enabled] if args.key?(:analytics_data_sharing_enabled) @custom_viewability_metric = args[:custom_viewability_metric] if args.key?(:custom_viewability_metric) @exposure_to_conversion_enabled = args[:exposure_to_conversion_enabled] if args.key?(:exposure_to_conversion_enabled) @first_day_of_week = args[:first_day_of_week] if args.key?(:first_day_of_week) @id = args[:id] if args.key?(:id) @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value) @in_app_attribution_tracking_enabled = args[:in_app_attribution_tracking_enabled] if args.key?(:in_app_attribution_tracking_enabled) @kind = args[:kind] if args.key?(:kind) @lookback_configuration = args[:lookback_configuration] if args.key?(:lookback_configuration) @natural_search_conversion_attribution_option = args[:natural_search_conversion_attribution_option] if args.key?(:natural_search_conversion_attribution_option) @omniture_settings = args[:omniture_settings] if args.key?(:omniture_settings) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) @tag_settings = args[:tag_settings] if args.key?(:tag_settings) @third_party_authentication_tokens = args[:third_party_authentication_tokens] if args.key?(:third_party_authentication_tokens) @user_defined_variable_configurations = args[:user_defined_variable_configurations] if args.key?(:user_defined_variable_configurations) end |