Class: Google::Apis::DfareportingV5::FsCommand
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::FsCommand
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
FsCommand.
Instance Attribute Summary collapse
-
#left ⇒ Fixnum
Distance from the left of the browser.Applicable when positionOption is DISTANCE_FROM_TOP_LEFT_CORNER.
-
#position_option ⇒ String
Position in the browser where the window will open.
-
#top ⇒ Fixnum
Distance from the top of the browser.
-
#window_height ⇒ Fixnum
Height of the window.
-
#window_width ⇒ Fixnum
Width of the window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FsCommand
constructor
A new instance of FsCommand.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FsCommand
Returns a new instance of FsCommand.
7864 7865 7866 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#left ⇒ Fixnum
Distance from the left of the browser.Applicable when positionOption is
DISTANCE_FROM_TOP_LEFT_CORNER.
Corresponds to the JSON property left
7841 7842 7843 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7841 def left @left end |
#position_option ⇒ String
Position in the browser where the window will open.
Corresponds to the JSON property positionOption
7846 7847 7848 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7846 def position_option @position_option end |
#top ⇒ Fixnum
Distance from the top of the browser. Applicable when positionOption is
DISTANCE_FROM_TOP_LEFT_CORNER.
Corresponds to the JSON property top
7852 7853 7854 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7852 def top @top end |
#window_height ⇒ Fixnum
Height of the window.
Corresponds to the JSON property windowHeight
7857 7858 7859 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7857 def window_height @window_height end |
#window_width ⇒ Fixnum
Width of the window.
Corresponds to the JSON property windowWidth
7862 7863 7864 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7862 def window_width @window_width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7869 7870 7871 7872 7873 7874 7875 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7869 def update!(**args) @left = args[:left] if args.key?(:left) @position_option = args[:position_option] if args.key?(:position_option) @top = args[:top] if args.key?(:top) @window_height = args[:window_height] if args.key?(:window_height) @window_width = args[:window_width] if args.key?(:window_width) end |