Class: Google::Apis::DfareportingV5::IngestionErrorRecord
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::IngestionErrorRecord
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains the ingestion error record of the dynamic feed. limited to 100 records.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::DfareportingV5::FieldError>
Output only.
-
#record_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestionErrorRecord
constructor
A new instance of IngestionErrorRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestionErrorRecord
Returns a new instance of IngestionErrorRecord.
7959 7960 7961 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7959 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::DfareportingV5::FieldError>
Output only. The list of field errors of the ingestion error record.
Corresponds to the JSON property errors
7952 7953 7954 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7952 def errors @errors end |
#record_id ⇒ String
Output only. The record ID of the ingestion error record.
Corresponds to the JSON property recordId
7957 7958 7959 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7957 def record_id @record_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7964 7965 7966 7967 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 7964 def update!(**args) @errors = args[:errors] if args.key?(:errors) @record_id = args[:record_id] if args.key?(:record_id) end |