Class: Google::Apis::DfareportingV5::Invoice
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Invoice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains information about a single invoice
Instance Attribute Summary collapse
-
#campaign_summaries ⇒ Array<Google::Apis::DfareportingV5::CampaignSummary>
The list of summarized campaign information associated with this invoice.
-
#corrected_invoice_id ⇒ String
The originally issued invoice that is being adjusted by this invoice, if applicable.
-
#currency_code ⇒ String
Invoice currency code in ISO 4217 format.
-
#due_date ⇒ String
The invoice due date.
-
#id ⇒ String
ID of this invoice.
-
#invoice_type ⇒ String
The type of invoice document.
-
#issue_date ⇒ String
The date when the invoice was issued.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#payments_account_id ⇒ String
The ID of the payments account the invoice belongs to.
-
#payments_profile_id ⇒ String
The ID of the payments profile the invoice belongs to.
-
#pdf_url ⇒ String
The URL to download a PDF copy of the invoice.
-
#purchase_order_number ⇒ String
Purchase order number associated with the invoice.
-
#replaced_invoice_ids ⇒ Array<String>
The originally issued invoice(s) that is being cancelled by this invoice, if applicable.
-
#service_end_date ⇒ String
The invoice service end date.
-
#service_start_date ⇒ String
The invoice service start date.
-
#subtotal_amount_micros ⇒ Fixnum
The pre-tax subtotal amount, in micros of the invoice's currency.
-
#total_amount_micros ⇒ Fixnum
The invoice total amount, in micros of the invoice's currency.
-
#total_tax_amount_micros ⇒ Fixnum
The sum of all taxes in invoice, in micros of the invoice's currency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Invoice
constructor
A new instance of Invoice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Invoice
Returns a new instance of Invoice.
8117 8118 8119 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign_summaries ⇒ Array<Google::Apis::DfareportingV5::CampaignSummary>
The list of summarized campaign information associated with this invoice.
Corresponds to the JSON property campaign_summaries
8020 8021 8022 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8020 def campaign_summaries @campaign_summaries end |
#corrected_invoice_id ⇒ String
The originally issued invoice that is being adjusted by this invoice, if
applicable. May appear on invoice PDF as Reference invoice number.
Corresponds to the JSON property correctedInvoiceId
8026 8027 8028 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8026 def corrected_invoice_id @corrected_invoice_id end |
#currency_code ⇒ String
Invoice currency code in ISO 4217 format.
Corresponds to the JSON property currencyCode
8031 8032 8033 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8031 def currency_code @currency_code end |
#due_date ⇒ String
The invoice due date.
Corresponds to the JSON property dueDate
8036 8037 8038 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8036 def due_date @due_date end |
#id ⇒ String
ID of this invoice.
Corresponds to the JSON property id
8041 8042 8043 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8041 def id @id end |
#invoice_type ⇒ String
The type of invoice document.
Corresponds to the JSON property invoiceType
8046 8047 8048 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8046 def invoice_type @invoice_type end |
#issue_date ⇒ String
The date when the invoice was issued.
Corresponds to the JSON property issueDate
8051 8052 8053 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8051 def issue_date @issue_date end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#invoice".
Corresponds to the JSON property kind
8057 8058 8059 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8057 def kind @kind end |
#payments_account_id ⇒ String
The ID of the payments account the invoice belongs to. Appears on the invoice
PDF as Billing Account Number.
Corresponds to the JSON property paymentsAccountId
8063 8064 8065 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8063 def payments_account_id @payments_account_id end |
#payments_profile_id ⇒ String
The ID of the payments profile the invoice belongs to. Appears on the invoice
PDF as Billing ID.
Corresponds to the JSON property paymentsProfileId
8069 8070 8071 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8069 def payments_profile_id @payments_profile_id end |
#pdf_url ⇒ String
The URL to download a PDF copy of the invoice. Note that this URL is user
specific and requires a valid OAuth 2.0 access token to access. The access
token must be provided in an Authorization: Bearer HTTP header. The URL will
only be usable for 7 days from when the api is called.
Corresponds to the JSON property pdfUrl
8077 8078 8079 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8077 def pdf_url @pdf_url end |
#purchase_order_number ⇒ String
Purchase order number associated with the invoice.
Corresponds to the JSON property purchaseOrderNumber
8082 8083 8084 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8082 def purchase_order_number @purchase_order_number end |
#replaced_invoice_ids ⇒ Array<String>
The originally issued invoice(s) that is being cancelled by this invoice, if
applicable. May appear on invoice PDF as Replaced invoice numbers. Note:
There may be multiple replaced invoices due to consolidation of multiple
invoices into a single invoice.
Corresponds to the JSON property replacedInvoiceIds
8090 8091 8092 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8090 def replaced_invoice_ids @replaced_invoice_ids end |
#service_end_date ⇒ String
The invoice service end date.
Corresponds to the JSON property serviceEndDate
8095 8096 8097 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8095 def service_end_date @service_end_date end |
#service_start_date ⇒ String
The invoice service start date.
Corresponds to the JSON property serviceStartDate
8100 8101 8102 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8100 def service_start_date @service_start_date end |
#subtotal_amount_micros ⇒ Fixnum
The pre-tax subtotal amount, in micros of the invoice's currency.
Corresponds to the JSON property subtotalAmountMicros
8105 8106 8107 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8105 def subtotal_amount_micros @subtotal_amount_micros end |
#total_amount_micros ⇒ Fixnum
The invoice total amount, in micros of the invoice's currency.
Corresponds to the JSON property totalAmountMicros
8110 8111 8112 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8110 def total_amount_micros @total_amount_micros end |
#total_tax_amount_micros ⇒ Fixnum
The sum of all taxes in invoice, in micros of the invoice's currency.
Corresponds to the JSON property totalTaxAmountMicros
8115 8116 8117 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8115 def total_tax_amount_micros @total_tax_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8122 def update!(**args) @campaign_summaries = args[:campaign_summaries] if args.key?(:campaign_summaries) @corrected_invoice_id = args[:corrected_invoice_id] if args.key?(:corrected_invoice_id) @currency_code = args[:currency_code] if args.key?(:currency_code) @due_date = args[:due_date] if args.key?(:due_date) @id = args[:id] if args.key?(:id) @invoice_type = args[:invoice_type] if args.key?(:invoice_type) @issue_date = args[:issue_date] if args.key?(:issue_date) @kind = args[:kind] if args.key?(:kind) @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id) @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id) @pdf_url = args[:pdf_url] if args.key?(:pdf_url) @purchase_order_number = args[:purchase_order_number] if args.key?(:purchase_order_number) @replaced_invoice_ids = args[:replaced_invoice_ids] if args.key?(:replaced_invoice_ids) @service_end_date = args[:service_end_date] if args.key?(:service_end_date) @service_start_date = args[:service_start_date] if args.key?(:service_start_date) @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros) @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros) @total_tax_amount_micros = args[:total_tax_amount_micros] if args.key?(:total_tax_amount_micros) end |