Class: Google::Apis::DfareportingV5::LandingPage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains information about where a user's browser is taken after the user clicks an ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LandingPage

Returns a new instance of LandingPage.



8206
8207
8208
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Advertiser ID of this landing page. This is a required field. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


8171
8172
8173
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8171

def advertiser_id
  @advertiser_id
end

#archivedBoolean Also known as: archived?

Whether this landing page has been archived. Corresponds to the JSON property archived

Returns:

  • (Boolean)


8176
8177
8178
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8176

def archived
  @archived
end

Links that will direct the user to a mobile app, if installed. Corresponds to the JSON property deepLinks



8182
8183
8184
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8182

def deep_links
  @deep_links
end

#idFixnum

ID of this landing page. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


8187
8188
8189
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8187

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#landingPage". Corresponds to the JSON property kind

Returns:

  • (String)


8193
8194
8195
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8193

def kind
  @kind
end

#nameString

Name of this landing page. This is a required field. It must be less than 256 characters long. Corresponds to the JSON property name

Returns:

  • (String)


8199
8200
8201
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8199

def name
  @name
end

#urlString

URL of this landing page. This is a required field. Corresponds to the JSON property url

Returns:

  • (String)


8204
8205
8206
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8204

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8211
8212
8213
8214
8215
8216
8217
8218
8219
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8211

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @archived = args[:archived] if args.key?(:archived)
  @deep_links = args[:deep_links] if args.key?(:deep_links)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @url = args[:url] if args.key?(:url)
end