Class: Google::Apis::DfareportingV5::ListPopulationClause
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::ListPopulationClause
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
A group clause made up of list population terms representing constraints joined by ORs.
Instance Attribute Summary collapse
-
#terms ⇒ Array<Google::Apis::DfareportingV5::ListPopulationTerm>
Terms of this list population clause.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPopulationClause
constructor
A new instance of ListPopulationClause.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPopulationClause
Returns a new instance of ListPopulationClause.
8340 8341 8342 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8340 def initialize(**args) update!(**args) end |
Instance Attribute Details
#terms ⇒ Array<Google::Apis::DfareportingV5::ListPopulationTerm>
Terms of this list population clause. Each clause is made up of list
population terms representing constraints and are joined by ORs.
Corresponds to the JSON property terms
8338 8339 8340 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8338 def terms @terms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8345 8346 8347 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8345 def update!(**args) @terms = args[:terms] if args.key?(:terms) end |