Class: Google::Apis::DfareportingV5::ListPopulationTerm
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::ListPopulationTerm
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Remarketing List Population Rule Term.
Instance Attribute Summary collapse
-
#contains ⇒ Boolean
(also: #contains?)
Will be true if the term should check if the user is in the list and false if the term should check if the user is not in the list.
-
#negation ⇒ Boolean
(also: #negation?)
Whether to negate the comparison result of this term during rule evaluation.
-
#operator ⇒ String
Comparison operator of this term.
-
#remarketing_list_id ⇒ Fixnum
ID of the list in question.
-
#type ⇒ String
List population term type determines the applicable fields in this object.
-
#value ⇒ String
Literal to compare the variable to.
-
#variable_friendly_name ⇒ String
Friendly name of this term's variable.
-
#variable_name ⇒ String
Name of the variable (U1, U2, etc.) being compared in this term.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPopulationTerm
constructor
A new instance of ListPopulationTerm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPopulationTerm
Returns a new instance of ListPopulationTerm.
8478 8479 8480 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contains ⇒ Boolean Also known as: contains?
Will be true if the term should check if the user is in the list and false if
the term should check if the user is not in the list. This field is only
relevant when type is set to LIST_MEMBERSHIP_TERM. False by default.
Corresponds to the JSON property contains
8427 8428 8429 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8427 def contains @contains end |
#negation ⇒ Boolean Also known as: negation?
Whether to negate the comparison result of this term during rule evaluation.
This field is only relevant when type is left unset or set to
CUSTOM_VARIABLE_TERM or REFERRER_TERM.
Corresponds to the JSON property negation
8435 8436 8437 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8435 def negation @negation end |
#operator ⇒ String
Comparison operator of this term. This field is only relevant when type is
left unset or set to CUSTOM_VARIABLE_TERM or REFERRER_TERM.
Corresponds to the JSON property operator
8442 8443 8444 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8442 def operator @operator end |
#remarketing_list_id ⇒ Fixnum
ID of the list in question. This field is only relevant when type is set to
LIST_MEMBERSHIP_TERM.
Corresponds to the JSON property remarketingListId
8448 8449 8450 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8448 def remarketing_list_id @remarketing_list_id end |
#type ⇒ String
List population term type determines the applicable fields in this object. If
left unset or set to CUSTOM_VARIABLE_TERM, then variableName,
variableFriendlyName, operator, value, and negation are applicable. If set to
LIST_MEMBERSHIP_TERM then remarketingListId and contains are applicable. If
set to REFERRER_TERM then operator, value, and negation are applicable.
Corresponds to the JSON property type
8457 8458 8459 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8457 def type @type end |
#value ⇒ String
Literal to compare the variable to. This field is only relevant when type is
left unset or set to CUSTOM_VARIABLE_TERM or REFERRER_TERM.
Corresponds to the JSON property value
8463 8464 8465 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8463 def value @value end |
#variable_friendly_name ⇒ String
Friendly name of this term's variable. This is a read-only, auto-generated
field. This field is only relevant when type is left unset or set to
CUSTOM_VARIABLE_TERM.
Corresponds to the JSON property variableFriendlyName
8470 8471 8472 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8470 def variable_friendly_name @variable_friendly_name end |
#variable_name ⇒ String
Name of the variable (U1, U2, etc.) being compared in this term. This field is
only relevant when type is set to null, CUSTOM_VARIABLE_TERM or REFERRER_TERM.
Corresponds to the JSON property variableName
8476 8477 8478 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8476 def variable_name @variable_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8483 8484 8485 8486 8487 8488 8489 8490 8491 8492 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8483 def update!(**args) @contains = args[:contains] if args.key?(:contains) @negation = args[:negation] if args.key?(:negation) @operator = args[:operator] if args.key?(:operator) @remarketing_list_id = args[:remarketing_list_id] if args.key?(:remarketing_list_id) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) @variable_friendly_name = args[:variable_friendly_name] if args.key?(:variable_friendly_name) @variable_name = args[:variable_name] if args.key?(:variable_name) end |