Class: Google::Apis::DfareportingV5::ListPopulationTerm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Remarketing List Population Rule Term.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPopulationTerm

Returns a new instance of ListPopulationTerm.



8444
8445
8446
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containsBoolean Also known as: contains?

Will be true if the term should check if the user is in the list and false if the term should check if the user is not in the list. This field is only relevant when type is set to LIST_MEMBERSHIP_TERM. False by default. Corresponds to the JSON property contains

Returns:

  • (Boolean)


8393
8394
8395
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8393

def contains
  @contains
end

#negationBoolean Also known as: negation?

Whether to negate the comparison result of this term during rule evaluation. This field is only relevant when type is left unset or set to CUSTOM_VARIABLE_TERM or REFERRER_TERM. Corresponds to the JSON property negation

Returns:

  • (Boolean)


8401
8402
8403
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8401

def negation
  @negation
end

#operatorString

Comparison operator of this term. This field is only relevant when type is left unset or set to CUSTOM_VARIABLE_TERM or REFERRER_TERM. Corresponds to the JSON property operator

Returns:

  • (String)


8408
8409
8410
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8408

def operator
  @operator
end

#remarketing_list_idFixnum

ID of the list in question. This field is only relevant when type is set to LIST_MEMBERSHIP_TERM. Corresponds to the JSON property remarketingListId

Returns:

  • (Fixnum)


8414
8415
8416
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8414

def remarketing_list_id
  @remarketing_list_id
end

#typeString

List population term type determines the applicable fields in this object. If left unset or set to CUSTOM_VARIABLE_TERM, then variableName, variableFriendlyName, operator, value, and negation are applicable. If set to LIST_MEMBERSHIP_TERM then remarketingListId and contains are applicable. If set to REFERRER_TERM then operator, value, and negation are applicable. Corresponds to the JSON property type

Returns:

  • (String)


8423
8424
8425
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8423

def type
  @type
end

#valueString

Literal to compare the variable to. This field is only relevant when type is left unset or set to CUSTOM_VARIABLE_TERM or REFERRER_TERM. Corresponds to the JSON property value

Returns:

  • (String)


8429
8430
8431
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8429

def value
  @value
end

#variable_friendly_nameString

Friendly name of this term's variable. This is a read-only, auto-generated field. This field is only relevant when type is left unset or set to CUSTOM_VARIABLE_TERM. Corresponds to the JSON property variableFriendlyName

Returns:

  • (String)


8436
8437
8438
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8436

def variable_friendly_name
  @variable_friendly_name
end

#variable_nameString

Name of the variable (U1, U2, etc.) being compared in this term. This field is only relevant when type is set to null, CUSTOM_VARIABLE_TERM or REFERRER_TERM. Corresponds to the JSON property variableName

Returns:

  • (String)


8442
8443
8444
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8442

def variable_name
  @variable_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8449
8450
8451
8452
8453
8454
8455
8456
8457
8458
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8449

def update!(**args)
  @contains = args[:contains] if args.key?(:contains)
  @negation = args[:negation] if args.key?(:negation)
  @operator = args[:operator] if args.key?(:operator)
  @remarketing_list_id = args[:remarketing_list_id] if args.key?(:remarketing_list_id)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
  @variable_friendly_name = args[:variable_friendly_name] if args.key?(:variable_friendly_name)
  @variable_name = args[:variable_name] if args.key?(:variable_name)
end