Class: Google::Apis::DfareportingV5::OfflineUserAddressInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Identify a user by name and address.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OfflineUserAddressInfo

Returns a new instance of OfflineUserAddressInfo.



9004
9005
9006
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cityString

City of the address. Corresponds to the JSON property city

Returns:

  • (String)


8969
8970
8971
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8969

def city
  @city
end

#country_codeString

2-letter country code in ISO-3166-1 alpha-2 of the user's address. Corresponds to the JSON property countryCode

Returns:

  • (String)


8974
8975
8976
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8974

def country_code
  @country_code
end

#hashed_first_nameString

First name of the user, which is hashed as SHA-256 after normalized (Lowercase all characters; Remove any extra spaces before, after, and in between). Corresponds to the JSON property hashedFirstName

Returns:

  • (String)


8980
8981
8982
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8980

def hashed_first_name
  @hashed_first_name
end

#hashed_last_nameString

Last name of the user, which is hashed as SHA-256 after normalized (lower case only and no punctuation). Corresponds to the JSON property hashedLastName

Returns:

  • (String)


8986
8987
8988
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8986

def hashed_last_name
  @hashed_last_name
end

#hashed_street_addressString

The street address of the user hashed using SHA-256 hash function after normalization (lower case only). Corresponds to the JSON property hashedStreetAddress

Returns:

  • (String)


8992
8993
8994
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8992

def hashed_street_address
  @hashed_street_address
end

#postal_codeString

Postal code of the user's address. Corresponds to the JSON property postalCode

Returns:

  • (String)


8997
8998
8999
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 8997

def postal_code
  @postal_code
end

#stateString

State code of the address. Corresponds to the JSON property state

Returns:

  • (String)


9002
9003
9004
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9002

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9009
9010
9011
9012
9013
9014
9015
9016
9017
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9009

def update!(**args)
  @city = args[:city] if args.key?(:city)
  @country_code = args[:country_code] if args.key?(:country_code)
  @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name)
  @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name)
  @hashed_street_address = args[:hashed_street_address] if args.key?(:hashed_street_address)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @state = args[:state] if args.key?(:state)
end