Class: Google::Apis::DfareportingV5::OptimizationActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Creative optimization activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OptimizationActivity

Returns a new instance of OptimizationActivity.



9244
9245
9246
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activity_idFixnum

Floodlight activity ID of this optimization activity. This is a required field. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


9230
9231
9232
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9230

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_activity_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightActivityIdDimensionValue



9235
9236
9237
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9235

def floodlight_activity_id_dimension_value
  @floodlight_activity_id_dimension_value
end

#weightFixnum

Weight associated with this optimization. The weight assigned will be understood in proportion to the weights assigned to the other optimization activities. Value must be greater than or equal to 1. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


9242
9243
9244
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9242

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9249
9250
9251
9252
9253
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9249

def update!(**args)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_activity_id_dimension_value = args[:floodlight_activity_id_dimension_value] if args.key?(:floodlight_activity_id_dimension_value)
  @weight = args[:weight] if args.key?(:weight)
end