Class: Google::Apis::DfareportingV5::PathToConversionReportCompatibleFields
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::PathToConversionReportCompatibleFields
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents fields that are compatible to be selected for a report of type " PATH_TO_CONVERSION".
Instance Attribute Summary collapse
-
#conversion_dimensions ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Conversion dimensions which are compatible to be selected in the " conversionDimensions" section of the report.
-
#custom_floodlight_variables ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Custom floodlight variables which are compatible to be selected in the " customFloodlightVariables" section of the report.
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting# pathToConversionReportCompatibleFields.
-
#metrics ⇒ Array<Google::Apis::DfareportingV5::Metric>
Metrics which are compatible to be selected in the "metricNames" section of the report.
-
#per_interaction_dimensions ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Per-interaction dimensions which are compatible to be selected in the " perInteractionDimensions" section of the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PathToConversionReportCompatibleFields
constructor
A new instance of PathToConversionReportCompatibleFields.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PathToConversionReportCompatibleFields
Returns a new instance of PathToConversionReportCompatibleFields.
9325 9326 9327 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_dimensions ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Conversion dimensions which are compatible to be selected in the "
conversionDimensions" section of the report.
Corresponds to the JSON property conversionDimensions
9299 9300 9301 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9299 def conversion_dimensions @conversion_dimensions end |
#custom_floodlight_variables ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Custom floodlight variables which are compatible to be selected in the "
customFloodlightVariables" section of the report.
Corresponds to the JSON property customFloodlightVariables
9305 9306 9307 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9305 def custom_floodlight_variables @custom_floodlight_variables end |
#kind ⇒ String
The kind of resource this is, in this case dfareporting#
pathToConversionReportCompatibleFields.
Corresponds to the JSON property kind
9311 9312 9313 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9311 def kind @kind end |
#metrics ⇒ Array<Google::Apis::DfareportingV5::Metric>
Metrics which are compatible to be selected in the "metricNames" section of
the report.
Corresponds to the JSON property metrics
9317 9318 9319 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9317 def metrics @metrics end |
#per_interaction_dimensions ⇒ Array<Google::Apis::DfareportingV5::Dimension>
Per-interaction dimensions which are compatible to be selected in the "
perInteractionDimensions" section of the report.
Corresponds to the JSON property perInteractionDimensions
9323 9324 9325 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9323 def per_interaction_dimensions @per_interaction_dimensions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9330 9331 9332 9333 9334 9335 9336 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9330 def update!(**args) @conversion_dimensions = args[:conversion_dimensions] if args.key?(:conversion_dimensions) @custom_floodlight_variables = args[:custom_floodlight_variables] if args.key?(:custom_floodlight_variables) @kind = args[:kind] if args.key?(:kind) @metrics = args[:metrics] if args.key?(:metrics) @per_interaction_dimensions = args[:per_interaction_dimensions] if args.key?(:per_interaction_dimensions) end |