Class: Google::Apis::DfareportingV5::PathToConversionReportCompatibleFields

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Represents fields that are compatible to be selected for a report of type " PATH_TO_CONVERSION".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PathToConversionReportCompatibleFields

Returns a new instance of PathToConversionReportCompatibleFields.



9291
9292
9293
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_dimensionsArray<Google::Apis::DfareportingV5::Dimension>

Conversion dimensions which are compatible to be selected in the " conversionDimensions" section of the report. Corresponds to the JSON property conversionDimensions



9265
9266
9267
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9265

def conversion_dimensions
  @conversion_dimensions
end

#custom_floodlight_variablesArray<Google::Apis::DfareportingV5::Dimension>

Custom floodlight variables which are compatible to be selected in the " customFloodlightVariables" section of the report. Corresponds to the JSON property customFloodlightVariables



9271
9272
9273
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9271

def custom_floodlight_variables
  @custom_floodlight_variables
end

#kindString

The kind of resource this is, in this case dfareporting# pathToConversionReportCompatibleFields. Corresponds to the JSON property kind

Returns:

  • (String)


9277
9278
9279
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9277

def kind
  @kind
end

#metricsArray<Google::Apis::DfareportingV5::Metric>

Metrics which are compatible to be selected in the "metricNames" section of the report. Corresponds to the JSON property metrics



9283
9284
9285
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9283

def metrics
  @metrics
end

#per_interaction_dimensionsArray<Google::Apis::DfareportingV5::Dimension>

Per-interaction dimensions which are compatible to be selected in the " perInteractionDimensions" section of the report. Corresponds to the JSON property perInteractionDimensions



9289
9290
9291
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9289

def per_interaction_dimensions
  @per_interaction_dimensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9296
9297
9298
9299
9300
9301
9302
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9296

def update!(**args)
  @conversion_dimensions = args[:conversion_dimensions] if args.key?(:conversion_dimensions)
  @custom_floodlight_variables = args[:custom_floodlight_variables] if args.key?(:custom_floodlight_variables)
  @kind = args[:kind] if args.key?(:kind)
  @metrics = args[:metrics] if args.key?(:metrics)
  @per_interaction_dimensions = args[:per_interaction_dimensions] if args.key?(:per_interaction_dimensions)
end