Class: Google::Apis::DfareportingV5::Placement
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Placement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of a placement.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this placement.
-
#active_status ⇒ String
Whether this placement is active, inactive, archived or permanently archived.
-
#ad_blocking_opt_out ⇒ Boolean
(also: #ad_blocking_opt_out?)
Whether this placement opts out of ad blocking.
-
#ad_serving_platform_id ⇒ Fixnum
Optional.
-
#additional_sizes ⇒ Array<Google::Apis::DfareportingV5::Size>
Additional sizes associated with this placement.
-
#advertiser_id ⇒ Fixnum
Advertiser ID of this placement.
-
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#allow_on_youtube ⇒ Boolean
(also: #allow_on_youtube?)
Optional.
-
#campaign_id ⇒ Fixnum
Campaign ID of this placement.
-
#campaign_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#comment ⇒ String
Comments for this placement.
-
#compatibility ⇒ String
Placement compatibility.
-
#content_category_id ⇒ Fixnum
ID of the content category assigned to this placement.
-
#conversion_domain_override ⇒ Google::Apis::DfareportingV5::PlacementConversionDomainOverride
Optional.
-
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#directory_site_id ⇒ Fixnum
Directory site ID of this placement.
-
#directory_site_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#external_id ⇒ String
External ID for this placement.
-
#id ⇒ Fixnum
ID of this placement.
-
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#key_name ⇒ String
Key name of this placement.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#lookback_configuration ⇒ Google::Apis::DfareportingV5::LookbackConfiguration
Lookback configuration settings.
-
#name ⇒ String
Name of this placement.This is a required field and must be less than or equal to 512 characters long.
-
#partner_wrapping_data ⇒ Google::Apis::DfareportingV5::MeasurementPartnerWrappingData
Placement tag wrapping Corresponds to the JSON property
partnerWrappingData. -
#payment_approved ⇒ Boolean
(also: #payment_approved?)
Whether payment was approved for this placement.
-
#payment_source ⇒ String
Payment source for this placement.
-
#placement_group_id ⇒ Fixnum
ID of this placement's group, if applicable.
-
#placement_group_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#placement_strategy_id ⇒ Fixnum
ID of the placement strategy assigned to this placement.
-
#pricing_schedule ⇒ Google::Apis::DfareportingV5::PricingSchedule
Pricing Schedule Corresponds to the JSON property
pricingSchedule. -
#primary ⇒ Boolean
(also: #primary?)
Whether this placement is the primary placement of a roadblock (placement group).
-
#publisher_update_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#site_id ⇒ Fixnum
Site ID associated with this placement.
-
#site_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#site_served ⇒ Boolean
(also: #site_served?)
Optional.
-
#size ⇒ Google::Apis::DfareportingV5::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#ssl_required ⇒ Boolean
(also: #ssl_required?)
Whether creatives assigned to this placement must be SSL-compliant.
-
#status ⇒ String
Third-party placement status.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this placement.
-
#tag_formats ⇒ Array<String>
Tag formats to generate for this placement.
-
#tag_setting ⇒ Google::Apis::DfareportingV5::TagSetting
Tag Settings Corresponds to the JSON property
tagSetting. -
#video_active_view_opt_out ⇒ Boolean
(also: #video_active_view_opt_out?)
Whether Verification and ActiveView are disabled for in-stream video creatives for this placement.
-
#video_settings ⇒ Google::Apis::DfareportingV5::VideoSettings
Video Settings Corresponds to the JSON property
videoSettings. -
#vpaid_adapter_choice ⇒ String
VPAID adapter setting for this placement.
-
#wrapping_opt_out ⇒ Boolean
(also: #wrapping_opt_out?)
Whether this placement opts out of tag wrapping.
-
#youtube_settings ⇒ Google::Apis::DfareportingV5::YoutubeSettings
Contains the YouTube settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Placement
constructor
A new instance of Placement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Placement
Returns a new instance of Placement.
9606 9607 9608 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this placement. This field can be left blank.
Corresponds to the JSON property accountId
9312 9313 9314 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9312 def account_id @account_id end |
#active_status ⇒ String
Whether this placement is active, inactive, archived or permanently archived.
Corresponds to the JSON property activeStatus
9317 9318 9319 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9317 def active_status @active_status end |
#ad_blocking_opt_out ⇒ Boolean Also known as: ad_blocking_opt_out?
Whether this placement opts out of ad blocking. When true, ad blocking is
disabled for this placement. When false, the campaign and site settings take
effect.
Corresponds to the JSON property adBlockingOptOut
9324 9325 9326 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9324 def ad_blocking_opt_out @ad_blocking_opt_out end |
#ad_serving_platform_id ⇒ Fixnum
Optional. Ad serving platform ID to identify the ad serving platform used by
the placement. Measurement partners can use this field to add ad-server
specific macros. Possible values are: * 1, Adelphic * 2, Adform * 3,
Adobe * 4, Amobee * 5, Basis (Centro) * 6, Beeswax * 7, Amazon * 8,
DV360 (DBM) * 9, Innovid * 10, MediaMath * 11, Roku OneView DSP * 12,
TabMo Hawk * 13, The Trade Desk * 14, Xandr Invest DSP * 15, Yahoo DSP *
16, Zeta Global * 17, Scaleout * 18, Bidtellect * 19, Unicorn * 20,
Teads * 21, Quantcast * 22, Cognitiv * 23, AdTheorent * 24, DeepIntent
25, Pulsepoint Corresponds to the JSON propertyadServingPlatformId
9338 9339 9340 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9338 def ad_serving_platform_id @ad_serving_platform_id end |
#additional_sizes ⇒ Array<Google::Apis::DfareportingV5::Size>
Additional sizes associated with this placement. When inserting or updating a
placement, only the size ID field is used.
Corresponds to the JSON property additionalSizes
9344 9345 9346 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9344 def additional_sizes @additional_sizes end |
#advertiser_id ⇒ Fixnum
Advertiser ID of this placement. This field can be left blank.
Corresponds to the JSON property advertiserId
9349 9350 9351 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9349 def advertiser_id @advertiser_id end |
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property advertiserIdDimensionValue
9354 9355 9356 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9354 def advertiser_id_dimension_value @advertiser_id_dimension_value end |
#allow_on_youtube ⇒ Boolean Also known as: allow_on_youtube?
Optional. Whether the placement is enabled for YouTube integration.
Corresponds to the JSON property allowOnYoutube
9359 9360 9361 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9359 def allow_on_youtube @allow_on_youtube end |
#campaign_id ⇒ Fixnum
Campaign ID of this placement. This field is a required field on insertion.
Corresponds to the JSON property campaignId
9365 9366 9367 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9365 def campaign_id @campaign_id end |
#campaign_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property campaignIdDimensionValue
9370 9371 9372 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9370 def campaign_id_dimension_value @campaign_id_dimension_value end |
#comment ⇒ String
Comments for this placement.
Corresponds to the JSON property comment
9375 9376 9377 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9375 def comment @comment end |
#compatibility ⇒ String
Placement compatibility. DISPLAY and DISPLAY_INTERSTITIAL refer to rendering
on desktop, on mobile devices or in mobile apps for regular or interstitial
ads respectively. APP and APP_INTERSTITIAL are no longer allowed for new
placement insertions. Instead, use DISPLAY or DISPLAY_INTERSTITIAL.
IN_STREAM_VIDEO refers to rendering in in-stream video ads developed with the
VAST standard. This field is required on insertion.
Corresponds to the JSON property compatibility
9385 9386 9387 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9385 def compatibility @compatibility end |
#content_category_id ⇒ Fixnum
ID of the content category assigned to this placement.
Corresponds to the JSON property contentCategoryId
9390 9391 9392 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9390 def content_category_id @content_category_id end |
#conversion_domain_override ⇒ Google::Apis::DfareportingV5::PlacementConversionDomainOverride
Optional. Conversion domain overrides for a placement.
Corresponds to the JSON property conversionDomainOverride
9395 9396 9397 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9395 def conversion_domain_override @conversion_domain_override end |
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property createInfo
9400 9401 9402 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9400 def create_info @create_info end |
#directory_site_id ⇒ Fixnum
Directory site ID of this placement. On insert, you must set either this field
or the siteId field to specify the site associated with this placement. This
is a required field that is read-only after insertion.
Corresponds to the JSON property directorySiteId
9407 9408 9409 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9407 def directory_site_id @directory_site_id end |
#directory_site_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property directorySiteIdDimensionValue
9412 9413 9414 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9412 def directory_site_id_dimension_value @directory_site_id_dimension_value end |
#external_id ⇒ String
External ID for this placement.
Corresponds to the JSON property externalId
9417 9418 9419 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9417 def external_id @external_id end |
#id ⇒ Fixnum
ID of this placement. This is a read-only, auto-generated field.
Corresponds to the JSON property id
9422 9423 9424 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9422 def id @id end |
#id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property idDimensionValue
9427 9428 9429 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9427 def id_dimension_value @id_dimension_value end |
#key_name ⇒ String
Key name of this placement. This is a read-only, auto-generated field.
Corresponds to the JSON property keyName
9432 9433 9434 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9432 def key_name @key_name end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#placement".
Corresponds to the JSON property kind
9438 9439 9440 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9438 def kind @kind end |
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property lastModifiedInfo
9443 9444 9445 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9443 def last_modified_info @last_modified_info end |
#lookback_configuration ⇒ Google::Apis::DfareportingV5::LookbackConfiguration
Lookback configuration settings.
Corresponds to the JSON property lookbackConfiguration
9448 9449 9450 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9448 def lookback_configuration @lookback_configuration end |
#name ⇒ String
Name of this placement.This is a required field and must be less than or equal
to 512 characters long.
Corresponds to the JSON property name
9454 9455 9456 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9454 def name @name end |
#partner_wrapping_data ⇒ Google::Apis::DfareportingV5::MeasurementPartnerWrappingData
Placement tag wrapping
Corresponds to the JSON property partnerWrappingData
9459 9460 9461 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9459 def partner_wrapping_data @partner_wrapping_data end |
#payment_approved ⇒ Boolean Also known as: payment_approved?
Whether payment was approved for this placement. This is a read-only field
relevant only to publisher-paid placements.
Corresponds to the JSON property paymentApproved
9465 9466 9467 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9465 def payment_approved @payment_approved end |
#payment_source ⇒ String
Payment source for this placement. This is a required field that is read-only
after insertion.
Corresponds to the JSON property paymentSource
9472 9473 9474 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9472 def payment_source @payment_source end |
#placement_group_id ⇒ Fixnum
ID of this placement's group, if applicable.
Corresponds to the JSON property placementGroupId
9477 9478 9479 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9477 def placement_group_id @placement_group_id end |
#placement_group_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property placementGroupIdDimensionValue
9482 9483 9484 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9482 def placement_group_id_dimension_value @placement_group_id_dimension_value end |
#placement_strategy_id ⇒ Fixnum
ID of the placement strategy assigned to this placement.
Corresponds to the JSON property placementStrategyId
9487 9488 9489 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9487 def placement_strategy_id @placement_strategy_id end |
#pricing_schedule ⇒ Google::Apis::DfareportingV5::PricingSchedule
Pricing Schedule
Corresponds to the JSON property pricingSchedule
9492 9493 9494 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9492 def pricing_schedule @pricing_schedule end |
#primary ⇒ Boolean Also known as: primary?
Whether this placement is the primary placement of a roadblock (placement
group). You cannot change this field from true to false. Setting this field to
true will automatically set the primary field on the original primary
placement of the roadblock to false, and it will automatically set the
roadblock's primaryPlacementId field to the ID of this placement.
Corresponds to the JSON property primary
9501 9502 9503 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9501 def primary @primary end |
#publisher_update_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property publisherUpdateInfo
9507 9508 9509 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9507 def publisher_update_info @publisher_update_info end |
#site_id ⇒ Fixnum
Site ID associated with this placement. On insert, you must set either this
field or the directorySiteId field to specify the site associated with this
placement. This is a required field that is read-only after insertion.
Corresponds to the JSON property siteId
9514 9515 9516 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9514 def site_id @site_id end |
#site_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property siteIdDimensionValue
9519 9520 9521 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9519 def site_id_dimension_value @site_id_dimension_value end |
#site_served ⇒ Boolean Also known as: site_served?
Optional. Whether the ads in the placement are served by another platform and
CM is only used for tracking or they are served by CM. A false value indicates
the ad is served by CM.
Corresponds to the JSON property siteServed
9526 9527 9528 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9526 def site_served @site_served end |
#size ⇒ Google::Apis::DfareportingV5::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property size
9532 9533 9534 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9532 def size @size end |
#ssl_required ⇒ Boolean Also known as: ssl_required?
Whether creatives assigned to this placement must be SSL-compliant.
Corresponds to the JSON property sslRequired
9537 9538 9539 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9537 def ssl_required @ssl_required end |
#status ⇒ String
Third-party placement status.
Corresponds to the JSON property status
9543 9544 9545 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9543 def status @status end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this placement. This field can be left blank.
Corresponds to the JSON property subaccountId
9548 9549 9550 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9548 def subaccount_id @subaccount_id end |
#tag_formats ⇒ Array<String>
Tag formats to generate for this placement. This field is required on
insertion. Acceptable values are: - "PLACEMENT_TAG_STANDARD" - "
PLACEMENT_TAG_IFRAME_JAVASCRIPT" - "PLACEMENT_TAG_IFRAME_ILAYER" - "
PLACEMENT_TAG_INTERNAL_REDIRECT" - "PLACEMENT_TAG_JAVASCRIPT" - "
PLACEMENT_TAG_INTERSTITIAL_IFRAME_JAVASCRIPT" - "
PLACEMENT_TAG_INTERSTITIAL_INTERNAL_REDIRECT" - "
PLACEMENT_TAG_INTERSTITIAL_JAVASCRIPT" - "PLACEMENT_TAG_CLICK_COMMANDS" - "
PLACEMENT_TAG_INSTREAM_VIDEO_PREFETCH" - "
PLACEMENT_TAG_INSTREAM_VIDEO_PREFETCH_VAST_3" - "
PLACEMENT_TAG_INSTREAM_VIDEO_PREFETCH_VAST_4" - "PLACEMENT_TAG_TRACKING" - "
PLACEMENT_TAG_TRACKING_IFRAME" - "PLACEMENT_TAG_TRACKING_JAVASCRIPT"
Corresponds to the JSON property tagFormats
9563 9564 9565 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9563 def tag_formats @tag_formats end |
#tag_setting ⇒ Google::Apis::DfareportingV5::TagSetting
Tag Settings
Corresponds to the JSON property tagSetting
9568 9569 9570 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9568 def tag_setting @tag_setting end |
#video_active_view_opt_out ⇒ Boolean Also known as: video_active_view_opt_out?
Whether Verification and ActiveView are disabled for in-stream video creatives
for this placement. The same setting videoActiveViewOptOut exists on the site
level -- the opt out occurs if either of these settings are true. These
settings are distinct from DirectorySites.settings.activeViewOptOut or Sites.
siteSettings.activeViewOptOut which only apply to display ads. However,
Accounts.activeViewOptOut opts out both video traffic, as well as display ads,
from Verification and ActiveView.
Corresponds to the JSON property videoActiveViewOptOut
9579 9580 9581 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9579 def video_active_view_opt_out @video_active_view_opt_out end |
#video_settings ⇒ Google::Apis::DfareportingV5::VideoSettings
Video Settings
Corresponds to the JSON property videoSettings
9585 9586 9587 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9585 def video_settings @video_settings end |
#vpaid_adapter_choice ⇒ String
VPAID adapter setting for this placement. Controls which VPAID format the
measurement adapter will use for in-stream video creatives assigned to this
placement. Note: Flash is no longer supported. This field now defaults to
HTML5 when the following values are provided: FLASH, BOTH.
Corresponds to the JSON property vpaidAdapterChoice
9593 9594 9595 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9593 def vpaid_adapter_choice @vpaid_adapter_choice end |
#wrapping_opt_out ⇒ Boolean Also known as: wrapping_opt_out?
Whether this placement opts out of tag wrapping.
Corresponds to the JSON property wrappingOptOut
9598 9599 9600 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9598 def wrapping_opt_out @wrapping_opt_out end |
#youtube_settings ⇒ Google::Apis::DfareportingV5::YoutubeSettings
Contains the YouTube settings.
Corresponds to the JSON property youtubeSettings
9604 9605 9606 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9604 def youtube_settings @youtube_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9611 9612 9613 9614 9615 9616 9617 9618 9619 9620 9621 9622 9623 9624 9625 9626 9627 9628 9629 9630 9631 9632 9633 9634 9635 9636 9637 9638 9639 9640 9641 9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9611 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @active_status = args[:active_status] if args.key?(:active_status) @ad_blocking_opt_out = args[:ad_blocking_opt_out] if args.key?(:ad_blocking_opt_out) @ad_serving_platform_id = args[:ad_serving_platform_id] if args.key?(:ad_serving_platform_id) @additional_sizes = args[:additional_sizes] if args.key?(:additional_sizes) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value) @allow_on_youtube = args[:allow_on_youtube] if args.key?(:allow_on_youtube) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @campaign_id_dimension_value = args[:campaign_id_dimension_value] if args.key?(:campaign_id_dimension_value) @comment = args[:comment] if args.key?(:comment) @compatibility = args[:compatibility] if args.key?(:compatibility) @content_category_id = args[:content_category_id] if args.key?(:content_category_id) @conversion_domain_override = args[:conversion_domain_override] if args.key?(:conversion_domain_override) @create_info = args[:create_info] if args.key?(:create_info) @directory_site_id = args[:directory_site_id] if args.key?(:directory_site_id) @directory_site_id_dimension_value = args[:directory_site_id_dimension_value] if args.key?(:directory_site_id_dimension_value) @external_id = args[:external_id] if args.key?(:external_id) @id = args[:id] if args.key?(:id) @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value) @key_name = args[:key_name] if args.key?(:key_name) @kind = args[:kind] if args.key?(:kind) @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info) @lookback_configuration = args[:lookback_configuration] if args.key?(:lookback_configuration) @name = args[:name] if args.key?(:name) @partner_wrapping_data = args[:partner_wrapping_data] if args.key?(:partner_wrapping_data) @payment_approved = args[:payment_approved] if args.key?(:payment_approved) @payment_source = args[:payment_source] if args.key?(:payment_source) @placement_group_id = args[:placement_group_id] if args.key?(:placement_group_id) @placement_group_id_dimension_value = args[:placement_group_id_dimension_value] if args.key?(:placement_group_id_dimension_value) @placement_strategy_id = args[:placement_strategy_id] if args.key?(:placement_strategy_id) @pricing_schedule = args[:pricing_schedule] if args.key?(:pricing_schedule) @primary = args[:primary] if args.key?(:primary) @publisher_update_info = args[:publisher_update_info] if args.key?(:publisher_update_info) @site_id = args[:site_id] if args.key?(:site_id) @site_id_dimension_value = args[:site_id_dimension_value] if args.key?(:site_id_dimension_value) @site_served = args[:site_served] if args.key?(:site_served) @size = args[:size] if args.key?(:size) @ssl_required = args[:ssl_required] if args.key?(:ssl_required) @status = args[:status] if args.key?(:status) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) @tag_formats = args[:tag_formats] if args.key?(:tag_formats) @tag_setting = args[:tag_setting] if args.key?(:tag_setting) @video_active_view_opt_out = args[:video_active_view_opt_out] if args.key?(:video_active_view_opt_out) @video_settings = args[:video_settings] if args.key?(:video_settings) @vpaid_adapter_choice = args[:vpaid_adapter_choice] if args.key?(:vpaid_adapter_choice) @wrapping_opt_out = args[:wrapping_opt_out] if args.key?(:wrapping_opt_out) @youtube_settings = args[:youtube_settings] if args.key?(:youtube_settings) end |