Class: Google::Apis::DfareportingV5::PlacementGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a package or roadblock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlacementGroup

Returns a new instance of PlacementGroup.



9876
9877
9878
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this placement group. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


9731
9732
9733
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9731

def 
  @account_id
end

#active_statusString

Whether this placement group is active, inactive, archived or permanently archived. Corresponds to the JSON property activeStatus

Returns:

  • (String)


9737
9738
9739
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9737

def active_status
  @active_status
end

#advertiser_idFixnum

Advertiser ID of this placement group. This is a required field on insertion. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


9742
9743
9744
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9742

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



9747
9748
9749
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9747

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#campaign_idFixnum

Campaign ID of this placement group. This field is required on insertion. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


9752
9753
9754
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9752

def campaign_id
  @campaign_id
end

#campaign_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property campaignIdDimensionValue



9757
9758
9759
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9757

def campaign_id_dimension_value
  @campaign_id_dimension_value
end

#child_placement_idsArray<Fixnum>

IDs of placements which are assigned to this placement group. This is a read- only, auto-generated field. Corresponds to the JSON property childPlacementIds

Returns:

  • (Array<Fixnum>)


9763
9764
9765
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9763

def child_placement_ids
  @child_placement_ids
end

#commentString

Comments for this placement group. Corresponds to the JSON property comment

Returns:

  • (String)


9768
9769
9770
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9768

def comment
  @comment
end

#content_category_idFixnum

ID of the content category assigned to this placement group. Corresponds to the JSON property contentCategoryId

Returns:

  • (Fixnum)


9773
9774
9775
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9773

def 
  @content_category_id
end

#create_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



9778
9779
9780
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9778

def create_info
  @create_info
end

#directory_site_idFixnum

Directory site ID associated with this placement group. On insert, you must set either this field or the site_id field to specify the site associated with this placement group. This is a required field that is read-only after insertion. Corresponds to the JSON property directorySiteId

Returns:

  • (Fixnum)


9786
9787
9788
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9786

def directory_site_id
  @directory_site_id
end

#directory_site_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property directorySiteIdDimensionValue



9791
9792
9793
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9791

def directory_site_id_dimension_value
  @directory_site_id_dimension_value
end

#external_idString

External ID for this placement. Corresponds to the JSON property externalId

Returns:

  • (String)


9796
9797
9798
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9796

def external_id
  @external_id
end

#idFixnum

ID of this placement group. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


9801
9802
9803
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9801

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



9806
9807
9808
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9806

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#placementGroup". Corresponds to the JSON property kind

Returns:

  • (String)


9812
9813
9814
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9812

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



9817
9818
9819
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9817

def last_modified_info
  @last_modified_info
end

#nameString

Name of this placement group. This is a required field and must be less than 256 characters long. Corresponds to the JSON property name

Returns:

  • (String)


9823
9824
9825
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9823

def name
  @name
end

#placement_group_typeString

Type of this placement group. A package is a simple group of placements that acts as a single pricing point for a group of tags. A roadblock is a group of placements that not only acts as a single pricing point, but also assumes that all the tags in it will be served at the same time. A roadblock requires one of its assigned placements to be marked as primary for reporting. This field is required on insertion. Corresponds to the JSON property placementGroupType

Returns:

  • (String)


9833
9834
9835
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9833

def placement_group_type
  @placement_group_type
end

#placement_strategy_idFixnum

ID of the placement strategy assigned to this placement group. Corresponds to the JSON property placementStrategyId

Returns:

  • (Fixnum)


9838
9839
9840
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9838

def placement_strategy_id
  @placement_strategy_id
end

#pricing_scheduleGoogle::Apis::DfareportingV5::PricingSchedule

Pricing Schedule Corresponds to the JSON property pricingSchedule



9843
9844
9845
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9843

def pricing_schedule
  @pricing_schedule
end

#primary_placement_idFixnum

ID of the primary placement, used to calculate the media cost of a roadblock ( placement group). Modifying this field will automatically modify the primary field on all affected roadblock child placements. Corresponds to the JSON property primaryPlacementId

Returns:

  • (Fixnum)


9850
9851
9852
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9850

def primary_placement_id
  @primary_placement_id
end

#primary_placement_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property primaryPlacementIdDimensionValue



9855
9856
9857
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9855

def primary_placement_id_dimension_value
  @primary_placement_id_dimension_value
end

#site_idFixnum

Site ID associated with this placement group. On insert, you must set either this field or the directorySiteId field to specify the site associated with this placement group. This is a required field that is read-only after insertion. Corresponds to the JSON property siteId

Returns:

  • (Fixnum)


9863
9864
9865
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9863

def site_id
  @site_id
end

#site_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property siteIdDimensionValue



9868
9869
9870
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9868

def site_id_dimension_value
  @site_id_dimension_value
end

#subaccount_idFixnum

Subaccount ID of this placement group. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


9874
9875
9876
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9874

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
9905
9906
9907
9908
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 9881

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @active_status = args[:active_status] if args.key?(:active_status)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @campaign_id_dimension_value = args[:campaign_id_dimension_value] if args.key?(:campaign_id_dimension_value)
  @child_placement_ids = args[:child_placement_ids] if args.key?(:child_placement_ids)
  @comment = args[:comment] if args.key?(:comment)
  @content_category_id = args[:content_category_id] if args.key?(:content_category_id)
  @create_info = args[:create_info] if args.key?(:create_info)
  @directory_site_id = args[:directory_site_id] if args.key?(:directory_site_id)
  @directory_site_id_dimension_value = args[:directory_site_id_dimension_value] if args.key?(:directory_site_id_dimension_value)
  @external_id = args[:external_id] if args.key?(:external_id)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @placement_group_type = args[:placement_group_type] if args.key?(:placement_group_type)
  @placement_strategy_id = args[:placement_strategy_id] if args.key?(:placement_strategy_id)
  @pricing_schedule = args[:pricing_schedule] if args.key?(:pricing_schedule)
  @primary_placement_id = args[:primary_placement_id] if args.key?(:primary_placement_id)
  @primary_placement_id_dimension_value = args[:primary_placement_id_dimension_value] if args.key?(:primary_placement_id_dimension_value)
  @site_id = args[:site_id] if args.key?(:site_id)
  @site_id_dimension_value = args[:site_id_dimension_value] if args.key?(:site_id_dimension_value)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end