Class: Google::Apis::DfareportingV5::PopupWindowProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Popup Window Properties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PopupWindowProperties

Returns a new instance of PopupWindowProperties.



10236
10237
10238
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionGoogle::Apis::DfareportingV5::Size

Represents the dimensions of ads, placements, creatives, or creative assets. Corresponds to the JSON property dimension



10189
10190
10191
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10189

def dimension
  @dimension
end

#offsetGoogle::Apis::DfareportingV5::OffsetPosition

Offset Position. Corresponds to the JSON property offset



10194
10195
10196
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10194

def offset
  @offset
end

#position_typeString

Popup window position either centered or at specific coordinate. Corresponds to the JSON property positionType

Returns:

  • (String)


10199
10200
10201
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10199

def position_type
  @position_type
end

#show_address_barBoolean Also known as: show_address_bar?

Whether to display the browser address bar. Corresponds to the JSON property showAddressBar

Returns:

  • (Boolean)


10204
10205
10206
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10204

def show_address_bar
  @show_address_bar
end

#show_menu_barBoolean Also known as: show_menu_bar?

Whether to display the browser menu bar. Corresponds to the JSON property showMenuBar

Returns:

  • (Boolean)


10210
10211
10212
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10210

def show_menu_bar
  @show_menu_bar
end

#show_scroll_barBoolean Also known as: show_scroll_bar?

Whether to display the browser scroll bar. Corresponds to the JSON property showScrollBar

Returns:

  • (Boolean)


10216
10217
10218
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10216

def show_scroll_bar
  @show_scroll_bar
end

#show_status_barBoolean Also known as: show_status_bar?

Whether to display the browser status bar. Corresponds to the JSON property showStatusBar

Returns:

  • (Boolean)


10222
10223
10224
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10222

def show_status_bar
  @show_status_bar
end

#show_tool_barBoolean Also known as: show_tool_bar?

Whether to display the browser tool bar. Corresponds to the JSON property showToolBar

Returns:

  • (Boolean)


10228
10229
10230
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10228

def show_tool_bar
  @show_tool_bar
end

#titleString

Title of popup window. Corresponds to the JSON property title

Returns:

  • (String)


10234
10235
10236
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10234

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10241
10242
10243
10244
10245
10246
10247
10248
10249
10250
10251
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10241

def update!(**args)
  @dimension = args[:dimension] if args.key?(:dimension)
  @offset = args[:offset] if args.key?(:offset)
  @position_type = args[:position_type] if args.key?(:position_type)
  @show_address_bar = args[:show_address_bar] if args.key?(:show_address_bar)
  @show_menu_bar = args[:show_menu_bar] if args.key?(:show_menu_bar)
  @show_scroll_bar = args[:show_scroll_bar] if args.key?(:show_scroll_bar)
  @show_status_bar = args[:show_status_bar] if args.key?(:show_status_bar)
  @show_tool_bar = args[:show_tool_bar] if args.key?(:show_tool_bar)
  @title = args[:title] if args.key?(:title)
end