Class: Google::Apis::DfareportingV5::Region

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains information about a region that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Region

Returns a new instance of Region.



10592
10593
10594
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Country code of the country to which this region belongs. Corresponds to the JSON property countryCode

Returns:

  • (String)


10564
10565
10566
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10564

def country_code
  @country_code
end

#country_dart_idFixnum

DART ID of the country to which this region belongs. Corresponds to the JSON property countryDartId

Returns:

  • (Fixnum)


10569
10570
10571
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10569

def country_dart_id
  @country_dart_id
end

#dart_idFixnum

DART ID of this region. Corresponds to the JSON property dartId

Returns:

  • (Fixnum)


10574
10575
10576
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10574

def dart_id
  @dart_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#region". Corresponds to the JSON property kind

Returns:

  • (String)


10580
10581
10582
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10580

def kind
  @kind
end

#nameString

Name of this region. Corresponds to the JSON property name

Returns:

  • (String)


10585
10586
10587
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10585

def name
  @name
end

#region_codeString

Region code. Corresponds to the JSON property regionCode

Returns:

  • (String)


10590
10591
10592
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10590

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10597
10598
10599
10600
10601
10602
10603
10604
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10597

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @country_dart_id = args[:country_dart_id] if args.key?(:country_dart_id)
  @dart_id = args[:dart_id] if args.key?(:dart_id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region_code = args[:region_code] if args.key?(:region_code)
end