Class: Google::Apis::DfareportingV5::RemarketingList
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::RemarketingList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains properties of a remarketing list. Remarketing enables you to create lists of users who have performed specific actions on a site, then target ads to members of those lists. This resource can be used to manage remarketing lists that are owned by your advertisers. To see all remarketing lists that are visible to your advertisers, including those that are shared to your advertiser or account, use the TargetableRemarketingLists resource.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this remarketing list.
-
#active ⇒ Boolean
(also: #active?)
Whether this remarketing list is active.
-
#advertiser_id ⇒ Fixnum
Dimension value for the advertiser ID that owns this remarketing list.
-
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#description ⇒ String
Remarketing list description.
-
#id ⇒ Fixnum
Remarketing list ID.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#life_span ⇒ Fixnum
Number of days that a user should remain in the remarketing list without an impression.
-
#list_population_rule ⇒ Google::Apis::DfareportingV5::ListPopulationRule
Remarketing List Population Rule.
-
#list_size ⇒ Fixnum
Number of users currently in the list.
-
#list_source ⇒ String
Product from which this remarketing list was originated.
-
#name ⇒ String
Name of the remarketing list.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this remarketing list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemarketingList
constructor
A new instance of RemarketingList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemarketingList
Returns a new instance of RemarketingList.
10714 10715 10716 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this remarketing list. This is a read-only, auto-generated field
that is only returned in GET requests.
Corresponds to the JSON property accountId
10646 10647 10648 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10646 def account_id @account_id end |
#active ⇒ Boolean Also known as: active?
Whether this remarketing list is active.
Corresponds to the JSON property active
10651 10652 10653 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10651 def active @active end |
#advertiser_id ⇒ Fixnum
Dimension value for the advertiser ID that owns this remarketing list. This is
a required field.
Corresponds to the JSON property advertiserId
10658 10659 10660 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10658 def advertiser_id @advertiser_id end |
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property advertiserIdDimensionValue
10663 10664 10665 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10663 def advertiser_id_dimension_value @advertiser_id_dimension_value end |
#description ⇒ String
Remarketing list description.
Corresponds to the JSON property description
10668 10669 10670 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10668 def description @description end |
#id ⇒ Fixnum
Remarketing list ID. This is a read-only, auto-generated field.
Corresponds to the JSON property id
10673 10674 10675 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10673 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#remarketingList".
Corresponds to the JSON property kind
10679 10680 10681 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10679 def kind @kind end |
#life_span ⇒ Fixnum
Number of days that a user should remain in the remarketing list without an
impression. Acceptable values are 1 to 540, inclusive.
Corresponds to the JSON property lifeSpan
10685 10686 10687 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10685 def life_span @life_span end |
#list_population_rule ⇒ Google::Apis::DfareportingV5::ListPopulationRule
Remarketing List Population Rule.
Corresponds to the JSON property listPopulationRule
10690 10691 10692 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10690 def list_population_rule @list_population_rule end |
#list_size ⇒ Fixnum
Number of users currently in the list. This is a read-only field.
Corresponds to the JSON property listSize
10695 10696 10697 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10695 def list_size @list_size end |
#list_source ⇒ String
Product from which this remarketing list was originated.
Corresponds to the JSON property listSource
10700 10701 10702 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10700 def list_source @list_source end |
#name ⇒ String
Name of the remarketing list. This is a required field. Must be no greater
than 128 characters long.
Corresponds to the JSON property name
10706 10707 10708 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10706 def name @name end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this remarketing list. This is a read-only, auto-generated
field that is only returned in GET requests.
Corresponds to the JSON property subaccountId
10712 10713 10714 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10712 def subaccount_id @subaccount_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 10733 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10719 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @active = args[:active] if args.key?(:active) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @life_span = args[:life_span] if args.key?(:life_span) @list_population_rule = args[:list_population_rule] if args.key?(:list_population_rule) @list_size = args[:list_size] if args.key?(:list_size) @list_source = args[:list_source] if args.key?(:list_source) @name = args[:name] if args.key?(:name) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) end |