Class: Google::Apis::DfareportingV5::Report
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Report
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents a Report resource.
Defined Under Namespace
Classes: Criteria, CrossMediaReachCriteria, Delivery, FloodlightCriteria, PathToConversionCriteria, ReachCriteria, Schedule
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
The account ID to which this report belongs.
-
#criteria ⇒ Google::Apis::DfareportingV5::Report::Criteria
The report criteria for a report of type "STANDARD".
-
#cross_media_reach_criteria ⇒ Google::Apis::DfareportingV5::Report::CrossMediaReachCriteria
Optional.
-
#delivery ⇒ Google::Apis::DfareportingV5::Report::Delivery
The report's email delivery settings.
-
#etag ⇒ String
The eTag of this response for caching purposes.
-
#file_name ⇒ String
The filename used when generating report files for this report.
-
#floodlight_criteria ⇒ Google::Apis::DfareportingV5::Report::FloodlightCriteria
The report criteria for a report of type "FLOODLIGHT".
-
#format ⇒ String
The output format of the report.
-
#id ⇒ Fixnum
The unique ID identifying this report resource.
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting#report.
-
#last_modified_time ⇒ Fixnum
The timestamp (in milliseconds since epoch) of when this report was last modified.
-
#name ⇒ String
The name of the report.
-
#owner_profile_id ⇒ Fixnum
The user profile id of the owner of this report.
-
#path_to_conversion_criteria ⇒ Google::Apis::DfareportingV5::Report::PathToConversionCriteria
The report criteria for a report of type "PATH_TO_CONVERSION".
-
#reach_criteria ⇒ Google::Apis::DfareportingV5::Report::ReachCriteria
The report criteria for a report of type "REACH".
-
#schedule ⇒ Google::Apis::DfareportingV5::Report::Schedule
The report's schedule.
-
#sub_account_id ⇒ Fixnum
The subaccount ID to which this report belongs if applicable.
-
#type ⇒ String
The type of the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Report
constructor
A new instance of Report.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Report
Returns a new instance of Report.
10933 10934 10935 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10933 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
The account ID to which this report belongs.
Corresponds to the JSON property accountId
10841 10842 10843 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10841 def account_id @account_id end |
#criteria ⇒ Google::Apis::DfareportingV5::Report::Criteria
The report criteria for a report of type "STANDARD".
Corresponds to the JSON property criteria
10846 10847 10848 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10846 def criteria @criteria end |
#cross_media_reach_criteria ⇒ Google::Apis::DfareportingV5::Report::CrossMediaReachCriteria
Optional. The report criteria for a report of type "CROSS_MEDIA_REACH".
Corresponds to the JSON property crossMediaReachCriteria
10851 10852 10853 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10851 def cross_media_reach_criteria @cross_media_reach_criteria end |
#delivery ⇒ Google::Apis::DfareportingV5::Report::Delivery
The report's email delivery settings.
Corresponds to the JSON property delivery
10856 10857 10858 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10856 def delivery @delivery end |
#etag ⇒ String
The eTag of this response for caching purposes.
Corresponds to the JSON property etag
10861 10862 10863 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10861 def etag @etag end |
#file_name ⇒ String
The filename used when generating report files for this report.
Corresponds to the JSON property fileName
10866 10867 10868 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10866 def file_name @file_name end |
#floodlight_criteria ⇒ Google::Apis::DfareportingV5::Report::FloodlightCriteria
The report criteria for a report of type "FLOODLIGHT".
Corresponds to the JSON property floodlightCriteria
10871 10872 10873 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10871 def floodlight_criteria @floodlight_criteria end |
#format ⇒ String
The output format of the report. If not specified, default format is "CSV".
Note that the actual format in the completed report file might differ if for
instance the report's size exceeds the format's capabilities. "CSV" will then
be the fallback format.
Corresponds to the JSON property format
10879 10880 10881 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10879 def format @format end |
#id ⇒ Fixnum
The unique ID identifying this report resource.
Corresponds to the JSON property id
10884 10885 10886 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10884 def id @id end |
#kind ⇒ String
The kind of resource this is, in this case dfareporting#report.
Corresponds to the JSON property kind
10889 10890 10891 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10889 def kind @kind end |
#last_modified_time ⇒ Fixnum
The timestamp (in milliseconds since epoch) of when this report was last
modified.
Corresponds to the JSON property lastModifiedTime
10895 10896 10897 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10895 def last_modified_time @last_modified_time end |
#name ⇒ String
The name of the report.
Corresponds to the JSON property name
10900 10901 10902 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10900 def name @name end |
#owner_profile_id ⇒ Fixnum
The user profile id of the owner of this report.
Corresponds to the JSON property ownerProfileId
10905 10906 10907 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10905 def owner_profile_id @owner_profile_id end |
#path_to_conversion_criteria ⇒ Google::Apis::DfareportingV5::Report::PathToConversionCriteria
The report criteria for a report of type "PATH_TO_CONVERSION".
Corresponds to the JSON property pathToConversionCriteria
10910 10911 10912 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10910 def path_to_conversion_criteria @path_to_conversion_criteria end |
#reach_criteria ⇒ Google::Apis::DfareportingV5::Report::ReachCriteria
The report criteria for a report of type "REACH".
Corresponds to the JSON property reachCriteria
10915 10916 10917 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10915 def reach_criteria @reach_criteria end |
#schedule ⇒ Google::Apis::DfareportingV5::Report::Schedule
The report's schedule. Can only be set if the report's 'dateRange' is a
relative date range and the relative date range is not "TODAY".
Corresponds to the JSON property schedule
10921 10922 10923 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10921 def schedule @schedule end |
#sub_account_id ⇒ Fixnum
The subaccount ID to which this report belongs if applicable.
Corresponds to the JSON property subAccountId
10926 10927 10928 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10926 def sub_account_id @sub_account_id end |
#type ⇒ String
The type of the report.
Corresponds to the JSON property type
10931 10932 10933 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10931 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10938 10939 10940 10941 10942 10943 10944 10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10938 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @criteria = args[:criteria] if args.key?(:criteria) @cross_media_reach_criteria = args[:cross_media_reach_criteria] if args.key?(:cross_media_reach_criteria) @delivery = args[:delivery] if args.key?(:delivery) @etag = args[:etag] if args.key?(:etag) @file_name = args[:file_name] if args.key?(:file_name) @floodlight_criteria = args[:floodlight_criteria] if args.key?(:floodlight_criteria) @format = args[:format] if args.key?(:format) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @name = args[:name] if args.key?(:name) @owner_profile_id = args[:owner_profile_id] if args.key?(:owner_profile_id) @path_to_conversion_criteria = args[:path_to_conversion_criteria] if args.key?(:path_to_conversion_criteria) @reach_criteria = args[:reach_criteria] if args.key?(:reach_criteria) @schedule = args[:schedule] if args.key?(:schedule) @sub_account_id = args[:sub_account_id] if args.key?(:sub_account_id) @type = args[:type] if args.key?(:type) end |