Class: Google::Apis::DfareportingV5::Report::Criteria
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Report::Criteria
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
The report criteria for a report of type "STANDARD".
Instance Attribute Summary collapse
-
#activities ⇒ Google::Apis::DfareportingV5::Activities
Represents an activity group.
-
#custom_rich_media_events ⇒ Google::Apis::DfareportingV5::CustomRichMediaEvents
Represents a Custom Rich Media Events group.
-
#date_range ⇒ Google::Apis::DfareportingV5::DateRange
Represents a date range.
-
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of filters on which dimensions are filtered.
-
#dimensions ⇒ Array<Google::Apis::DfareportingV5::SortedDimension>
The list of standard dimensions the report should include.
-
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Criteria
constructor
A new instance of Criteria.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Criteria
Returns a new instance of Criteria.
10995 10996 10997 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activities ⇒ Google::Apis::DfareportingV5::Activities
Represents an activity group.
Corresponds to the JSON property activities
10966 10967 10968 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10966 def activities @activities end |
#custom_rich_media_events ⇒ Google::Apis::DfareportingV5::CustomRichMediaEvents
Represents a Custom Rich Media Events group.
Corresponds to the JSON property customRichMediaEvents
10971 10972 10973 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10971 def custom_rich_media_events @custom_rich_media_events end |
#date_range ⇒ Google::Apis::DfareportingV5::DateRange
Represents a date range.
Corresponds to the JSON property dateRange
10976 10977 10978 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10976 def date_range @date_range end |
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of filters on which dimensions are filtered. Filters for different
dimensions are ANDed, filters for the same dimension are grouped together and
ORed.
Corresponds to the JSON property dimensionFilters
10983 10984 10985 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10983 def dimension_filters @dimension_filters end |
#dimensions ⇒ Array<Google::Apis::DfareportingV5::SortedDimension>
The list of standard dimensions the report should include.
Corresponds to the JSON property dimensions
10988 10989 10990 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10988 def dimensions @dimensions end |
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
Corresponds to the JSON property metricNames
10993 10994 10995 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 10993 def metric_names @metric_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11000 11001 11002 11003 11004 11005 11006 11007 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11000 def update!(**args) @activities = args[:activities] if args.key?(:activities) @custom_rich_media_events = args[:custom_rich_media_events] if args.key?(:custom_rich_media_events) @date_range = args[:date_range] if args.key?(:date_range) @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters) @dimensions = args[:dimensions] if args.key?(:dimensions) @metric_names = args[:metric_names] if args.key?(:metric_names) end |