Class: Google::Apis::DfareportingV5::Report::Delivery
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Report::Delivery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
The report's email delivery settings.
Instance Attribute Summary collapse
-
#email_owner ⇒ Boolean
(also: #email_owner?)
Whether the report should be emailed to the report owner.
-
#email_owner_delivery_type ⇒ String
The type of delivery for the owner to receive, if enabled.
-
#message ⇒ String
The message to be sent with each email.
-
#recipients ⇒ Array<Google::Apis::DfareportingV5::Recipient>
The list of recipients to which to email the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Delivery
constructor
A new instance of Delivery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Delivery
Returns a new instance of Delivery.
11108 11109 11110 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email_owner ⇒ Boolean Also known as: email_owner?
Whether the report should be emailed to the report owner.
Corresponds to the JSON property emailOwner
11090 11091 11092 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11090 def email_owner @email_owner end |
#email_owner_delivery_type ⇒ String
The type of delivery for the owner to receive, if enabled.
Corresponds to the JSON property emailOwnerDeliveryType
11096 11097 11098 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11096 def email_owner_delivery_type @email_owner_delivery_type end |
#message ⇒ String
The message to be sent with each email.
Corresponds to the JSON property message
11101 11102 11103 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11101 def @message end |
#recipients ⇒ Array<Google::Apis::DfareportingV5::Recipient>
The list of recipients to which to email the report.
Corresponds to the JSON property recipients
11106 11107 11108 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11106 def recipients @recipients end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11113 11114 11115 11116 11117 11118 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11113 def update!(**args) @email_owner = args[:email_owner] if args.key?(:email_owner) @email_owner_delivery_type = args[:email_owner_delivery_type] if args.key?(:email_owner_delivery_type) @message = args[:message] if args.key?(:message) @recipients = args[:recipients] if args.key?(:recipients) end |