Class: Google::Apis::DfareportingV5::Report::FloodlightCriteria
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Report::FloodlightCriteria
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
The report criteria for a report of type "FLOODLIGHT".
Defined Under Namespace
Classes: ReportProperties
Instance Attribute Summary collapse
-
#custom_rich_media_events ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of custom rich media events to include.
-
#date_range ⇒ Google::Apis::DfareportingV5::DateRange
Represents a date range.
-
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of filters on which dimensions are filtered.
-
#dimensions ⇒ Array<Google::Apis::DfareportingV5::SortedDimension>
The list of dimensions the report should include.
-
#floodlight_config_id ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
-
#report_properties ⇒ Google::Apis::DfareportingV5::Report::FloodlightCriteria::ReportProperties
The properties of the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloodlightCriteria
constructor
A new instance of FloodlightCriteria.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloodlightCriteria
Returns a new instance of FloodlightCriteria.
11162 11163 11164 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_rich_media_events ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of custom rich media events to include.
Corresponds to the JSON property customRichMediaEvents
11128 11129 11130 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11128 def custom_rich_media_events @custom_rich_media_events end |
#date_range ⇒ Google::Apis::DfareportingV5::DateRange
Represents a date range.
Corresponds to the JSON property dateRange
11133 11134 11135 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11133 def date_range @date_range end |
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of filters on which dimensions are filtered. Filters for different
dimensions are ANDed, filters for the same dimension are grouped together and
ORed.
Corresponds to the JSON property dimensionFilters
11140 11141 11142 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11140 def dimension_filters @dimension_filters end |
#dimensions ⇒ Array<Google::Apis::DfareportingV5::SortedDimension>
The list of dimensions the report should include.
Corresponds to the JSON property dimensions
11145 11146 11147 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11145 def dimensions @dimensions end |
#floodlight_config_id ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property floodlightConfigId
11150 11151 11152 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11150 def floodlight_config_id @floodlight_config_id end |
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
Corresponds to the JSON property metricNames
11155 11156 11157 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11155 def metric_names @metric_names end |
#report_properties ⇒ Google::Apis::DfareportingV5::Report::FloodlightCriteria::ReportProperties
The properties of the report.
Corresponds to the JSON property reportProperties
11160 11161 11162 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11160 def report_properties @report_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11167 11168 11169 11170 11171 11172 11173 11174 11175 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11167 def update!(**args) @custom_rich_media_events = args[:custom_rich_media_events] if args.key?(:custom_rich_media_events) @date_range = args[:date_range] if args.key?(:date_range) @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters) @dimensions = args[:dimensions] if args.key?(:dimensions) @floodlight_config_id = args[:floodlight_config_id] if args.key?(:floodlight_config_id) @metric_names = args[:metric_names] if args.key?(:metric_names) @report_properties = args[:report_properties] if args.key?(:report_properties) end |