Class: Google::Apis::DfareportingV5::Report::FloodlightCriteria
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::Report::FloodlightCriteria
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
The report criteria for a report of type "FLOODLIGHT".
Defined Under Namespace
Classes: ReportProperties
Instance Attribute Summary collapse
-
#custom_rich_media_events ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of custom rich media events to include.
-
#date_range ⇒ Google::Apis::DfareportingV5::DateRange
Represents a date range.
-
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of filters on which dimensions are filtered.
-
#dimensions ⇒ Array<Google::Apis::DfareportingV5::SortedDimension>
The list of dimensions the report should include.
-
#floodlight_config_id ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
-
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
-
#report_properties ⇒ Google::Apis::DfareportingV5::Report::FloodlightCriteria::ReportProperties
The properties of the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloodlightCriteria
constructor
A new instance of FloodlightCriteria.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloodlightCriteria
Returns a new instance of FloodlightCriteria.
11128 11129 11130 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_rich_media_events ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of custom rich media events to include.
Corresponds to the JSON property customRichMediaEvents
11094 11095 11096 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11094 def custom_rich_media_events @custom_rich_media_events end |
#date_range ⇒ Google::Apis::DfareportingV5::DateRange
Represents a date range.
Corresponds to the JSON property dateRange
11099 11100 11101 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11099 def date_range @date_range end |
#dimension_filters ⇒ Array<Google::Apis::DfareportingV5::DimensionValue>
The list of filters on which dimensions are filtered. Filters for different
dimensions are ANDed, filters for the same dimension are grouped together and
ORed.
Corresponds to the JSON property dimensionFilters
11106 11107 11108 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11106 def dimension_filters @dimension_filters end |
#dimensions ⇒ Array<Google::Apis::DfareportingV5::SortedDimension>
The list of dimensions the report should include.
Corresponds to the JSON property dimensions
11111 11112 11113 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11111 def dimensions @dimensions end |
#floodlight_config_id ⇒ Google::Apis::DfareportingV5::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property floodlightConfigId
11116 11117 11118 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11116 def floodlight_config_id @floodlight_config_id end |
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
Corresponds to the JSON property metricNames
11121 11122 11123 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11121 def metric_names @metric_names end |
#report_properties ⇒ Google::Apis::DfareportingV5::Report::FloodlightCriteria::ReportProperties
The properties of the report.
Corresponds to the JSON property reportProperties
11126 11127 11128 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11126 def report_properties @report_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11133 11134 11135 11136 11137 11138 11139 11140 11141 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11133 def update!(**args) @custom_rich_media_events = args[:custom_rich_media_events] if args.key?(:custom_rich_media_events) @date_range = args[:date_range] if args.key?(:date_range) @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters) @dimensions = args[:dimensions] if args.key?(:dimensions) @floodlight_config_id = args[:floodlight_config_id] if args.key?(:floodlight_config_id) @metric_names = args[:metric_names] if args.key?(:metric_names) @report_properties = args[:report_properties] if args.key?(:report_properties) end |