Class: Google::Apis::DfareportingV5::Report::FloodlightCriteria::ReportProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

The properties of the report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportProperties

Returns a new instance of ReportProperties.



11169
11170
11171
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_attributed_ip_conversionsBoolean Also known as: include_attributed_ip_conversions?

Include conversions that have no cookie, but do have an exposure path. Corresponds to the JSON property includeAttributedIPConversions

Returns:

  • (Boolean)


11150
11151
11152
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11150

def include_attributed_ip_conversions
  @include_attributed_ip_conversions
end

Include conversions of users with a DoubleClick cookie but without an exposure. That means the user did not click or see an ad from the advertiser within the Floodlight group, or that the interaction happened outside the lookback window. Corresponds to the JSON property includeUnattributedCookieConversions

Returns:

  • (Boolean)


11158
11159
11160
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11158

def include_unattributed_cookie_conversions
  @include_unattributed_cookie_conversions
end

#include_unattributed_ip_conversionsBoolean Also known as: include_unattributed_ip_conversions?

Include conversions that have no associated cookies and no exposures. It’s therefore impossible to know how the user was exposed to your ads during the lookback window prior to a conversion. Corresponds to the JSON property includeUnattributedIPConversions

Returns:

  • (Boolean)


11166
11167
11168
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11166

def include_unattributed_ip_conversions
  @include_unattributed_ip_conversions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11174
11175
11176
11177
11178
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11174

def update!(**args)
  @include_attributed_ip_conversions = args[:include_attributed_ip_conversions] if args.key?(:include_attributed_ip_conversions)
  @include_unattributed_cookie_conversions = args[:include_unattributed_cookie_conversions] if args.key?(:include_unattributed_cookie_conversions)
  @include_unattributed_ip_conversions = args[:include_unattributed_ip_conversions] if args.key?(:include_unattributed_ip_conversions)
end