Class: Google::Apis::DfareportingV5::Report::PathToConversionCriteria

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

The report criteria for a report of type "PATH_TO_CONVERSION".

Defined Under Namespace

Classes: ReportProperties

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PathToConversionCriteria

Returns a new instance of PathToConversionCriteria.



11231
11232
11233
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activity_filtersArray<Google::Apis::DfareportingV5::DimensionValue>

The list of 'dfa:activity' values to filter on. Corresponds to the JSON property activityFilters



11189
11190
11191
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11189

def activity_filters
  @activity_filters
end

#conversion_dimensionsArray<Google::Apis::DfareportingV5::SortedDimension>

The list of conversion dimensions the report should include. Corresponds to the JSON property conversionDimensions



11194
11195
11196
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11194

def conversion_dimensions
  @conversion_dimensions
end

#custom_floodlight_variablesArray<Google::Apis::DfareportingV5::SortedDimension>

The list of custom floodlight variables the report should include. Corresponds to the JSON property customFloodlightVariables



11199
11200
11201
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11199

def custom_floodlight_variables
  @custom_floodlight_variables
end

#custom_rich_media_eventsArray<Google::Apis::DfareportingV5::DimensionValue>

The list of custom rich media events to include. Corresponds to the JSON property customRichMediaEvents



11204
11205
11206
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11204

def custom_rich_media_events
  @custom_rich_media_events
end

#date_rangeGoogle::Apis::DfareportingV5::DateRange

Represents a date range. Corresponds to the JSON property dateRange



11209
11210
11211
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11209

def date_range
  @date_range
end

#floodlight_config_idGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightConfigId



11214
11215
11216
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11214

def floodlight_config_id
  @floodlight_config_id
end

#metric_namesArray<String>

The list of names of metrics the report should include. Corresponds to the JSON property metricNames

Returns:

  • (Array<String>)


11219
11220
11221
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11219

def metric_names
  @metric_names
end

#per_interaction_dimensionsArray<Google::Apis::DfareportingV5::SortedDimension>

The list of per interaction dimensions the report should include. Corresponds to the JSON property perInteractionDimensions



11224
11225
11226
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11224

def per_interaction_dimensions
  @per_interaction_dimensions
end

#report_propertiesGoogle::Apis::DfareportingV5::Report::PathToConversionCriteria::ReportProperties

The properties of the report. Corresponds to the JSON property reportProperties



11229
11230
11231
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11229

def report_properties
  @report_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11236
11237
11238
11239
11240
11241
11242
11243
11244
11245
11246
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11236

def update!(**args)
  @activity_filters = args[:activity_filters] if args.key?(:activity_filters)
  @conversion_dimensions = args[:conversion_dimensions] if args.key?(:conversion_dimensions)
  @custom_floodlight_variables = args[:custom_floodlight_variables] if args.key?(:custom_floodlight_variables)
  @custom_rich_media_events = args[:custom_rich_media_events] if args.key?(:custom_rich_media_events)
  @date_range = args[:date_range] if args.key?(:date_range)
  @floodlight_config_id = args[:floodlight_config_id] if args.key?(:floodlight_config_id)
  @metric_names = args[:metric_names] if args.key?(:metric_names)
  @per_interaction_dimensions = args[:per_interaction_dimensions] if args.key?(:per_interaction_dimensions)
  @report_properties = args[:report_properties] if args.key?(:report_properties)
end