Class: Google::Apis::DfareportingV5::ReportList
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::ReportList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Represents the list of reports.
Instance Attribute Summary collapse
-
#etag ⇒ String
The eTag of this response for caching purposes.
-
#items ⇒ Array<Google::Apis::DfareportingV5::Report>
The reports returned in this response.
-
#kind ⇒ String
The kind of list this is, in this case dfareporting#reportList.
-
#next_page_token ⇒ String
Continuation token used to page through reports.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportList
constructor
A new instance of ReportList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportList
Returns a new instance of ReportList.
11540 11541 11542 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
The eTag of this response for caching purposes.
Corresponds to the JSON property etag
11520 11521 11522 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11520 def etag @etag end |
#items ⇒ Array<Google::Apis::DfareportingV5::Report>
The reports returned in this response.
Corresponds to the JSON property items
11525 11526 11527 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11525 def items @items end |
#kind ⇒ String
The kind of list this is, in this case dfareporting#reportList.
Corresponds to the JSON property kind
11530 11531 11532 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11530 def kind @kind end |
#next_page_token ⇒ String
Continuation token used to page through reports. To retrieve the next page of
results, set the next request's "pageToken" to the value of this field. The
page token is only valid for a limited amount of time and should not be
persisted.
Corresponds to the JSON property nextPageToken
11538 11539 11540 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11538 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11545 11546 11547 11548 11549 11550 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11545 def update!(**args) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |