Class: Google::Apis::DfareportingV5::RichMediaExitOverride
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::RichMediaExitOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Rich Media Exit Override.
Instance Attribute Summary collapse
-
#click_through_url ⇒ Google::Apis::DfareportingV5::ClickThroughUrl
Click-through URL Corresponds to the JSON property
clickThroughUrl. -
#enabled ⇒ Boolean
(also: #enabled?)
Whether to use the clickThroughUrl.
-
#exit_id ⇒ Fixnum
ID for the override to refer to a specific exit in the creative.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RichMediaExitOverride
constructor
A new instance of RichMediaExitOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RichMediaExitOverride
Returns a new instance of RichMediaExitOverride.
11655 11656 11657 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#click_through_url ⇒ Google::Apis::DfareportingV5::ClickThroughUrl
Click-through URL
Corresponds to the JSON property clickThroughUrl
11641 11642 11643 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11641 def click_through_url @click_through_url end |
#enabled ⇒ Boolean Also known as: enabled?
Whether to use the clickThroughUrl. If false, the creative-level exit will be
used.
Corresponds to the JSON property enabled
11647 11648 11649 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11647 def enabled @enabled end |
#exit_id ⇒ Fixnum
ID for the override to refer to a specific exit in the creative.
Corresponds to the JSON property exitId
11653 11654 11655 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11653 def exit_id @exit_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11660 11661 11662 11663 11664 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11660 def update!(**args) @click_through_url = args[:click_through_url] if args.key?(:click_through_url) @enabled = args[:enabled] if args.key?(:enabled) @exit_id = args[:exit_id] if args.key?(:exit_id) end |