Class: Google::Apis::DfareportingV5::SiteCompanionSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Companion Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SiteCompanionSetting

Returns a new instance of SiteCompanionSetting.



11826
11827
11828
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#companions_disabledBoolean Also known as: companions_disabled?

Whether companions are disabled for this site template. Corresponds to the JSON property companionsDisabled

Returns:

  • (Boolean)


11805
11806
11807
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11805

def companions_disabled
  @companions_disabled
end

#enabled_sizesArray<Google::Apis::DfareportingV5::Size>

Allowlist of companion sizes to be served via this site template. Set this list to null or empty to serve all companion sizes. Corresponds to the JSON property enabledSizes



11812
11813
11814
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11812

def enabled_sizes
  @enabled_sizes
end

#image_onlyBoolean Also known as: image_only?

Whether to serve only static images as companions. Corresponds to the JSON property imageOnly

Returns:

  • (Boolean)


11817
11818
11819
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11817

def image_only
  @image_only
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#siteCompanionSetting". Corresponds to the JSON property kind

Returns:

  • (String)


11824
11825
11826
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11824

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11831
11832
11833
11834
11835
11836
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11831

def update!(**args)
  @companions_disabled = args[:companions_disabled] if args.key?(:companions_disabled)
  @enabled_sizes = args[:enabled_sizes] if args.key?(:enabled_sizes)
  @image_only = args[:image_only] if args.key?(:image_only)
  @kind = args[:kind] if args.key?(:kind)
end