Class: Google::Apis::DfareportingV5::SiteSettings
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::SiteSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Site Settings
Instance Attribute Summary collapse
-
#active_view_opt_out ⇒ Boolean
(also: #active_view_opt_out?)
Whether active view creatives are disabled for this site.
-
#ad_blocking_opt_out ⇒ Boolean
(also: #ad_blocking_opt_out?)
Whether this site opts out of ad blocking.
-
#disable_new_cookie ⇒ Boolean
(also: #disable_new_cookie?)
Whether new cookies are disabled for this site.
-
#tag_setting ⇒ Google::Apis::DfareportingV5::TagSetting
Tag Settings Corresponds to the JSON property
tagSetting. -
#video_active_view_opt_out_template ⇒ Boolean
(also: #video_active_view_opt_out_template?)
Whether Verification and ActiveView for in-stream video creatives are disabled by default for new placements created under this site.
-
#vpaid_adapter_choice_template ⇒ String
Default VPAID adapter setting for new placements created under this site.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SiteSettings
constructor
A new instance of SiteSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SiteSettings
Returns a new instance of SiteSettings.
11951 11952 11953 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_view_opt_out ⇒ Boolean Also known as: active_view_opt_out?
Whether active view creatives are disabled for this site.
Corresponds to the JSON property activeViewOptOut
11907 11908 11909 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11907 def active_view_opt_out @active_view_opt_out end |
#ad_blocking_opt_out ⇒ Boolean Also known as: ad_blocking_opt_out?
Whether this site opts out of ad blocking. When true, ad blocking is disabled
for all placements under the site, regardless of the individual placement
settings. When false, the campaign and placement settings take effect.
Corresponds to the JSON property adBlockingOptOut
11915 11916 11917 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11915 def ad_blocking_opt_out @ad_blocking_opt_out end |
#disable_new_cookie ⇒ Boolean Also known as:
Whether new cookies are disabled for this site.
Corresponds to the JSON property disableNewCookie
11921 11922 11923 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11921 def @disable_new_cookie end |
#tag_setting ⇒ Google::Apis::DfareportingV5::TagSetting
Tag Settings
Corresponds to the JSON property tagSetting
11927 11928 11929 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11927 def tag_setting @tag_setting end |
#video_active_view_opt_out_template ⇒ Boolean Also known as: video_active_view_opt_out_template?
Whether Verification and ActiveView for in-stream video creatives are disabled
by default for new placements created under this site. This value will be used
to populate the placement.videoActiveViewOptOut field, when no value is
specified for the new placement.
Corresponds to the JSON property videoActiveViewOptOutTemplate
11935 11936 11937 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11935 def video_active_view_opt_out_template @video_active_view_opt_out_template end |
#vpaid_adapter_choice_template ⇒ String
Default VPAID adapter setting for new placements created under this site. This
value will be used to populate the placements.vpaidAdapterChoice field, when
no value is specified for the new placement. Controls which VPAID format the
measurement adapter will use for in-stream video creatives assigned to the
placement. The publisher's specifications will typically determine this
setting. For VPAID creatives, the adapter format will match the VPAID format (
HTML5 VPAID creatives use the HTML5 adapter). Note: Flash is no longer
supported. This field now defaults to HTML5 when the following values are
provided: FLASH, BOTH.
Corresponds to the JSON property vpaidAdapterChoiceTemplate
11949 11950 11951 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11949 def vpaid_adapter_choice_template @vpaid_adapter_choice_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11956 11957 11958 11959 11960 11961 11962 11963 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11956 def update!(**args) @active_view_opt_out = args[:active_view_opt_out] if args.key?(:active_view_opt_out) @ad_blocking_opt_out = args[:ad_blocking_opt_out] if args.key?(:ad_blocking_opt_out) @disable_new_cookie = args[:disable_new_cookie] if args.key?(:disable_new_cookie) @tag_setting = args[:tag_setting] if args.key?(:tag_setting) @video_active_view_opt_out_template = args[:video_active_view_opt_out_template] if args.key?(:video_active_view_opt_out_template) @vpaid_adapter_choice_template = args[:vpaid_adapter_choice_template] if args.key?(:vpaid_adapter_choice_template) end |