Class: Google::Apis::DfareportingV5::SiteSkippableSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Skippable Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SiteSkippableSetting

Returns a new instance of SiteSkippableSetting.



11993
11994
11995
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#siteSkippableSetting". Corresponds to the JSON property kind

Returns:

  • (String)


11974
11975
11976
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11974

def kind
  @kind
end

#progress_offsetGoogle::Apis::DfareportingV5::VideoOffset

Video Offset Corresponds to the JSON property progressOffset



11979
11980
11981
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11979

def progress_offset
  @progress_offset
end

#skip_offsetGoogle::Apis::DfareportingV5::VideoOffset

Video Offset Corresponds to the JSON property skipOffset



11984
11985
11986
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11984

def skip_offset
  @skip_offset
end

#skippableBoolean Also known as: skippable?

Whether the user can skip creatives served to this site. This will act as default for new placements created under this site. Corresponds to the JSON property skippable

Returns:

  • (Boolean)


11990
11991
11992
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11990

def skippable
  @skippable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11998
11999
12000
12001
12002
12003
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 11998

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @progress_offset = args[:progress_offset] if args.key?(:progress_offset)
  @skip_offset = args[:skip_offset] if args.key?(:skip_offset)
  @skippable = args[:skippable] if args.key?(:skippable)
end