Class: Google::Apis::DfareportingV5::StudioCreative

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains studio creative information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StudioCreative

Returns a new instance of StudioCreative.



12358
12359
12360
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_idsArray<Fixnum>

List of assets associated with this studio creative. It is a required field on insertion. Corresponds to the JSON property assetIds

Returns:

  • (Array<Fixnum>)


12290
12291
12292
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12290

def asset_ids
  @asset_ids
end

#backup_image_asset_idFixnum

Backup image asset ID of this studio creative. It is a required field on insertion. Corresponds to the JSON property backupImageAssetId

Returns:

  • (Fixnum)


12296
12297
12298
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12296

def backup_image_asset_id
  @backup_image_asset_id
end

#created_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createdInfo



12301
12302
12303
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12301

def created_info
  @created_info
end

#dimensionGoogle::Apis::DfareportingV5::StudioCreativeDimension

Dimension information for a studio creative. Corresponds to the JSON property dimension



12306
12307
12308
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12306

def dimension
  @dimension
end

#dynamic_profile_idFixnum

Dynamic profile ID of this studio creative. Corresponds to the JSON property dynamicProfileId

Returns:

  • (Fixnum)


12311
12312
12313
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12311

def dynamic_profile_id
  @dynamic_profile_id
end

#formatString

Format of this studio creative. This is a required field on insertion. Corresponds to the JSON property format

Returns:

  • (String)


12316
12317
12318
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12316

def format
  @format
end

#idFixnum

Output only. Unique ID of this studio creative. This is a read-only, auto- generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12322
12323
12324
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12322

def id
  @id
end

#last_modified_infoGoogle::Apis::DfareportingV5::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



12327
12328
12329
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12327

def last_modified_info
  @last_modified_info
end

#nameString

Identifier. Name of this studio creative. This is a required field on insertion. Corresponds to the JSON property name

Returns:

  • (String)


12333
12334
12335
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12333

def name
  @name
end

#statusString

Output only. Status of this studio creative. It is a read-only field. Corresponds to the JSON property status

Returns:

  • (String)


12338
12339
12340
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12338

def status
  @status
end

#studio_account_idFixnum

Studio account ID of this creative. This field, if left unset, will be auto- populated. Corresponds to the JSON property studioAccountId

Returns:

  • (Fixnum)


12344
12345
12346
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12344

def 
  @studio_account_id
end

#studio_advertiser_idFixnum

Studio advertiser ID of this studio creative. This is a required field on insertion. Corresponds to the JSON property studioAdvertiserId

Returns:

  • (Fixnum)


12350
12351
12352
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12350

def studio_advertiser_id
  @studio_advertiser_id
end

#studio_campaign_idFixnum

Studio campaign ID of this studio creative. This is a required field on insertion. Corresponds to the JSON property studioCampaignId

Returns:

  • (Fixnum)


12356
12357
12358
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12356

def studio_campaign_id
  @studio_campaign_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12363

def update!(**args)
  @asset_ids = args[:asset_ids] if args.key?(:asset_ids)
  @backup_image_asset_id = args[:backup_image_asset_id] if args.key?(:backup_image_asset_id)
  @created_info = args[:created_info] if args.key?(:created_info)
  @dimension = args[:dimension] if args.key?(:dimension)
  @dynamic_profile_id = args[:dynamic_profile_id] if args.key?(:dynamic_profile_id)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @studio_account_id = args[:studio_account_id] if args.key?(:studio_account_id)
  @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id)
  @studio_campaign_id = args[:studio_campaign_id] if args.key?(:studio_campaign_id)
end