Class: Google::Apis::DfareportingV5::StudioCreativeAsset
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::StudioCreativeAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains studio creative asset information.
Instance Attribute Summary collapse
-
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#filename ⇒ String
The filename of the studio creative asset.
-
#filesize ⇒ Fixnum
The filesize of the studio creative asset.
-
#id ⇒ Fixnum
Output only.
-
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
-
#studio_account_id ⇒ Fixnum
Studio account ID of this studio creative asset.
-
#studio_advertiser_id ⇒ Fixnum
Studio advertiser ID of this studio creative asset.
-
#studio_creative_id ⇒ Fixnum
Studio creative ID of this studio creative asset.
-
#type ⇒ String
The type of the studio creative asset.
-
#video_processing_data ⇒ Google::Apis::DfareportingV5::VideoProcessingData
Contains processing data for a video asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StudioCreativeAsset
constructor
A new instance of StudioCreativeAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StudioCreativeAsset
Returns a new instance of StudioCreativeAsset.
12441 12442 12443 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property createInfo
12389 12390 12391 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12389 def create_info @create_info end |
#filename ⇒ String
The filename of the studio creative asset. It is default to the original
filename of the asset.
Corresponds to the JSON property filename
12395 12396 12397 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12395 def filename @filename end |
#filesize ⇒ Fixnum
The filesize of the studio creative asset. This is a read-only field.
Corresponds to the JSON property filesize
12400 12401 12402 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12400 def filesize @filesize end |
#id ⇒ Fixnum
Output only. Unique ID of this studio creative asset. This is a read-only,
auto-generated field.
Corresponds to the JSON property id
12406 12407 12408 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12406 def id @id end |
#last_modified_info ⇒ Google::Apis::DfareportingV5::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property lastModifiedInfo
12411 12412 12413 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12411 def last_modified_info @last_modified_info end |
#studio_account_id ⇒ Fixnum
Studio account ID of this studio creative asset. This field, if left unset,
will be auto-populated..
Corresponds to the JSON property studioAccountId
12417 12418 12419 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12417 def studio_account_id @studio_account_id end |
#studio_advertiser_id ⇒ Fixnum
Studio advertiser ID of this studio creative asset. This is a required field
on insertion.
Corresponds to the JSON property studioAdvertiserId
12423 12424 12425 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12423 def studio_advertiser_id @studio_advertiser_id end |
#studio_creative_id ⇒ Fixnum
Studio creative ID of this studio creative asset. The asset will be associated
to the creative if creative id is set.
Corresponds to the JSON property studioCreativeId
12429 12430 12431 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12429 def studio_creative_id @studio_creative_id end |
#type ⇒ String
The type of the studio creative asset. It is a auto-generated, read-only field.
Corresponds to the JSON property type
12434 12435 12436 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12434 def type @type end |
#video_processing_data ⇒ Google::Apis::DfareportingV5::VideoProcessingData
Contains processing data for a video asset.
Corresponds to the JSON property videoProcessingData
12439 12440 12441 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12439 def video_processing_data @video_processing_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12446 12447 12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12446 def update!(**args) @create_info = args[:create_info] if args.key?(:create_info) @filename = args[:filename] if args.key?(:filename) @filesize = args[:filesize] if args.key?(:filesize) @id = args[:id] if args.key?(:id) @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info) @studio_account_id = args[:studio_account_id] if args.key?(:studio_account_id) @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id) @studio_creative_id = args[:studio_creative_id] if args.key?(:studio_creative_id) @type = args[:type] if args.key?(:type) @video_processing_data = args[:video_processing_data] if args.key?(:video_processing_data) end |