Class: Google::Apis::DfareportingV5::Subaccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a Campaign Manager subaccount.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subaccount

Returns a new instance of Subaccount.



12536
12537
12538
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

ID of the account that contains this subaccount. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


12512
12513
12514
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12512

def 
  @account_id
end

#available_permission_idsArray<Fixnum>

IDs of the available user role permissions for this subaccount. Corresponds to the JSON property availablePermissionIds

Returns:

  • (Array<Fixnum>)


12517
12518
12519
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12517

def available_permission_ids
  @available_permission_ids
end

#idFixnum

ID of this subaccount. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12522
12523
12524
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12522

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#subaccount". Corresponds to the JSON property kind

Returns:

  • (String)


12528
12529
12530
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12528

def kind
  @kind
end

#nameString

Name of this subaccount. This is a required field. Must be less than 128 characters long and be unique among subaccounts of the same account. Corresponds to the JSON property name

Returns:

  • (String)


12534
12535
12536
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12534

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12541
12542
12543
12544
12545
12546
12547
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12541

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @available_permission_ids = args[:available_permission_ids] if args.key?(:available_permission_ids)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
end