Class: Google::Apis::DfareportingV5::TargetableRemarketingList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a targetable remarketing list. Remarketing enables you to create lists of users who have performed specific actions on a site, then target ads to members of those lists. This resource is a read-only view of a remarketing list to be used to facilitate targeting ads to specific lists. Remarketing lists that are owned by your advertisers and those that are shared to your advertisers or account are accessible via this resource. To manage remarketing lists that are owned by your advertisers, use the RemarketingLists resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetableRemarketingList

Returns a new instance of TargetableRemarketingList.



12812
12813
12814
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this remarketing list. This is a read-only, auto-generated field that is only returned in GET requests. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


12749
12750
12751
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12749

def 
  @account_id
end

#activeBoolean Also known as: active?

Whether this targetable remarketing list is active. Corresponds to the JSON property active

Returns:

  • (Boolean)


12754
12755
12756
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12754

def active
  @active
end

#advertiser_idFixnum

Dimension value for the advertiser ID that owns this targetable remarketing list. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


12761
12762
12763
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12761

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



12766
12767
12768
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12766

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#descriptionString

Targetable remarketing list description. Corresponds to the JSON property description

Returns:

  • (String)


12771
12772
12773
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12771

def description
  @description
end

#idFixnum

Targetable remarketing list ID. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12776
12777
12778
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12776

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#targetableRemarketingList". Corresponds to the JSON property kind

Returns:

  • (String)


12782
12783
12784
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12782

def kind
  @kind
end

#life_spanFixnum

Number of days that a user should remain in the targetable remarketing list without an impression. Corresponds to the JSON property lifeSpan

Returns:

  • (Fixnum)


12788
12789
12790
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12788

def life_span
  @life_span
end

#list_sizeFixnum

Number of users currently in the list. This is a read-only field. Corresponds to the JSON property listSize

Returns:

  • (Fixnum)


12793
12794
12795
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12793

def list_size
  @list_size
end

#list_sourceString

Product from which this targetable remarketing list was originated. Corresponds to the JSON property listSource

Returns:

  • (String)


12798
12799
12800
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12798

def list_source
  @list_source
end

#nameString

Name of the targetable remarketing list. Is no greater than 128 characters long. Corresponds to the JSON property name

Returns:

  • (String)


12804
12805
12806
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12804

def name
  @name
end

#subaccount_idFixnum

Subaccount ID of this remarketing list. This is a read-only, auto-generated field that is only returned in GET requests. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


12810
12811
12812
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12810

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12817
12818
12819
12820
12821
12822
12823
12824
12825
12826
12827
12828
12829
12830
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12817

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @active = args[:active] if args.key?(:active)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @life_span = args[:life_span] if args.key?(:life_span)
  @list_size = args[:list_size] if args.key?(:list_size)
  @list_source = args[:list_source] if args.key?(:list_source)
  @name = args[:name] if args.key?(:name)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end