Class: Google::Apis::DfareportingV5::TargetingTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

Contains properties of a targeting template. A targeting template encapsulates targeting information which can be reused across multiple ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetingTemplate

Returns a new instance of TargetingTemplate.



12945
12946
12947
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12945

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this targeting template. This field, if left unset, will be auto- generated on insert and is read-only after insert. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


12874
12875
12876
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12874

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this targeting template. This is a required field on insert and is read-only after insert. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


12880
12881
12882
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12880

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV5::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



12885
12886
12887
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12885

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#contextual_keyword_targetingGoogle::Apis::DfareportingV5::ContextualKeywordTargeting

Contextual Keyword Targeting. Corresponds to the JSON property contextualKeywordTargeting



12890
12891
12892
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12890

def contextual_keyword_targeting
  @contextual_keyword_targeting
end

#day_part_targetingGoogle::Apis::DfareportingV5::DayPartTargeting

Day Part Targeting. Corresponds to the JSON property dayPartTargeting



12895
12896
12897
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12895

def day_part_targeting
  @day_part_targeting
end

#geo_targetingGoogle::Apis::DfareportingV5::GeoTargeting

Geographical Targeting. Corresponds to the JSON property geoTargeting



12900
12901
12902
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12900

def geo_targeting
  @geo_targeting
end

#idFixnum

ID of this targeting template. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12905
12906
12907
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12905

def id
  @id
end

#key_value_targeting_expressionGoogle::Apis::DfareportingV5::KeyValueTargetingExpression

Key Value Targeting Expression. Corresponds to the JSON property keyValueTargetingExpression



12910
12911
12912
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12910

def key_value_targeting_expression
  @key_value_targeting_expression
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#targetingTemplate". Corresponds to the JSON property kind

Returns:

  • (String)


12916
12917
12918
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12916

def kind
  @kind
end

#language_targetingGoogle::Apis::DfareportingV5::LanguageTargeting

Language Targeting. Corresponds to the JSON property languageTargeting



12921
12922
12923
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12921

def language_targeting
  @language_targeting
end

#list_targeting_expressionGoogle::Apis::DfareportingV5::ListTargetingExpression

Remarketing List Targeting Expression. Corresponds to the JSON property listTargetingExpression



12926
12927
12928
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12926

def list_targeting_expression
  @list_targeting_expression
end

#nameString

Name of this targeting template. This field is required. It must be less than 256 characters long and unique within an advertiser. Corresponds to the JSON property name

Returns:

  • (String)


12932
12933
12934
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12932

def name
  @name
end

#subaccount_idFixnum

Subaccount ID of this targeting template. This field, if left unset, will be auto-generated on insert and is read-only after insert. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


12938
12939
12940
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12938

def subaccount_id
  @subaccount_id
end

#technology_targetingGoogle::Apis::DfareportingV5::TechnologyTargeting

Technology Targeting. Corresponds to the JSON property technologyTargeting



12943
12944
12945
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12943

def technology_targeting
  @technology_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12950
12951
12952
12953
12954
12955
12956
12957
12958
12959
12960
12961
12962
12963
12964
12965
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 12950

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @contextual_keyword_targeting = args[:contextual_keyword_targeting] if args.key?(:contextual_keyword_targeting)
  @day_part_targeting = args[:day_part_targeting] if args.key?(:day_part_targeting)
  @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting)
  @id = args[:id] if args.key?(:id)
  @key_value_targeting_expression = args[:key_value_targeting_expression] if args.key?(:key_value_targeting_expression)
  @kind = args[:kind] if args.key?(:kind)
  @language_targeting = args[:language_targeting] if args.key?(:language_targeting)
  @list_targeting_expression = args[:list_targeting_expression] if args.key?(:list_targeting_expression)
  @name = args[:name] if args.key?(:name)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @technology_targeting = args[:technology_targeting] if args.key?(:technology_targeting)
end