Class: Google::Apis::DfareportingV5::TranscodeSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::TranscodeSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Transcode Settings
Instance Attribute Summary collapse
-
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this placement.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TranscodeSetting
constructor
A new instance of TranscodeSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TranscodeSetting
Returns a new instance of TranscodeSetting.
13134 13135 13136 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this placement. Set this list to
null or empty to serve all video formats.
Corresponds to the JSON property enabledVideoFormats
13126 13127 13128 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13126 def enabled_video_formats @enabled_video_formats end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#transcodeSetting".
Corresponds to the JSON property kind
13132 13133 13134 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13132 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13139 13140 13141 13142 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13139 def update!(**args) @enabled_video_formats = args[:enabled_video_formats] if args.key?(:enabled_video_formats) @kind = args[:kind] if args.key?(:kind) end |