Class: Google::Apis::DfareportingV5::TvCampaignTimepoint
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::TvCampaignTimepoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
A single data point for TvCampaignDetail, which holds information about the TV campaign for a specific start date and date window.
Instance Attribute Summary collapse
-
#date_window ⇒ String
The date window of the timepoint.
-
#spend ⇒ Float
The spend within the time range of the timepoint.
-
#start_date ⇒ String
The start date of the timepoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TvCampaignTimepoint
constructor
A new instance of TvCampaignTimepoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TvCampaignTimepoint
Returns a new instance of TvCampaignTimepoint.
13294 13295 13296 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13294 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date_window ⇒ String
The date window of the timepoint.
Corresponds to the JSON property dateWindow
13282 13283 13284 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13282 def date_window @date_window end |
#spend ⇒ Float
The spend within the time range of the timepoint.
Corresponds to the JSON property spend
13287 13288 13289 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13287 def spend @spend end |
#start_date ⇒ String
The start date of the timepoint. A string in the format of "yyyy-MM-dd".
Corresponds to the JSON property startDate
13292 13293 13294 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13292 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13299 13300 13301 13302 13303 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13299 def update!(**args) @date_window = args[:date_window] if args.key?(:date_window) @spend = args[:spend] if args.key?(:spend) @start_date = args[:start_date] if args.key?(:start_date) end |