Class: Google::Apis::DfareportingV5::UserDefinedVariableConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb

Overview

User Defined Variable configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserDefinedVariableConfiguration

Returns a new instance of UserDefinedVariableConfiguration.



13355
13356
13357
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_typeString

Data type for the variable. This is a required field. Corresponds to the JSON property dataType

Returns:

  • (String)


13341
13342
13343
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13341

def data_type
  @data_type
end

#report_nameString

User-friendly name for the variable which will appear in reports. This is a required field, must be less than 64 characters long, and cannot contain the following characters: ""<>". Corresponds to the JSON property reportName

Returns:

  • (String)


13348
13349
13350
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13348

def report_name
  @report_name
end

#variable_typeString

Variable name in the tag. This is a required field. Corresponds to the JSON property variableType

Returns:

  • (String)


13353
13354
13355
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13353

def variable_type
  @variable_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13360
13361
13362
13363
13364
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13360

def update!(**args)
  @data_type = args[:data_type] if args.key?(:data_type)
  @report_name = args[:report_name] if args.key?(:report_name)
  @variable_type = args[:variable_type] if args.key?(:variable_type)
end