Class: Google::Apis::DfareportingV5::UserProfile
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::UserProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
A UserProfile resource lets you list all DFA user profiles that are associated with a Google user account. The profile_id needs to be specified in other API requests.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
The account ID to which this profile belongs.
-
#account_name ⇒ String
The account name this profile belongs to.
-
#etag ⇒ String
Etag of this resource.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#profile_id ⇒ Fixnum
The unique ID of the user profile.
-
#sub_account_id ⇒ Fixnum
The sub account ID this profile belongs to if applicable.
-
#sub_account_name ⇒ String
The sub account name this profile belongs to if applicable.
-
#user_name ⇒ String
The user name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserProfile
constructor
A new instance of UserProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserProfile
Returns a new instance of UserProfile.
13446 13447 13448 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
The account ID to which this profile belongs.
Corresponds to the JSON property accountId
13408 13409 13410 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13408 def account_id @account_id end |
#account_name ⇒ String
The account name this profile belongs to.
Corresponds to the JSON property accountName
13413 13414 13415 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13413 def account_name @account_name end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
13418 13419 13420 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13418 def etag @etag end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#userProfile".
Corresponds to the JSON property kind
13424 13425 13426 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13424 def kind @kind end |
#profile_id ⇒ Fixnum
The unique ID of the user profile.
Corresponds to the JSON property profileId
13429 13430 13431 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13429 def profile_id @profile_id end |
#sub_account_id ⇒ Fixnum
The sub account ID this profile belongs to if applicable.
Corresponds to the JSON property subAccountId
13434 13435 13436 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13434 def sub_account_id @sub_account_id end |
#sub_account_name ⇒ String
The sub account name this profile belongs to if applicable.
Corresponds to the JSON property subAccountName
13439 13440 13441 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13439 def sub_account_name @sub_account_name end |
#user_name ⇒ String
The user name.
Corresponds to the JSON property userName
13444 13445 13446 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13444 def user_name @user_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13451 13452 13453 13454 13455 13456 13457 13458 13459 13460 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13451 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @account_name = args[:account_name] if args.key?(:account_name) @etag = args[:etag] if args.key?(:etag) @kind = args[:kind] if args.key?(:kind) @profile_id = args[:profile_id] if args.key?(:profile_id) @sub_account_id = args[:sub_account_id] if args.key?(:sub_account_id) @sub_account_name = args[:sub_account_name] if args.key?(:sub_account_name) @user_name = args[:user_name] if args.key?(:user_name) end |