Class: Google::Apis::DfareportingV5::VideoFormat
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV5::VideoFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v5/classes.rb,
lib/google/apis/dfareporting_v5/representations.rb,
lib/google/apis/dfareporting_v5/representations.rb
Overview
Contains information about supported video formats.
Instance Attribute Summary collapse
-
#file_type ⇒ String
File type of the video format.
-
#id ⇒ Fixnum
ID of the video format.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#resolution ⇒ Google::Apis::DfareportingV5::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#target_bit_rate ⇒ Fixnum
The target bit rate of this video format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoFormat
constructor
A new instance of VideoFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoFormat
Returns a new instance of VideoFormat.
13756 13757 13758 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_type ⇒ String
File type of the video format.
Corresponds to the JSON property fileType
13733 13734 13735 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13733 def file_type @file_type end |
#id ⇒ Fixnum
ID of the video format.
Corresponds to the JSON property id
13738 13739 13740 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13738 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#videoFormat".
Corresponds to the JSON property kind
13744 13745 13746 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13744 def kind @kind end |
#resolution ⇒ Google::Apis::DfareportingV5::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property resolution
13749 13750 13751 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13749 def resolution @resolution end |
#target_bit_rate ⇒ Fixnum
The target bit rate of this video format.
Corresponds to the JSON property targetBitRate
13754 13755 13756 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13754 def target_bit_rate @target_bit_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13761 13762 13763 13764 13765 13766 13767 |
# File 'lib/google/apis/dfareporting_v5/classes.rb', line 13761 def update!(**args) @file_type = args[:file_type] if args.key?(:file_type) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @resolution = args[:resolution] if args.key?(:resolution) @target_bit_rate = args[:target_bit_rate] if args.key?(:target_bit_rate) end |